@@ -1,3 +1,5 @@
+/* $Id: acconfig.h,v 1.48 1996/11/02 17:01:37 bg Exp $ */
+
 /*  Define this if RETSIGTYPE == void  */
 #undef VOID_RETSIGTYPE
 
@@ -19,6 +21,9 @@
 /*  Define this if struct utmp have ut_id  */
 #undef HAVE_UT_ID
 
+/*  Define this if struct utmpx have ut_syslen  */
+#undef HAVE_UT_SYSLEN
+
 /*  Define this to be the directory where the dictionary for cracklib */
 /*  resides */
 #undef DICTPATH
@@ -26,6 +31,9 @@
 /* Define this if you want S/Key support in the login program */
 #undef SKEY
 
+/* Define this if you want to use SOCKS v5 */
+#undef SOCKS
+
 /* Define this to the path of the mail spool directory */
 #undef KRB4_MAILDIR
 
@@ -41,18 +49,30 @@
 /* define if the system is missing a prototype for crypt() */
 #undef NEED_CRYPT_PROTO
 
-/* define this if netdb.h includes declaration of h_errno */
-#undef HAVE_H_ERRNO
-
-/* define if your system doesn't declare h_errlist */
-#undef NEED_H_ERRLIST_PROTO
-
 /* define if /bin/ls takes -A */
 #undef HAVE_LS_A
 
 /* define if you have h_errlist but not hstrerror */
 #undef HAVE_H_ERRLIST
 
+/* define if your system doesn't declare h_errlist */
+#undef NEED_H_ERRLIST_DECLARATION
+
+/* define this if you need a declaration for h_errno */
+#undef NEED_H_ERRNO_DECLARATION
+
+/* define if you need a declaration for optarg */
+#undef NEED_OPTARG_DECLARATION
+
+/* define if you need a declaration for optind */
+#undef NEED_OPTIND_DECLARATION
+
+/* define if you need a declaration for opterr */
+#undef NEED_OPTERR_DECLARATION
+
+/* define if you need a declaration for optopt */
+#undef NEED_OPTOPT_DECLARATION
+
 @BOTTOM@
 
 #define RCSID(msg) \
@@ -188,10 +208,8 @@ static /**/const char *const rcsid[] = { (char *)rcsid, "@(#)" msg }
 #define SIGRETURN(x) return (RETSIGTYPE)(x)
 #endif
 
-/* utmpx is defined in some silly standard */
-#if defined(HAVE_UTMPX_H) && !defined(__osf__) && !defined(_AIX)
-#define HAVE_UTMPX
-#endif
+/* Define this if your compiler supports '#pragma weak' */
+#undef HAVE_PRAGMA_WEAK
 
 /*
  * AIX braindamage!
@@ -222,8 +240,20 @@ static /**/const char *const rcsid[] = { (char *)rcsid, "@(#)" msg }
 #endif
 #endif
 
-
 /* IRIX 4 braindamage */
 #if IRIX == 4 && !defined(__STDC__)
 #define __STDC__ 0
 #endif
+
+/* Some systems are utmp compatible in the utmpx API */
+#if defined(HAVE_UTMPX_H)
+#if (SunOS == 5) || defined(IRIX)
+#define UTMPX_DOES_UTMP_LOGGING
+#endif
+#endif
+
+/* Remove this when telnetd/sys_term.c has been updated */
+/* utmpx is defined in some silly standard */
+#if defined(HAVE_UTMPX_H) && !defined(__osf__) && !defined(_AIX)
+#define HAVE_UTMPX
+#endif
