@@ -9,7 +9,7 @@
 
 #include "adm_locl.h"
 
-RCSID("$Id: ext_srvtab.c,v 1.9 1996/05/29 23:23:09 assar Exp $");
+RCSID("$Id: ext_srvtab.c,v 1.11 1996/11/17 20:22:57 assar Exp $");
 
 static des_cblock master_key;
 static des_cblock session_key;
@@ -59,7 +59,7 @@ main(int argc, char **argv)
     Principal princs[40];
     int more; 
     int prompt = KDB_GET_PROMPT;
-    register int n, i;
+    int n, i;
     
     memset(realm, 0, sizeof(realm));
     
@@ -111,7 +111,7 @@ main(int argc, char **argv)
 	    fprintf(stderr, "%s: couldn't get local realm\n", progname);
 	    exit(1);
 	}
-    (void) umask(077);
+    umask(077);
 
     for (arg = 1; arg < argc; arg++) {
 	if (argv[arg][0] == '-')
