@@ -15,7 +15,7 @@
 
 #include "adm_locl.h"
 
-RCSID("$Id: kdb_edit.c,v 1.18 1996/06/27 03:55:27 assar Exp $");
+RCSID("$Id: kdb_edit.c,v 1.20 1996/11/17 20:22:57 assar Exp $");
 
 #ifdef DEBUG
 extern  kerb_debug;
@@ -113,7 +113,7 @@ change_principal(void)
 	principal_data[0].key_version = 0; /* bumped up later */
     }
     tp = k_localtime(&principal_data[0].exp_date);
-    (void) sprintf(principal_data[0].exp_date_txt, "%4d-%02d-%02d",
+    sprintf(principal_data[0].exp_date_txt, "%4d-%02d-%02d",
 		   tp->tm_year > 1900 ? tp->tm_year : tp->tm_year + 1900,
 		   tp->tm_mon + 1, tp->tm_mday); /* January is 0, not 1 */
     for (i = 0; i < j; i++) {
@@ -378,7 +378,7 @@ main(int argc, char **argv)
     if (argc > 0) {
 	if (kerb_db_set_name(*argv) != 0) {
 	    fprintf(stderr, "Could not open altername database name\n");
-	    exit(1);
+	    return 1;
 	}
     }
 
@@ -386,13 +386,13 @@ main(int argc, char **argv)
 			    &master_key, master_key_schedule) != 0) {
       fprintf (stdout, "Couldn't read master key.\n");
       fflush (stdout);
-      exit (-1);
+      return 1;
     }
 
     if ((master_key_version = kdb_verify_master_key(&master_key,
 						    master_key_schedule,
 						    stdout)) < 0)
-      exit (-1);
+      return 1;
 
     /* Initialize non shared random sequence */
     des_init_random_number_generator(&master_key);
@@ -404,7 +404,7 @@ main(int argc, char **argv)
 	fprintf(stderr,
 	     "%s: Kerberos error on default value lookup, %ld found.\n",
 		progname, n);
-	exit(-1);
+	return 1;
     }
     fprintf(stdout, "Previous or default values are in [brackets] ,\n");
     fprintf(stdout, "enter return to leave the same, or new value.\n");
