@@ -10,7 +10,7 @@
 
 #include "adm_locl.h"
 
-RCSID("$Id: kdb_init.c,v 1.18 1996/07/02 09:48:30 bg Exp $");
+RCSID("$Id: kdb_init.c,v 1.20 1996/11/17 21:08:22 assar Exp $");
 
 enum ap_op {
     NULL_KEY,			/* setup null keys */
@@ -96,7 +96,7 @@ main(int argc, char **argv)
 
     if (argc > 3) {
 	fprintf(stderr, "Usage: %s [realm-name] [database-name]\n", argv[0]);
-	exit(1);
+	return 1;
     }
     if (argc == 3) {
 	database = argv[2];
@@ -108,7 +108,7 @@ main(int argc, char **argv)
     if ((code = kerb_db_create(database)) != 0) {
 	fprintf(stderr, "Couldn't create database %s: %s\n", database,
 		strerror(code));
-	exit(1);
+	return 1;
     }
     kerb_db_set_name(database);
 
@@ -120,7 +120,7 @@ main(int argc, char **argv)
 	fprintf(stderr, "Realm name [default  %s ]: ", realm);
 	if (fgets(realm, sizeof(realm), stdin) == NULL) {
 	    fprintf(stderr, "\nEOF reading realm\n");
-	    exit(1);
+	    return 1;
 	}
 	if ((cp = strchr(realm, '\n')))
 	    *cp = '\0';
@@ -131,7 +131,7 @@ main(int argc, char **argv)
     if (!k_isrealm(realm)) {
 	fprintf(stderr, "%s: Bad kerberos realm name \"%s\"\n",
 		progname, realm);
-	exit(1);
+	return 1;
     }
 #ifndef RANDOM_MKEY
     printf("You will be prompted for the database Master Password.\n");
@@ -145,13 +145,13 @@ main(int argc, char **argv)
     if (kdb_get_master_key (KDB_GET_TWICE, &master_key,
 			    master_key_schedule) != 0) {
       fprintf (stderr, "Couldn't read master key.\n");
-      exit (-1);
+      return 1;
     }
 
 #ifdef RANDOM_MKEY
     if(kdb_kstash(&master_key, MKEYFILE) < 0){
       perror("Error writing master key");
-      exit(1);
+      return 1;
     }
     fprintf(stderr, "Wrote master key to %s\n", MKEYFILE);
 #endif
@@ -162,16 +162,16 @@ main(int argc, char **argv)
     if (
 	add_principal(KERB_M_NAME, KERB_M_INST, MASTER_KEY) ||
 	add_principal(KERB_DEFAULT_NAME, KERB_DEFAULT_INST, NULL_KEY) ||
-	add_principal("krbtgt", realm, RANDOM_KEY) ||
-	add_principal("changepw", KRB_MASTER, RANDOM_KEY) 
+	add_principal(KRB_TICKET_GRANTING_TICKET, realm, RANDOM_KEY) ||
+	add_principal(PWSERV_NAME, KRB_MASTER, RANDOM_KEY) 
 	) {
 	fprintf(stderr, "\n%s: couldn't initialize database.\n",
 		progname);
-	exit(1);
+	return 1;
     }
 
     /* play it safe */
     memset(master_key, 0, sizeof (des_cblock));
     memset(master_key_schedule, 0, sizeof (des_key_schedule));
-    exit(0);
+    return 0;
 }
