@@ -10,7 +10,7 @@
 
 #include "adm_locl.h"
 
-RCSID("$Id: kstash.c,v 1.8 1996/05/29 23:23:15 assar Exp $");
+RCSID("$Id: kstash.c,v 1.9 1996/09/08 22:09:59 assar Exp $");
 
 /* change this later, but krblib_dbm needs it for now */
 char   *progname;
@@ -38,14 +38,13 @@ main(int argc, char **argv)
     if (kdb_get_master_key (KDB_GET_PROMPT, &master_key,
 			    master_key_schedule) != 0) {
 	fprintf (stderr, "%s: Couldn't read master key.\n", argv[0]);
-	fflush (stderr);
 	clear_secrets();
-	exit (-1);
+	return 1;
     }
 
     if (kdb_verify_master_key (&master_key, master_key_schedule, stderr) < 0) {
 	clear_secrets();
-	exit (-1);
+	return 1;
     }
 
     ret = kdb_kstash(&master_key, MKEYFILE);
