@@ -33,11 +33,10 @@
 
 #include "bsd_locl.h"
 
-RCSID("$Id: klogin.c,v 1.13 1996/08/24 20:31:14 assar Exp $");
+RCSID("$Id: klogin.c,v 1.18 1996/11/23 17:12:52 joda Exp $");
 
 #ifdef KERBEROS
 
-#define	INITIAL_TICKET	"krbtgt"
 #define	VERIFY_SERVICE	"rcmd"
 
 extern int notickets;
@@ -60,7 +59,6 @@ klogin(struct passwd *pw, char *instance, char *localhost, char *password)
 	struct hostent *hp;
 	u_int32_t faddr;
 	char realm[REALM_SZ], savehost[MaxHostNameLen];
-	char *krb_get_phost();
 	extern int noticketsdontcomplain;
 
 #ifdef KLOGIN_PARANOID
@@ -87,26 +85,18 @@ klogin(struct passwd *pw, char *instance, char *localhost, char *password)
 	 */
 
 	if (strcmp(instance, "root") != 0)
-		(void)sprintf(tkt_location, "%s%d_%d",
+		sprintf(tkt_location, "%s%d_%d",
 			      TKT_ROOT, (int)pw->pw_uid, (int)getpid());
 	else {
-		(void)sprintf(tkt_location, "%s_root_%d", TKT_ROOT,
+		sprintf(tkt_location, "%s_root_%d", TKT_ROOT,
 			      (int)pw->pw_uid);
 	}
 	krbtkfile_env = tkt_location;
-	(void)krb_set_tkt_string(tkt_location);
+	krb_set_tkt_string(tkt_location);
 
-	/*
-	 * Set real as well as effective ID to 0 for the moment,
-	 * to make the kerberos library do the right thing.
-	 */
-	if (setuid(0) < 0) {
-		warnx("setuid");
-		return (1);
-	}
-	dest_tkt();		/* Need to remove old file first */
 	kerror = krb_get_pw_in_tkt(pw->pw_name, instance,
-		    realm, INITIAL_TICKET, realm, DEFAULT_TKT_LIFE, password);
+				   realm, KRB_TICKET_GRANTING_TICKET, realm,
+				   DEFAULT_TKT_LIFE, password);
 
 	/*
 	 * If we got a TGT, get a local "rcmd" ticket and check it so as to
@@ -129,7 +119,7 @@ klogin(struct passwd *pw, char *instance, char *localhost, char *password)
 	if (chown(TKT_FILE, pw->pw_uid, pw->pw_gid) < 0)
 		syslog(LOG_ERR, "chown tkfile (%s): %m", TKT_FILE);
 
-	(void)strncpy(savehost, krb_get_phost(localhost), sizeof(savehost));
+	strncpy(savehost, krb_get_phost(localhost), sizeof(savehost));
 	savehost[sizeof(savehost)-1] = '\0';
 
 #ifdef KLOGIN_PARANOID
@@ -161,7 +151,7 @@ klogin(struct passwd *pw, char *instance, char *localhost, char *password)
 		return (1);
 	}
 
-	memcpy((void *)&faddr, (void *)hp->h_addr, sizeof(faddr));
+	memcpy(&faddr, hp->h_addr, sizeof(faddr));
 
 	kerror = krb_rd_req(&ticket, VERIFY_SERVICE, savehost, faddr,
 	    &authdata, "");
