@@ -39,33 +39,29 @@
 
 #include "bsd_locl.h"
 
-RCSID("$Id: login.c,v 1.76 1996/08/24 20:30:56 assar Exp $");
+RCSID("$Id: login.c,v 1.94 1996/11/19 22:48:21 assar Exp $");
 
-#ifdef	xSKEY			/* Don't bother to find this header file. */
-#include <skey.h>
-#endif
+#include <otp.h>
 
 #include "sysv_default.h"
 #ifdef SYSV_SHADOW
 #include "sysv_shadow.h"
 #endif
 
-void	 badlogin __P((char *));
-void	 checknologin __P((void));
-void	 dolastlog __P((int));
-void	 getloginname __P((int));
-void	 motd __P((void));
-int	 rootterm __P((char *));
-void	 sigint __P((int));
-char	*stypeof __P((char *));
-void	 timedout __P((int));
-static int	 doremotelogin __P((char *));
-void     login_fbtab __P((char *, uid_t, gid_t));
+static	void	 badlogin (char *);
+static	void	 checknologin (void);
+static	void	 dolastlog (int);
+static	void	 getloginname (int);
+static	int	 rootterm (char *);
+static	char	*stypeof (char *);
+static	RETSIGTYPE	 timedout (int);
+static	int	 doremotelogin (char *);
+void	login_fbtab (char *, uid_t, gid_t);
 #ifdef KERBEROS
-int	 klogin __P((struct passwd *, char *, char *, char *));
+int	klogin (struct passwd *, char *, char *, char *);
 #endif
 
-extern void login __P((struct utmp *));
+extern void login (struct utmp *);
 
 #define	TTYGRPNAME	"tty"		/* name of group to own ttys */
 
@@ -73,7 +69,7 @@ extern void login __P((struct utmp *));
  * This bounds the time given to login.  Not a define so it can
  * be patched on machines where it's too small.
  */
-u_int	login_timeout = 300;
+static	u_int	login_timeout = 300;
 
 #ifdef KERBEROS
 int	notickets = 1;
@@ -83,18 +79,17 @@ char	*krbtkfile_env;
 int	authok;
 #endif
 
-char    *ttyprompt;
-
-char *__progname;
-struct	passwd *pwd;
-int	failures;
-char	term[64], *envinit[1], *hostname, *username, *tty;
-
-static  char rusername[100], lusername[100];
 #ifdef HAVE_SHADOW_H
-static  struct spwd *spwd;
+static  struct spwd *spwd = NULL;
 #endif
 
+static	char    *ttyprompt;
+
+static	struct	passwd *pwd;
+static	int	failures;
+static	char	term[64], *hostname, *username, *tty;
+
+static  char rusername[100], lusername[100];
 static int
 change_passwd(struct passwd  *who)
 {
@@ -116,28 +111,76 @@ change_passwd(struct passwd  *who)
 	}
 }
 
+#ifndef NO_MOTD /* message of the day stuff */
+
+jmp_buf motdinterrupt;
+
+static RETSIGTYPE
+sigint(int signo)
+{
+	longjmp(motdinterrupt, 1);
+}
+
+static void
+motd(void)
+{
+	int fd, nchars;
+	RETSIGTYPE (*oldint)();
+	char tbuf[8192];
+
+	if ((fd = open(_PATH_MOTDFILE, O_RDONLY, 0)) < 0)
+		return;
+	oldint = signal(SIGINT, sigint);
+	if (setjmp(motdinterrupt) == 0)
+		while ((nchars = read(fd, tbuf, sizeof(tbuf))) > 0)
+			write(fileno(stdout), tbuf, nchars);
+	signal(SIGINT, oldint);
+	close(fd);
+}
+
+#endif /* !NO_MOTD */
+
+#define AUTH_NONE 0
+#define AUTH_OTP  1
+
+/*
+ * getpwnam and try to detect the worst form of NIS attack.
+ */
+
+static struct passwd *
+paranoid_getpwnam (char *user)
+{
+	struct passwd *p;
+
+	p = k_getpwnam (user);
+	if (p == NULL)
+		return p;
+	if (p->pw_uid == 0 && strcmp (username, "root") != 0) {
+		syslog (LOG_ALERT,
+			"NIS attack, user %s has uid 0", username);
+		return NULL;
+	}
+	return p;
+}
+
 int
-main(argc, argv)
-	int argc;
-	char *argv[];
+main(int argc, char **argv)
 {
 	struct group *gr;
-	int ask, ch, cnt, fflag, hflag, pflag, quietlog, rootlogin, rval;
+	int ask, ch, cnt, fflag, hflag, pflag, quietlog, nomailcheck;
+	int rootlogin, rval;
 	int rflag;
 	int changepass = 0;
-	uid_t uid;
+	uid_t uid, pwd_uid;
 	char *domain, *p, passwd[128], ep[20], *salt, *ttyn;
 	char tbuf[MaxPathLen + 2], tname[sizeof(_PATH_TTY) + 10];
 	char localhost[MaxHostNameLen];
 	char full_hostname[MaxHostNameLen];
-#ifdef	SKEY
-	int permit_passwd = 0;
-#endif
+	int auth_level = AUTH_NONE;
+	OtpContext otp_ctx;
 	int mask = 022;		/* Default umask (set below) */
 	int maxtrys = 5;	/* Default number of allowed failed logins */
 
-	__progname = argv[0];
-
 	openlog("login", LOG_ODELAY, LOG_AUTH);
 
         /* Read defaults file and set the login timeout period. */
@@ -149,11 +192,11 @@ main(argc, argv)
         else
                 umask(mask);
 
-	(void)signal(SIGALRM, timedout);
-	(void)alarm(login_timeout);
-	(void)signal(SIGQUIT, SIG_IGN);
-	(void)signal(SIGINT, SIG_IGN);
-	(void)setpriority(PRIO_PROCESS, 0, 0);
+	signal(SIGALRM, timedout);
+	alarm(login_timeout);
+	signal(SIGQUIT, SIG_IGN);
+	signal(SIGINT, SIG_IGN);
+	setpriority(PRIO_PROCESS, 0, 0);
 
 	/*
 	 * -p is used by getty to tell login not to destroy the environment
@@ -162,6 +205,7 @@ main(argc, argv)
 	 *    host to login so that it may be placed in utmp and wtmp
 	 * -r is used by old-style rlogind to execute the autologin protocol
 	 */
+
 	*full_hostname = '\0';
 	domain = NULL;
 	if (k_gethostname(localhost, sizeof(localhost)) < 0)
@@ -171,10 +215,18 @@ main(argc, argv)
 
 	fflag = hflag = pflag = rflag = 0;
 	uid = getuid();
-	while ((ch = getopt(argc, argv, "d:fh:pr:")) != EOF)
+	while ((ch = getopt(argc, argv, "a:d:fh:pr:")) != EOF)
 	        switch (ch) {
+		case 'a':
+			if (strcmp (optarg, "none") == 0)
+				auth_level = AUTH_NONE;
+			else if (strcmp (optarg, "otp") == 0)
+				auth_level = AUTH_OTP;
+			else
+				warnx ("bad value for -a: %s", optarg);
+			break;
 		case 'd':
-                                break;
+			break;
 		case 'f':
 			fflag = 1;
 			break;
@@ -222,8 +274,9 @@ main(argc, argv)
 		default:
 			if (!uid)
 				syslog(LOG_ERR, "invalid flag %c", ch);
-			(void)fprintf(stderr,
-			    "usage: login [-fp] [-h hostname | -r hostname] [username]\n");
+			fprintf(stderr,
+				"usage: login [-fp] [-a otp]"
+				"[-h hostname | -r hostname] [username]\n");
 			exit(1);
 		}
 	argc -= optind;
@@ -232,6 +285,7 @@ main(argc, argv)
 	if (geteuid() != 0) {
 	        fprintf(stderr, "login: only root may use login, use su\n");
 	        /* Or install login setuid root, which is not necessary */
+		sleep(10);
 		exit(1);
 	}
         /*
@@ -266,7 +320,7 @@ main(argc, argv)
 	stty_default();
 
 	for (cnt = getdtablesize(); cnt > 2; cnt--)
-		(void)close(cnt);
+		close(cnt);
 
         /*
          * Determine the tty name. BSD takes the basename, SYSV4 takes
@@ -275,7 +329,7 @@ main(argc, argv)
          */
         ttyn = ttyname(STDIN_FILENO);
         if (ttyn == NULL || *ttyn == '\0') {
-	        (void)sprintf(tname, "%s??", _PATH_TTY);
+	        sprintf(tname, "%s??", _PATH_TTY);
 	        ttyn = tname;
 	}
         if ((tty = strchr(ttyn + 1, '/')))
@@ -284,19 +338,20 @@ main(argc, argv)
 	        tty = ttyn;
 
 	for (cnt = 0;; ask = 1) {
-	        char prompt[128];
+	        char prompt[128], ss[256];
 		if (ask) {
 			fflag = 0;
 			getloginname(1);
 		}
 		rootlogin = 0;
+		rval = 1;
 #ifdef	KERBEROS
 		if ((instance = strchr(username, '.')) != NULL) {
-			if (strncmp(instance, ".root", 5) == 0)
-				rootlogin = 1;
-			*instance++ = '\0';
+		    if (strcmp(instance, ".root") == 0)
+			rootlogin = 1;
+		    *instance++ = '\0';
 		} else
-			instance = "";
+		    instance = "";
 #endif
 		if (strlen(username) > UT_NAMESIZE)
 			username[UT_NAMESIZE] = '\0';
@@ -311,19 +366,9 @@ main(argc, argv)
 				badlogin(tbuf);
 			failures = 0;
 		}
-		(void)strcpy(tbuf, username);
+		strcpy(tbuf, username);
 
-		if ((pwd = k_getpwnam(username)) != 0)
-			salt = pwd->pw_passwd;
-		else
-			salt = "xx";
-
-		if (pwd && pwd->pw_uid == 0 && strcmp("root", username) != 0)
-		  {
-		    pwd = 0;
-		    syslog(LOG_ALERT,
-			   "NIS attack, user %s has uid 0", username);
-		  }
+		pwd = paranoid_getpwnam (username);
 
 		/*
 		 * if we have a valid account name, and it doesn't have a
@@ -347,59 +392,59 @@ main(argc, argv)
 
 		fflag = 0;
 
-		(void)setpriority(PRIO_PROCESS, 0, -4);
+		setpriority(PRIO_PROCESS, 0, -4);
 
-		sprintf(prompt, "%s's Password: ", username);
-#ifdef	SKEY
-		permit_passwd = skeyaccess(pwd, tty,
-					   hostname ? full_hostname : NULL,
-					   NULL);
-		p = (char *) skey_getpass(prompt, pwd, permit_passwd);
-		strncpy(ep,
-			(char *)skey_crypt(p, salt, pwd, permit_passwd),
-			sizeof(ep));
-		ep[sizeof(ep) - 1] = 0;
-#else
-		des_read_pw_string (passwd, sizeof(passwd) - 1, prompt, 0);
-		passwd[sizeof(passwd) - 1] = '\0';
-		strncpy(ep, crypt(passwd, salt), sizeof(ep));
-		ep[sizeof(ep) - 1] = 0;
-#endif
-
-		if (pwd) {
-#ifdef KERBEROS
-#ifdef SKEY
-			/*
-			 * Do not allow user to type in kerberos password
-			 * over the net (actually, this is ok for encrypted
-			 * links, but we have no way of determining if the
-			 * link is encrypted.
-			 */
-			if (!permit_passwd) {
-				rval = 1;		/* failed */
-			} else
-#endif
-			rval = klogin(pwd, instance, localhost, passwd);
-			memset(passwd, 0, sizeof(passwd));
-			/* getpwnam() is not reentrant and klogin used it! */
-			pwd = k_getpwnam(username);
-			if (pwd == NULL){
-			      fprintf(stderr, "unknown login %s\n", username);
-			      exit(1);
+		if (otp_challenge (&otp_ctx, username,
+				   ss, sizeof(ss)) == 0)
+			sprintf (prompt, "%s's %s Password: ",
+				 username, ss);
+		else {
+			if (auth_level == AUTH_NONE)
+				sprintf(prompt, "%s's Password: ",
+					username);
+			else {
+				rval = 1;
+				printf ("OTP: %s\n", otp_error(&otp_ctx));
+				continue;
 			}
-			if (rval != 0 && rootlogin && pwd->pw_uid != 0)
+		}
+
+		if (des_read_pw_string (passwd, sizeof(passwd) - 1, prompt, 0))
+			continue;
+		passwd[sizeof(passwd) - 1] = '\0';
+
+		/* Verify it somehow */
+
+		if (otp_verify_user (&otp_ctx, passwd) == 0)
+			rval = 0;
+		else if (pwd == NULL)
+			;
+		else if (auth_level == AUTH_NONE) {
+			uid_t pwd_uid;
+
+			pwd_uid = pwd->pw_uid;
+			rval = klogin(pwd, instance, localhost, passwd);
+			if (rval != 0 && rootlogin && pwd_uid != 0)
 				rootlogin = 0;
 			if (rval == 0)
 				authok = 1;
-			else if (rval == 1)
-				rval = strcmp(ep, pwd->pw_passwd);
-#else
-			rval = strcmp(ep, pwd->pw_passwd);
-#endif
-		}
-		memset(passwd, 0, sizeof(passwd));
+			else
+				rval = unix_verify_user (username, passwd);
+		} else {
+			char *s;
 
-		(void)setpriority(PRIO_PROCESS, 0, 0);
+			rval = 1;
+			if (s = otp_error(&otp_ctx))
+				printf ("OTP: %s\n", s);
+		}
+
+		memset (passwd, 0, sizeof(passwd));
+		setpriority (PRIO_PROCESS, 0, 0);
+
+		/*
+		 * Santa Claus, give me a portable and reentrant getpwnam.
+		 */
+		pwd = paranoid_getpwnam (username);
 
 	ttycheck:
 		/*
@@ -411,24 +456,24 @@ main(argc, argv)
 #endif
 		if (pwd && !rval && rootlogin && !rootterm(tty)
 		    && !rootterm(ttyn)) {
-			(void)fprintf(stderr,
-			    "%s login refused on this terminal.\n",
-			    pwd->pw_name);
+			fprintf(stderr,
+				"%s login refused on this terminal.\n",
+				pwd->pw_name);
 			if (hostname)
 				syslog(LOG_NOTICE,
-				    "LOGIN %s REFUSED FROM %s ON TTY %s",
-				    pwd->pw_name, hostname, tty);
+				       "LOGIN %s REFUSED FROM %s ON TTY %s",
+				       pwd->pw_name, hostname, tty);
 			else
 				syslog(LOG_NOTICE,
-				    "LOGIN %s REFUSED ON TTY %s",
-				     pwd->pw_name, tty);
+				       "LOGIN %s REFUSED ON TTY %s",
+				       pwd->pw_name, tty);
 			continue;
 		}
 
-		if (pwd && !rval)
+		if (rval == 0)
 			break;
 
-		(void)printf("Login incorrect\n");
+		printf("Login incorrect\n");
 		failures++;
 
                 /* max number of attemps and delays taken from defaults file */
@@ -443,50 +488,39 @@ main(argc, argv)
 	}
 
 	/* committed to login -- turn off timeout */
-	(void)alarm((u_int)0);
+	alarm(0);
 
 	endpwent();
 
 #if defined(HAVE_GETUDBNAM) && defined(HAVE_SETLIM)
 	{
 	    struct udb *udb;
-	    struct resclim lim;
-	    int t;
-	    const int maxcpu = 46116860184; /* some random constant */
+	    long t;
+	    const long maxcpu = 46116860184; /* some random constant */
 	    udb = getudbnam(pwd->pw_name);
 	    if(udb == UDB_NULL){
 		fprintf(stderr, "Failed to get UDB entry.\n");
 		exit(1);
 	    }
-	    lim.resc_resource = L_CPU;
-	    lim.resc_category = C_PROC;
-	    lim.resc_type = L_T_ABSOLUTE;
-	    lim.resc_action = 0;
-	    lim.resc_used = 0;
 	    t = udb->ue_pcpulim[UDBRC_INTER];
 	    if(t == 0 || t > maxcpu)
-		lim.resc_value[lim.resc_type] = CPUUNLIM;
+		t = CPUUNLIM;
 	    else
-		lim.resc_value[lim.resc_type] = 100 * CLOCKS_PER_SEC * t;
+		t *= 100 * CLOCKS_PER_SEC;
 
-	    if(setlim(0, &lim) < 0){
-		fprintf(stderr, "setlim: %s\n", strerror(errno));
-	    }
+	    if(limit(C_PROC, 0, L_CPU, t) < 0)
+		perror("login: limit");
 
-	    lim.resc_resource = L_CPU;
-	    lim.resc_category = C_SESS;
-	    lim.resc_type = L_T_ABSOLUTE;
-	    lim.resc_action = 0;
-	    lim.resc_used = 0;
 	    t = udb->ue_jcpulim[UDBRC_INTER];
 	    if(t == 0 || t > maxcpu)
-		lim.resc_value[lim.resc_type] = CPUUNLIM;
+		t = CPUUNLIM;
 	    else
-		lim.resc_value[lim.resc_type] = 100 * CLOCKS_PER_SEC * t;
+		t *= 100 * CLOCKS_PER_SEC;
 
-	    if(setlim(0, &lim) < 0){
-		fprintf(stderr, "setlim: %s\n", strerror(errno));
-	    }
+	    if(limit(C_JOBPROCS, 0, L_CPU, t) < 0)
+		perror("login: limit");
+
+	    nice(udb->ue_nice[UDBRC_INTER]);
 	}
 #endif
 	/* if user not super-user, check for disabled logins */
@@ -494,34 +528,35 @@ main(argc, argv)
 		checknologin();
 
 	if (chdir(pwd->pw_dir) < 0) {
-		(void)printf("No home directory %s!\n", pwd->pw_dir);
+		printf("No home directory %s!\n", pwd->pw_dir);
 		if (chdir("/"))
 			exit(0);
 		pwd->pw_dir = "/";
-		(void)printf("Logging in with home = \"/\".\n");
+		printf("Logging in with home = \"/\".\n");
 	}
 
 	quietlog = access(_PATH_HUSHLOGIN, F_OK) == 0;
+	nomailcheck = access(_PATH_NOMAILCHECK, F_OK) == 0;
 
 #if defined(HAVE_PASSWD_CHANGE) && defined(HAVE_PASSWD_EXPIRE)
 	if (pwd->pw_change || pwd->pw_expire)
-		(void)gettimeofday(&tp, (struct timezone *)NULL);
+		gettimeofday(&tp, (struct timezone *)NULL);
 
 	if (pwd->pw_change)
 		if (tp.tv_sec >= pwd->pw_change) {
-			(void)printf("Sorry -- your password has expired.\n");
+			printf("Sorry -- your password has expired.\n");
 			changepass=1;
 		} else if (pwd->pw_change - tp.tv_sec <
 		    2 * DAYSPERWEEK * SECSPERDAY && !quietlog)
-			(void)printf("Warning: your password expires on %s",
+			printf("Warning: your password expires on %s",
 			    ctime(&pwd->pw_change));
 	if (pwd->pw_expire)
 		if (tp.tv_sec >= pwd->pw_expire) {
-			(void)printf("Sorry -- your account has expired.\n");
+			printf("Sorry -- your account has expired.\n");
 			sleepexit(1);
 		} else if (pwd->pw_expire - tp.tv_sec <
 		    2 * DAYSPERWEEK * SECSPERDAY && !quietlog)
-			(void)printf("Warning: your account expires on %s",
+			printf("Warning: your account expires on %s",
 			    ctime(&pwd->pw_expire));
 #endif /* defined(HAVE_PASSWD_CHANGE) && defined(HAVE_PASSWD_EXPIRE) */
 
@@ -545,10 +580,10 @@ main(argc, argv)
 	 */
 	login_fbtab(tty, pwd->pw_uid, pwd->pw_gid);
 
-	(void)chown(ttyn, pwd->pw_uid,
+	chown(ttyn, pwd->pw_uid,
 	    (gr = getgrnam(TTYGRPNAME)) ? gr->gr_gid : pwd->pw_gid);
 	chmod(ttyn, S_IRUSR | S_IWUSR | S_IWGRP);
-	(void)setgid(pwd->pw_gid);
+	setgid(pwd->pw_gid);
 
 	initgroups(username, pwd->pw_gid);
 
@@ -563,12 +598,12 @@ main(argc, argv)
          * that LD_* and IFS are never preserved.
          */
 	if (term[0] == '\0')
-		(void)strncpy(term, stypeof(tty), sizeof(term));
+		strncpy(term, stypeof(tty), sizeof(term));
         /* set up a somewhat censored environment. */
         sysv_newenv(argc, argv, pwd, term, pflag);
 #ifdef KERBEROS
 	if (krbtkfile_env)
-		(void)setenv("KRBTKFILE", krbtkfile_env, 1);
+		setenv("KRBTKFILE", krbtkfile_env, 1);
 #endif
 
 	if (tty[sizeof("tty")-1] == 'd')
@@ -584,7 +619,7 @@ main(argc, argv)
 
 #ifdef KERBEROS
 	if (!quietlog && notickets == 1 && !noticketsdontcomplain)
-		(void)printf("Warning: no Kerberos tickets issued.\n");
+		printf("Warning: no Kerberos tickets issued.\n");
 #endif
 
 #ifdef LOGALL
@@ -607,17 +642,18 @@ main(argc, argv)
 	if (!quietlog) {
 	        struct stat st;
 #if 0
-		(void)printf("%s\n\t%s  %s\n\n",
+		printf("%s\n\t%s  %s\n\n",
 	    "Copyright (c) 1980, 1983, 1986, 1988, 1990, 1991, 1993, 1994",
 		    "The Regents of the University of California. ",
 		    "All rights reserved.");
 #endif
 		motd();
-		(void)sprintf(tbuf,
-		    "%s/%s", _PATH_MAILDIR, pwd->pw_name);
-		if (stat(tbuf, &st) == 0 && st.st_size != 0)
-			(void)printf("You have %smail.\n",
-			    (st.st_mtime > st.st_atime) ? "new " : "");
+		if(!nomailcheck){
+		    sprintf(tbuf, "%s/%s", _PATH_MAILDIR, pwd->pw_name);
+		    if (stat(tbuf, &st) == 0 && st.st_size != 0)
+			printf("You have %smail.\n",
+			       (st.st_mtime > st.st_atime) ? "new " : "");
+		}
 	}
 #endif /* NO_MOTD */
 
@@ -634,14 +670,14 @@ main(argc, argv)
 	}
 #endif
 
-	(void)signal(SIGALRM, SIG_DFL);
-	(void)signal(SIGQUIT, SIG_DFL);
-	(void)signal(SIGINT, SIG_DFL);
-	(void)signal(SIGTSTP, SIG_IGN);
+	signal(SIGALRM, SIG_DFL);
+	signal(SIGQUIT, SIG_DFL);
+	signal(SIGINT, SIG_DFL);
+	signal(SIGTSTP, SIG_IGN);
 
 	tbuf[0] = '-';
-	(void)strcpy(tbuf + 1, (p = strrchr(pwd->pw_shell, '/')) ?
-	    p + 1 : pwd->pw_shell);
+	strcpy(tbuf + 1, (p = strrchr(pwd->pw_shell, '/')) ?
+	       p + 1 : pwd->pw_shell);
 
 #ifdef HAVE_SETLOGIN
      	if (setlogin(pwd->pw_name) < 0)
@@ -653,6 +689,10 @@ main(argc, argv)
 		syslog(LOG_ERR, "setpcred() failure: %m");
 #endif /* HAVE_SETPCRED */
 
+#if defined(SYSV_SHADOW) && defined(HAVE_GETSPNAM)
+	spwd = getspnam (username);
+	endspent ();
+#endif
 	/* Discard permissions last so can't get killed and drop core. */
 	{
 	    int uid = rootlogin ? 0 : pwd->pw_uid;
@@ -670,7 +710,8 @@ main(argc, argv)
          * optionally run, as the user, /bin/passwd.
          */
  
-        if (pwd->pw_passwd[0] == 0 && strcasecmp(default_passreq, "YES") == 0) {
+        if (pwd->pw_passwd[0] == 0 &&
+	    strcasecmp(default_passreq, "YES") == 0) {
                 printf("You don't have a password.  Choose one.\n");
                 if (change_passwd(pwd))
                         sleepexit(0);
@@ -678,9 +719,6 @@ main(argc, argv)
         }
 
 #ifdef SYSV_SHADOW
-#ifdef HAVE_GETSPNAM
-	spwd = getspnam (username);
-#endif
         if (spwd && sysv_expire(spwd)) {
                 if (change_passwd(pwd))
                         sleepexit(0);
@@ -694,8 +732,11 @@ main(argc, argv)
 	}
 
 	if (k_hasafs()) {
-		k_setpag();
-		k_afsklog(0, 0);
+	    char cell[64];
+	    k_setpag();
+	    if(k_afs_cell_of_file(pwd->pw_dir, cell, sizeof(cell)) == 0)
+		k_afsklog(cell, 0);
+	    k_afsklog(0, 0);
 	}
 
 	execlp(pwd->pw_shell, tbuf, 0);
@@ -706,6 +747,7 @@ main(argc, argv)
 		err(1, "%s", _PATH_BSHELL);
 	}
 	err(1, "%s", pwd->pw_shell);
+	return 1;
 }
 
 #ifdef	KERBEROS
@@ -714,9 +756,8 @@ main(argc, argv)
 #define	NBUFSIZ		(UT_NAMESIZE + 1)
 #endif
 
-void
-getloginname(prompt)
-     int prompt;
+static void
+getloginname(int prompt)
 {
 	int ch;
 	char *p;
@@ -725,9 +766,9 @@ getloginname(prompt)
 	for (;;) {
                 if (prompt)
                     if (ttyprompt && *ttyprompt)
-                        (void)printf("%s", ttyprompt);
+                        printf("%s", ttyprompt);
                     else
-		        (void)printf("login: ");
+		        printf("login: ");
 		prompt = 1;
 		for (p = nbuf; (ch = getchar()) != '\n'; ) {
 			if (ch == EOF) {
@@ -739,7 +780,7 @@ getloginname(prompt)
 		}
 		if (p > nbuf)
 			if (nbuf[0] == '-')
-				(void)fprintf(stderr,
+				fprintf(stderr,
 				    "login names may not start with '-'.\n");
 			else {
 				*p = '\0';
@@ -749,9 +790,8 @@ getloginname(prompt)
 	}
 }
 
-int
-rootterm(ttyn)
-	char *ttyn;
+static int
+rootterm(char *ttyn)
 {
 #ifndef HAVE_TTYENT_H
         return (default_console == 0 || strcmp(default_console, ttyname(0)) == 0);
@@ -762,74 +802,38 @@ rootterm(ttyn)
 #endif
 }
 
-#ifndef NO_MOTD /* message of the day stuff */
-
-jmp_buf motdinterrupt;
-
-void
-motd()
+static RETSIGTYPE
+timedout(int signo)
 {
-	int fd, nchars;
-	RETSIGTYPE (*oldint)();
-	char tbuf[8192];
-
-	if ((fd = open(_PATH_MOTDFILE, O_RDONLY, 0)) < 0)
-		return;
-	oldint = signal(SIGINT, sigint);
-	if (setjmp(motdinterrupt) == 0)
-		while ((nchars = read(fd, tbuf, sizeof(tbuf))) > 0)
-			(void)write(fileno(stdout), tbuf, nchars);
-	(void)signal(SIGINT, oldint);
-	(void)close(fd);
-}
-
-/* ARGSUSED */
-void
-sigint(signo)
-	int signo;
-{
-
-	longjmp(motdinterrupt, 1);
-}
-
-#endif /* !NO_MOTD */
-
-/* ARGSUSED */
-void
-timedout(signo)
-	int signo;
-{
-
-	(void)fprintf(stderr, "Login timed out after %d seconds\n",
+	fprintf(stderr, "Login timed out after %d seconds\n",
 		      login_timeout);
 	exit(0);
 }
 
-void
-checknologin()
+static void
+checknologin(void)
 {
 	int fd, nchars;
 	char tbuf[8192];
 
 	if ((fd = open(_PATH_NOLOGIN, O_RDONLY, 0)) >= 0) {
 		while ((nchars = read(fd, tbuf, sizeof(tbuf))) > 0)
-			(void)write(fileno(stdout), tbuf, nchars);
+			write(fileno(stdout), tbuf, nchars);
 		sleepexit(0);
 	}
 }
 
-void
-dolastlog(quiet)
-	int quiet;
+static void
+dolastlog(int quiet)
 {
 #if defined(HAVE_LASTLOG_H) || defined(HAVE_LOGIN_H) || defined(SYSV_SHADOW)
 	struct lastlog ll;
 	int fd;
 
 	if ((fd = open(_PATH_LASTLOG, O_RDWR, 0)) >= 0) {
-		(void)lseek(fd, (off_t)pwd->pw_uid * sizeof(ll), SEEK_SET);
+		lseek(fd, (off_t)pwd->pw_uid * sizeof(ll), SEEK_SET);
 #ifdef SYSV_SHADOW
-                if (read(fd, (char *)&ll, sizeof(ll)) == sizeof(ll) &&
+                if (read(fd, &ll, sizeof(ll)) == sizeof(ll) &&
                     ll.ll_time != 0) {
                         if (pwd->pw_uid && spwd && spwd->sp_inact > 0
                             && ll.ll_time / DAY + spwd->sp_inact < DAY_NOW) {
@@ -838,7 +842,7 @@ dolastlog(quiet)
                         }
                         if (!quiet) {
                                 printf("Last login: %.*s ",
-                                    24-5, (char *)ctime(&ll.ll_time));
+                                    24-5, ctime(&ll.ll_time));
                                 if (*ll.ll_host != '\0') {
                                         printf("from %.*s\n",
                                             (int)sizeof(ll.ll_host),
@@ -849,39 +853,38 @@ dolastlog(quiet)
 					       ll.ll_line);
                         }
                 }
-                (void)lseek(fd, (off_t)pwd->pw_uid * sizeof(ll), SEEK_SET);
+                lseek(fd, (off_t)pwd->pw_uid * sizeof(ll), SEEK_SET);
 #else /* SYSV_SHADOW */
 		if (!quiet) {
-			if (read(fd, (char *)&ll, sizeof(ll)) == sizeof(ll) &&
+			if (read(fd, &ll, sizeof(ll)) == sizeof(ll) &&
 			    ll.ll_time != 0) {
-				(void)printf("Last login: %.*s ",
-				    24-5, (char *)ctime(&ll.ll_time));
+				printf("Last login: %.*s ",
+				    24-5, ctime(&ll.ll_time));
 				if (*ll.ll_host != '\0')
-					(void)printf("from %.*s\n",
+					printf("from %.*s\n",
 					    (int)sizeof(ll.ll_host),
 					    ll.ll_host);
 				else
-					(void)printf("on %.*s\n",
+					printf("on %.*s\n",
 					    (int)sizeof(ll.ll_line),
 					    ll.ll_line);
 			}
-			(void)lseek(fd, (off_t)pwd->pw_uid * sizeof(ll), SEEK_SET);
+			lseek(fd, (off_t)pwd->pw_uid * sizeof(ll), SEEK_SET);
 		}
 #endif /* SYSV_SHADOW */
-		memset((void *)&ll, 0, sizeof(ll));
-		(void)time(&ll.ll_time);
-		(void)strncpy(ll.ll_line, tty, sizeof(ll.ll_line));
+		memset(&ll, 0, sizeof(ll));
+		time(&ll.ll_time);
+		strncpy(ll.ll_line, tty, sizeof(ll.ll_line));
 		if (hostname)
-			(void)strncpy(ll.ll_host, hostname, sizeof(ll.ll_host));
-		(void)write(fd, (char *)&ll, sizeof(ll));
-		(void)close(fd);
+			strncpy(ll.ll_host, hostname, sizeof(ll.ll_host));
+		write(fd, &ll, sizeof(ll));
+		close(fd);
 	}
 #endif /* DOLASTLOG */
 }
 
-void
-badlogin(name)
-	char *name;
+static void
+badlogin(char *name)
 {
 
 	if (failures == 0)
@@ -904,9 +907,8 @@ badlogin(name)
 #undef	UNKNOWN
 #define	UNKNOWN	"su"
 
-char *
-stypeof(ttyid)
-        char *ttyid;
+static char *
+stypeof(char *ttyid)
 {
     /* TERM is probably a better guess than anything else. */
     char *term = getenv("TERM");
@@ -924,8 +926,7 @@ stypeof(ttyid)
     }
 }
 
-static
-void
+static void
 xgetstr(char *buf, int cnt, char *err)
 {
         char ch;
@@ -948,8 +949,7 @@ xgetstr(char *buf, int cnt, char *err)
  * so we have to trust that rlogind resolved the name correctly.
  */
 
-static
-int
+static int
 doremotelogin(char *host)
 {
         int code;
@@ -976,7 +976,6 @@ void
 sleepexit(int eval)
 {
 
-	(void)sleep(5);
+	sleep(5);
 	exit(eval);
 }
-
