@@ -1,5 +1,3 @@
-/*	$NetBSD: rcp.c,v 1.9 1995/03/21 08:19:06 cgd Exp $	*/
-
 /*
  * Copyright (c) 1983, 1990, 1992, 1993
  *	The Regents of the University of California.  All rights reserved.
@@ -35,7 +33,7 @@
 
 #include "bsd_locl.h"
 
-RCSID("$Id: rcp.c,v 1.25 1996/08/05 17:02:48 bg Exp $");
+RCSID("$Id: rcp.c,v 1.31 1996/11/19 04:11:17 assar Exp $");
 
 /* Globals */
 char *__progname;
@@ -100,7 +98,7 @@ send_auth(char *h, char *r)
 }
 
 static void
-answer_auth()
+answer_auth(void)
 {
     int lslen, fslen, status;
     long opts;
@@ -216,7 +214,7 @@ allocbuf(BUF *bp, int fd, int blksize)
 static void
 usage(void)
 {
-	(void)fprintf(stderr, "%s\n\t%s\n",
+	fprintf(stderr, "%s\n\t%s\n",
 	    "usage: rcp [-Kpx] [-k realm] f1 f2",
 	    "or: rcp [-Kprx] [-k realm] f1 ... fn directory");
 	exit(1);
@@ -229,13 +227,13 @@ oldw(const char *fmt, const char *arg)
     if (rstar_no_warn == 0)
 	rstar_no_warn = "";
     if (strncmp(rstar_no_warn, "yes", 3) != 0) {
-	(void)fprintf(stderr, "rcp: ");
-	(void)fprintf(stderr, fmt, arg);
-	(void)fprintf(stderr, ", using standard rcp\n");
+	fprintf(stderr, "rcp: ");
+	fprintf(stderr, fmt, arg);
+	fprintf(stderr, ", using standard rcp\n");
     }
 }
 
-static void
+static RETSIGTYPE
 lostconn(int signo)
 {
 	if (!iamremote)
@@ -267,7 +265,7 @@ response(void)
 		} while (cp < &rbuf[BUFSIZ] && ch != '\n');
 
 		if (!iamremote)
-			(void)write(STDERR_FILENO, rbuf, cp - rbuf);
+			write(STDERR_FILENO, rbuf, cp - rbuf);
 		++errs;
 		if (resp == 1)
 			return (-1);
@@ -316,19 +314,19 @@ syserr:			run_err("%s: %s", name, strerror(errno));
 			 * Make it compatible with possible future
 			 * versions expecting microseconds.
 			 */
-			(void)sprintf(buf, "T%ld 0 %ld 0\n",
+			sprintf(buf, "T%ld 0 %ld 0\n",
 			    (long)stb.st_mtime, (long)stb.st_atime);
-			(void)des_write(rem, buf, strlen(buf));
+			des_write(rem, buf, strlen(buf));
 			if (response() < 0)
 				goto next;
 		}
-		(void)sprintf(buf, "C%04o %ld %s\n",
+		sprintf(buf, "C%04o %ld %s\n",
 		    (int)stb.st_mode & MODEMASK, (long) stb.st_size, last);
-		(void)des_write(rem, buf, strlen(buf));
+		des_write(rem, buf, strlen(buf));
 		if (response() < 0)
 			goto next;
 		if ((bp = allocbuf(&buffer, fd, BUFSIZ)) == NULL) {
-next:			(void)close(fd);
+next:			close(fd);
 			continue;
 		}
 
@@ -343,7 +341,7 @@ next:			(void)close(fd);
 					haderr = result >= 0 ? EIO : errno;
 			}
 			if (haderr)
-				(void)des_write(rem, bp->buf, amt);
+				des_write(rem, bp->buf, amt);
 			else {
 				result = des_write(rem, bp->buf, amt);
 				if (result != amt)
@@ -353,10 +351,10 @@ next:			(void)close(fd);
 		if (close(fd) && !haderr)
 			haderr = errno;
 		if (!haderr)
-			(void)des_write(rem, "", 1);
+			des_write(rem, "", 1);
 		else
 			run_err("%s: %s", name, strerror(haderr));
-		(void)response();
+		response();
 	}
 }
 
@@ -377,17 +375,17 @@ rsource(char *name, struct stat *statp)
 	else
 		last++;
 	if (pflag) {
-		(void)sprintf(path, "T%ld 0 %ld 0\n",
+		sprintf(path, "T%ld 0 %ld 0\n",
 		    (long)statp->st_mtime, (long)statp->st_atime);
-		(void)des_write(rem, path, strlen(path));
+		des_write(rem, path, strlen(path));
 		if (response() < 0) {
 			closedir(dirp);
 			return;
 		}
 	}
-	(void)sprintf(path,
+	sprintf(path,
 	    "D%04o %d %s\n", (int)statp->st_mode & MODEMASK, 0, last);
-	(void)des_write(rem, path, strlen(path));
+	des_write(rem, path, strlen(path));
 	if (response() < 0) {
 		closedir(dirp);
 		return;
@@ -401,34 +399,13 @@ rsource(char *name, struct stat *statp)
 			run_err("%s/%s: name too long", name, dp->d_name);
 			continue;
 		}
-		(void)sprintf(path, "%s/%s", name, dp->d_name);
+		sprintf(path, "%s/%s", name, dp->d_name);
 		vect[0] = path;
 		source(1, vect);
 	}
-	(void)closedir(dirp);
-	(void)des_write(rem, "E\n", 2);
-	(void)response();
-}
-
-static int get_shell_port(int kerberos, int encryption)
-{
-  struct servent *sp;
-  char *service="shell";
-  int port=htons(514);
-
-  if(kerberos){
-    service="kshell";
-    port=htons(544);
-  }
-  
-  sp=getservbyname(service, "tcp");
-  if(sp == NULL){
-    fprintf(stderr, "rcp: can't get entry for %s service, using default port %d.\n",
-	    service, ntohs(port));
-  }else{
-    port=sp->s_port;
-  }
-  return port;
+	closedir(dirp);
+	des_write(rem, "E\n", 2);
+	response();
 }
 
 static int
@@ -537,25 +514,25 @@ toremote(char *targ, int argc, char **argv)
 					suser = pwd->pw_name;
 				else if (!okname(suser))
 					continue;
-				(void)sprintf(bp,
+				sprintf(bp,
 				    "%s %s -l %s -n %s %s '%s%s%s:%s'",
 				    _PATH_RSH, host, suser, cmd, src,
 				    tuser ? tuser : "", tuser ? "@" : "",
 				    thost, targ);
 			} else
-				(void)sprintf(bp,
+				sprintf(bp,
 				    "exec %s %s -n %s %s '%s%s%s:%s'",
 				    _PATH_RSH, argv[i], cmd, src,
 				    tuser ? tuser : "", tuser ? "@" : "",
 				    thost, targ);
-			(void)susystem(bp, userid);
-			(void)free(bp);
+			susystem(bp, userid);
+			free(bp);
 		} else {			/* local to remote */
 			if (rem == -1) {
 				len = strlen(targ) + CMDNEEDS + 20;
 				if (!(bp = malloc(len)))
 					err(1, " ");
-				(void)sprintf(bp, "%s -t %s", cmd, targ);
+				sprintf(bp, "%s -t %s", cmd, targ);
 				host = thost;
 				if (use_kerberos)
 					rem = kerberos(&host, bp,
@@ -577,8 +554,8 @@ toremote(char *targ, int argc, char **argv)
 				    send_auth(host, dest_realm);
 				if (response() < 0)
 					exit(1);
-				(void)free(bp);
-				(void)setuid(userid);
+				free(bp);
+				setuid(userid);
 			}
 			source(1, argv+i);
 		}
@@ -605,7 +582,7 @@ sink(int argc, char **argv)
 	setimes = targisdir = 0;
 	mask = umask(0);
 	if (!pflag)
-		(void)umask(mask);
+		umask(mask);
 	if (argc != 1) {
 		run_err("ambiguous target", "", "");
 		exit(1);
@@ -613,7 +590,7 @@ sink(int argc, char **argv)
 	targ = *argv;
 	if (targetshouldbedirectory)
 		verifydir(targ);
-	(void)des_write(rem, "", 1);
+	des_write(rem, "", 1);
 	if (stat(targ, &stb) == 0 && S_ISDIR(stb.st_mode))
 		targisdir = 1;
 	for (first = 1;; first = 0) {
@@ -631,7 +608,7 @@ sink(int argc, char **argv)
 
 		if (buf[0] == '\01' || buf[0] == '\02') {
 			if (iamremote == 0)
-				(void)write(STDERR_FILENO,
+				write(STDERR_FILENO,
 				    buf + 1, strlen(buf + 1));
 			if (buf[0] == '\02')
 				exit(1);
@@ -639,7 +616,7 @@ sink(int argc, char **argv)
 			continue;
 		}
 		if (buf[0] == 'E') {
-			(void)des_write(rem, "", 1);
+			des_write(rem, "", 1);
 			return;
 		}
 
@@ -663,7 +640,7 @@ sink(int argc, char **argv)
 			getnum(atime.tv_usec);
 			if (*cp++ != '\0')
 				SCREWUP("atime.usec not delimited");
-			(void)des_write(rem, "", 1);
+			des_write(rem, "", 1);
 			continue;
 		}
 		if (*cp != 'C' && *cp != 'D') {
@@ -703,7 +680,7 @@ sink(int argc, char **argv)
 				if (!(namebuf = malloc(need)))
 					run_err("%s", strerror(errno), "");
 			}
-			(void)sprintf(namebuf, "%s%s%s", targ,
+			sprintf(namebuf, "%s%s%s", targ,
 			    *targ ? "/" : "", cp);
 			np = namebuf;
 		} else
@@ -717,7 +694,7 @@ sink(int argc, char **argv)
 					goto bad;
 				}
 				if (pflag)
-					(void)chmod(np, mode);
+					chmod(np, mode);
 			} else {
 				/* Handle copying from a read-only directory */
 				mod_flag = 1;
@@ -736,7 +713,7 @@ sink(int argc, char **argv)
 					np, strerror(errno));
 			}
 			if (mod_flag)
-				(void)chmod(np, mode);
+				chmod(np, mode);
 			continue;
 		}
 		omode = mode;
@@ -745,9 +722,9 @@ sink(int argc, char **argv)
 bad:			run_err("%s: %s", np, strerror(errno));
 			continue;
 		}
-		(void)des_write(rem, "", 1);
+		des_write(rem, "", 1);
 		if ((bp = allocbuf(&buffer, ofd, BUFSIZ)) == NULL) {
-			(void)close(ofd);
+			close(ofd);
 			continue;
 		}
 		cp = bp->buf;
@@ -800,8 +777,8 @@ bad:			run_err("%s: %s", np, strerror(errno));
 					run_err("%s: set mode: %s",
 					    np, strerror(errno));
 		}
-		(void)close(ofd);
-		(void)response();
+		close(ofd);
+		response();
 		if (setimes && wrerr == NO) {
 		        struct utimbuf times;
 			times.actime = atime.tv_sec;
@@ -818,7 +795,7 @@ bad:			run_err("%s: %s", np, strerror(errno));
 			run_err("%s: %s", np, strerror(wrerrno));
 			break;
 		case NO:
-			(void)des_write(rem, "", 1);
+			des_write(rem, "", 1);
 			break;
 		case DISPLAYED:
 			break;
@@ -844,12 +821,12 @@ tolocal(int argc, char **argv)
 			    strlen(argv[argc - 1]) + 20;
 			if (!(bp = malloc(len)))
 				err(1, " ");
-			(void)sprintf(bp, "exec %s%s%s %s %s", _PATH_CP,
+			sprintf(bp, "exec %s%s%s %s %s", _PATH_CP,
 			    iamrecursive ? " -r" : "", pflag ? " -p" : "",
 			    argv[i], argv[argc - 1]);
 			if (susystem(bp, userid))
 				++errs;
-			(void)free(bp);
+			free(bp);
 			continue;
 		}
 		*src++ = 0;
@@ -869,17 +846,17 @@ tolocal(int argc, char **argv)
 		len = strlen(src) + CMDNEEDS + 20;
 		if ((bp = malloc(len)) == NULL)
 			err(1, " ");
-		(void)sprintf(bp, "%s -f %s", cmd, src);
+		sprintf(bp, "%s -f %s", cmd, src);
 		rem = 
 		    use_kerberos ? 
 			kerberos(&host, bp, pwd->pw_name, suser) : 
 			rcmd(&host, port, pwd->pw_name, suser, bp, 0);
-		(void)free(bp);
+		free(bp);
 		if (rem < 0) {
 			++errs;
 			continue;
 		}
-		(void)seteuid(userid);
+		seteuid(userid);
 #ifdef IP_TOS
 		tos = IPTOS_THROUGHPUT;
 		if (setsockopt(rem, IPPROTO_IP, IP_TOS, (void *)&tos,
@@ -889,8 +866,8 @@ tolocal(int argc, char **argv)
 		if (doencrypt)
 		    send_auth(host, dest_realm);
 		sink(1, argv + argc - 1);
-		(void)seteuid(0);
-		(void)close(rem);
+		seteuid(0);
+		close(rem);
 		rem = -1;
 	}
 }
@@ -911,7 +888,7 @@ main(int argc, char **argv)
 			break;
 		case 'k':
 			dest_realm = dst_realm_buf;
-			(void)strncpy(dst_realm_buf, optarg, REALM_SZ);
+			strncpy(dst_realm_buf, optarg, REALM_SZ);
 			break;
 		case 'x':
 			doencrypt = 1;
@@ -944,7 +921,7 @@ main(int argc, char **argv)
 
 	port=get_shell_port(use_kerberos, doencrypt);
 
-	if ((pwd = getpwuid(userid = getuid())) == NULL)
+	if ((pwd = k_getpwuid(userid = getuid())) == NULL)
 		errx(1, "unknown user %d", (int)userid);
 
 	rem = STDIN_FILENO;		/* XXX */
@@ -952,8 +929,14 @@ main(int argc, char **argv)
 	if (fflag) {			/* Follow "protocol", send data. */
 		if (doencrypt)
 		    answer_auth();
-		(void)response();
-		(void)setuid(userid);
+		response();
+		setuid(userid);
+		if (k_hasafs()) {
+		  char cell[64];
+		  if (k_afs_cell_of_file(pwd->pw_dir, cell, sizeof(cell)) == 0)
+		    k_afsklog(cell, 0);
+		  k_afsklog(0, 0);
+		}
 		source(argc, argv);
 		exit(errs);
 	}
@@ -961,7 +944,13 @@ main(int argc, char **argv)
 	if (tflag) {			/* Receive data. */
 	    if (doencrypt)
 		    answer_auth();
-		(void)setuid(userid);
+		setuid(userid);
+		if (k_hasafs()) {
+		  char cell[64];
+		  if (k_afs_cell_of_file(pwd->pw_dir, cell, sizeof(cell)) == 0)
+		    k_afsklog(cell, 0);
+		  k_afsklog(0, 0);
+		}
 		sink(argc, argv);
 		exit(errs);
 	}
@@ -973,12 +962,12 @@ main(int argc, char **argv)
 
 	rem = -1;
 	/* Command to be executed on remote system using "rsh". */
-	(void)sprintf(cmd,
+	sprintf(cmd,
 	    "rcp%s%s%s%s", iamrecursive ? " -r" : "",
 	    (doencrypt && use_kerberos ? " -x" : ""),
 	    pflag ? " -p" : "", targetshouldbedirectory ? " -d" : "");
 
-	(void)signal(SIGPIPE, lostconn);
+	signal(SIGPIPE, lostconn);
 
 	if ((targ = colon(argv[argc - 1])))	/* Dest is remote host. */
 		toremote(targ, argc, argv);
