@@ -1,5 +1,3 @@
-/*	$NetBSD: rlogin.c,v 1.7 1995/05/17 13:35:50 mycroft Exp $	*/
-
 /*
  * Copyright (c) 1983, 1990, 1993
  *	The Regents of the University of California.  All rights reserved.
@@ -38,53 +36,13 @@
  */
 #include "bsd_locl.h"
 
-RCSID("$Id: rlogin.c,v 1.39 1996/08/17 14:26:47 assar Exp $");
-
-#include <termios.h>
-
-#if defined(NeXT)               /* NEXTSTEP 3.3 */
-#include <sys/ioctl.h>
-#endif
-
-#if defined(__osf__)		/* OSF/1 */
-#include <sys/ioctl.h>
-#endif
-
-#if defined(__hpux)		/* HP-UX */
-#include <sys/proc.h>
-#include <sys/tty.h>
-#endif
-
-#if defined(_AIX)		/* AIX */
-#include <sys/ioctl.h>
-#endif
-
-#if SunOS == 4
-#ifndef _POSIX_VDISABLE
-#define _POSIX_VDISABLE 0
-#endif /* _POSIX_VDISABLE */
-#include <sys/ttold.h>
-#endif
-
-#if SunOS == 5
-#include <sys/tty.h>
-#include <sys/ptyvar.h>
-#endif
+RCSID("$Id: rlogin.c,v 1.51 1996/11/19 04:11:20 assar Exp $");
 
 CREDENTIALS cred;
 Key_schedule schedule;
 int use_kerberos = 1, doencrypt;
 char dst_realm_buf[REALM_SZ], *dest_realm = NULL;
 
-#ifndef TIOCPKT_WINDOW
-#define	TIOCPKT_WINDOW	0x80
-#endif
-
-/* concession to Sun */
-#ifndef SIGUSR1
-#define	SIGUSR1	30
-#endif
-
 #ifndef CCEQ
 #define c2uc(x) ((unsigned char) x)
 #define CCEQ__(val, c)	(c == val ? val != c2uc(_POSIX_VDISABLE) : 0)
@@ -139,9 +97,9 @@ warning(const char *fmt, const char *arg)
     if (rstar_no_warn == 0)
 	rstar_no_warn = "";
     if (strncmp(rstar_no_warn, "yes", 3) != 0) {
-	(void)fprintf(stderr, "rlogin: warning, using standard rlogin: ");
+	fprintf(stderr, "rlogin: warning, using standard rlogin: ");
 	fprintf(stderr, fmt, arg);
-	(void)fprintf(stderr, ".\n");
+	fprintf(stderr, ".\n");
     }
 }
 
@@ -152,9 +110,9 @@ int		get_window_size __P((int, struct winsize *));
 int child;
 
 static void
-echo(register char c)
+echo(char c)
 {
-	register char *p;
+	char *p;
 	char buf[8];
 
 	p = buf;
@@ -170,7 +128,7 @@ echo(register char c)
 		*p++ = c;
 	*p++ = '\r';
 	*p++ = '\n';
-	(void)write(STDOUT_FILENO, buf, p - buf);
+	write(STDOUT_FILENO, buf, p - buf);
 }
 
 static void
@@ -180,10 +138,10 @@ mode(int f)
 
 	switch (f) {
 	case 0:
-		(void)tcsetattr(0, TCSANOW, &deftty);
+		tcsetattr(0, TCSANOW, &deftty);
 		break;
 	case 1:
-		(void)tcgetattr(0, &deftty);
+		tcgetattr(0, &deftty);
 		tty = deftty;
 		/* This is loosely derived from sys/compat/tty_compat.c. */
 		tty.c_lflag &= ~(ECHO|ICANON|ISIG|IEXTEN);
@@ -196,7 +154,7 @@ mode(int f)
 			tty.c_cflag &= ~(CSIZE|PARENB);
 			tty.c_cflag |= CS8;
 		}
-		(void)tcsetattr(0, TCSANOW, &tty);
+		tcsetattr(0, TCSANOW, &tty);
 		break;
 	default:
 		return;
@@ -211,7 +169,7 @@ done(int status)
 	mode(0);
 	if (child > 0) {
 		/* make sure catch_child does not snap it up */
-		(void)signal(SIGCHLD, SIG_DFL);
+		signal(SIGCHLD, SIG_DFL);
 		if (kill(child, SIGKILL) >= 0)
 			while ((w = wait(&wstatus)) > 0 && w != child);
 	}
@@ -239,7 +197,7 @@ catch_child(int foo)
 static void
 msg(char *str)
 {
-	(void)fprintf(stderr, "rlogin: %s\r\n", str);
+	fprintf(stderr, "rlogin: %s\r\n", str);
 }
 
 /*
@@ -254,7 +212,7 @@ static int tty_kludge = 1;
 /* Return the number of OOB bytes processed. */
 static
 int
-oob_real()
+oob_real(void)
 {
 	struct termios tty;
 	int atmark, n, out, rcvd;
@@ -267,31 +225,31 @@ oob_real()
 	}
 	if (mark & TIOCPKT_WINDOW) {
 		/* Let server know about window size changes */
-		(void)kill(parent, SIGUSR1);
+		kill(parent, SIGUSR1);
 	} else if (tty_kludge) {
 		/* Let server know about window size changes */
-		(void)kill(parent, SIGUSR1);
+		kill(parent, SIGUSR1);
 		tty_kludge = 0;
 	}
 	if (!eight && (mark & TIOCPKT_NOSTOP)) {
-		(void)tcgetattr(0, &tty);
+		tcgetattr(0, &tty);
 		tty.c_iflag &= ~IXON;
-		(void)tcsetattr(0, TCSANOW, &tty);
+		tcsetattr(0, TCSANOW, &tty);
 	}
 	if (!eight && (mark & TIOCPKT_DOSTOP)) {
-		(void)tcgetattr(0, &tty);
+		tcgetattr(0, &tty);
 		tty.c_iflag |= (deftty.c_iflag & IXON);
-		(void)tcsetattr(0, TCSANOW, &tty);
+		tcsetattr(0, TCSANOW, &tty);
 	}
 	if (mark & TIOCPKT_FLUSHWRITE) {
 #ifdef TCOFLUSH
-		(void) tcflush(1, TCOFLUSH);
+		tcflush(1, TCOFLUSH);
 #else
-		(void)ioctl(1, TIOCFLUSH, (char *)&out);
+		ioctl(1, TIOCFLUSH, (char *)&out);
 #endif
 		for (;;) {
 			if (ioctl(rem, SIOCATMARK, &atmark) < 0) {
-				(void)fprintf(stderr, "rlogin: ioctl: %s.\n",
+				fprintf(stderr, "rlogin: ioctl: %s.\n",
 				    strerror(errno));
 				break;
 			}
@@ -320,6 +278,7 @@ reader(void)
 {
 	int n, remaining;
 	char *bufp;
+	int kludgep = 1;
 
 	bufp = rcvbuf;
 	for (;;) {
@@ -339,7 +298,8 @@ reader(void)
 		FD_ZERO (&readfds);
 		FD_SET (rem, &readfds);
 		FD_ZERO (&exceptfds);
-		FD_SET (rem, &exceptfds);
+		if (kludgep)
+		  FD_SET (rem, &exceptfds);
 		if (select(rem+1, &readfds, 0, &exceptfds, 0) == -1)
 		    {
 			if (errno == EINTR)
@@ -357,27 +317,32 @@ reader(void)
 		    continue;
 		  }
 
-		if (FD_ISSET(rem, &exceptfds))
-		  if (oob_real() >= 1)
+		if (FD_ISSET(rem, &exceptfds)) {
+		  int foo = oob_real ();
+		  if (foo >= 1)
 		    continue;	/* First check if there is more OOB data. */
+		  else if (foo < 0)
+		    kludgep = 0;
+		}
 
 		if (!FD_ISSET(rem, &readfds))
 		    continue;	/* Nothing to read. */
 
+		kludgep = 1;
+#ifndef NOENCRYPTION
 		if (doencrypt)
-#ifdef NOENCRYPTION
-			rcvcnt = read(rem, rcvbuf, sizeof (rcvbuf));
-#else
-			rcvcnt = des_enc_read(rem, rcvbuf, sizeof(rcvbuf), schedule, &cred.session);
-#endif
+			rcvcnt = des_enc_read(rem, rcvbuf,
+					      sizeof(rcvbuf),
+					      schedule, &cred.session);
 		else
+#endif
 			rcvcnt = read(rem, rcvbuf, sizeof (rcvbuf));
 		if (rcvcnt == 0)
 			return (0);
 		if (rcvcnt < 0) {
 			if (errno == EINTR)
 				continue;
-			(void)fprintf(stderr, "rlogin: read: %s.\n",
+			fprintf(stderr, "rlogin: read: %s.\n",
 			    strerror(errno));
 			return (-1);
 		}
@@ -403,14 +368,12 @@ sendwindow(void)
 	wp->ws_xpixel = htons(winsize.ws_xpixel);
 	wp->ws_ypixel = htons(winsize.ws_ypixel);
 
+#ifndef NOENCRYPTION
 	if(doencrypt)
-#ifdef NOENCRYPTION
-		(void)write(rem, obuf, sizeof(obuf));
-#else
-		(void)des_enc_write(rem, obuf, sizeof(obuf), schedule, &cred.session);
-#endif
+		des_enc_write(rem, obuf, sizeof(obuf), schedule, &cred.session);
 	else
-		(void)write(rem, obuf, sizeof(obuf));
+#endif
+		write(rem, obuf, sizeof(obuf));
 }
 
 static
@@ -430,9 +393,9 @@ static void
 stop(int all)
 {
 	mode(0);
-	(void)signal(SIGCHLD, SIG_IGN);
-	(void)kill(all ? 0 : getpid(), SIGTSTP);
-	(void)signal(SIGCHLD, catch_child);
+	signal(SIGCHLD, SIG_IGN);
+	kill(all ? 0 : getpid(), SIGTSTP);
+	signal(SIGCHLD, catch_child);
 	mode(1);
 	kill(SIGWINCH, getpid()); /* check for size changes, if caught */
 }
@@ -446,7 +409,7 @@ stop(int all)
 static void
 writer(void)
 {
-	register int bol, local, n;
+	int bol, local, n;
 	char c;
 
 	bol = 1;			/* beginning of line */
@@ -494,14 +457,12 @@ writer(void)
 			}
 #endif /* VDSUSP */
 			if (c != escapechar)
+#ifndef NOENCRYPTION
 				if (doencrypt)
-#ifdef NOENCRYPTION
-					(void)write(rem, &escapechar, 1);
-#else
-					(void)des_enc_write(rem, &escapechar, 1, schedule, &cred.session);
-#endif
+					des_enc_write(rem, &escapechar,1, schedule, &cred.session);
 				else
-					(void)write(rem, &escapechar, 1);
+#endif
+					write(rem, &escapechar, 1);
 		}
 
 		if (doencrypt) {
@@ -530,7 +491,7 @@ static
 RETSIGTYPE
 lostpeer(int foo)
 {
-	(void)signal(SIGPIPE, SIG_IGN);
+	signal(SIGPIPE, SIG_IGN);
 	msg("\aconnection closed.");
 	done(1);
 }
@@ -548,35 +509,36 @@ sigusr1(int foo)
 	 * Now we now daemon supports winsize hack,
 	 */
 	sendwindow();
-	(void)signal(SIGWINCH, sigwinch); /* so we start to support it */
+	signal(SIGWINCH, sigwinch); /* so we start to support it */
+	SIGRETURN(0);
 }
 
 static void
 doit(void)
 {
-	(void)signal(SIGINT, SIG_IGN);
-	(void)signal(SIGHUP, SIG_IGN);
-	(void)signal(SIGQUIT, SIG_IGN);
+	signal(SIGINT, SIG_IGN);
+	signal(SIGHUP, SIG_IGN);
+	signal(SIGQUIT, SIG_IGN);
 
-	(void)signal(SIGCHLD, catch_child);
+	signal(SIGCHLD, catch_child);
 
 	/*
 	 * Child sends parent this signal for window size hack.
 	 */
-	(void)signal(SIGUSR1, sigusr1);
+	signal(SIGUSR1, sigusr1);
 
-	(void)signal(SIGPIPE, lostpeer);
+	signal(SIGPIPE, lostpeer);
 
 	mode(1);
 	parent = getpid();
 	child = fork();
 	if (child == -1) {
-		(void)fprintf(stderr, "rlogin: fork: %s.\n", strerror(errno));
+		fprintf(stderr, "rlogin: fork: %s.\n", strerror(errno));
 		done(1);
 	}
 	if (child == 0) {
-	        (void)signal(SIGCHLD, SIG_IGN);
-	        (void)signal(SIGTTOU, SIG_IGN);
+	        signal(SIGCHLD, SIG_IGN);
+	        signal(SIGTTOU, SIG_IGN);
 		if (reader() == 0) {
 			msg("connection closed.");
 			exit(0);
@@ -594,14 +556,14 @@ doit(void)
 static void
 usage(void)
 {
-	(void)fprintf(stderr,
+	fprintf(stderr,
 	    "usage: rlogin [ -%s]%s[-e char] [ -l username ] host\n",
 	    "8DEKLdx", " [-k realm] ");
 	exit(1);
 }
 
 static u_int
-getescape(register char *p)
+getescape(char *p)
 {
 	long val;
 	int len;
@@ -623,37 +585,9 @@ getescape(register char *p)
 	return 0;
 }
 
-static int get_login_port(int kerberos, int encryption)
-{
-  struct servent *sp;
-  char *service="login";
-  int port=htons(513);
-
-  if(kerberos && encryption){
-    service="eklogin";
-    port=htons(2105);
-  }
-  
-  if(kerberos && !encryption){
-    service="klogin";
-    port=htons(543);
-  }
-  
-  sp=getservbyname(service, "tcp");
-  if(sp == NULL){
-    fprintf(stderr, "rlogin: can't get entry for %s service, using default port %d.\n",
-	    service, ntohs(port));
-  }else{
-    port=sp->s_port;
-  }
-  return port;
-}
-
 int
 main(int argc, char **argv)
 {
-	extern char *optarg;
-	extern int optind;
 	struct passwd *pw;
 	int sv_port;
 	struct termios tty;
@@ -702,7 +636,7 @@ main(int argc, char **argv)
 			break;
 		case 'k':
 			dest_realm = dst_realm_buf;
-			(void)strncpy(dest_realm, optarg, REALM_SZ);
+			strncpy(dest_realm, optarg, REALM_SZ);
 			break;
 		case 'l':
 			user = optarg;
@@ -725,8 +659,8 @@ main(int argc, char **argv)
 	if (*argv)
 		usage();
 
-	if (!(pw = getpwuid(uid = getuid()))) {
-		(void)fprintf(stderr, "rlogin: unknown user id.\n");
+	if (!(pw = k_getpwuid(uid = getuid()))) {
+		fprintf(stderr, "rlogin: unknown user id.\n");
 		exit(1);
 	}
 	if (!user)
@@ -740,13 +674,17 @@ main(int argc, char **argv)
 	term[sizeof(term) - 1] = '\0';
 	if (tcgetattr(0, &tty) == 0) {
 		char tmp[17];
+		int i;
 
-		sprintf (tmp, "/%ld", (long) cfgetospeed(&tty));
-		if (strlen (term) + strlen (tmp) < sizeof(term) - 1)
-			strcat (term, tmp);
+		i = speed_t2int (cfgetospeed(&tty));
+		if (i > 0) {
+			sprintf (tmp, "/%d", i);
+			if (strlen (term) + strlen (tmp) < sizeof(term) - 1)
+				strcat (term, tmp);
+		}
 	}
 
-	(void)get_window_size(0, &winsize);
+	get_window_size(0, &winsize);
 
       try_connect:
 	if (use_kerberos) {
@@ -755,7 +693,7 @@ main(int argc, char **argv)
 		/* Fully qualify hostname (needed for krb_realmofhost). */
 		hp = gethostbyname(host);
 		if (hp != NULL && !(host = strdup(hp->h_name))) {
-			(void)fprintf(stderr, "rlogin: %s\n",
+			fprintf(stderr, "rlogin: %s\n",
 			    strerror(ENOMEM));
 			exit(1);
 		}
@@ -782,7 +720,7 @@ main(int argc, char **argv)
 		}
 	} else {
 		if (doencrypt) {
-			(void)fprintf(stderr,
+			fprintf(stderr,
 			    "rlogin: the -x flag requires Kerberos authentication.\n");
 			exit(1);
 		}
@@ -799,7 +737,7 @@ main(int argc, char **argv)
 	if (dflag &&
 	    setsockopt(rem, SOL_SOCKET, SO_DEBUG, (void *)&one,
 		       sizeof(one)) < 0)
-		(void)fprintf(stderr, "rlogin: setsockopt: %s.\n",
+		fprintf(stderr, "rlogin: setsockopt: %s.\n",
 		    strerror(errno));
 	if (Dflag &&
 	    setsockopt(rem, IPPROTO_TCP, TCP_NODELAY, (void *)&one,
@@ -811,7 +749,7 @@ main(int argc, char **argv)
 		perror("rlogin: setsockopt TOS (ignored)");
 #endif /* IP_TOS */
 
-	(void)setuid(uid);
+	setuid(uid);
 	doit();
 	return 0;
 }
