@@ -42,43 +42,9 @@
 
 #include "bsd_locl.h"
 
-RCSID("$Id: rlogind.c,v 1.69 1996/08/24 20:27:55 joda Exp $");
+RCSID("$Id: rlogind.c,v 1.88 1996/11/23 17:14:38 joda Exp $");
 
-#include <termios.h>
-
-#if defined(HAVE_SYS_IOCTL_H) && SunOS != 4
-#include <sys/ioctl.h>
-#endif
-
-#if defined(__hpux)		/* HP-UX */
-#include <sys/proc.h>
-#include <sys/tty.h>
-#include <sys/ptyio.h>
-#endif
-
-#if SunOS == 4
-#ifndef _POSIX_VDISABLE
-#define _POSIX_VDISABLE 0
-#endif /* _POSIX_VDISABLE */
-#include <sys/ttold.h>
-#endif
-
-#if SunOS == 5
-#include <sys/tty.h>
-#include <sys/ptyvar.h>
-#endif
-
-#if defined(_AIX)
-#include <sys/termio.h>
-#endif
-
-#ifndef CEOF
-#define CEOF 04
-#endif
-
-#ifndef TIOCPKT_WINDOW
-#define TIOCPKT_WINDOW 0x80
-#endif
+extern int __check_rhosts_file;
 
 char *INSECURE_MESSAGE =
 "\r\n*** Connection not encrypted! Communication may be eavesdropped. ***"
@@ -116,8 +82,8 @@ static const char *new_login = _PATH_LOGIN;
 static void	doit __P((int, struct sockaddr_in *));
 static int	control __P((int, char *, int));
 static void	protocol __P((int, int));
-static void	cleanup __P((int));
-void	fatal __P((int, const char *, int));
+static RETSIGTYPE cleanup __P((int));
+	void	fatal __P((int, const char *, int));
 static int	do_rlogin __P((struct sockaddr_in *));
 static void	setup_term __P((int));
 static int	do_krb_login __P((struct sockaddr_in *));
@@ -222,15 +188,14 @@ readstream(int p, char *ibuf, int bufsize)
 static int
 logout(const char *line)
 {
-	register FILE *fp;
+	FILE *fp;
 	struct utmp ut;
 	int rval;
-	time_t time();
 
 	if (!(fp = fopen(_PATH_UTMP, "r+")))
 		return(0);
 	rval = 1;
-	while (fread((char *)&ut, sizeof(struct utmp), 1, fp) == 1) {
+	while (fread(&ut, sizeof(struct utmp), 1, fp) == 1) {
 		if (!ut.ut_name[0] ||
 		    strncmp(ut.ut_line, line, sizeof(ut.ut_line)))
 			continue;
@@ -238,13 +203,13 @@ logout(const char *line)
 #ifdef HAVE_UT_HOST
 		memset(ut.ut_host, 0, sizeof(ut.ut_host));
 #endif
-		(void)time(&ut.ut_time);
-		(void)fseek(fp, (long)-sizeof(struct utmp), SEEK_CUR);
-		(void)fwrite((char *)&ut, sizeof(struct utmp), 1, fp);
-		(void)fseek(fp, (long)0, SEEK_CUR);
+		time(&ut.ut_time);
+		fseek(fp, (long)-sizeof(struct utmp), SEEK_CUR);
+		fwrite(&ut, sizeof(struct utmp), 1, fp);
+		fseek(fp, (long)0, SEEK_CUR);
 		rval = 0;
 	}
-	(void)fclose(fp);
+	fclose(fp);
 	return(rval);
 }
 
@@ -255,16 +220,15 @@ logwtmp(const char *line, const char *name, const char *host)
 	struct utmp ut;
 	struct stat buf;
 	int fd;
-	time_t time();
 
 	memset (&ut, 0, sizeof(ut));
 	if ((fd = open(_PATH_WTMP, O_WRONLY|O_APPEND, 0)) < 0)
 		return;
 	if (!fstat(fd, &buf)) {
-		(void)strncpy(ut.ut_line, line, sizeof(ut.ut_line));
-		(void)strncpy(ut.ut_name, name, sizeof(ut.ut_name));
+		strncpy(ut.ut_line, line, sizeof(ut.ut_line));
+		strncpy(ut.ut_name, name, sizeof(ut.ut_name));
 #ifdef HAVE_UT_HOST
-		(void)strncpy(ut.ut_host, host, sizeof(ut.ut_host));
+		strncpy(ut.ut_host, host, sizeof(ut.ut_host));
 #endif
 #ifdef HAVE_UT_PID
 		ut.ut_pid = getpid();
@@ -275,69 +239,22 @@ logwtmp(const char *line, const char *name, const char *host)
 		else
 		  ut.ut_type = DEAD_PROCESS;
 #endif
-		(void)time(&ut.ut_time);
-		if (write(fd, (char *)&ut, sizeof(struct utmp)) !=
+		time(&ut.ut_time);
+		if (write(fd, &ut, sizeof(struct utmp)) !=
 		    sizeof(struct utmp))
-			(void)ftruncate(fd, buf.st_size);
+			ftruncate(fd, buf.st_size);
 	}
-	(void)close(fd);
+	close(fd);
 }
 #endif
 
-static void
-wait_for_connection(char *port)
+int
+main(int argc, char **argv)
 {
-    int s;
-    int fd;
-    struct sockaddr_in sa;
-    struct sockaddr_in from;
-    int from_len;
-    struct servent *se;
-    int one = 1;
-    
-    s = socket(AF_INET, SOCK_STREAM, 0);
-    if(s < 0){
-	perror("socket");
-	exit(1);
-    }
-    
-    if(setsockopt(s, SOL_SOCKET, SO_REUSEADDR, (void *)&one, sizeof(one)) < 0){
-	perror("setsockopt");
-	exit(1);
-    }
-
-    memset(&sa, 0, sizeof(sa));
-    se = getservbyname(port, "tcp");
-    if(se)
-	sa.sin_port = se->s_port;
-    else
-	sa.sin_port = htons(atoi(port));
-    
-    sa.sin_addr.s_addr = INADDR_ANY;
-    if(bind(s, (struct sockaddr*)&sa, sizeof(sa)) < 0){
-	perror("bind");
-	exit(1);
-    }
-    listen(s, 5);
-    from_len = sizeof(from);
-    if((fd = accept(s, (struct sockaddr*)&from, &from_len)) < 0){
-	perror("accept");
-	exit(-1);
-    }
-    close(s);
-    dup2(fd, 0);
-    dup2(fd, 1);
-    if(fd > 1)
-	close(fd);
-}
-
-int main(int argc, char **argv)
-{
-	extern int __check_rhosts_file;
 	struct sockaddr_in from;
 	int ch, fromlen, on;
 	int interactive = 0;
-	char *port = NULL;
+	int portnum;
 
 	openlog("rlogind", LOG_PID | LOG_CONS, LOG_AUTH);
 
@@ -353,7 +270,7 @@ int main(int argc, char **argv)
 			interactive = 1;
 			break;
 		case 'p':
-			port = optarg;
+			portnum = atoi(optarg);
 			break;
 		case 'l':
 			__check_rhosts_file = 0;
@@ -385,8 +302,9 @@ int main(int argc, char **argv)
 		usage();
 		fatal(STDERR_FILENO, "only one of -k and -v allowed", 0);
 	}
-	if(interactive)
-	    wait_for_connection(port?port:use_kerberos?doencrypt?"eklogin":"klogin":"login");
+	portnum = get_login_port (use_kerberos, doencrypt);
+	if (interactive)
+		mini_inetd (portnum);
 
 	fromlen = sizeof (from);
 	if (getpeername(0, (struct sockaddr *)&from, &fromlen) < 0) {
@@ -425,7 +343,6 @@ doit(int f, struct sockaddr_in *fromp)
 {
 	int master, pid, on = 1;
 	int authenticated = 0;
-	struct hostent *hp;
 	char hostname[2 * MaxHostNameLen + 1];
 	char c;
 
@@ -438,14 +355,6 @@ doit(int f, struct sockaddr_in *fromp)
 		fatal(f, "Remote host requires Kerberos authentication", 0);
 
 	alarm(0);
-#if 0
-	hp = gethostbyaddr((char *)&fromp->sin_addr, sizeof(struct in_addr),
-	    fromp->sin_family);
-	if (hp)
-		(void)strcpy(hostname, hp->h_name);
-	else
-		(void)strcpy(hostname, inet_ntoa(fromp->sin_addr));
-#endif
 	inaddr2str (fromp->sin_addr, hostname, sizeof(hostname));
 
 	if (use_kerberos) {
@@ -465,34 +374,7 @@ doit(int f, struct sockaddr_in *fromp)
 				inet_ntoa(fromp->sin_addr));
 			fatal(f, "Permission denied", 0);
 		}
-#ifdef IP_OPTIONS
-		{
-		u_char optbuf[BUFSIZ/3], *cp;
-		char lbuf[BUFSIZ], *lp;
-		int optsize = sizeof(optbuf), ipproto;
-		struct protoent *ip;
-
-		if ((ip = getprotobyname("ip")) != NULL)
-			ipproto = ip->p_proto;
-		else
-			ipproto = IPPROTO_IP;
-		if (getsockopt(0, ipproto, IP_OPTIONS, (void *)optbuf,
-		    &optsize) == 0 && optsize != 0) {
-			lp = lbuf;
-			for (cp = optbuf; optsize > 0; cp++, optsize--, lp += 3)
-				sprintf(lp, " %2.2x", *cp);
-			syslog(LOG_NOTICE,
-			    "Connection received using IP options (ignored):%s",
-			    lbuf);
-			if (setsockopt(0, ipproto, IP_OPTIONS,
-			    (void *)NULL, optsize) != 0) {
-				syslog(LOG_ERR,
-				    "setsockopt IP_OPTIONS NULL: %m");
-				exit(1);
-			}
-		}
-		}
-#endif
+		ip_options_and_die (0, fromp);
 		if (do_rlogin(fromp) == 0)
 			authenticated++;
 	}
@@ -500,14 +382,14 @@ doit(int f, struct sockaddr_in *fromp)
 		write(f, "", 1);
 		confirmed = 1;		/* we sent the null! */
 	}
+#ifndef NOENCRYPTION
 	if (doencrypt)
-#ifdef NOENCRYPTION
-	    (void) write(f, INSECURE_MESSAGE, strlen(INSECURE_MESSAGE));
-#else
-	    (void) des_enc_write(f, SECURE_MESSAGE, strlen(SECURE_MESSAGE), schedule, &kdata->session);
-#endif
+	    des_enc_write(f, SECURE_MESSAGE,
+				 strlen(SECURE_MESSAGE),
+				 schedule, &kdata->session);
 	else
-	    (void) write(f, INSECURE_MESSAGE, strlen(INSECURE_MESSAGE));
+#endif
+	    write(f, INSECURE_MESSAGE, strlen(INSECURE_MESSAGE));
 	netf = f;
 
 	pid = forkpty(&master, line, NULL, NULL);
@@ -519,7 +401,7 @@ doit(int f, struct sockaddr_in *fromp)
 	}
 	if (pid == 0) {
 		if (f > 2)	/* f should always be 0, but... */
-			(void) close(f);
+			close(f);
 		setup_term(0);
 		if (lusername[0] == '-'){
 			syslog(LOG_ERR, "tried to pass user \"%s\" to login",
@@ -577,7 +459,7 @@ control(int master, char *cp, int n)
 	w.ws_col = ntohs(w.ws_col);
 	w.ws_xpixel = ntohs(w.ws_xpixel);
 	w.ws_ypixel = ntohs(w.ws_ypixel);
-	(void)ioctl(master, TIOCSWINSZ, &w);
+	ioctl(master, TIOCSWINSZ, &w);
 	return (4+sizeof (w));
 }
 
@@ -624,13 +506,14 @@ protocol(int f, int master)
 	int pcc = 0, fcc = 0;
 	int cc, nfd, n;
 	char cntl;
+	unsigned char oob_queue = 0;
 
 	/*
 	 * Must ignore SIGTTOU, otherwise we'll stop
 	 * when we try and set slave pty's window shape
 	 * (our controlling tty is the master pty).
 	 */
-	(void) signal(SIGTTOU, SIG_IGN);
+	signal(SIGTTOU, SIG_IGN);
 
 	send_oob(f, TIOCPKT_WINDOW); /* indicate new rlogin */
 
@@ -674,7 +557,10 @@ protocol(int f, int master)
 		if (FD_ISSET(master, &ebits)) {
 			cc = readstream(master, &cntl, 1);
 			if (cc == 1 && pkcontrol(cntl)) {
+#if 0				/* Kludge around */
 				send_oob(f, cntl);
+#endif
+				oob_queue = cntl;
 				if (cntl & TIOCPKT_FLUSHWRITE) {
 					pcc = 0;
 					FD_CLR(master, &ibits);
@@ -682,15 +568,13 @@ protocol(int f, int master)
 			}
 		}
 		if (FD_ISSET(f, &ibits)) {
+#ifndef NOENCRYPTION
 			if (doencrypt)
-#ifdef NOENCRYPTION
-				fcc = read(f, fibuf, sizeof(fibuf));
-#else
 				fcc = des_enc_read(f, fibuf,
 						   sizeof(fibuf),
 						   schedule, &kdata->session);
-#endif
 			else
+#endif
 				fcc = read(f, fibuf, sizeof(fibuf));
 			if (fcc < 0 && errno == EWOULDBLOCK)
 				fcc = 0;
@@ -741,19 +625,20 @@ protocol(int f, int master)
 					FD_SET(f, &obits);	/* try write */
 			} else {
 				if (pkcontrol(pibuf[0])) {
+					oob_queue = pibuf[0];
+#if 0				/* Kludge around */
 					send_oob(f, pibuf[0]);
+#endif
 				}
 				pcc = 0;
 			}
 		}
 		if ((FD_ISSET(f, &obits)) && pcc > 0) {
+#ifndef NOENCRYPTION
 			if (doencrypt)
-#ifdef NOENCRYPTION
-				cc = write(f, pbp, pcc);
-#else
 				cc = des_enc_write(f, pbp, pcc, schedule, &kdata->session);
-#endif
 			else
+#endif
 				cc = write(f, pbp, pcc);
 			if (cc < 0 && errno == EWOULDBLOCK) {
 				/*
@@ -768,12 +653,21 @@ protocol(int f, int master)
 			if (cc > 0) {
 				pcc -= cc;
 				pbp += cc;
+				/* Only send urg data when normal data
+				 * has just been sent.
+				 * Linux has deep problems with more
+				 * than one byte of OOB data.
+				 */
+				if (oob_queue) {
+					send_oob (f, oob_queue);
+					oob_queue = 0;
+				}
 			}
 		}
 	}
 }
 
-static void
+static RETSIGTYPE
 cleanup(int signo)
 {
 	char *p;
@@ -781,11 +675,11 @@ cleanup(int signo)
 	p = line + sizeof(_PATH_DEV) - 1;
 	if (logout(p))
 		logwtmp(p, "", "");
-	(void)chmod(line, 0666);
-	(void)chown(line, 0, 0);
+	chmod(line, 0666);
+	chown(line, 0, 0);
 	*p = 'p';
-	(void)chmod(line, 0666);
-	(void)chown(line, 0, 0);
+	chmod(line, 0666);
+	chown(line, 0, 0);
 	shutdown(netf, 2);
 	signal(SIGHUP, SIG_IGN);
 #ifdef HAVE_VHANGUP
@@ -812,14 +706,12 @@ fatal(int f, const char *msg, int syserr)
 	else
 		sprintf(bp, "rlogind: %s.\r\n", msg);
 	len = strlen(bp);
+#ifndef NOENCRYPTION
 	if (doencrypt)
-#ifdef NOENCRYPTION
-	    (void) write(f, buf, bp + len - buf);
-#else
-	    (void) des_enc_write(f, buf, bp + len - buf, schedule, &kdata->session);
-#endif
+	    des_enc_write(f, buf, bp + len - buf, schedule, &kdata->session);
 	else
-	    (void) write(f, buf, bp + len - buf);
+#endif
+	    write(f, buf, bp + len - buf);
 	exit(1);
 }
 
@@ -852,23 +744,33 @@ do_rlogin(struct sockaddr_in *dest)
 	  	syslog(LOG_ALERT, "NIS attack, user %s has uid 0", lusername);
 		return (-1);
 	  }
-	return (iruserok(dest->sin_addr.s_addr, 0, rusername, lusername));
+	return (iruserok(dest->sin_addr.s_addr,
+			 (pwd->pw_uid == 0),
+			 rusername,
+			 lusername));
 }
 
 static void 
 setup_term(int fd)
 {
-	register char *cp = strchr(term+ENVSIZE, '/');
+	char *cp = strchr(term+ENVSIZE, '/');
 	char *speed;
 	struct termios tt;
 
 	tcgetattr(fd, &tt);
 	if (cp) {
+		int s;
+
 		*cp++ = '\0';
 		speed = cp;
 		cp = strchr(speed, '/');
 		if (cp)
 			*cp++ = '\0';
+		s = int2speed_t (atoi (speed));
+		if (s > 0) {
+			cfsetospeed (&tt, s);
+			cfsetispeed (&tt, s);
+		}
 	}
 
         tt.c_iflag &= ~INPCK;
@@ -964,4 +866,5 @@ usage(void)
 {
 	syslog(LOG_ERR,
 	       "usage: rlogind [-Dailn] [-p port] [-x] [-L login] [-k | -v]");
+	exit(1);
 }
