@@ -33,7 +33,7 @@
 
 #include "bsd_locl.h"
 
-RCSID("$Id: rsh.c,v 1.19 1996/08/07 15:34:06 bg Exp $");
+RCSID("$Id: rsh.c,v 1.27 1996/11/19 04:11:20 assar Exp $");
 
 CREDENTIALS cred;
 Key_schedule schedule;
@@ -48,7 +48,7 @@ int rfd2;
 static void
 usage(void)
 {
-	(void)fprintf(stderr,
+	fprintf(stderr,
 	    "usage: rsh [-nd%s]%s[-l login] host [command]\n",
 	    "x", " [-k realm] ");
 	exit(1);
@@ -61,28 +61,28 @@ warning(const char *fmt, const char *arg)
     if (rstar_no_warn == 0)
 	rstar_no_warn = "";
     if (strncmp(rstar_no_warn, "yes", 3) != 0) {
-	(void)fprintf(stderr, "rsh: warning, using standard rsh: ");
+	fprintf(stderr, "rsh: warning, using standard rsh: ");
 	fprintf(stderr, fmt, arg);
-	(void)fprintf(stderr, ".\n");
+	fprintf(stderr, ".\n");
     }
 }
 
 static char *
 copyargs(char **argv)
 {
-	register int cc;
-	register char **ap, *p;
+	int cc;
+	char **ap, *p;
 	char *args;
 
 	cc = 0;
 	for (ap = argv; *ap; ++ap)
 		cc += strlen(*ap) + 1;
 	if (!(args = malloc((u_int)cc))) {
-		(void)fprintf(stderr, "rsh: %s.\n", strerror(ENOMEM));
+		fprintf(stderr, "rsh: %s.\n", strerror(ENOMEM));
 		exit(1);
 	}
 	for (p = args, ap = argv; *ap; ++ap) {
-		(void)strcpy(p, *ap);
+		strcpy(p, *ap);
 		for (p = strcpy(p, *ap); *p; ++p);
 		if (ap[1])
 			*p++ = ' ';
@@ -96,19 +96,20 @@ sendsig(int signo_)
     char signo = signo_;
 	if (doencrypt)
 #ifdef NOENCRYPTION
-		(void)write(rfd2, &signo, 1);
+		write(rfd2, &signo, 1);
 #else
-		(void)des_enc_write(rfd2, &signo, 1, schedule, &cred.session);
+		des_enc_write(rfd2, &signo, 1, schedule, &cred.session);
 #endif
 	else
-		(void)write(rfd2, &signo, 1);
+		write(rfd2, &signo, 1);
+	SIGRETURN(0);
 }
 
 static void
-talk(int nflag, sigset_t omask, int pid, register int rem)
+talk(int nflag, sigset_t omask, int pid, int rem)
 {
-	register int cc, wc;
-	register char *bp;
+	int cc, wc;
+	char *bp;
 	fd_set readfrom, ready, rembits;
 	char buf[BUFSIZ];
 
@@ -116,7 +117,7 @@ talk(int nflag, sigset_t omask, int pid, register int rem)
 		if (nflag)
 			goto done;
 
-		(void)close(rfd2);
+		close(rfd2);
 
 reread:		errno = 0;
 		if ((cc = read(0, buf, sizeof buf)) <= 0)
@@ -127,7 +128,7 @@ rewrite:	FD_ZERO(&rembits);
 		FD_SET(rem, &rembits);
 		if (select(16, 0, &rembits, 0, 0) < 0) {
 			if (errno != EINTR) {
-				(void)fprintf(stderr,
+				fprintf(stderr,
 				    "rsh: select: %s.\n", strerror(errno));
 				exit(1);
 			}
@@ -154,7 +155,7 @@ rewrite:	FD_ZERO(&rembits);
 			goto reread;
 		goto rewrite;
 done:
-		(void)shutdown(rem, 1);
+		shutdown(rem, 1);
 		exit(0);
 	}
 
@@ -167,7 +168,7 @@ done:
 		ready = readfrom;
 		if (select(16, &ready, 0, 0, 0) < 0) {
 			if (errno != EINTR) {
-				(void)fprintf(stderr,
+				fprintf(stderr,
 				    "rsh: select: %s.\n", strerror(errno));
 				exit(1);
 			}
@@ -187,7 +188,7 @@ done:
 				if (errno != EWOULDBLOCK)
 					FD_CLR(rfd2, &readfrom);
 			} else
-				(void)write(2, buf, cc);
+				write(2, buf, cc);
 		}
 		if (FD_ISSET(rem, &ready)) {
 			errno = 0;
@@ -203,37 +204,11 @@ done:
 				if (errno != EWOULDBLOCK)
 					FD_CLR(rem, &readfrom);
 			} else
-				(void)write(1, buf, cc);
+				write(1, buf, cc);
 		}
 	} while (FD_ISSET(rfd2, &readfrom) || FD_ISSET(rem, &readfrom));
 }
 
-static int get_shell_port(int kerberos, int encryption)
-{
-  struct servent *sp;
-  char *service="shell";
-  int port=htons(514);
-
-  if(kerberos && encryption){
-    service="ekshell";
-    port=htons(545);
-  }
-  
-  if(kerberos && !encryption){
-    service="kshell";
-    port=htons(544);
-  }
-  
-  sp=getservbyname(service, "tcp");
-  if(sp == NULL){
-    fprintf(stderr, "rsh: can't get entry for %s service, using default port %d.\n",
-	    service, ntohs(port));
-  }else{
-    port=sp->s_port;
-  }
-  return port;
-}
-
 int
 main(int argc, char **argv)
 {
@@ -241,7 +216,7 @@ main(int argc, char **argv)
 	int sv_port;
 	sigset_t omask;
 	int argoff, asrsh, ch, dflag, nflag, nfork, one, pid, rem, uid;
-	register char *p;
+	char *p;
 	char *args, *host, *user;
 
 	argoff = asrsh = dflag = nflag = nfork = 0;
@@ -265,7 +240,7 @@ main(int argc, char **argv)
 		argoff = 1;
 	}
 
-#define	OPTIONS	"8KLde:k:l:nwx"
+#define	OPTIONS	"+8KLde:k:l:nwx"
 	while ((ch = getopt(argc - argoff, argv + argoff, OPTIONS)) != EOF)
 		switch(ch) {
 		case 'K':
@@ -306,16 +281,17 @@ main(int argc, char **argv)
 	if (!argv[optind]) {
 		if (asrsh)
 			*argv = "rlogin";
+		setuid(getuid());
 		execv(_PATH_RLOGIN, argv);
-		(void)fprintf(stderr, "rsh: can't exec %s.\n", _PATH_RLOGIN);
+		fprintf(stderr, "rsh: can't exec %s.\n", _PATH_RLOGIN);
 		exit(1);
 	}
 
 	argc -= optind;
 	argv += optind;
 
-	if (!(pw = getpwuid(uid = getuid()))) {
-		(void)fprintf(stderr, "rsh: unknown user id.\n");
+	if (!(pw = k_getpwuid(uid = getuid()))) {
+		fprintf(stderr, "rsh: unknown user id.\n");
 		exit(1);
 	}
 	if (!user)
@@ -353,7 +329,7 @@ try_connect:
 		}
 	} else {
 		if (doencrypt) {
-			(void)fprintf(stderr,
+			fprintf(stderr,
 			    "rsh: the -x flag requires Kerberos authentication.\n");
 			exit(1);
 		}
@@ -368,21 +344,21 @@ try_connect:
 		exit(1);
 
 	if (rfd2 < 0) {
-		(void)fprintf(stderr, "rsh: can't establish stderr.\n");
+		fprintf(stderr, "rsh: can't establish stderr.\n");
 		exit(1);
 	}
 	if (dflag) {
 		if (setsockopt(rem, SOL_SOCKET, SO_DEBUG, (void *)&one,
 		    sizeof(one)) < 0)
-			(void)fprintf(stderr, "rsh: setsockopt: %s.\n",
+			fprintf(stderr, "rsh: setsockopt: %s.\n",
 			    strerror(errno));
 		if (setsockopt(rfd2, SOL_SOCKET, SO_DEBUG, (void *)&one,
 		    sizeof(one)) < 0)
-			(void)fprintf(stderr, "rsh: setsockopt: %s.\n",
+			fprintf(stderr, "rsh: setsockopt: %s.\n",
 			    strerror(errno));
 	}
 
-	(void)setuid(uid);
+	setuid(uid);
 	{
 	    sigset_t sigmsk;
 	    sigemptyset(&sigmsk);
@@ -393,16 +369,16 @@ try_connect:
 	        perror("sigprocmask");
         }
 	if (signal(SIGINT, SIG_IGN) != SIG_IGN)
-		(void)signal(SIGINT, sendsig);
+		signal(SIGINT, sendsig);
 	if (signal(SIGQUIT, SIG_IGN) != SIG_IGN)
-		(void)signal(SIGQUIT, sendsig);
+		signal(SIGQUIT, sendsig);
 	if (signal(SIGTERM, SIG_IGN) != SIG_IGN)
-		(void)signal(SIGTERM, sendsig);
+		signal(SIGTERM, sendsig);
 
 	if (!nfork) {
 		pid = fork();
 		if (pid < 0) {
-			(void)fprintf(stderr,
+			fprintf(stderr,
 			    "rsh: fork: %s.\n", strerror(errno));
 			exit(1);
 		}
@@ -410,13 +386,13 @@ try_connect:
 
 	if (!doencrypt)
 	{
-		(void)ioctl(rfd2, FIONBIO, &one);
-		(void)ioctl(rem, FIONBIO, &one);
+		ioctl(rfd2, FIONBIO, &one);
+		ioctl(rem, FIONBIO, &one);
 	}
 
 	talk(nflag, omask, pid, rem);
 
 	if (!nflag)
-		(void)kill(pid, SIGKILL);
+		kill(pid, SIGKILL);
 	exit(0);
 }
