@@ -2,8 +2,7 @@
 
 #include "bsd_locl.h"
 
-RCSID("$Id: sysv_environ.c,v 1.15 1996/07/22 11:34:37 joda Exp $");
-
+RCSID("$Id: sysv_environ.c,v 1.18 1996/11/08 18:49:43 assar Exp $");
 
 #ifdef HAVE_ULIMIT_H
 #include <ulimit.h>
@@ -20,12 +19,12 @@ RCSID("$Id: sysv_environ.c,v 1.15 1996/07/22 11:34:37 joda Exp $");
  */
 
 static void
-read_etc_environment ()
+read_etc_environment (void)
 {
     FILE *f;
     char buf[BUFSIZ];
 
-    f = fopen("/etc/environment", "r");
+    f = fopen(_PATH_ETC_ENVIRONMENT, "r");
     if (f) {
 	char *val;
 
@@ -150,7 +149,10 @@ void sysv_newenv(int argc, char **argv, struct passwd *pwd,
     /* Undocumented: HOME, MAIL and LOGNAME are always reset (SunOS 5.1). */
 
     setenv("HOME", pwd->pw_dir, 1);
-    sprintf(buf, "%s/%s", KRB4_MAILDIR, pwd->pw_name);
+    strcpy (buf, KRB4_MAILDIR);
+    if (buf[strlen(buf) - 1] == '/')
+      buf[strlen(buf) - 1] = '\0';
+    sprintf(buf, "%s/%s", buf, pwd->pw_name);
     setenv("MAIL", buf, 1);
     setenv("LOGNAME", pwd->pw_name, 1);
     setenv("USER", pwd->pw_name, 1);
