@@ -1,5 +1,3 @@
-/*	$NetBSD: glob.c,v 1.5 1995/02/27 04:13:35 cgd Exp $	*/
-
 /*
  * Copyright (c) 1989, 1993
  *	The Regents of the University of California.  All rights reserved.
@@ -65,18 +63,30 @@
 #include <config.h>
 #endif
 
+#ifdef HAVE_SYS_PARAM_H
 #include <sys/param.h>
+#endif
+#ifdef HAVE_SYS_STAT_H
 #include <sys/stat.h>
+#endif
+#ifdef HAVE_SYS_TYPES_H
 #include <sys/types.h>
+#endif
 
 #include <ctype.h>
+#ifdef HAVE_DIRENT_H
 #include <dirent.h>
+#endif
 #include <errno.h>
+#ifdef HAVE_PWD_H
 #include <pwd.h>
+#endif
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#ifdef HAVE_UNISTD_H
 #include <unistd.h>
+#endif
 
 #include "glob.h"
 #include "roken.h"
@@ -354,7 +364,7 @@ globtilde(const Char *pattern, Char *patbuf, glob_t *pglob)
 		 * first and then trying the password file
 		 */
 		if ((h = getenv("HOME")) == NULL) {
-			if ((pwd = getpwuid(getuid())) == NULL)
+			if ((pwd = k_getpwuid(getuid())) == NULL)
 				return pattern;
 			else
 				h = pwd->pw_dir;
@@ -552,7 +562,7 @@ static int
 glob3(Char *pathbuf, Char *pathend, Char *pattern, Char *restpattern, 
       glob_t *pglob)
 {
-	register struct dirent *dp;
+	struct dirent *dp;
 	DIR *dirp;
 	int err;
 	char buf[MaxPathLen];
@@ -563,7 +573,7 @@ glob3(Char *pathbuf, Char *pathend, Char *pattern, Char *restpattern,
 	 * and dirent.h as taking pointers to differently typed opaque
 	 * structures.
 	 */
-	struct dirent *(*readdirfunc)();
+	struct dirent *(*readdirfunc)(void *);
 
 	*pathend = EOS;
 	errno = 0;
@@ -585,10 +595,10 @@ glob3(Char *pathbuf, Char *pathend, Char *pattern, Char *restpattern,
 	if (pglob->gl_flags & GLOB_ALTDIRFUNC)
 		readdirfunc = pglob->gl_readdir;
 	else
-		readdirfunc = readdir;
+		readdirfunc = (struct dirent *(*)(void *))readdir;
 	while ((dp = (*readdirfunc)(dirp))) {
-		register u_char *sc;
-		register Char *dc;
+		u_char *sc;
+		Char *dc;
 
 		/* Initial DOT must be matched literally. */
 		if (dp->d_name[0] == DOT && *pattern != DOT)
@@ -630,15 +640,15 @@ glob3(Char *pathbuf, Char *pathend, Char *pattern, Char *restpattern,
 static int
 globextend(const Char *path, glob_t *pglob)
 {
-	register char **pathv;
-	register int i;
+	char **pathv;
+	int i;
 	u_int newsize;
 	char *copy;
 	const Char *p;
 
 	newsize = sizeof(*pathv) * (2 + pglob->gl_pathc + pglob->gl_offs);
 	pathv = pglob->gl_pathv ? 
-		    realloc((char *)pglob->gl_pathv, newsize) :
+		    realloc(pglob->gl_pathv, newsize) :
 		    malloc(newsize);
 	if (pathv == NULL)
 		return(GLOB_NOSPACE);
@@ -716,8 +726,8 @@ match(Char *name, Char *pat, Char *patend)
 void
 globfree(glob_t *pglob)
 {
-	register int i;
-	register char **pp;
+	int i;
+	char **pp;
 
 	if (pglob->gl_pathv != NULL) {
 		pp = pglob->gl_pathv + pglob->gl_offs;
@@ -795,7 +805,7 @@ g_strcat(Char *dst, const Char *src)
 static void
 g_Ctoc(const Char *str, char *buf)
 {
-	register char *dc;
+	char *dc;
 
 	for (dc = buf; (*dc++ = *str++) != EOS;)
 		continue;
@@ -805,17 +815,17 @@ g_Ctoc(const Char *str, char *buf)
 static void 
 qprintf(const Char *str, Char *s)
 {
-	register Char *p;
+	Char *p;
 
-	(void)printf("%s:\n", str);
+	printf("%s:\n", str);
 	for (p = s; *p; p++)
-		(void)printf("%c", CHAR(*p));
-	(void)printf("\n");
+		printf("%c", CHAR(*p));
+	printf("\n");
 	for (p = s; *p; p++)
-		(void)printf("%c", *p & M_PROTECT ? '"' : ' ');
-	(void)printf("\n");
+		printf("%c", *p & M_PROTECT ? '"' : ' ');
+	printf("\n");
 	for (p = s; *p; p++)
-		(void)printf("%c", ismeta(*p) ? '_' : ' ');
-	(void)printf("\n");
+		printf("%c", ismeta(*p) ? '_' : ' ');
+	printf("\n");
 }
 #endif
