@@ -1,5 +1,3 @@
-/*      $NetBSD: extern.h,v 1.4 1995/09/08 01:06:19 tls Exp $      */
-
 /*-
  * Copyright (c) 1994 The Regents of the University of California.
  * All rights reserved.
@@ -35,11 +33,13 @@
  *	@(#)extern.h	8.3 (Berkeley) 10/9/94
  */
 
-/* $Id: extern.h,v 1.8 1996/08/26 22:46:23 assar Exp $ */
+/* $Id: extern.h,v 1.12 1996/10/26 16:03:09 bg Exp $ */
 
 #include <setjmp.h>
 #include <stdlib.h>
+#ifdef HAVE_SYS_TIME_H
 #include <sys/time.h>
+#endif
 #ifdef HAVE_SYS_SELECT_H
 #include <sys/select.h>
 #endif
@@ -55,7 +55,6 @@
 void    abort_remote __P((FILE *));
 void    abortpt __P((int));
 void    abortrecv __P((int));
-void    abortsend __P((int));
 void	account __P((int, char **));
 int	another __P((int *, char ***, char *));
 void	blkfree __P((char **));
@@ -90,9 +89,8 @@ int     initconn __P((void));
 void	intr __P((int));
 void	lcd __P((int, char **));
 int	login __P((char *));
-void	lostpeer __P((int));
+RETSIGTYPE	lostpeer __P((int));
 void	ls __P((int, char **));
-void	mabort __P((int));
 void	macdef __P((int, char **));
 void	makeargv __P((void));
 void	makedir __P((int, char **));
@@ -103,7 +101,6 @@ void	modtime __P((int, char **));
 void	mput __P((int, char **));
 char   *onoff __P((int));
 void	newer __P((int, char **));
-void	proxabort __P((int));
 void    proxtrans __P((char *, char *, char *));
 void    psabort __P((int));
 void    pswitch __P((int));
