@@ -1,6 +1,44 @@
+/*
+ * Copyright (c) 1995, 1996 Kungliga Tekniska Hgskolan (Royal Institute
+ * of Technology, Stockholm, Sweden).
+ * All rights reserved.
+ * 
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
+ * 
+ * 1. Redistributions of source code must retain the above copyright
+ *    notice, this list of conditions and the following disclaimer.
+ * 
+ * 2. Redistributions in binary form must reproduce the above copyright
+ *    notice, this list of conditions and the following disclaimer in the
+ *    documentation and/or other materials provided with the distribution.
+ * 
+ * 3. All advertising materials mentioning features or use of this software
+ *    must display the following acknowledgement:
+ *      This product includes software developed by the Kungliga Tekniska
+ *      Hgskolan and its contributors.
+ * 
+ * 4. Neither the name of the Institute nor the names of its contributors
+ *    may be used to endorse or promote products derived from this software
+ *    without specific prior written permission.
+ * 
+ * THIS SOFTWARE IS PROVIDED BY THE INSTITUTE AND CONTRIBUTORS ``AS IS'' AND
+ * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED.  IN NO EVENT SHALL THE INSTITUTE OR CONTRIBUTORS BE LIABLE
+ * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
+ * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
+ * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
+ * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
+ * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
+ * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
+ * SUCH DAMAGE.
+ */
+
 #include "ftp_locl.h"
 
-RCSID("$Id: krb4.c,v 1.10 1996/08/22 19:04:53 assar Exp $");
+RCSID("$Id: krb4.c,v 1.14 1996/10/27 16:49:52 joda Exp $");
 
 #include <des.h>
 #include <krb.h>
@@ -116,10 +154,8 @@ sec_prot_internal(int level)
 
 void sec_prot(int argc, char **argv)
 {
-    int s;
-    int ret;
-    char *p;
     int level = -1;
+
     if(argc != 2){
 	fprintf(stderr,
 		"usage: %s (clear | safe | confidential | private)\n",
@@ -134,7 +170,6 @@ void sec_prot(int argc, char **argv)
     }
     level = name_to_level(argv[1]);
     
-
     if(level == -1){
 	fprintf(stderr,
 		"usage: %s (clear | safe | confidential | private)\n",
@@ -340,7 +375,6 @@ sec_write(int fd, char *data, int length)
 {
     int len = auth_pbsz;
     int tx = 0;
-    int bytes;
       
     if(data_prot == prot_clear)
 	return write(fd, data, length);
@@ -384,13 +418,11 @@ int
 do_klogin(char *host)
 {
     int ret;
-    char *phost;
-    char *p, *q;
+    char *p;
     int len;
     char adat[1024];
     MSG_DAT msg_data;
     int checksum;
-    int tmp;
 
     int old_verbose = verbose;
 
