@@ -36,14 +36,14 @@
  */
 
 #include "ftp_locl.h"
-RCSID("$Id: main.c,v 1.9 1996/08/26 22:46:29 assar Exp $");
+RCSID("$Id: main.c,v 1.16 1996/11/24 08:37:21 joda Exp $");
 
 int
 main(int argc, char **argv)
 {
 	int ch, top;
 	struct passwd *pw = NULL;
-	char *cp, homedir[MaxPathLen];
+	char homedir[MaxPathLen];
 	struct servent *sp;
 
 	sp = getservbyname("ftp", "tcp");
@@ -81,7 +81,7 @@ main(int argc, char **argv)
 			break;
 
 		default:
-			(void)fprintf(stderr,
+			fprintf(stderr,
 				"usage: ftp [-dgintv] [host [port]]\n");
 			exit(1);
 		}
@@ -100,18 +100,18 @@ main(int argc, char **argv)
 	/*
 	 * Set up the home directory in case we're globbing.
 	 */
-	pw = getpwuid(getuid());
+	pw = k_getpwuid(getuid());
 	if (pw != NULL) {
 		home = homedir;
-		(void) strcpy(home, pw->pw_dir);
+		strcpy(home, pw->pw_dir);
 	}
 	if (argc > 0) {
 		char *xargv[5];
 
 		if (setjmp(toplevel))
 			exit(0);
-		(void) signal(SIGINT, intr);
-		(void) signal(SIGPIPE, lostpeer);
+		signal(SIGINT, intr);
+		signal(SIGPIPE, lostpeer);
 		xargv[0] = argv[0]; /* or should this be "ftp"? */
 		xargv[1] = argv[0];
 		xargv[2] = argv[1];
@@ -121,8 +121,8 @@ main(int argc, char **argv)
 	}
 	if (setjmp(toplevel) == 0) {
 	        top = 1;
-		(void) signal(SIGINT, intr);
-		(void) signal(SIGPIPE, lostpeer);
+		signal(SIGINT, intr);
+		signal(SIGPIPE, lostpeer);
 	} else
 	        top = 0;
 	for (;;) {
@@ -138,19 +138,19 @@ intr(int sig)
 	longjmp(toplevel, 1);
 }
 
-void
+RETSIGTYPE
 lostpeer(int sig)
 {
 
 	if (connected) {
 		if (cout != NULL) {
-			(void) shutdown(fileno(cout), 1+1);
-			(void) fclose(cout);
+			shutdown(fileno(cout), 1+1);
+			fclose(cout);
 			cout = NULL;
 		}
 		if (data >= 0) {
-			(void) shutdown(data, 1+1);
-			(void) close(data);
+			shutdown(data, 1+1);
+			close(data);
 			data = -1;
 		}
 		connected = 0;
@@ -158,14 +158,15 @@ lostpeer(int sig)
 	pswitch(1);
 	if (connected) {
 		if (cout != NULL) {
-			(void) shutdown(fileno(cout), 1+1);
-			(void) fclose(cout);
+			shutdown(fileno(cout), 1+1);
+			fclose(cout);
 			cout = NULL;
 		}
 		connected = 0;
 	}
 	proxflag = 0;
 	pswitch(0);
+	SIGRETURN(0);
 }
 
 /*
@@ -187,62 +188,92 @@ tail(filename)
 }
 */
 
+#ifndef HAVE_READLINE
+
+static char *
+readline(char *prompt)
+{
+    char buf[BUFSIZ];
+    printf ("%s", prompt);
+    fflush (stdout);
+    if(fgets(buf, sizeof(buf), stdin) == NULL)
+	return NULL;
+    if (buf[strlen(buf) - 1] == '\n')
+	buf[strlen(buf) - 1] = '\0';
+    return strdup(buf);
+}
+
+static void
+add_history(char *p)
+{
+}
+
+#endif
+
 /*
  * Command parser.
  */
 void
 cmdscanner(int top)
 {
-	struct cmd *c;
-	int l;
+    struct cmd *c;
+    int l;
 
-	if (!top)
-		(void) putchar('\n');
-	for (;;) {
-		if (fromatty) {
-			printf("ftp> ");
-			(void) fflush(stdout);
-		}
-		if (fgets(line, sizeof line, stdin) == NULL)
-			quit(0, 0);
-		l = strlen(line);
-		if (l == 0)
-			break;
-		if (line[--l] == '\n') {
-			if (l == 0)
-				break;
-			line[l] = '\0';
-		} else if (l == sizeof(line) - 2) {
-			printf("sorry, input line too long\n");
-			while ((l = getchar()) != '\n' && l != EOF)
-				/* void */;
-			break;
-		} /* else it was a line without a newline */
-		makeargv();
-		if (margc == 0) {
-			continue;
-		}
-		c = getcmd(margv[0]);
-		if (c == (struct cmd *)-1) {
-			printf("?Ambiguous command\n");
-			continue;
-		}
-		if (c == 0) {
-			printf("?Invalid command\n");
-			continue;
-		}
-		if (c->c_conn && !connected) {
-			printf("Not connected.\n");
-			continue;
-		}
-		(*c->c_handler)(margc, margv);
-		if (bell && c->c_bell)
-			(void) putchar('\007');
-		if (c->c_handler != help)
-			break;
+    if (!top)
+	putchar('\n');
+    for (;;) {
+	if (fromatty) {
+	    char *p;
+	    p = readline("ftp> ");
+	    if(p == NULL)
+		quit(0, 0);
+	    strncpy(line, p, sizeof(line));
+	    line[sizeof(line) - 1] = 0;
+	    add_history(p);
+	    free(p);
+	} else{
+	    if (fgets(line, sizeof line, stdin) == NULL)
+		quit(0, 0);
 	}
-	(void) signal(SIGINT, intr);
-	(void) signal(SIGPIPE, lostpeer);
+	/* XXX will break on long lines */
+	l = strlen(line);
+	if (l == 0)
+	    break;
+	if (line[--l] == '\n') {
+	    if (l == 0)
+		break;
+	    line[l] = '\0';
+	} else if (l == sizeof(line) - 2) {
+	    printf("sorry, input line too long\n");
+	    while ((l = getchar()) != '\n' && l != EOF)
+		/* void */;
+	    break;
+	} /* else it was a line without a newline */
+	makeargv();
+	if (margc == 0) {
+	    continue;
+	}
+	c = getcmd(margv[0]);
+	if (c == (struct cmd *)-1) {
+	    printf("?Ambiguous command\n");
+	    continue;
+	}
+	if (c == 0) {
+	    printf("?Invalid command\n");
+	    continue;
+	}
+	if (c->c_conn && !connected) {
+	    printf("Not connected.\n");
+	    continue;
+	}
+	(*c->c_handler)(margc, margv);
+	if (bell && c->c_bell)
+	    putchar('\007');
+	if (c->c_handler != help)
+	    break;
+    }
+    signal(SIGINT, intr);
+    signal(SIGPIPE, lostpeer);
 }
 
 struct cmd *
@@ -255,7 +286,7 @@ getcmd(char *name)
 	longest = 0;
 	nmatches = 0;
 	found = 0;
-	for (c = cmdtab; p = c->c_name; c++) {
+	for (c = cmdtab; (p = c->c_name); c++) {
 		for (q = name; *q == *p++; q++)
 			if (*q == 0)		/* exact match? */
 				return (c);
@@ -427,7 +458,7 @@ OUT:
 		default:
 			break;
 	}
-	return ((char *)0);
+	return NULL;
 }
 
 #define HELPINDENT ((int) sizeof ("directory"))
@@ -465,7 +496,7 @@ help(int argc, char **argv)
 				}
 				else if (c->c_name) {
 					for (k=0; k < strlen(c->c_name); k++) {
-						(void) putchar(' ');
+						putchar(' ');
 					}
 				}
 				if (c + lines >= &cmdtab[NCMDS]) {
@@ -475,7 +506,7 @@ help(int argc, char **argv)
 				w = strlen(c->c_name);
 				while (w < width) {
 					w = (w + 8) &~ 7;
-					(void) putchar('\t');
+					putchar('\t');
 				}
 			}
 		}
