@@ -1,5 +1,3 @@
-/*	$NetBSD: extern.h,v 1.2 1995/04/11 02:44:49 cgd Exp $	*/
-
 /*-
  * Copyright (c) 1992, 1993
  *	The Regents of the University of California.  All rights reserved.
@@ -38,22 +36,28 @@
 #ifndef _EXTERN_H_
 #define _EXTERN_H_
 
+#ifdef HAVE_NETINET_IN_H
 #include <netinet/in.h>
+#endif
+#ifdef HAVE_NETDB_H
 #include <netdb.h>
+#endif
 
 #include <stdio.h>
 #include <stdarg.h>
 #include <setjmp.h>
+#ifdef HAVE_PWD_H
 #include <pwd.h>
+#endif
 
 void	blkfree(char **);
 char  **copyblk(char **);
 void	cwd(char *);
-void	delete(char *);
+void	do_delete(char *);
 void	dologout(int);
 void	fatal(char *);
 int	ftpd_pclose(FILE *);
-FILE   *ftpd_popen(char *, char *);
+FILE   *ftpd_popen(char *, char *, int, int);
 char   *getline(char *, int);
 void	logwtmp(char *, char *, char *);
 void	lreply(int, const char *, ...);
@@ -72,14 +76,20 @@ void	send_file_list(char *);
 void	setproctitle(const char *, ...);
 void	statcmd(void);
 void	statfilecmd(char *);
-void	store(char *, char *, int);
+void	do_store(char *, char *, int);
 void	upper(char *);
 void	user(char *);
 void	yyerror(char *);
 
 void	kauth(char *, char*);
+void	klist(void);
 
-int klogin(char *name, char *password);
+int	find(char *);
+
+int	do_login(int code, char *passwd);
+int	klogin(char *name, char *password);
+
+const char *ftp_rooted(const char *path);
 
 extern struct sockaddr_in ctrl_addr, his_addr;
 extern char hostname[];
