@@ -1,5 +1,3 @@
-/*	$NetBSD: ftpd.c,v 1.15 1995/06/03 22:46:47 mycroft Exp $	*/
-
 /*
  * Copyright (c) 1985, 1988, 1990, 1992, 1993, 1994
  *	The Regents of the University of California.  All rights reserved.
@@ -35,25 +33,47 @@
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
-RCSID("$Id: ftpd.c,v 1.31 1996/08/24 23:30:05 assar Exp $");
+RCSID("$Id: ftpd.c,v 1.60 1996/11/21 20:02:54 assar Exp $");
+#endif
+
+#ifdef SOCKS
+#include <socks.h>
 #endif
 
 /*
  * FTP server.
  */
+#ifdef HAVE_SYS_PARAM_H
 #include <sys/param.h>
+#endif
+#ifdef HAVE_SYS_STAT_H
 #include <sys/stat.h>
+#endif
+#ifdef HAVE_SYS_IOCTL_H
 #include <sys/ioctl.h>
+#endif
+#ifdef HAVE_SYS_SOCKET_H
 #include <sys/socket.h>
+#endif
+#ifdef HAVE_SYS_TIME_H
 #include <sys/time.h>
+#endif
 #ifdef HAVE_SYS_RESOURCE_H
 #include <sys/resource.h>
 #endif
+#ifdef HAVE_SYS_WAIT_H
 #include <sys/wait.h>
+#endif
 
+#ifdef HAVE_NETINET_IN_H
 #include <netinet/in.h>
+#endif
+#ifdef HAVE_NETINET_IN_SYSTM_H
 #include <netinet/in_systm.h>
+#endif
+#ifdef HAVE_NETINET_IP_H
 #include <netinet/ip.h>
+#endif
 
 #ifdef HAVE_SYS_MMAN_H
 #include <sys/mman.h>
@@ -61,27 +81,44 @@ RCSID("$Id: ftpd.c,v 1.31 1996/08/24 23:30:05 assar Exp $");
 
 #define	FTP_NAMES
 #include <arpa/ftp.h>
+#ifdef HAVE_ARPA_INET_H
 #include <arpa/inet.h>
+#endif
+#ifdef HAVE_ARPA_TELNET_H
 #include <arpa/telnet.h>
+#endif
 
 #include <ctype.h>
+#ifdef HAVE_DIRENT_H
 #include <dirent.h>
+#endif
 #include <errno.h>
+#ifdef HAVE_FCNTL_H
 #include <fcntl.h>
+#endif
 #include <glob.h>
 #include <limits.h>
+#ifdef HAVE_PWD_H
 #include <pwd.h>
+#endif
 #include <setjmp.h>
 #include <signal.h>
 #include <stdio.h>
 #include <stdlib.h>
-#include <string.h>
-#include <syslog.h>
-#include <time.h>
-#include <unistd.h>
-#include <grp.h>
-
 #include <stdarg.h>
+#include <string.h>
+#ifdef HAVE_SYSLOG_H
+#include <syslog.h>
+#endif
+#include <time.h>
+#ifdef HAVE_UNISTD_H
+#include <unistd.h>
+#endif
+#ifdef HAVE_GRP_H
+#include <grp.h>
+#endif
+
+#include <err.h>
 
 #include "pathnames.h"
 #include "extern.h"
@@ -93,23 +130,14 @@ RCSID("$Id: ftpd.c,v 1.31 1996/08/24 23:30:05 assar Exp $");
 #include <kafs.h>
 #include "roken.h"
 
-#if defined(SKEY)
-#include <skey.h>
-#endif
+#include <otp.h>
 
 void yyparse();
 
-extern char *optarg;
-extern int optind, opterr;
-
 #ifndef LOG_FTP
 #define LOG_FTP LOG_DAEMON
 #endif
 
-#ifndef LOG_DAEMON
-#define openlog(id,option,facility) openlog((id),(option))
-#endif
-
 static char version[] = "Version 6.00";
 
 extern	off_t restart_point;
@@ -150,20 +178,12 @@ char	tmpline[10240];
 char	hostname[MaxHostNameLen];
 char	remotehost[MaxHostNameLen];
 static char ttyline[20];
-char	*tty = ttyline;		/* for klogin */
 
-/* Default level for security, 0 allow any kind of connection, 1 only
-   authorized and anonymous connections, 2 only authorized */
-static int auth_level = 1;
+#define AUTH_PLAIN	(1 << 0) /* allow sending passwords */
+#define AUTH_OTP	(1 << 1) /* passwords are one-time */
+#define AUTH_FTP	(1 << 2) /* allow anonymous login */
 
-#ifdef sun
-extern char *optarg;
-extern int optind, opterr;
-
-int fclose(FILE*);
-#endif
-
-char *getusershell(void);
+static int auth_level = 0; /* Only allow kerberos login by default */
 
 /*
  * Timeout intervals for retrying connections
@@ -207,10 +227,10 @@ static void	 dolog (struct sockaddr_in *);
 static void	 end_login (void);
 static FILE	*getdatasock (char *);
 static char	*gunique (char *);
-static void	 lostconn (int);
+static RETSIGTYPE	 lostconn (int);
 static int	 receive_data (FILE *, FILE *);
 static void	 send_data (FILE *, FILE *, off_t);
-static struct passwd * sk_getpwnam (char *);
+static struct passwd * sgetpwnam (char *);
 
 static char *
 curdir(void)
@@ -229,25 +249,31 @@ curdir(void)
 #define LINE_MAX 1024
 #endif
 
-static void conn_wait(int port)
+static int
+parse_auth_level(char *str)
 {
-    int s, t;
-    struct sockaddr_in sa;
-    int one = 1;
-    s = socket(AF_INET, SOCK_STREAM, 0);
+    char *p;
+    int ret = 0;
+    char *foo;
 
-    setsockopt(s, SOL_SOCKET, SO_REUSEADDR, (char *)&one, sizeof(one));
-    memset(&sa, 0, sizeof(sa));
-    sa.sin_port = port; /* in network byteorder */
-    sa.sin_addr.s_addr = INADDR_ANY;
-    bind(s, (struct sockaddr*)&sa, sizeof(sa));
-    listen(s, 5);
-    t = accept(s, NULL, 0);
-    close(s);
-    dup2(t, 0);
-    dup2(t, 1);
-    if(t > 2)
-	close(t);
+    for(p = strtok_r(str, ",", &foo);
+	p;
+	p = strtok_r(NULL, ",", &foo)) {
+	if(strcmp(p, "user") == 0)
+	    ;
+	else if(strcmp(p, "otp") == 0)
+	    ret |= AUTH_PLAIN|AUTH_OTP;
+	else if(strcmp(p, "ftp") == 0 ||
+		strcmp(p, "safe") == 0)
+	    ret |= AUTH_FTP;
+	else if(strcmp(p, "plain") == 0)
+	    ret |= AUTH_PLAIN;
+	else if(strcmp(p, "none") == 0)
+	    ret |= AUTH_PLAIN|AUTH_FTP;
+	else
+	    warnx("bad value for -a");
+    }
+    return ret;	    
 }
 
 int
@@ -265,7 +291,7 @@ main(int argc, char **argv)
 
 	/* detach from any tickets and tokens */
 
-	sprintf(tkfile, "/tmp/ftp_%d", getpid());
+	sprintf(tkfile, "/tmp/ftp_%u", (unsigned int)getpid());
 	krb_set_tkt_string(tkfile);
 	if(k_hasafs())
 	    k_setpag();
@@ -279,17 +305,8 @@ main(int argc, char **argv)
 	while ((ch = getopt(argc, argv, "a:dilp:t:T:u:v")) != EOF) {
 		switch (ch) {
 		case 'a':
-		{
-		    if(strcmp(optarg, "none") == 0)
-			auth_level = 0;
-		    else if(strcmp(optarg, "safe") == 0)
-			auth_level = 1;
-		    else if(strcmp(optarg, "user") == 0)
-			auth_level = 2;
-		    else
-			warnx("bad value for -a");
+		    auth_level = parse_auth_level(optarg);
 		    break;
-		}
 		case 'd':
 			debug = 1;
 			break;
@@ -347,7 +364,7 @@ main(int argc, char **argv)
 	}
 
 	if(not_inetd)
-	    conn_wait(port);
+	    mini_inetd (port);
 
 
 	/*
@@ -367,27 +384,28 @@ main(int argc, char **argv)
 	}
 #ifdef IP_TOS
 	tos = IPTOS_LOWDELAY;
-	if (setsockopt(0, IPPROTO_IP, IP_TOS, (char *)&tos, sizeof(int)) < 0)
+	if (setsockopt(0, IPPROTO_IP, IP_TOS, (void *)&tos, sizeof(int)) < 0)
 		syslog(LOG_WARNING, "setsockopt (IP_TOS): %m");
 #endif
 	data_source.sin_port = htons(ntohs(ctrl_addr.sin_port) - 1);
 	debug = 0;
 
-	/* set this here so klogin can use it... */
-	(void)sprintf(ttyline, "ftp%d", getpid());
+	/* set this here so it can be put in wtmp */
+	sprintf(ttyline, "ftp%u", (unsigned)getpid());
 
 
-	/*	(void) freopen(_PATH_DEVNULL, "w", stderr); */
-	(void) signal(SIGPIPE, lostconn);
-	(void) signal(SIGCHLD, SIG_IGN);
-	if ((long)signal(SIGURG, myoob) < 0)
-		syslog(LOG_ERR, "signal: %m");
+	/*	freopen(_PATH_DEVNULL, "w", stderr); */
+	signal(SIGPIPE, lostconn);
+	signal(SIGCHLD, SIG_IGN);
+	if (signal(SIGURG, myoob) == SIG_ERR)
+	    syslog(LOG_ERR, "signal: %m");
 
 	auth_init();
 
 	/* Try to handle urgent data inline */
 #ifdef SO_OOBINLINE
-	if (setsockopt(0, SOL_SOCKET, SO_OOBINLINE, (char *)&on, sizeof(on)) < 0)
+	if (setsockopt(0, SOL_SOCKET, SO_OOBINLINE, (void *)&on,
+		       sizeof(on)) < 0)
 		syslog(LOG_ERR, "setsockopt: %m");
 #endif
 
@@ -413,8 +431,8 @@ main(int argc, char **argv)
 				*cp = '\0';
 			lreply(530, "%s", line);
 		}
-		(void) fflush(stdout);
-		(void) fclose(fd);
+		fflush(stdout);
+		fclose(fd);
 		reply(530, "System not available.");
 		exit(0);
 	}
@@ -424,19 +442,20 @@ main(int argc, char **argv)
 				*cp = '\0';
 			lreply(220, "%s", line);
 		}
-		(void) fflush(stdout);
-		(void) fclose(fd);
+		fflush(stdout);
+		fclose(fd);
 		/* reply(220,) must follow */
 	}
-	(void) gethostname(hostname, sizeof(hostname));
-	reply(220, "%s FTP server (%s) ready.", hostname, version);
-	(void) setjmp(errcatch);
+	k_gethostname(hostname, sizeof(hostname));
+	reply(220, "%s FTP server (%s+%s) ready.", hostname, 
+	      version, krb4_version);
+	setjmp(errcatch);
 	for (;;)
-		(void) yyparse();
+	    yyparse();
 	/* NOTREACHED */
 }
 
-static void
+static RETSIGTYPE
 lostconn(int signo)
 {
 
@@ -458,7 +477,7 @@ sgetsave(char *s)
 		dologout(1);
 		/* NOTREACHED */
 	}
-	(void) strcpy(new, s);
+	strcpy(new, s);
 	return (new);
 }
 
@@ -494,10 +513,7 @@ sgetpwnam(char *name)
 static int login_attempts;	/* number of failed login attempts */
 static int askpasswd;		/* had user command, ask for passwd */
 static char curname[10];	/* current USER name */
-#ifdef SKEY
-static struct skey sk;
-static int permit_passwd;
-#endif /* SKEY */
+OtpContext otp_ctx;
 
 /*
  * USER command.
@@ -515,7 +531,7 @@ user(char *name)
 {
 	char *cp, *shell;
 
-	if(auth_level == 2 && !auth_complete){
+	if(auth_level == 0 && !auth_complete){
 	    reply(530, "No login allowed without authorization.");
 	    return;
 	}
@@ -533,11 +549,13 @@ user(char *name)
 
 	guest = 0;
 	if (strcmp(name, "ftp") == 0 || strcmp(name, "anonymous") == 0) {
-	    if (checkuser(_PATH_FTPUSERS, "ftp") ||
+	    if ((auth_level & AUTH_FTP) == 0 || 
+		checkuser(_PATH_FTPUSERS, "ftp") ||
 		checkuser(_PATH_FTPUSERS, "anonymous"))
 		reply(530, "User %s access denied.", name);
 	    else if ((pw = sgetpwnam("ftp")) != NULL) {
 		guest = 1;
+		defumask = 0777; /* paranoia for incoming directories */
 		askpasswd = 1;
 		reply(331, "Guest login ok, type your name as password.");
 	    } else
@@ -547,7 +565,7 @@ user(char *name)
 		       "ANONYMOUS FTP LOGIN REFUSED FROM %s", remotehost);
 	    return;
 	}
-	if(auth_level == 1 && !auth_complete){
+	if((auth_level & AUTH_PLAIN) == 0 && !auth_complete){
 	    reply(530, "Only authorized and anonymous login allowed.");
 	    return;
 	}
@@ -574,29 +592,32 @@ user(char *name)
 	if(auth_ok())
 		ct->userok(name);
 	else {
-#ifdef SKEY
 		char ss[256];
 
-		permit_passwd = skeyaccess(k_getpwnam (name), NULL,
-					   remotehost, NULL);
-
-		if (skeychallenge (&sk, name, ss) == 0) {
-			reply (331, "Password [%s] for %s required.",
-			       ss, name);
-			askpasswd = 1;
-		} else if (permit_passwd)
-#endif
-		{
-			reply(331, "Password required for %s.", name);
+		if (otp_challenge(&otp_ctx, name, ss, sizeof(ss)) == 0) {
+			reply(331, "Password %s for %s required.",
+			      ss, name);
 			askpasswd = 1;
+		} else if ((auth_level & AUTH_OTP) == 0) {
+		    reply(331, "Password required for %s.", name);
+		    askpasswd = 1;
+		} else {
+		    char *s;
+		    
+		    if (s = otp_error (&otp_ctx))
+			lreply(530, "OTP: %s", s);
+		    reply(530,
+			  "Only authorized, anonymous and OTP "
+			  "login allowed.");
 		}
+
 	}
 	/*
 	 * Delay before reading passwd after first failed
 	 * attempt to slow down passwd-guessing programs.
 	 */
 	if (login_attempts)
-		sleep((unsigned) login_attempts);
+		sleep(login_attempts);
 }
 
 /*
@@ -620,7 +641,7 @@ checkuser(char *fname, char *name)
 					break;
 				}
 			}
-		(void) fclose(fd);
+		fclose(fd);
 	}
 	return (found);
 }
@@ -633,7 +654,7 @@ int do_login(int code, char *passwd)
 		reply(550, "Can't set gid.");
 		return -1;
 	}
-	(void) initgroups(pw->pw_name, pw->pw_gid);
+	initgroups(pw->pw_name, pw->pw_gid);
 
 	/* open wtmp before chroot */
 	logwtmp(ttyline, pw->pw_name, remotehost);
@@ -701,7 +722,7 @@ int do_login(int code, char *passwd)
 			syslog(LOG_INFO, "FTP LOGIN FROM %s as %s",
 			    remotehost, pw->pw_name);
 	}
-	(void) umask(defumask);
+	umask(defumask);
 	return 0;
 }
 
@@ -714,7 +735,7 @@ static void
 end_login(void)
 {
 
-	(void) seteuid((uid_t)0);
+	seteuid((uid_t)0);
 	if (logged_in)
 		logwtmp(ttyline, "", "");
 	pw = NULL;
@@ -727,6 +748,7 @@ void
 pass(char *passwd)
 {
 	int rval;
+
 	/* some clients insists on sending a password */
 	if (logged_in && askpasswd == 0){
 	     reply(230, "Dumpucko!");
@@ -738,33 +760,27 @@ pass(char *passwd)
 		return;
 	}
 	askpasswd = 0;
+	rval = 1;
 	if (!guest) {		/* "ftp" is only account allowed no password */
-		if (pw == NULL) {
+		if (pw == NULL)
 			rval = 1;	/* failure below */
-			goto skip;
+		else if (otp_verify_user (&otp_ctx, passwd) == 0) {
+		    rval = 0;
+		} else if((auth_level & AUTH_OTP) == 0) {
+		    char realm[REALM_SZ];
+		    if((rval = krb_get_lrealm(realm, 1)) == KSUCCESS)
+			rval = krb_verify_user(pw->pw_name, "", realm, 
+					       passwd, 1, NULL);
+		    if (rval != 0 )
+			rval = unix_verify_user(pw->pw_name, passwd);
+		} else {
+		    char *s;
+		    
+		    if (s = otp_error(&otp_ctx))
+			lreply(530, "OTP: %s", s);
 		}
-#ifdef SKEY
-		if (skeyverify (&sk, passwd) == 0) {
-			rval = 0;
-			goto skip;
-		} else if(!permit_passwd) {
-			rval = 1;
-			goto skip;
-		}
-#endif
-		rval = klogin(pw->pw_name, passwd);
-		if (rval == 0)
-			goto skip;
+		memset (passwd, 0, strlen(passwd));
 
-		/* the strcmp does not catch null passwords! */
-		if (pw == NULL || *pw->pw_passwd == 0 ||
-		    strcmp((char*)crypt(passwd, pw->pw_passwd), pw->pw_passwd)){
-		    rval = 1;	 /* failure */
-		    goto skip;
-		}
-		rval = 0;
-
-skip:
 		/*
 		 * If rval == 1, the user failed the authentication check
 		 * above.  If rval == 0, either Kerberos or local authentication
@@ -800,7 +816,7 @@ set_buffer_size(int fd, int read)
     size_t size = 1048576;
     while(size >= 131072 && 
 	  setsockopt(fd, SOL_SOCKET, read ? SO_RCVBUF : SO_SNDBUF, 
-		     (char*)&size, sizeof(size)) < 0)
+		     (void *)&size, sizeof(size)) < 0)
 	size /= 2;
 #endif
 }
@@ -809,18 +825,60 @@ set_buffer_size(int fd, int read)
 void
 retrieve(char *cmd, char *name)
 {
-	FILE *fin, *dout;
+	FILE *fin = NULL, *dout;
 	struct stat st;
 	int (*closefunc) (FILE *);
+	char line[BUFSIZ];
+
 
 	if (cmd == 0) {
-		fin = fopen(name, "r"), closefunc = fclose;
+		fin = fopen(name, "r");
+		closefunc = fclose;
 		st.st_size = 0;
+		if(fin == NULL){
+		    struct cmds {
+			char *ext;
+			char *cmd;
+		    } cmds[] = {
+		        /* XXX  - make this more general */
+			{".tar", "/bin/gtar cPf - "},
+			{".tar.gz", "/bin/gtar zcPf - "},
+			{".tar.Z", "/bin/gtar ZcPf - "},
+			{".gz", "/bin/gzip -c "},
+			{".Z", "/bin/compress -c "},
+			{NULL, NULL}
+		    };
+		    struct cmds *p;
+		    for(p = cmds; p->ext; p++){
+			char *tail = name + strlen(name) - strlen(p->ext);
+			
+			if(strcmp(tail, p->ext) == 0){
+			    strncpy(line, p->cmd, sizeof(line));
+			    line[sizeof(line) - 1] = '\0';
+			    strncat(line, name, sizeof(line)-strlen(line));
+			    line[sizeof(line) - 1] = '\0';
+			    line[strlen(line) - strlen(p->ext)] = 0; 
+#if 0
+			    sprintf(line, p->cmd, name);
+			    /* XXX */
+#endif
+			    break;
+			}
+		    }
+		    if(p->ext){
+			fin = ftpd_popen(line, "r", 0, 0);
+			closefunc = ftpd_pclose;
+			st.st_size = -1;
+#ifdef HAVE_ST_BLKSIZE
+			st.st_blksize = BUFSIZ;
+			cmd = line;
+#endif
+		    }
+		}
 	} else {
-		char line[BUFSIZ];
-
-		(void) sprintf(line, cmd, name), name = line;
-		fin = ftpd_popen(line, "r"), closefunc = ftpd_pclose;
+		sprintf(line, cmd, name), name = line;
+		fin = ftpd_popen(line, "r", 1, 0);
+		closefunc = ftpd_pclose;
 		st.st_size = -1;
 #ifdef HAVE_ST_BLKSIZE
 		st.st_blksize = BUFSIZ;
@@ -869,7 +927,7 @@ retrieve(char *cmd, char *name)
 #else
 	send_data(fin, dout, BUFSIZ);
 #endif
-	(void) fclose(dout);
+	fclose(dout);
 	data = -1;
 	pdata = -1;
 done:
@@ -880,11 +938,10 @@ done:
 
 /* filename sanity check */
 
-static const char good_chars[] = "+-=_,.";
-
 int 
 filename_check(char *filename)
 {
+  static const char good_chars[] = "+-=_,.";
     char *p;
 
     p = strrchr(filename, '/');
@@ -909,13 +966,13 @@ filename_check(char *filename)
 }
 
 void
-store(char *name, char *mode, int unique)
+do_store(char *name, char *mode, int unique)
 {
 	FILE *fout, *din;
 	struct stat st;
 	int (*closefunc) (FILE *);
 
-	if(filename_check(name))
+	if(guest && filename_check(name))
 	    return;
 	if (unique && stat(name, &st) == 0 &&
 	    (name = gunique(name)) == NULL) {
@@ -973,7 +1030,7 @@ store(char *name, char *mode, int unique)
 		else
 			reply(226, "Transfer complete.");
 	}
-	(void) fclose(din);
+	fclose(din);
 	data = -1;
 	pdata = -1;
 done:
@@ -988,12 +1045,12 @@ getdatasock(char *mode)
 
 	if (data >= 0)
 		return (fdopen(data, mode));
-	(void) seteuid((uid_t)0);
+	seteuid((uid_t)0);
 	s = socket(AF_INET, SOCK_STREAM, 0);
 	if (s < 0)
 		goto bad;
 	if (setsockopt(s, SOL_SOCKET, SO_REUSEADDR,
-	    (char *) &on, sizeof(on)) < 0)
+	    (void *) &on, sizeof(on)) < 0)
 		goto bad;
 	/* anchor socket to avoid multi-homing problems */
 	data_source.sin_family = AF_INET;
@@ -1006,18 +1063,18 @@ getdatasock(char *mode)
 			goto bad;
 		sleep(tries);
 	}
-	(void) seteuid((uid_t)pw->pw_uid);
+	seteuid((uid_t)pw->pw_uid);
 #ifdef IP_TOS
 	on = IPTOS_THROUGHPUT;
-	if (setsockopt(s, IPPROTO_IP, IP_TOS, (char *)&on, sizeof(int)) < 0)
+	if (setsockopt(s, IPPROTO_IP, IP_TOS, (void *)&on, sizeof(int)) < 0)
 		syslog(LOG_WARNING, "setsockopt (IP_TOS): %m");
 #endif
 	return (fdopen(s, mode));
 bad:
 	/* Return the real value of errno (close may change it) */
 	t = errno;
-	(void) seteuid((uid_t)pw->pw_uid);
-	(void) close(s);
+	seteuid((uid_t)pw->pw_uid);
+	close(s);
 	errno = t;
 	return (NULL);
 }
@@ -1032,9 +1089,9 @@ dataconn(char *name, off_t size, char *mode)
 	file_size = size;
 	byte_count = 0;
 	if (size != (off_t) -1)
-		(void) sprintf(sizebuf, " (%ld bytes)", size);
+		sprintf(sizebuf, " (%ld bytes)", size);
 	else
-		(void) strcpy(sizebuf, "");
+		strcpy(sizebuf, "");
 	if (pdata >= 0) {
 		struct sockaddr_in from;
 		int s, fromlen = sizeof(from);
@@ -1042,15 +1099,15 @@ dataconn(char *name, off_t size, char *mode)
 		s = accept(pdata, (struct sockaddr *)&from, &fromlen);
 		if (s < 0) {
 			reply(425, "Can't open data connection.");
-			(void) close(pdata);
+			close(pdata);
 			pdata = -1;
 			return (NULL);
 		}
-		(void) close(pdata);
+		close(pdata);
 		pdata = s;
 #ifdef IP_TOS
 		tos = IPTOS_THROUGHPUT;
-		(void) setsockopt(s, IPPROTO_IP, IP_TOS, (char *)&tos,
+		setsockopt(s, IPPROTO_IP, IP_TOS, (void *)&tos,
 		    sizeof(int));
 #endif
 		reply(150, "Opening %s mode data connection for '%s'%s.",
@@ -1082,7 +1139,7 @@ dataconn(char *name, off_t size, char *mode)
 			continue;
 		}
 		perror_reply(425, "Can't build data connection");
-		(void) fclose(file);
+		fclose(file);
 		data = -1;
 		return (NULL);
 	}
@@ -1295,27 +1352,27 @@ statfilecmd(char *filename)
 	int c;
 	char line[LINE_MAX];
 
-	sprintf(line, "/bin/ls -lA %s", filename);
-	fin = ftpd_popen(line, "r");
+	sprintf(line, "/bin/ls -la %s", filename);
+	fin = ftpd_popen(line, "r", 1, 0);
 	lreply(211, "status of %s:", filename);
 	while ((c = getc(fin)) != EOF) {
 		if (c == '\n') {
 			if (ferror(stdout)){
 				perror_reply(421, "control connection");
-				(void) ftpd_pclose(fin);
+				ftpd_pclose(fin);
 				dologout(1);
 				/* NOTREACHED */
 			}
 			if (ferror(fin)) {
 				perror_reply(551, filename);
-				(void) ftpd_pclose(fin);
+				ftpd_pclose(fin);
 				return;
 			}
-			(void) putc('\r', stdout);
+			putc('\r', stdout);
 		}
-		(void) putc(c, stdout);
+		putc(c, stdout);
 	}
-	(void) ftpd_pclose(fin);
+	ftpd_pclose(fin);
 	reply(211, "End of Status");
 }
 
@@ -1390,8 +1447,10 @@ int_reply(int n, char *c, const char *fmt, va_list ap)
   char buf[10240];
   char *p;
   p=buf;
-  sprintf(p, "%d%s", n, c);
-  p+=strlen(p);
+  if(n){
+      sprintf(p, "%d%s", n, c);
+      p+=strlen(p);
+  }
   vsprintf(p, fmt, ap);
   p+=strlen(p);
   sprintf(p, "\r\n");
@@ -1421,6 +1480,15 @@ lreply(int n, const char *fmt, ...)
   va_end(ap);
 }
 
+void
+nreply(const char *fmt, ...)
+{
+  va_list ap;
+  va_start(ap, fmt);
+  int_reply(0, NULL, fmt, ap);
+  va_end(ap);
+}
+
 static void
 ack(char *s)
 {
@@ -1447,7 +1515,7 @@ yyerror(char *s)
 }
 
 void
-delete(char *name)
+do_delete(char *name)
 {
 	struct stat st;
 
@@ -1486,12 +1554,15 @@ makedir(char *name)
 {
 
 	LOGCMD("mkdir", name);
-	if(filename_check(name))
+	if(guest && filename_check(name))
 	    return;
 	if (mkdir(name, 0777) < 0)
 		perror_reply(550, name);
-	else
-		reply(257, "MKD command successful.");
+	else{
+	    if(guest)
+		chmod(name, 0700); /* guest has umask 777 */
+	    reply(257, "MKD command successful.");
+	}
 }
 
 void
@@ -1528,7 +1599,7 @@ renamefrom(char *name)
 
 	if (stat(name, &st) < 0) {
 		perror_reply(550, name);
-		return ((char *)0);
+		return NULL;
 	}
 	reply(350, "File exists, ready for destination name");
 	return (name);
@@ -1539,7 +1610,7 @@ renamecmd(char *from, char *to)
 {
 
 	LOGCMD2("rename", from, to);
-	if(filename_check(to))
+	if(guest && filename_check(to))
 	    return;
 	if (rename(from, to) < 0)
 		perror_reply(550, "rename");
@@ -1550,16 +1621,6 @@ renamecmd(char *from, char *to)
 static void
 dolog(struct sockaddr_in *sin)
 {
-#if 0
-	struct hostent *hp = gethostbyaddr((char *)&sin->sin_addr,
-		sizeof(struct in_addr), AF_INET);
-
-	if (hp)
-		(void) strncpy(remotehost, hp->h_name, sizeof(remotehost));
-	else
-		(void) strncpy(remotehost, inet_ntoa(sin->sin_addr),
-		    sizeof(remotehost));
-#endif
 	inaddr2str (sin->sin_addr, remotehost, sizeof(remotehost));
 #ifdef HAVE_SETPROCTITLE
 	sprintf(proctitle, "%s: connected", remotehost);
@@ -1579,7 +1640,7 @@ dologout(int status)
 {
 
 	if (logged_in) {
-		(void) seteuid((uid_t)0);
+		seteuid((uid_t)0);
 		logwtmp(ttyline, "", "");
 		dest_tkt();
 		if(k_hasafs())
@@ -1657,12 +1718,12 @@ passive(void)
 	}
 	pasv_addr = ctrl_addr;
 	pasv_addr.sin_port = 0;
-	(void) seteuid((uid_t)0);
+	seteuid((uid_t)0);
 	if (bind(pdata, (struct sockaddr *)&pasv_addr, sizeof(pasv_addr)) < 0) {
-		(void) seteuid((uid_t)pw->pw_uid);
+		seteuid((uid_t)pw->pw_uid);
 		goto pasv_error;
 	}
-	(void) seteuid((uid_t)pw->pw_uid);
+	seteuid((uid_t)pw->pw_uid);
 	len = sizeof(pasv_addr);
 	if (getsockname(pdata, (struct sockaddr *) &pasv_addr, &len) < 0)
 		goto pasv_error;
@@ -1678,7 +1739,7 @@ passive(void)
 	return;
 
 pasv_error:
-	(void) close(pdata);
+	close(pdata);
 	pdata = -1;
 	perror_reply(425, "Can't open passive connection");
 	return;
@@ -1702,15 +1763,15 @@ gunique(char *local)
 		*cp = '\0';
 	if (stat(cp ? local : ".", &st) < 0) {
 		perror_reply(553, cp ? local : ".");
-		return ((char *) 0);
+		return NULL;
 	}
 	if (cp)
 		*cp = '/';
-	(void) strcpy(new, local);
+	strcpy(new, local);
 	cp = new + strlen(new);
 	*cp++ = '.';
 	for (count = 1; count < 100; count++) {
-		(void)sprintf(cp, "%d", count);
+		sprintf(cp, "%d", count);
 		if (stat(new, &st) < 0)
 			return (new);
 	}
@@ -1724,7 +1785,6 @@ gunique(char *local)
 void
 perror_reply(int code, char *string)
 {
-
 	reply(code, "%s: %s.", string, strerror(errno));
 }
 
@@ -1736,132 +1796,155 @@ static char *onefile[] = {
 void
 send_file_list(char *whichf)
 {
-	struct stat st;
-	DIR *dirp = NULL;
-	struct dirent *dir;
-	FILE *dout = NULL;
-	char **dirlist, *dirname;
-	int simple = 0;
-	int freeglob = 0;
-	glob_t gl;
+  struct stat st;
+  DIR *dirp = NULL;
+  struct dirent *dir;
+  FILE *dout = NULL;
+  char **dirlist, *dirname;
+  int simple = 0;
+  int freeglob = 0;
+  glob_t gl;
 
-	char buf[MaxPathLen];
+  char buf[MaxPathLen];
 
-	if (strpbrk(whichf, "~{[*?") != NULL) {
-		int flags = GLOB_BRACE|GLOB_NOCHECK|GLOB_QUOTE|GLOB_TILDE;
+  if (strpbrk(whichf, "~{[*?") != NULL) {
+    int flags = GLOB_BRACE|GLOB_NOCHECK|GLOB_QUOTE|GLOB_TILDE;
 
-		memset(&gl, 0, sizeof(gl));
-		freeglob = 1;
-		if (glob(whichf, flags, 0, &gl)) {
-			reply(550, "not found");
-			goto out;
-		} else if (gl.gl_pathc == 0) {
-			errno = ENOENT;
-			perror_reply(550, whichf);
-			goto out;
-		}
-		dirlist = gl.gl_pathv;
-	} else {
-		onefile[0] = whichf;
-		dirlist = onefile;
-		simple = 1;
-	}
-
-	if (setjmp(urgcatch)) {
-		transflag = 0;
-		goto out;
-	}
-	while ((dirname = *dirlist++)) {
-		if (stat(dirname, &st) < 0) {
-			/*
-			 * If user typed "ls -l", etc, and the client
-			 * used NLST, do what the user meant.
-			 */
-			if (dirname[0] == '-' && *dirlist == NULL &&
-			    transflag == 0) {
-				retrieve("/bin/ls %s", dirname);
-				goto out;
-			}
-			perror_reply(550, whichf);
-			if (dout != NULL) {
-				(void) fclose(dout);
-				transflag = 0;
-				data = -1;
-				pdata = -1;
-			}
-			goto out;
-		}
-
-		if (S_ISREG(st.st_mode)) {
-			if (dout == NULL) {
-				dout = dataconn("file list", (off_t)-1, "w");
-				if (dout == NULL)
-					goto out;
-				transflag++;
-			}
-			sprintf(buf, "%s%s\n", dirname,
-				type == TYPE_A ? "\r" : "");
-			auth_write(fileno(dout), buf, strlen(buf));
-			byte_count += strlen(dirname) + 1;
-			continue;
-		} else if (!S_ISDIR(st.st_mode))
-			continue;
-
-		if ((dirp = opendir(dirname)) == NULL)
-			continue;
-
-		while ((dir = readdir(dirp)) != NULL) {
-			char nbuf[MaxPathLen];
-
-			if (!strcmp(dir->d_name, "."))
-				continue;
-			if (!strcmp(dir->d_name, ".."))
-				continue;
-
-			sprintf(nbuf, "%s/%s", dirname, dir->d_name);
-
-			/*
-			 * We have to do a stat to insure it's
-			 * not a directory or special file.
-			 */
-			if (simple || (stat(nbuf, &st) == 0 &&
-				       S_ISREG(st.st_mode))) {
-			    if (dout == NULL) {
-				dout = dataconn("file list", (off_t)-1, "w");
-				if (dout == NULL)
-				    goto out;
-				transflag++;
-			    }
-			    if(strncmp(nbuf, "./", 2) == 0)
-				sprintf(buf, "%s%s\n", nbuf +2,
-					type == TYPE_A ? "\r" : "");
-			    else
-				sprintf(buf, "%s%s\n", nbuf,
-					type == TYPE_A ? "\r" : "");
-			    auth_write(fileno(dout), buf, strlen(buf));
-			    byte_count += strlen(nbuf) + 1;
-			}
-		}
-		(void) closedir(dirp);
-	}
-	if (dout == NULL)
-		reply(550, "No files found.");
-	else if (ferror(dout) != 0)
-		perror_reply(550, "Data connection");
-	else
-		reply(226, "Transfer complete.");
+    memset(&gl, 0, sizeof(gl));
+    freeglob = 1;
+    if (glob(whichf, flags, 0, &gl)) {
+      reply(550, "not found");
+      goto out;
+    } else if (gl.gl_pathc == 0) {
+      errno = ENOENT;
+      perror_reply(550, whichf);
+      goto out;
+    }
+    dirlist = gl.gl_pathv;
+  } else {
+    onefile[0] = whichf;
+    dirlist = onefile;
+    simple = 1;
+  }
 
+  if (setjmp(urgcatch)) {
+    transflag = 0;
+    goto out;
+  }
+  while ((dirname = *dirlist++)) {
+    if (stat(dirname, &st) < 0) {
+      /*
+       * If user typed "ls -l", etc, and the client
+       * used NLST, do what the user meant.
+       */
+      if (dirname[0] == '-' && *dirlist == NULL &&
+	  transflag == 0) {
+	retrieve("/bin/ls %s", dirname);
+	goto out;
+      }
+      perror_reply(550, whichf);
+      if (dout != NULL) {
+	fclose(dout);
 	transflag = 0;
-	if (dout != NULL){
-	    auth_write(fileno(dout), buf, 0); /* XXX flush */
-	    
-	    (void) fclose(dout);
-	}
 	data = -1;
 	pdata = -1;
-out:
-	if (freeglob) {
-		freeglob = 0;
-		globfree(&gl);
+      }
+      goto out;
+    }
+
+    if (S_ISREG(st.st_mode)) {
+      if (dout == NULL) {
+	dout = dataconn("file list", (off_t)-1, "w");
+	if (dout == NULL)
+	  goto out;
+	transflag++;
+      }
+      sprintf(buf, "%s%s\n", dirname,
+	      type == TYPE_A ? "\r" : "");
+      auth_write(fileno(dout), buf, strlen(buf));
+      byte_count += strlen(dirname) + 1;
+      continue;
+    } else if (!S_ISDIR(st.st_mode))
+      continue;
+
+    if ((dirp = opendir(dirname)) == NULL)
+      continue;
+
+    while ((dir = readdir(dirp)) != NULL) {
+      char nbuf[MaxPathLen];
+
+      if (!strcmp(dir->d_name, "."))
+	continue;
+      if (!strcmp(dir->d_name, ".."))
+	continue;
+
+      sprintf(nbuf, "%s/%s", dirname, dir->d_name);
+
+      /*
+       * We have to do a stat to insure it's
+       * not a directory or special file.
+       */
+      if (simple || (stat(nbuf, &st) == 0 &&
+		     S_ISREG(st.st_mode))) {
+	if (dout == NULL) {
+	  dout = dataconn("file list", (off_t)-1, "w");
+	  if (dout == NULL)
+	    goto out;
+	  transflag++;
 	}
+	if(strncmp(nbuf, "./", 2) == 0)
+	  sprintf(buf, "%s%s\n", nbuf +2,
+		  type == TYPE_A ? "\r" : "");
+	else
+	  sprintf(buf, "%s%s\n", nbuf,
+		  type == TYPE_A ? "\r" : "");
+	auth_write(fileno(dout), buf, strlen(buf));
+	byte_count += strlen(nbuf) + 1;
+      }
+    }
+    closedir(dirp);
+  }
+  if (dout == NULL)
+    reply(550, "No files found.");
+  else if (ferror(dout) != 0)
+    perror_reply(550, "Data connection");
+  else
+    reply(226, "Transfer complete.");
+
+  transflag = 0;
+  if (dout != NULL){
+    auth_write(fileno(dout), buf, 0); /* XXX flush */
+	    
+    fclose(dout);
+  }
+  data = -1;
+  pdata = -1;
+out:
+  if (freeglob) {
+    freeglob = 0;
+    globfree(&gl);
+  }
+}
+
+
+int
+find(char *pattern)
+{
+    char line[1024];
+    FILE *f;
+    sprintf(line, "/bin/locate -d %s %s", ftp_rooted("/etc/locatedb"), pattern);
+    f = ftpd_popen(line, "r", 1, 1);
+    if(f == NULL){
+	perror_reply(550, "/bin/locate");
+	return 1;
+    }
+    lreply(200, "Output from find.");
+    while(fgets(line, sizeof(line), f)){
+	if(line[strlen(line)-1] == '\n')
+	    line[strlen(line)-1] = 0;
+	nreply("%s", line);
+    }
+    reply(200, "Done");
+    ftpd_pclose(f);
+    return 0;
 }
