@@ -1,3 +1,41 @@
+/*
+ * Copyright (c) 1995, 1996 Kungliga Tekniska Hgskolan (Royal Institute
+ * of Technology, Stockholm, Sweden).
+ * All rights reserved.
+ * 
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
+ * 
+ * 1. Redistributions of source code must retain the above copyright
+ *    notice, this list of conditions and the following disclaimer.
+ * 
+ * 2. Redistributions in binary form must reproduce the above copyright
+ *    notice, this list of conditions and the following disclaimer in the
+ *    documentation and/or other materials provided with the distribution.
+ * 
+ * 3. All advertising materials mentioning features or use of this software
+ *    must display the following acknowledgement:
+ *      This product includes software developed by the Kungliga Tekniska
+ *      Hgskolan and its contributors.
+ * 
+ * 4. Neither the name of the Institute nor the names of its contributors
+ *    may be used to endorse or promote products derived from this software
+ *    without specific prior written permission.
+ * 
+ * THIS SOFTWARE IS PROVIDED BY THE INSTITUTE AND CONTRIBUTORS ``AS IS'' AND
+ * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED.  IN NO EVENT SHALL THE INSTITUTE OR CONTRIBUTORS BE LIABLE
+ * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
+ * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
+ * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
+ * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
+ * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
+ * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
+ * SUCH DAMAGE.
+ */
+
 /*
  * Little program that reads an srvtab or password and
  * creates a suitable ticketfile and associated AFS tokens.
@@ -8,7 +46,7 @@
 
 #include "kauth.h"
 
-RCSID("$Id: kauth.c,v 1.60 1996/07/02 09:48:31 bg Exp $");
+RCSID("$Id: kauth.c,v 1.67 1996/11/17 21:08:26 assar Exp $");
 
 char *prog;
 static char inst[100];
@@ -21,7 +59,7 @@ static char remoteuser[100];
 static char *cell = 0;
 
 static void
-usage()
+usage(void)
 {
   fprintf(stderr,
 	  "Usage: %s [-n <name>] [-r remoteuser] [-t remote ticketfile]"
@@ -33,11 +71,10 @@ usage()
 }
 
 static void
-doexec(argc, argv)
-     int argc;
-     char **argv;
+doexec(int argc, char **argv)
 {
-  int status, ret;
+  int status;
+  pid_t ret;
 
   switch (fork()) {
   case -1:
@@ -72,7 +109,8 @@ renew(int sig)
   signal(SIGALRM, renew);
 
   code = krb_get_svc_in_tkt(name, inst, realm,
-			    "krbtgt", realm, lifetime, srvtab);
+			    KRB_TICKET_GRANTING_TICKET,
+			    realm, lifetime, srvtab);
   if (code)
     fprintf(stderr, "%s: %s\n", prog, krb_get_err_text(code));
   else if (k_hasafs())
@@ -87,7 +125,7 @@ renew(int sig)
 }
 
 static int
-zrefresh()
+zrefresh(void)
 {
   switch (fork()) {
   case -1:
@@ -97,9 +135,6 @@ zrefresh()
       /* Child */
       execlp("zrefresh", "zrefresh", 0);
       execl(BINDIR "/zrefresh", "zrefresh", 0);
-#if 0
-      fprintf(stderr, "Warning %s: Failed to exec zrefresh\n", prog);
-#endif
       exit(1);
   default:
       /* Parent */
@@ -124,9 +159,7 @@ key_to_key(char *user, char *instance, char *realm, void *arg,
 }
 
 int
-main(argc, argv)
-     int argc;
-     char **argv;
+main(int argc, char **argv)
 {
   int code, more_args;
   int ret;
@@ -190,11 +223,8 @@ main(argc, argv)
 	++nhost;
       break;
     case '?':
-      usage();
-      break;
     default:
-      fprintf(stderr, "Unknown option, try -?\n");
-      exit(1);
+      usage();
       break;
     }
   
@@ -210,7 +240,7 @@ main(argc, argv)
       krb_get_default_principal (name, inst, realm) < 0)
     {
       fprintf (stderr, "%s: Could not get default principal\n",
-	       argv[0]);
+	       prog);
       return 1;
     }
   
@@ -219,7 +249,7 @@ main(argc, argv)
 
   more_args = argc - optind;
 
-  if (realm[0] == 0)
+  if (realm[0] == '\0')
     if (krb_get_lrealm(realm, 1) != KSUCCESS)
       strcpy(realm, KRB_REALM);
 
@@ -240,28 +270,36 @@ main(argc, argv)
     {
       signal(SIGALRM, renew);
 
-
       code = read_service_key (name, inst, realm, 0, srvtab, (char *)&key);
       if (code == KSUCCESS)
-	code = krb_get_in_tkt(name, inst, realm, "krbtgt", realm, lifetime,
+	code = krb_get_in_tkt(name, inst, realm,
+			      KRB_TICKET_GRANTING_TICKET,
+			      realm, lifetime,
 			      key_to_key, NULL, key);
       alarm(krb_life_to_time(0, lifetime)/2 - 60);
     }
   else
     {
       char prompt[128];
+
       sprintf(prompt,
 	      "%s%s%s@%s's Password: ",
 	      name, inst[0] ? "." : "", inst, realm);
-      if (des_read_pw_string(passwd, sizeof(passwd)-1, prompt, 0))
-	*passwd = '\0';
+      if (des_read_pw_string(passwd, sizeof(passwd)-1, prompt, 0)){
+	  memset(passwd, 0, sizeof(passwd));
+	  exit(1);
+      }
       des_string_to_key (passwd, &key);
-      code = krb_get_in_tkt (name, inst, realm, "krbtgt", realm, lifetime,
+      code = krb_get_in_tkt (name, inst, realm,
+			     KRB_TICKET_GRANTING_TICKET,
+			     realm, lifetime,
 			     key_to_key, NULL, key);
       if(code == INTK_BADPW)
 	{
 	  afs_string_to_key (passwd, realm, &key);
-	  code = krb_get_in_tkt (name, inst, realm, "krbtgt", realm, lifetime,
+	  code = krb_get_in_tkt (name, inst, realm,
+				 KRB_TICKET_GRANTING_TICKET,
+				 realm, lifetime,
 				 key_to_key, NULL, key);
 	}
       memset(passwd, 0, sizeof(passwd));
