@@ -1,6 +1,44 @@
+/*
+ * Copyright (c) 1995, 1996 Kungliga Tekniska Hgskolan (Royal Institute
+ * of Technology, Stockholm, Sweden).
+ * All rights reserved.
+ * 
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
+ * 
+ * 1. Redistributions of source code must retain the above copyright
+ *    notice, this list of conditions and the following disclaimer.
+ * 
+ * 2. Redistributions in binary form must reproduce the above copyright
+ *    notice, this list of conditions and the following disclaimer in the
+ *    documentation and/or other materials provided with the distribution.
+ * 
+ * 3. All advertising materials mentioning features or use of this software
+ *    must display the following acknowledgement:
+ *      This product includes software developed by the Kungliga Tekniska
+ *      Hgskolan and its contributors.
+ * 
+ * 4. Neither the name of the Institute nor the names of its contributors
+ *    may be used to endorse or promote products derived from this software
+ *    without specific prior written permission.
+ * 
+ * THIS SOFTWARE IS PROVIDED BY THE INSTITUTE AND CONTRIBUTORS ``AS IS'' AND
+ * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED.  IN NO EVENT SHALL THE INSTITUTE OR CONTRIBUTORS BE LIABLE
+ * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
+ * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
+ * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
+ * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
+ * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
+ * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
+ * SUCH DAMAGE.
+ */
+
 #include "kauth.h"
 
-RCSID("$Id: kauthd.c,v 1.9 1996/08/22 19:11:08 assar Exp $");
+RCSID("$Id: kauthd.c,v 1.15 1996/11/17 21:08:27 assar Exp $");
 
 static char name[SNAME_SZ + 1];
 static char inst[INST_SZ + 1];
@@ -91,18 +129,16 @@ doit(int sock)
      }
 
      if( kuserok(&auth, locuser) != 0) {
-	  sprintf(buf, "%s cannot get tickets for %s%s%s@%s",
+	  syslog (LOG_ERR, "%s cannot get tickets for %s%s%s@%s",
 		  locuser, name, *inst == '\0' ? "" : ".",
 		  inst, realm);
-	  syslog (LOG_ERR, buf);
 	  write_encrypted (sock, buf, strlen(buf), schedule,
 			   &auth.session, &thisaddr, &thataddr);
 	  return 1;
      }
      passwd = k_getpwnam (locuser);
      if (passwd == NULL) {
-	  sprintf (buf, "No user '%s'", locuser);
-	  syslog (LOG_ERR, buf);
+	  syslog (LOG_ERR, "No user '%s'", locuser);
 	  write_encrypted (sock, buf, strlen(buf), schedule,
 			   &auth.session, &thisaddr, &thataddr);
 	  return 1;
@@ -110,8 +146,7 @@ doit(int sock)
      if (setgid (passwd->pw_gid) ||
 	 initgroups(passwd->pw_name, passwd->pw_gid) ||
 	 setuid(passwd->pw_uid)) {
-	  sprintf (buf, "Could not change user");
-	  syslog (LOG_ERR, buf);
+	  syslog (LOG_ERR, "Could not change user");
 	  write_encrypted (sock, buf, strlen(buf), schedule,
 			   &auth.session, &thisaddr, &thataddr);
 	  return 1;
@@ -120,7 +155,7 @@ doit(int sock)
 		      &auth.session, &thisaddr, &thataddr);
 
      if (*tktfile == 0)
-	 sprintf(tktfile, "%s%d", TKT_ROOT, getuid());
+	 sprintf(tktfile, "%s%u", TKT_ROOT, (unsigned)getuid());
      krb_set_tkt_string (tktfile);
 
      {
@@ -131,7 +166,10 @@ doit(int sock)
 	  arg.session  = &auth.session;
 	  arg.me       = &thisaddr;
 	  arg.her      = &thataddr;
-	  status = krb_get_in_tkt (name, inst, realm, "krbtgt", realm,
+
+	  status = krb_get_in_tkt (name, inst, realm,
+				   KRB_TICKET_GRANTING_TICKET,
+				   realm,
 				   lifetime, NULL, decrypt_remote_tkt, &arg);
      }
      if (status == KSUCCESS) {
@@ -143,8 +181,7 @@ doit(int sock)
 			   &auth.session, &thisaddr, &thataddr);
 	  return 0;
      } else {
-	  sprintf (buf, "TGT failed: %s", krb_get_err_text(status));
-	  syslog (LOG_NOTICE, buf);
+	  syslog (LOG_NOTICE, "TGT failed: %s", krb_get_err_text(status));
 	  write_encrypted (sock, buf, strlen(buf), schedule,
 			   &auth.session, &thisaddr, &thataddr);
 	  return 1;
@@ -154,42 +191,9 @@ doit(int sock)
 int
 main (int argc, char **argv)
 {
-    int s = 0;
     openlog ("kauthd", LOG_ODELAY, LOG_AUTH);
 
-    if(argc > 1 && strcmp(argv[1], "-i") == 0){
-	int s2;
-	int one = 1;
-	struct sockaddr_in sa;
-	s2 = socket(AF_INET, SOCK_STREAM, 0);
-	if(s2 < 0){
-	    perror("socket");
-	    exit(1);
-	}
-	memset(&sa, 0, sizeof(sa));
-	sa.sin_family = AF_INET;
-	sa.sin_port = k_getportbyname("kauth", "tcp", htons(KAUTH_PORT));
-	
-	if(setsockopt(s2, SOL_SOCKET, SO_REUSEADDR, (void *)&one,
-		      sizeof(one)) < 0){
-	    perror("setsockopt");
-	    exit(1);
-	}
-
-	if(bind(s2, (struct sockaddr*)&sa, sizeof(sa)) < 0){
-	    perror("bind");
-	    exit(1);
-	}
-	if(listen(s2, 5) < 0){
-	    perror("listen");
-	    exit(1);
-	}
-	s = accept(s2, NULL, 0);
-	if(s < 0){
-	    perror("accept");
-	    exit(1);
-	}
-	close(s2);
-    }
-    return doit(s);
+    if(argc > 1 && strcmp(argv[1], "-i") == 0)
+	mini_inetd (k_getportbyname("kauth", "tcp", htons(KAUTH_PORT)));
+    return doit(STDIN_FILENO);
 }
