@@ -4,13 +4,8 @@
  * specifies the terms and conditions for redistribution.
  */
 
-#if 0
-static char copyright[] = "Copyright (c) 1990 Regents of the University of California.\nAll rights reserved.\n";
-static char SccsId[] = "@(#)@(#)pop_dropcopy.c	2.6  2.6 4/3/91";
-#endif /* not lint */
-
 #include <popper.h>
-RCSID("$Id: pop_dropcopy.c,v 1.12 1996/06/15 16:58:36 assar Exp $");
+RCSID("$Id: pop_dropcopy.c,v 1.14 1996/11/17 20:23:14 assar Exp $");
 
 /* 
  *  dropcopy:   Make a temporary copy of the user's mail drop and 
@@ -31,7 +26,7 @@ pop_dropcopy(POP *p, struct passwd *pwp)
     int                     nchar;                  /*  Bytes written/read */
 
     /*  Create a temporary maildrop into which to copy the updated maildrop */
-    (void)sprintf(p->temp_drop,POP_DROP,p->user);
+    sprintf(p->temp_drop,POP_DROP,p->user);
 
 #ifdef DEBUG
     if(p->debug)
@@ -46,7 +41,7 @@ pop_dropcopy(POP *p, struct passwd *pwp)
 
     /* First create a unique file.  Would prefer mkstemp, but Ultrix...*/
     strcpy(template,POP_TMPDROP);
-    (void) mktemp(template);
+    mktemp(template);
     if ( (tf=fopen(template,"w+")) == NULL ) {	/* failure, bail out	*/
         pop_log(p,POP_PRIORITY,
             "Unable to create temporary temporary maildrop '%s': %s",template,
@@ -57,23 +52,23 @@ pop_dropcopy(POP *p, struct passwd *pwp)
 
     /* Now give this file to the user	*/
     if (pwp) {
-    	(void) chown(template,pwp->pw_uid, pwp->pw_gid);
+    	chown(template,pwp->pw_uid, pwp->pw_gid);
     }
-    (void) chmod(template,0600);
+    chmod(template,0600);
 
     /* Now link this file to the temporary maildrop.  If this fails it
      * is probably because the temporary maildrop already exists.  If so,
      * this is ok.  We can just go on our way, because by the time we try
      * to write into the file we will be running as the user.
      */
-    (void) link(template,p->temp_drop);
-    (void) fclose(tf);
-    (void) unlink(template);
+    link(template,p->temp_drop);
+    fclose(tf);
+    unlink(template);
 
     /* Now we run as the user. */
     if (pwp) {
-    	(void) setuid(pwp->pw_uid);
-    	(void) setgid(pwp->pw_gid);
+    	setuid(pwp->pw_uid);
+    	setgid(pwp->pw_gid);
     }
 #ifdef DEBUG
     if(p->debug)pop_log(p,POP_DEBUG,"uid = %d, gid = %d",getuid(),getgid());
@@ -109,7 +104,7 @@ pop_dropcopy(POP *p, struct passwd *pwp)
 
         /*  Lock the maildrop */
         if (k_flock (mfd, K_LOCK_EX) == -1) {
-            (void)close(mfd) ;
+            close(mfd) ;
             return pop_msg(p,POP_FAILURE, "flock: '%s': %s", p->temp_drop,
 		strerror(errno));
         }
@@ -127,21 +122,21 @@ pop_dropcopy(POP *p, struct passwd *pwp)
                see the new mail until the error goes away.
                Should let them process the current backlog,  in case
                the error is a quota problem requiring deletions! */
-            (void)ftruncate(dfd,(int)offset) ;
+            ftruncate(dfd,(int)offset) ;
         } else {
             /* Mail transferred!  Zero the mail drop NOW,  that we
                do not have to do gymnastics to figure out what's new
                and what is old later */
-            (void)ftruncate(mfd,0) ;
+            ftruncate(mfd,0) ;
         }
 
         /*  Close the actual mail drop */
-        (void)close (mfd);
+        close (mfd);
     }
 
     /*  Acquire a stream pointer for the temporary maildrop */
     if ( (p->drop = fdopen(dfd,"a+")) == NULL ) {
-        (void)close(dfd) ;
+        close(dfd) ;
         return pop_msg(p,POP_FAILURE,"Cannot assign stream for %s",
             p->temp_drop);
     }
