@@ -4,37 +4,36 @@
  * specifies the terms and conditions for redistribution.
  */
 
-#if 0
-static char copyright[] = "Copyright (c) 1990 Regents of the University of California.\nAll rights reserved.\n";
-static char SccsId[] = "@(#)@(#)pop_get_command.c	2.1  2.1 3/18/91";
-#endif /* not lint */
-
 #include <popper.h>
-RCSID("$Id: pop_get_command.c,v 1.6 1996/06/15 16:58:39 assar Exp $");
+RCSID("$Id: pop_get_command.c,v 1.11 1996/10/28 16:25:25 assar Exp $");
 
 /* 
  *  get_command:    Extract the command from an input line form a POP client
  */
 
 static state_table states[] = {
-        auth1,  "user", 1,  1,  pop_user,   {auth1, auth2},
-        auth2,  "pass", 1,  1,  pop_pass,   {auth1, trans},
+        {auth1,  "user", 1,  1,  pop_user,   {auth1, auth2}},
+        {auth2,  "pass", 1,  99, pop_pass,   {auth1, trans}},
 #ifdef RPOP
-        auth2,  "rpop", 1,  1,  pop_rpop,   {auth1, trans},
+        {auth2,  "rpop", 1,  1,  pop_rpop,   {auth1, trans}},
 #endif /* RPOP */
-        auth1,  "quit", 0,  0,  pop_quit,   {halt,  halt},
-        auth2,  "quit", 0,  0,  pop_quit,   {halt,  halt},
-        trans,  "stat", 0,  0,  pop_stat,   {trans, trans},
-        trans,  "list", 0,  1,  pop_list,   {trans, trans},
-        trans,  "retr", 1,  1,  pop_send,   {trans, trans},
-        trans,  "dele", 1,  1,  pop_dele,   {trans, trans},
-        trans,  "noop", 0,  0,  NULL,       {trans, trans},
-        trans,  "rset", 0,  0,  pop_rset,   {trans, trans},
-        trans,  "top",  2,  2,  pop_send,   {trans, trans},
-        trans,  "last", 0,  0,  pop_last,   {trans, trans},
-        trans,  "xtnd", 1,  99, pop_xtnd,   {trans, trans},
-        trans,  "quit", 0,  0,  pop_updt,   {halt,  halt},
-        (state) 0,  NULL,   0,  0,  NULL,       {halt,  halt},
+        {auth1,  "quit", 0,  0,  pop_quit,   {halt,  halt}},
+        {auth2,  "quit", 0,  0,  pop_quit,   {halt,  halt}},
+        {trans,  "stat", 0,  0,  pop_stat,   {trans, trans}},
+        {trans,  "list", 0,  1,  pop_list,   {trans, trans}},
+        {trans,  "retr", 1,  1,  pop_send,   {trans, trans}},
+        {trans,  "dele", 1,  1,  pop_dele,   {trans, trans}},
+        {trans,  "noop", 0,  0,  NULL,       {trans, trans}},
+        {trans,  "rset", 0,  0,  pop_rset,   {trans, trans}},
+        {trans,  "top",  2,  2,  pop_send,   {trans, trans}},
+        {trans,  "last", 0,  0,  pop_last,   {trans, trans}},
+        {trans,  "xtnd", 1,  99, pop_xtnd,   {trans, trans}},
+        {trans,  "quit", 0,  0,  pop_updt,   {halt,  halt}},
+	{trans,  "help", 0,  0,  pop_help,   {trans, trans}},
+#ifdef UIDL
+        {trans,  "uidl", 0,  1,  pop_uidl,   {trans, trans}},
+#endif
+        {(state) 0,  NULL,   0,  0,  NULL,       {halt,  halt}},
 };
 
 state_table *
@@ -97,3 +96,18 @@ pop_get_command(POP *p, char *mp)
 	    "Unknown command: \"%s\".",p->pop_command);
     return NULL;
 }
+
+int
+pop_help (POP *p)
+{
+    state_table		*s;
+
+    pop_msg(p, POP_SUCCESS, "help");
+
+    for (s = states; s->command; s++) {
+	fprintf (p->output, "%s\r\n", s->command);
+    }
+    fprintf (p->output, ".\r\n");
+    fflush (p->output);
+    return POP_SUCCESS;
+}
