@@ -4,21 +4,16 @@
  * specifies the terms and conditions for redistribution.
  */
 
-#if 0
-static char copyright[] = "Copyright (c) 1990 Regents of the University of California.\nAll rights reserved.\n";
-static char SccsId[] = "@(#)@(#)pop_get_subcommand.c	2.1  2.1 3/18/91";
-#endif /* not lint */
-
 #include <popper.h>
-RCSID("$Id: pop_get_subcommand.c,v 1.6 1996/06/15 16:58:40 assar Exp $");
+RCSID("$Id: pop_get_subcommand.c,v 1.8 1996/10/28 16:25:26 assar Exp $");
 
 /* 
  *  get_subcommand: Extract a POP XTND subcommand from a client input line
  */
 
 static xtnd_table subcommands[] = {
-        "xmit",     0,  0,  pop_xmit,
-        NULL
+        {"xmit",     0,  0,  pop_xmit},
+        {NULL}
 };
 
 xtnd_table *
