@@ -4,13 +4,8 @@
  * specifies the terms and conditions for redistribution.
  */
 
-#if 0
-static char copyright[] = "Copyright (c) 1990 Regents of the University of California.\nAll rights reserved.\n";
-static char SccsId[] = "@(#)@(#)pop_log.c	2.1  2.1 3/18/91";
-#endif /* not lint */
-
 #include <popper.h>
-RCSID("$Id: pop_log.c,v 1.7 1996/06/15 16:58:44 assar Exp $");
+RCSID("$Id: pop_log.c,v 1.9 1996/11/17 20:23:15 assar Exp $");
 
 /* 
  *  log:    Make a log entry
@@ -34,13 +29,13 @@ pop_log(POP *p, int stat, char *format, ...)
 	    int a3 = va_arg(ap, int);
 	    int a4 = va_arg(ap, int);
 	    int a5 = va_arg(ap, int);
-	    (void)sprintf(msgbuf, format, a0, a1, a2, a3, a4, a5, 0, 4711);
+	    sprintf(msgbuf, format, a0, a1, a2, a3, a4, a5, 0, 4711);
 	}
 #endif /* HAVE_VSPRINTF */
 
     if (p->debug && p->trace) {
-        (void)fprintf(p->trace,"%s\n",msgbuf);
-        (void)fflush(p->trace);
+        fprintf(p->trace,"%s\n",msgbuf);
+        fflush(p->trace);
     }
     else {
         syslog (stat,"%s",msgbuf);
