@@ -4,13 +4,8 @@
  * specifies the terms and conditions for redistribution.
  */
 
-#if 0
-static char copyright[] = "Copyright (c) 1990 Regents of the University of California.\nAll rights reserved.\n";
-static char SccsId[] = "@(#)@(#)pop_lower.c	2.1  2.1 3/18/91";
-#endif /* not lint */
-
 #include <popper.h>
-RCSID("$Id: pop_lower.c,v 1.5 1996/06/15 16:58:45 assar Exp $");
+RCSID("$Id: pop_lower.c,v 1.6 1996/10/28 16:25:31 assar Exp $");
 
 /* 
  *  lower:  Convert a string to lowercase
