@@ -4,13 +4,8 @@
  * specifies the terms and conditions for redistribution.
  */
 
-#if 0
-static char copyright[] = "Copyright (c) 1990 Regents of the University of California.\nAll rights reserved.\n";
-static char SccsId[] = "@(#)@(#)pop_msg.c	2.1  2.1 3/18/91";
-#endif /* not lint */
-
 #include <popper.h>
-RCSID("$Id: pop_msg.c,v 1.8 1996/06/15 16:58:46 assar Exp $");
+RCSID("$Id: pop_msg.c,v 1.11 1996/11/17 20:23:16 assar Exp $");
 
 /* 
  *  msg:    Send a formatted line to the POP client
@@ -19,9 +14,10 @@ RCSID("$Id: pop_msg.c,v 1.8 1996/06/15 16:58:46 assar Exp $");
 int
 pop_msg(POP *p, int stat, char *format, ...)
 {
-    register char   *   mp;
+    char	       *mp;
     char                message[MAXLINELEN];
     va_list             ap;
+
     va_start(ap, format);
     
     /*  Point to the message buffer */
@@ -29,9 +25,9 @@ pop_msg(POP *p, int stat, char *format, ...)
 
     /*  Format the POP status code at the beginning of the message */
     if (stat == POP_SUCCESS)
-        (void)sprintf (mp,"%s ",POP_OK);
+        sprintf (mp,"%s ",POP_OK);
     else
-        (void)sprintf (mp,"%s ",POP_ERR);
+        sprintf (mp,"%s ",POP_ERR);
 
     /*  Point past the POP status indicator in the message message */
     mp += strlen(mp);
@@ -48,7 +44,7 @@ pop_msg(POP *p, int stat, char *format, ...)
 	    int a3 = va_arg(ap, int);
 	    int a4 = va_arg(ap, int);
 	    int a5 = va_arg(ap, int);
-	    (void)sprintf(mp, format, a0, a1, a2, a3, a4, a5, 0, 4711);
+	    sprintf(mp, format, a0, a1, a2, a3, a4, a5, 0, 4711);
 	}
 #endif /* HAVE_VSPRINTF */
     
@@ -63,11 +59,11 @@ pop_msg(POP *p, int stat, char *format, ...)
         pop_log(p,POP_PRIORITY,"%s",message);
 
     /*  Append the <CR><LF> */
-    (void)strcat(message, "\r\n");
+    strcat(message, "\r\n");
         
     /*  Send the message to the client */
-    (void)fputs(message,p->output);
-    (void)fflush(p->output);
+    fputs(message,p->output);
+    fflush(p->output);
 
     va_end(ap);
     return(stat);
