@@ -4,13 +4,8 @@
  * specifies the terms and conditions for redistribution.
  */
 
-#if 0
-static char copyright[] = "Copyright (c) 1990 Regents of the University of California.\nAll rights reserved.\n";
-static char SccsId[] = "@(#)@(#)pop_parse.c	2.1  2.1 3/18/91";
-#endif /* not lint */
-
 #include <popper.h>
-RCSID("$Id: pop_parse.c,v 1.5 1996/06/15 16:58:47 assar Exp $");
+RCSID("$Id: pop_parse.c,v 1.7 1996/11/17 20:04:18 assar Exp $");
 
 /* 
  *  parse:  Parse a raw input line from a POP client 
@@ -21,7 +16,7 @@ int
 pop_parse(POP *p, char *buf)
 {
     char            *   mp;
-    register int        i;
+    int        i;
     
     /*  Loop through the POP command array */
     for (mp = buf, i = 0; ; i++) {
