@@ -4,13 +4,8 @@
  * specifies the terms and conditions for redistribution.
  */
 
-#if 0
-static char copyright[] = "Copyright (c) 1990 Regents of the University of California.\nAll rights reserved.\n";
-static char SccsId[] = "@(#)@(#)pop_rset.c	2.1  2.1 3/18/91";
-#endif /* not lint */
-
 #include <popper.h>
-RCSID("$Id: pop_rset.c,v 1.5 1996/06/15 16:58:51 assar Exp $");
+RCSID("$Id: pop_rset.c,v 1.7 1996/11/17 20:04:19 assar Exp $");
 
 /* 
  *  rset:   Unflag all messages flagged for deletion in a POP maildrop
@@ -20,7 +15,7 @@ int
 pop_rset (POP *p)
 {
     MsgInfoList     *   mp;         /*  Pointer to the message info list */
-    register int        i;
+    int		        i;
 
     /*  Unmark all the messages */
     for (i = p->msg_count, mp = p->mlp; i > 0; i--, mp++)
