@@ -4,13 +4,8 @@
  * specifies the terms and conditions for redistribution.
  */
 
-#if 0
-static char copyright[] = "Copyright (c) 1990 Regents of the University of California.\nAll rights reserved.\n";
-static char SccsId[] = "@(#)@(#)pop_send.c	2.1  2.1 3/18/91";
-#endif /* not lint */
-
 #include <popper.h>
-RCSID("$Id: pop_send.c,v 1.11 1996/06/15 16:58:52 assar Exp $");
+RCSID("$Id: pop_send.c,v 1.15 1996/11/17 20:23:19 assar Exp $");
 
 /*
  *  sendline:   Send a line of a multi-line response to a client.
@@ -22,20 +17,24 @@ pop_sendline(POP *p, char *buffer)
     char        *   bp;
 
     /*  Byte stuff lines that begin with the temirnation octet */
-    if (*buffer == POP_TERMINATE) (void)fputc(POP_TERMINATE,p->output);
+    if (*buffer == POP_TERMINATE) 
+      fputc(POP_TERMINATE,p->output);
 
     /*  Look for a <NL> in the buffer */
-    if ((bp = strchr(buffer,NEWLINE))) *bp = 0;
+    if ((bp = strchr(buffer, '\n')))
+      *bp = 0;
 
     /*  Send the line to the client */
-    (void)fputs(buffer,p->output);
+    fputs(buffer,p->output);
 
 #ifdef DEBUG
-    if(p->debug)pop_log(p,POP_DEBUG,"Sending line \"%s\"",buffer);
+    if(p->debug)
+      pop_log(p,POP_DEBUG,"Sending line \"%s\"",buffer);
 #endif /* DEBUG */
 
     /*  Put a <CR><NL> if a newline was removed from the buffer */
-    if (bp) (void)fputs ("\r\n",p->output);
+    if (bp)
+      fputs ("\r\n",p->output);
 }
 
 /* 
@@ -47,8 +46,8 @@ int
 pop_send(POP *p)
 {
     MsgInfoList         *   mp;         /*  Pointer to message info list */
-    register int            msg_num;
-    register int            msg_lines;
+    int		            msg_num;
+    int			    msg_lines;
     char                    buffer[MAXMSGLINELEN];
 #ifdef RETURN_PATH_HANDLING
     char		*   return_path_adr;
@@ -88,10 +87,10 @@ pop_send(POP *p)
     pop_msg(p,POP_SUCCESS,"%u octets",mp->length);
 
     /*  Position to the start of the message */
-    (void)fseek(p->drop,mp->offset,0);
+    fseek(p->drop,mp->offset,0);
 
     /*  Skip the first line (the sendmail "From" line) */
-    (void)fgets (buffer,MAXMSGLINELEN,p->drop);
+    fgets (buffer,MAXMSGLINELEN,p->drop);
 
 #ifdef RETURN_PATH_HANDLING
     return_path_sent = 0;
@@ -147,8 +146,8 @@ pop_send(POP *p)
           return (pop_msg (p,POP_FAILURE,"SIGHUP or SIGPIPE flagged"));
     }
     /*  "." signals the end of a multi-line transmission */
-    (void)fputs(".\r\n",p->output);
-    (void)fflush(p->output);
+    fputs(".\r\n",p->output);
+    fflush(p->output);
 
     return(POP_SUCCESS);
 }
