@@ -57,21 +57,51 @@ the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.  */
 #include <config.h>
 #endif
 
+#ifdef SOCKS
+#include <socks.h>
+#endif
+
 #include <stdio.h>
 #include <stdarg.h>
+#ifdef HAVE_UNISTD_H
+#include <unistd.h>
+#endif
+#ifdef HAVE_SYS_TYPES_H
 #include <sys/types.h>
+#endif
+#ifdef HAVE_SYS_STAT_H
 #include <sys/stat.h>
+#endif
+#ifdef HAVE_SYS_FILE_H
 #include <sys/file.h>
+#endif
+#ifdef HAVE_SYS_TIME_H
 #include <sys/time.h>
+#endif
 #ifdef HAVE_SYS_RESOURCE_H
 #include <sys/resource.h>
 #endif /* HAVE_SYS_RESOURCE_H */
+#ifdef HAVE_SYS_WAIT_H
 #include <sys/wait.h>
+#endif
 #include <stdlib.h>
 #include <string.h>
+#ifdef HAVE_FCNTL_H
 #include <fcntl.h>
-#include <stdio.h>
+#endif
 #include <errno.h>
+#ifdef HAVE_SYS_SOCKET_H
+#include <sys/socket.h>
+#endif
+#ifdef HAVE_NETINET_IN_H
+#include <netinet/in.h>
+#endif
+#ifdef HAVE_NETDB_H
+#include <netdb.h>
+#endif
+#ifdef HAVE_PWD_H
+#include <pwd.h>
+#endif
 #if 0
 #include "syswait.h"
 #endif
@@ -81,22 +111,14 @@ the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.  */
 #undef access
 #endif /* MSDOS */
 
-#ifdef USG
-#include <fcntl.h>
-#include <unistd.h>
 #ifndef F_OK
 #define F_OK 0
 #define X_OK 1
 #define W_OK 2
 #define R_OK 4
 #endif
-#endif /* USG */
 
-#ifdef HAVE_UNISTD_H
-#include <unistd.h>
-#endif
-
-#ifdef XENIX
+#ifdef HAVE_SYS_LOCKING_H
 #include <sys/locking.h>
 #endif
 
@@ -112,17 +134,6 @@ the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.  */
 extern int lk_open (), lk_close ();
 #endif
 
-/* Cancel substitutions made by config.h for Emacs.  */
-#undef open
-#undef read
-#undef write
-#undef close
-
-#ifndef errno
-extern int errno;
-#endif
-char *strerror ();
-
 void fatal (char *s1, char *s2);
 void error (char *s1, ...);
 void pfatal_with_name (char *name);
@@ -130,7 +141,8 @@ void pfatal_and_delete (char *name);
 char *concat (char *s1, char *s2, char *s3);
 long *xmalloc (unsigned size);
 int popmail (char *user, char *outfile);
-int pop_retr (popserver server, int msgno, int (*action)(), void *arg);
+int pop_retr (popserver server, int msgno, int (*action)(char *, void *),
+	      void *arg);
 int mbx_write (char *line, FILE *mbf);
 int mbx_delimit_begin (FILE *mbf);
 int mbx_delimit_end (FILE *mbf);
@@ -457,22 +469,6 @@ xmalloc (unsigned size)
 
 /* This is the guts of the interface to the Post Office Protocol.  */
 
-
-#include <sys/socket.h>
-#include <netinet/in.h>
-#include <netdb.h>
-#include <stdio.h>
-#include <pwd.h>
-
-#ifdef USG
-#include <fcntl.h>
-/* Cancel substitutions made by config.h for Emacs.  */
-#undef open
-#undef read
-#undef write
-#undef close
-#endif /* USG */
-
 #define NOTOK (-1)
 #define OK 0
 #define DONE 1
@@ -488,11 +484,9 @@ int
 popmail (char *user, char *outfile)
 {
   int nmsgs, nbytes;
-  register int i;
+  int i;
   int mbfi;
   FILE *mbf;
-  char *getenv ();
-  int mbx_write ();
   popserver server;
 
   server = pop_open (0, user, 0, POP_NO_GETPASS);
@@ -535,7 +529,7 @@ popmail (char *user, char *outfile)
   for (i = 1; i <= nmsgs; i++)
     {
       mbx_delimit_begin (mbf);
-      if (pop_retr (server, i, mbx_write, mbf) != OK)
+      if (pop_retr (server, i, (int (*)(char *, void *))mbx_write, mbf) != OK)
 	{
 	  error (Errmsg);
 	  close (mbfi);
@@ -592,7 +586,8 @@ popmail (char *user, char *outfile)
 }
 
 int
-pop_retr (popserver server, int msgno, int (*action)(), void *arg)
+pop_retr (popserver server, int msgno, int (*action)(char *, void *),
+	  void *arg)
 {
   char *line;
   int ret;
