@@ -22,21 +22,24 @@ the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.  */
 #include <config.h>
 #endif
 
-
-#ifdef HAVE_CONFIG_H
-/* Cancel these substitutions made in config.h */
-#undef open
-#undef read
-#undef write
-#undef close
+#ifdef SOCKS
+#include <socks.h>
 #endif
 
 #include <stdlib.h>
 #include <string.h>
+#ifdef HAVE_UNISTD_H
 #include <unistd.h>
+#endif
+#ifdef HAVE_SYS_TYPES_H
 #include <sys/types.h>
+#endif
+#ifdef HAVE_NETINET_IN_H
 #include <netinet/in.h>
+#endif
+#ifdef HAVE_SYS_SOCKET_H
 #include <sys/socket.h>
+#endif
 #include <pop.h>
 
 #ifdef HESIOD
@@ -50,25 +53,17 @@ the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.  */
 extern struct servent *hes_getservbyname (/* char *, char * */);
 #endif
 
+#ifdef HAVE_PWD_H
 #include <pwd.h>
+#endif
+#ifdef HAVE_NETDB_H
 #include <netdb.h>
+#endif
 #include <errno.h>
-#include <stdio.h>
 
 #include <des.h>
 #include <krb.h>
 
-extern char *getenv (/* char * */);
-extern char *getlogin (/* void */);
-extern char *getpass (/* char * */);
-extern char *strerror (/* int */);
-
-extern int krb_sendauth (/* long, int, KTEXT, char *, char *, char *,
-			    u_long, MSG_DAT *, CREDENTIALS *, Key_schedule,
-			    struct sockaddr_in *, struct sockaddr_in *,
-			    char * */);
-extern char *krb_realmofhost (/* char * */);
-
 #if !defined(HAVE_H_ERRNO) || !defined(HAVE_CONFIG_H)
 extern int h_errno;
 #endif
@@ -89,6 +84,9 @@ static int fullwrite (int fd, char *buf, int nbytes);
 static int getok (popserver server);
 static void pop_trash (popserver server);
 static char *find_crlf (char *in_string);
+#if defined(__ultrix) || IRIX == 4
+char *getpass(const char*);
+#endif
 
 #define ERROR_MAX 80		/* a pretty arbitrary size */
 #define POP_PORT 110
@@ -99,10 +97,6 @@ static char *find_crlf (char *in_string);
 char pop_error[ERROR_MAX];
 int pop_debug = 0;
 
-#ifndef min
-#define min(a,b) (((a) < (b)) ? (a) : (b))
-#endif
-
 /*
  * Function: pop_open (char *host, char *username, char *password,
  * 		       int flags)
@@ -237,7 +231,7 @@ pop_open (host, username, password, flags)
   if (! server->buffer)
     {
       strcpy (pop_error, "Out of memory in pop_open");
-      free ((char *) server);
+      free (server);
       return (0);
     }
 	  
@@ -403,14 +397,14 @@ pop_list (server, message, IDs, sizes)
       sprintf (pop_error, "LIST %d", message);
       if (sendline (server, pop_error))
 	{
-	  free ((char *) *IDs);
-	  free ((char *) *sizes);
+	  free (*IDs);
+	  free (*sizes);
 	  return (-1);
 	}
       if (! (fromserver = getline (server)))
 	{
-	  free ((char *) *IDs);
-	  free ((char *) *sizes);
+	  free (*IDs);
+	  free (*sizes);
 	  return (-1);
 	}
       if (strncmp (fromserver, "+OK ", 4))
@@ -423,8 +417,8 @@ pop_list (server, message, IDs, sizes)
 		      "Unexpected response from server in pop_list");
 	      pop_trash (server);
 	    }
-	  free ((char *) *IDs);
-	  free ((char *) *sizes);
+	  free (*IDs);
+	  free (*sizes);
 	  return (-1);
 	}
       (*IDs)[0] = atoi (&fromserver[4]);
@@ -434,8 +428,8 @@ pop_list (server, message, IDs, sizes)
 	  strcpy (pop_error,
 		  "Badly formatted response from server in pop_list");
 	  pop_trash (server);
-	  free ((char *) *IDs);
-	  free ((char *) *sizes);
+	  free (*IDs);
+	  free (*sizes);
 	  return (-1);
 	}
       (*sizes)[0] = atoi (fromserver);
@@ -446,16 +440,16 @@ pop_list (server, message, IDs, sizes)
     {
       if (pop_multi_first (server, "LIST", &fromserver))
 	{
-	  free ((char *) *IDs);
-	  free ((char *) *sizes);
+	  free (*IDs);
+	  free (*sizes);
 	  return (-1);
 	}
       for (i = 0; i < how_many; i++)
 	{
 	  if (pop_multi_next (server, &fromserver))
 	    {
-	      free ((char *) *IDs);
-	      free ((char *) *sizes);
+	      free (*IDs);
+	      free (*sizes);
 	      return (-1);
 	    }
 	  (*IDs)[i] = atoi (fromserver);
@@ -464,8 +458,8 @@ pop_list (server, message, IDs, sizes)
 	    {
 	      strcpy (pop_error,
 		      "Badly formatted response from server in pop_list");
-	      free ((char *) *IDs);
-	      free ((char *) *sizes);
+	      free (*IDs);
+	      free (*sizes);
 	      pop_trash (server);
 	      return (-1);
 	    }
@@ -473,16 +467,16 @@ pop_list (server, message, IDs, sizes)
 	}
       if (pop_multi_next (server, &fromserver))
 	{
-	  free ((char *) *IDs);
-	  free ((char *) *sizes);
+	  free (*IDs);
+	  free (*sizes);
 	  return (-1);
 	}
       else if (fromserver)
 	{
 	  strcpy (pop_error,
 		  "Too many response lines from server in pop_list");
-	  free ((char *) *IDs);
-	  free ((char *) *sizes);
+	  free (*IDs);
+	  free (*sizes);
 	  return (-1);
 	}
       (*IDs)[i] = (*sizes)[i] = 0;
@@ -539,8 +533,8 @@ pop_retrieve (server, message, markfrom)
    */
   bufsize = sizes[0] + (markfrom ? 5 : 0);
   ptr = malloc (bufsize);
-  free ((char *) IDs);
-  free ((char *) sizes);
+  free (IDs);
+  free (sizes);
 
   if (! ptr)
     {
@@ -587,6 +581,7 @@ pop_retrieve (server, message, markfrom)
       free (ptr);
       return (0);
     }
+  return (0);
 }
 
 int
@@ -911,7 +906,7 @@ pop_quit (server)
 
   if (server->buffer)
     free (server->buffer);
-  free ((char *) server);
+  free (server);
 
   return (ret);
 }
@@ -976,16 +971,9 @@ socket_connection (char *host, int flags)
 #endif
   if (! found_port)
     {
-      servent = getservbyname (service, "tcp");
-      if (servent)
-	{
-	  addr.sin_port = servent->s_port;
-	}
-      else
-	{
-	  addr.sin_port = htons ((flags & POP_NO_KERBEROS) ?
-				POP_PORT : KPOP_PORT);
-	}
+      addr.sin_port = k_getportbyname (service, "tcp",
+				       htons((flags & POP_NO_KERBEROS) ?
+					     POP_PORT : KPOP_PORT));
     }
 
 #define SOCKET_ERROR "Could not create socket for POP connection: "
@@ -1003,8 +991,7 @@ socket_connection (char *host, int flags)
 
   while (*hostent->h_addr_list)
     {
-      memcpy ((char *) &addr.sin_addr, *hostent->h_addr_list,
-	     hostent->h_length);
+      memcpy (&addr.sin_addr, *hostent->h_addr_list, sizeof(addr.sin_addr));
       if (! connect (sock, (struct sockaddr *) &addr, sizeof (addr)))
 	break;
       hostent->h_addr_list++;
@@ -1014,7 +1001,7 @@ socket_connection (char *host, int flags)
      
   if (! *hostent->h_addr_list)
     {
-      (void) close (sock);
+      close (sock);
       strcpy (pop_error, CONNECT_ERROR);
       strncat (pop_error, strerror (errno),
 	       ERROR_MAX - sizeof (CONNECT_ERROR));
@@ -1026,19 +1013,19 @@ socket_connection (char *host, int flags)
   if (! (flags & POP_NO_KERBEROS))
     {
       ticket = (KTEXT) malloc (sizeof (KTEXT_ST));
-      rem = krb_sendauth (0L, sock, ticket, "pop", hostent->h_name,
+      rem = krb_sendauth (0L, sock, ticket, "pop", (char *)hostent->h_name,
 			  (char *) krb_realmofhost (hostent->h_name),
 			  (unsigned long) 0, &msg_data, &cred, schedule,
 			  (struct sockaddr_in *) 0,
 			  (struct sockaddr_in *) 0,
 			  "KPOPV0.1");
-      free ((char *) ticket);
+      free (ticket);
       if (rem != KSUCCESS)
 	{
 	  strcpy (pop_error, KRB_ERROR);
 	  strncat (pop_error, krb_get_err_text(rem),
 		   ERROR_MAX - sizeof (KRB_ERROR));
-	  (void) close (sock);
+	  close (sock);
 	  return (-1);
 	}
     }
@@ -1328,7 +1315,7 @@ pop_close (server)
      popserver server;
 {
   pop_trash (server);
-  free ((char *) server);
+  free (server);
 
   return;
 }
