@@ -19,35 +19,25 @@
  * <checksum> is an integer checksum to be used for the call to krb_mk_req()
  *	and mutual authentication
  *
- * If DEBUG is defined, authenticate to server "test.test".
  */
 
-#ifndef	lint
-static char rcsid_sample_client_c[] =
-"$Id: sample_client.c,v 1.5 1996/06/12 21:28:28 bg Exp $";
-#endif	lint
+#include "sample.h"
 
-#include <mit-copyright.h>
-#include <stdio.h>
-#include <sys/types.h>
-#include <sys/socket.h>
-#include <netinet/in.h>
-#include <netdb.h>
-#include <krb.h>
+RCSID("$Id: sample_client.c,v 1.8 1996/11/19 21:56:05 assar Exp $");
 
-#define SAMPLE_SERVICE	"sample"
+static char *prog;
 
-#ifdef DEBUG
-#define	TEST_SERVICE	"test"
-#endif
+static void
+usage (void)
+{
+  fprintf (stderr, "Usage: %s [-s service] [-p port] hostname checksum\n",
+	   prog);
+  exit (1);
+}
 
-char *malloc();
-
-main(argc, argv)
-int argc;
-char **argv;
+int
+main(int argc, char **argv)
 {
-    struct servent *sp;
     struct hostent *hp;
     struct sockaddr_in sin, lsin;
     char *remote_host;
@@ -59,62 +49,87 @@ char **argv;
     MSG_DAT msg_data;
     CREDENTIALS cred;
     des_key_schedule sched;
-    long cksum;
+    u_int32_t cksum;
+    int c;
+    char service[SNAME_SZ];
+    char *p;
+    u_int16_t port;
+    struct servent *serv;
 
-    if (argc != 3) {
-	fprintf(stderr, "usage: %s <hostname> <checksum>\n",argv[0]);
-	exit(1);
-    }
+    prog = argv[0];
+    strcpy (service, SAMPLE_SERVICE);
+    port = 0;
+
+    while ((c = getopt(argc, argv, "s:p:")) != EOF)
+	switch(c) {
+	case 's' :
+	    strncpy (service, optarg, sizeof(service));
+	    break;
+	case 'p' :
+	    serv = getservbyname (optarg, "tcp");
+	    if (serv)
+		port = serv->s_port;
+	    else
+		port = htons(atoi(optarg));
+	    break;
+	case '?' :
+	default :
+	    usage();
+	}
+
+    argc -= optind;
+    argv += optind;
+
+    if (argc != 2)
+	usage ();
     
     /* convert cksum to internal rep */
-    cksum = (long) atoi(argv[2]);
+    cksum = atoi(argv[1]);
 
-    (void) printf("Setting checksum to %ld\n",cksum);
+    printf("Setting checksum to %ld\n", (long)cksum);
 
     /* clear out the structure first */
     memset(&sin, 0, sizeof(sin));
-
-    /* find the port number for knetd */
-    sp = getservbyname(SAMPLE_SERVICE, "tcp");
-    if (!sp) {
-	fprintf(stderr,
-		"unknown service %s/tcp; check /etc/services\n",
-		SAMPLE_SERVICE);
-	exit(1);
-    }
-    /* copy the port number */
-    sin.sin_port = sp->s_port;
     sin.sin_family = AF_INET;
+    if (port)
+	sin.sin_port = port;
+    else
+	sin.sin_port = k_getportbyname (service, "tcp", htons(SAMPLE_PORT));
 
     /* look up the server host */
-    hp = gethostbyname(argv[1]);
-    if (!hp) {
-	fprintf(stderr, "unknown host %s\n",argv[1]);
-	exit(1);
+    hp = gethostbyname(argv[0]);
+    if (hp == NULL) {
+	fprintf(stderr, "unknown host %s: %s\n",
+		argv[0], hstrerror(h_errno));
+	return 1;
     }
 
     /* copy the hostname into non-volatile storage */
-    remote_host = malloc(strlen(hp->h_name) + 1);
-    (void) strcpy(remote_host, hp->h_name);
+    remote_host = strdup(hp->h_name);
 
     /* set up the address of the foreign socket for connect() */
     sin.sin_family = hp->h_addrtype;
-    (void) memcpy(
-		 (char *)&sin.sin_addr, (char *)hp->h_addr, 
-		 sizeof(hp->h_addr));
 
-    /* open a TCP socket */
-    sock = socket(PF_INET, SOCK_STREAM, 0);
-    if (sock < 0) {
-	perror("socket");
-	exit(1);
+    while ((p = *(hp->h_addr_list++))) {
+	memcpy(&sin.sin_addr, p, sizeof(sin.sin_addr));
+	fprintf (stderr, "Trying %s...\n", inet_ntoa(sin.sin_addr));
+
+	/* open a TCP socket */
+	sock = socket(PF_INET, SOCK_STREAM, 0);
+	if (sock < 0) {
+	    perror("socket");
+	    return 1;
+	}
+
+	/* connect to the server */
+	if (connect(sock, (struct sockaddr *)&sin, sizeof(sin)) >= 0)
+	    break;
+	close (sock);
     }
 
-    /* connect to the server */
-    if (connect(sock, &sin, sizeof(sin)) < 0) {
-	perror("connect");
-	close(sock);
-	exit(1);
+    if (p == NULL) {
+	perror ("connect");
+	return 1;
     }
 
     /* find out who I am, now that we are connected and therefore bound */
@@ -122,7 +137,7 @@ char **argv;
     if (getsockname(sock, (struct sockaddr *) &lsin, &namelen) < 0) {
 	perror("getsockname");
 	close(sock);
-	exit(1);
+	return 1;
     }
 
     /* call Kerberos library routine to obtain an authenticator,
@@ -131,32 +146,31 @@ char **argv;
 
     authopts = KOPT_DO_MUTUAL;
     status = krb_sendauth(authopts, sock, &ticket,
-#ifdef DEBUG
-			  TEST_SERVICE, TEST_SERVICE,
-#else
-			  SAMPLE_SERVICE, remote_host,
-#endif
+			  service, remote_host,
 			  NULL, cksum, &msg_data, &cred,
-			  sched, &lsin, &sin, "VERSION9");
+			  sched, &lsin, &sin, SAMPLE_VERSION);
     if (status != KSUCCESS) {
 	fprintf(stderr, "%s: cannot authenticate to server: %s\n",
-		argv[0], krb_get_err_text(status));
-	exit(1);
+		prog, krb_get_err_text(status));
+	return 1;
     }
 
     /* After we send the authenticator to the server, it will write
        back the name we authenticated to. Read what it has to say. */
-    status = read(sock, buf, 512);
+    status = read(sock, buf, sizeof(buf));
     if (status < 0) {
 	perror("read");
-	exit(1);
+	return 1;
     }
 
     /* make sure it's null terminated before printing */
-    if (status < 512)
+    if (status < sizeof(buf))
 	buf[status] = '\0';
+    else
+	buf[sizeof(buf) - 1] = '\0';
+
     printf("The server says:\n%s\n", buf);
 
     close(sock);
-    exit(0);
+    return 0;
 }
