@@ -16,29 +16,21 @@
  * client (this will be correct if this server is started by inetd).
  */
 
-#ifndef	lint
-static char rcsid_sample_server_c[] =
-"$Id: sample_server.c,v 1.4 1996/06/12 21:28:29 bg Exp $";
-#endif	lint
+#include "sample.h"
 
-#include <mit-copyright.h>
-#include <stdio.h>
-#include <sys/types.h>
-#include <sys/socket.h>
-#include <netinet/in.h>
-#include <krb.h>
-#include <syslog.h>
+RCSID("$Id: sample_server.c,v 1.6 1996/09/27 15:54:21 assar Exp $");
 
-#define	SAMPLE_SERVER	"sample"
+static char *prog;
 
-#ifdef	DEBUG
-#define	TEST_SERVER	"test"
-#define	SRVTAB		"/tmp/srvtab"
-#else
-#define SRVTAB		""
-#endif
+static void
+usage (void)
+{
+    fprintf (stderr, "Usage: %s [-i] [-s service] [-t srvtab]\n", prog);
+    exit (1);
+}
 
-main()
+int
+main(int argc, char **argv)
 {
     struct sockaddr_in peername, myname;
     int namelen = sizeof(peername);
@@ -48,61 +40,84 @@ main()
     KTEXT_ST clt_ticket;
     des_key_schedule sched;
     char instance[INST_SZ];
-    char version[9];
+    char service[ANAME_SZ];
+    char version[KRB_SENDAUTH_VLEN+1];
     char retbuf[512];
     char lname[ANAME_SZ];
+    char srvtab[MaxPathLen];
+    int c;
+    int no_inetd = 0;
 
     /* open a log connection */
 
-#ifndef LOG_DAEMON /* 4.2 syslog */
-    openlog("sample_server", 0);
-#else /* 4.3 syslog */
-    openlog("sample_server", 0, LOG_DAEMON);
-#endif /* 4.2 syslog */
+    prog = argv[0];
+
+    openlog(prog, LOG_ODELAY, LOG_DAEMON);
+
+    strcpy (service, SAMPLE_SERVICE);
+    *srvtab = '\0';
+
+    while ((c = getopt (argc, argv, "s:t:i")) != EOF)
+	switch (c) {
+	case 's' :
+	    strncpy (service, optarg, sizeof(service));
+	    break;
+	case 't' :
+	    strncpy (srvtab, optarg, sizeof(srvtab));
+	    break;
+	case 'i':
+	    no_inetd = 1;
+	    break;
+	case '?' :
+	default :
+	    usage ();
+	}
+
+    if (no_inetd)
+	mini_inetd (SAMPLE_PORT);
+
     /*
      * To verify authenticity, we need to know the address of the
      * client.
      */
-    if (getpeername(0, (struct sockaddr *)&peername, &namelen) < 0) {
+    if (getpeername(STDIN_FILENO,
+		    (struct sockaddr *)&peername,
+		    &namelen) < 0) {
 	syslog(LOG_ERR, "getpeername: %m");
-	exit(1);
+	return 1;
     }
 
     /* for mutual authentication, we need to know our address */
     namelen = sizeof(myname);
-    if (getsockname(0, (struct sockaddr *)&myname, &namelen) < 0) {
+    if (getsockname(STDIN_FILENO, (struct sockaddr *)&myname, &namelen) < 0) {
 	syslog(LOG_ERR, "getsocknamename: %m");
-	exit(1);
+	return 1;
     }
 
-    /* read the authenticator and decode it.  Since we
-       don't care what the instance is, we use "*" so that krb_rd_req
-       will fill it in from the authenticator */
-    (void) strcpy(instance, "*");
+    /* read the authenticator and decode it.  Using `k_getsockinst' we
+     * always get the right instance on a multi-homed host.
+     */
+    k_getsockinst (STDIN_FILENO, instance);
 
     /* we want mutual authentication */
     authopts = KOPT_DO_MUTUAL;
-    status = krb_recvauth(authopts, 0, &clt_ticket,
-#ifdef DEBUG
-		TEST_SERVER,
-#else
-		SAMPLE_SERVER,
-#endif
-		instance, &peername, &myname, &auth_data, SRVTAB,
-		sched, version);
+    status = krb_recvauth(authopts, STDIN_FILENO, &clt_ticket,
+			  service, instance, &peername, &myname,
+			  &auth_data, srvtab,
+			  sched, version);
     if (status != KSUCCESS) {
 	syslog(LOG_ERR, "Kerberos error: %s\n", krb_get_err_text(status));
-	(void) sprintf(retbuf, "Kerberos error: %s\n",
-		       krb_get_err_text(status));
+	sprintf(retbuf, "Kerberos error: %s\n",
+		krb_get_err_text(status));
     } else {
-	/* Check the version string (8 chars) */
-	if (strncmp(version, "VERSION9", 8)) {
+	/* Check the version string (KRB_SENDAUTH_VLEN chars) */
+	if (strncmp(version, SAMPLE_VERSION, KRB_SENDAUTH_VLEN)) {
 	    /* didn't match the expected version */
 	    /* could do something different, but we just log an error
 	       and continue */
 	    version[8] = '\0';		/* make sure null term */
-	    syslog(LOG_ERR, "Version mismatch: '%s' isn't 'VERSION9'",
-		   version);
+	    syslog(LOG_ERR, "Version mismatch: '%s' isn't '%s'",
+		   version, SAMPLE_VERSION);
 	}
 	/* now that we have decoded the authenticator, translate
 	   the kerberos principal.instance@realm into a local name */
@@ -118,20 +133,20 @@ main()
 		lname,
 		inet_ntoa(peername.sin_addr),
 		version,
-		auth_data.checksum);
+		(long)auth_data.checksum);
     }
 
     /* write back the response */
     if ((count = write(0, retbuf, (len = strlen(retbuf) + 1))) < 0) {
 	syslog(LOG_ERR,"write: %m");
-	exit(1);
+	return 1;
     } else if (count != len) {
 	syslog(LOG_ERR, "write count incorrect: %d != %d\n",
 		count, len);
-	exit(1);
+	return 1;
     }
 
     /* close up and exit */
     close(0);
-    exit(0);
+    return 0;
 }
