@@ -32,8 +32,11 @@
  */
 
 #include <config.h>
+#ifdef SOCKS
+#include <socks.h>
+#endif
 
-RCSID("$Id: enc_des.c,v 1.7 1996/08/13 23:37:08 assar Exp $");
+RCSID("$Id: enc_des.c,v 1.10 1996/11/19 22:48:33 assar Exp $");
 
 #if	defined(AUTHENTICATION) && defined(ENCRYPTION) && defined(DES_ENCRYPTION)
 #include <arpa/telnet.h>
@@ -140,7 +143,7 @@ void ofb64_init(int server)
 
 void fb64_init(struct fb *fbp)
 {
-	memset((void *)fbp,0, sizeof(*fbp));
+	memset(fbp,0, sizeof(*fbp));
 	fbp->state[0] = fbp->state[1] = FAILED;
 	fbp->fb_feed[0] = IAC;
 	fbp->fb_feed[1] = SB;
@@ -170,7 +173,7 @@ static int fb64_start(struct fb *fbp, int dir, int server)
 {
 	int x;
 	unsigned char *p;
-	register int state;
+	int state;
 
 	switch (dir) {
 	case DIR_DECRYPT:
@@ -260,7 +263,7 @@ int ofb64_is(unsigned char *data, int cnt)
 int fb64_is(unsigned char *data, int cnt, struct fb *fbp)
 {
 	unsigned char *p;
-	register int state = fbp->state[DIR_DECRYPT-1];
+	int state = fbp->state[DIR_DECRYPT-1];
 
 	if (cnt-- < 1)
 		goto failure;
@@ -280,7 +283,7 @@ int fb64_is(unsigned char *data, int cnt, struct fb *fbp)
 		if (encrypt_debug_mode)
 			printf("Initializing Decrypt stream\r\n");
 
-		fb64_stream_iv((void *)data, &fbp->streams[DIR_DECRYPT-1]);
+		fb64_stream_iv(data, &fbp->streams[DIR_DECRYPT-1]);
 
 		p = fbp->fb_feed + 3;
 		*p++ = ENCRYPT_REPLY;
@@ -341,7 +344,7 @@ int ofb64_reply(unsigned char *data, int cnt)
 
 int fb64_reply(unsigned char *data, int cnt, struct fb *fbp)
 {
-	register int state = fbp->state[DIR_ENCRYPT-1];
+	int state = fbp->state[DIR_ENCRYPT-1];
 
 	if (cnt-- < 1)
 		goto failure;
@@ -394,7 +397,7 @@ static void fb64_session(Session_Key *key, int server, struct fb *fbp)
 				key ? key->type : -1, SK_DES);
 		return;
 	}
-	memcpy((void *)fbp->krbdes_key, (void *)key->data, sizeof(des_cblock));
+	memcpy(fbp->krbdes_key, key->data, sizeof(des_cblock));
 
 	fb64_stream_key(fbp->krbdes_key, &fbp->streams[DIR_ENCRYPT-1]);
 	fb64_stream_key(fbp->krbdes_key, &fbp->streams[DIR_DECRYPT-1]);
@@ -434,7 +437,7 @@ int ofb64_keyid(int dir, unsigned char *kp, int *lenp)
 
 int fb64_keyid(int dir, unsigned char *kp, int *lenp, struct fb *fbp)
 {
-	register int state = fbp->state[dir-1];
+	int state = fbp->state[dir-1];
 
 	if (*lenp != 1 || (*kp != '\0')) {
 		*lenp = 0;
@@ -453,7 +456,7 @@ void fb64_printsub(unsigned char *data, int cnt,
 		   unsigned char *buf, int buflen, char *type)
 {
 	char lbuf[32];
-	register int i;
+	int i;
 	char *cp;
 
 	buf[buflen-1] = '\0';		/* make sure it's NULL terminated */
@@ -505,20 +508,20 @@ void ofb64_printsub(unsigned char *data, int cnt,
 void fb64_stream_iv(des_cblock seed, struct stinfo *stp)
 {
 
-	memcpy((void *)stp->str_iv, (void *)seed,sizeof(des_cblock));
-	memcpy((void *)stp->str_output, (void *)seed, sizeof(des_cblock));
+	memcpy(stp->str_iv, seed,sizeof(des_cblock));
+	memcpy(stp->str_output, seed, sizeof(des_cblock));
 
 	des_key_sched(&stp->str_ikey, stp->str_sched);
 
 	stp->str_index = sizeof(des_cblock);
 }
 
-void fb64_stream_key(des_cblock key, register struct stinfo *stp)
+void fb64_stream_key(des_cblock key, struct stinfo *stp)
 {
-	memcpy((void *)stp->str_ikey, (void *)key, sizeof(des_cblock));
+	memcpy(stp->str_ikey, key, sizeof(des_cblock));
 	des_key_sched((des_cblock*)key, stp->str_sched);
 
-	memcpy((void *)stp->str_output, (void *)stp->str_iv, sizeof(des_cblock));
+	memcpy(stp->str_output, stp->str_iv, sizeof(des_cblock));
 
 	stp->str_index = sizeof(des_cblock);
 }
@@ -547,15 +550,15 @@ void fb64_stream_key(des_cblock key, register struct stinfo *stp)
 
 void cfb64_encrypt(unsigned char *s, int c)
 {
-	register struct stinfo *stp = &fb[CFB].streams[DIR_ENCRYPT-1];
-	register int index;
+	struct stinfo *stp = &fb[CFB].streams[DIR_ENCRYPT-1];
+	int index;
 
 	index = stp->str_index;
 	while (c-- > 0) {
 		if (index == sizeof(des_cblock)) {
 			des_cblock b;
 			des_ecb_encrypt(&stp->str_output, &b,stp->str_sched, 1);
-			memcpy((void *)stp->str_feed, (void *)b, sizeof(des_cblock));
+			memcpy(stp->str_feed, b, sizeof(des_cblock));
 			index = 0;
 		}
 
@@ -569,7 +572,7 @@ void cfb64_encrypt(unsigned char *s, int c)
 
 int cfb64_decrypt(int data)
 {
-	register struct stinfo *stp = &fb[CFB].streams[DIR_DECRYPT-1];
+	struct stinfo *stp = &fb[CFB].streams[DIR_DECRYPT-1];
 	int index;
 
 	if (data == -1) {
@@ -587,7 +590,7 @@ int cfb64_decrypt(int data)
 	if (index == sizeof(des_cblock)) {
 		des_cblock b;
 		des_ecb_encrypt(&stp->str_output,&b, stp->str_sched, 1);
-		memcpy((void *)stp->str_feed, (void *)b, sizeof(des_cblock));
+		memcpy(stp->str_feed, b, sizeof(des_cblock));
 		stp->str_index = 1;	/* Next time will be 1 */
 		index = 0;		/* But now use 0 */ 
 	}
@@ -619,15 +622,15 @@ int cfb64_decrypt(int data)
 
 void ofb64_encrypt(unsigned char *s, int c)
 {
-	register struct stinfo *stp = &fb[OFB].streams[DIR_ENCRYPT-1];
-	register int index;
+	struct stinfo *stp = &fb[OFB].streams[DIR_ENCRYPT-1];
+	int index;
 
 	index = stp->str_index;
 	while (c-- > 0) {
 		if (index == sizeof(des_cblock)) {
 			des_cblock b;
 			des_ecb_encrypt(&stp->str_feed,&b, stp->str_sched, 1);
-			memcpy((void *)stp->str_feed, (void *)b, sizeof(des_cblock));
+			memcpy(stp->str_feed, b, sizeof(des_cblock));
 			index = 0;
 		}
 		*s++ ^= stp->str_feed[index];
@@ -638,7 +641,7 @@ void ofb64_encrypt(unsigned char *s, int c)
 
 int ofb64_decrypt(int data)
 {
-	register struct stinfo *stp = &fb[OFB].streams[DIR_DECRYPT-1];
+	struct stinfo *stp = &fb[OFB].streams[DIR_DECRYPT-1];
 	int index;
 
 	if (data == -1) {
@@ -656,7 +659,7 @@ int ofb64_decrypt(int data)
 	if (index == sizeof(des_cblock)) {
 		des_cblock b;
 		des_ecb_encrypt(&stp->str_feed,&b,stp->str_sched, 1);
-		memcpy((void *)stp->str_feed, (void *)b, sizeof(des_cblock));
+		memcpy(stp->str_feed, b, sizeof(des_cblock));
 		stp->str_index = 1;	/* Next time will be 1 */
 		index = 0;		/* But now use 0 */ 
 	}
