@@ -3,7 +3,7 @@ static
 #ifdef __STDC__
 const
 #endif
-char rcsid_kerberos5_c[] = "$Id: kerberos5.c,v 1.5 1996/06/12 21:28:36 bg Exp $";
+char rcsid_kerberos5_c[] = "$Id: kerberos5.c,v 1.10 1996/11/19 22:48:34 assar Exp $";
 #endif /* lint */
 
 /*-
@@ -60,8 +60,11 @@ char rcsid_kerberos5_c[] = "$Id: kerberos5.c,v 1.5 1996/06/12 21:28:36 bg Exp $"
  */
 
 #include <config.h>
+#ifdef SOCKS
+#include <socks.h>
+#endif
 
-RCSID("$Id: kerberos5.c,v 1.5 1996/06/12 21:28:36 bg Exp $");
+RCSID("$Id: kerberos5.c,v 1.10 1996/11/19 22:48:34 assar Exp $");
 
 #ifdef	KRB5
 #include <arpa/telnet.h>
@@ -136,7 +139,7 @@ Data(ap, type, d, c)
 	unsigned char *cd = (unsigned char *)d;
 
 	if (c == -1)
-		c = strlen((char *)cd);
+		c = strlen(cd);
 
 	if (auth_debug_mode) {
 		printf("%s:%d: [%d] (%d)",
@@ -246,7 +249,7 @@ kerberos5_send(ap)
 	}
 
 
-	memset((char *)&creds, 0, sizeof(creds));
+	memset(&creds, 0, sizeof(creds));
 	creds.server = server;
 
 	if (r = krb5_cc_get_principal(ccache, &creds.client)) {
@@ -382,8 +385,8 @@ kerberos5_is(ap, data, cnt)
 
 		    errout:
 			authdat = 0;
-			(void) strcpy(errbuf, "Read req failed: ");
-			(void) strcat(errbuf, error_message(r));
+			strcpy(errbuf, "Read req failed: ");
+			strcat(errbuf, error_message(r));
 			Data(ap, KRB_REJECT, errbuf, -1);
 			if (auth_debug_mode)
 				printf("%s\r\n", errbuf);
@@ -440,8 +443,8 @@ kerberos5_is(ap, data, cnt)
 					       UserNameRequested)) {
 		    char errbuf[128];
 
-		    (void) strcpy(errbuf, "Read forwarded creds failed: ");
-		    (void) strcat(errbuf, error_message(r));
+		    strcpy(errbuf, "Read forwarded creds failed: ");
+		    strcat(errbuf, error_message(r));
 		    Data(ap, KRB_FORWARD_REJECT, errbuf, -1);
 		    if (auth_debug_mode)
 		      printf("Could not read forwarded credentials\r\n");
@@ -483,14 +486,14 @@ kerberos5_reply(ap, data, cnt)
 	case KRB_ACCEPT:
 		if ((ap->way & AUTH_HOW_MASK) == AUTH_HOW_MUTUAL &&
 		    !mutual_complete) {
-		    printf("[ Kerberos V5 accepted you, but didn't provide mutual authentication! ]\n");
+		    printf("[ Kerberos V5 accepted you, but didn't provide mutual authentication! ]\r\n");
 		    auth_send_retry();
 		    return;
 		}
 		if (cnt)
-		    printf("[ Kerberos V5 accepts you as ``%.*s'' ]\n", cnt, data);
+		    printf("[ Kerberos V5 accepts you as ``%.*s'' ]\r\n", cnt, data);
 		else
-		    printf("[ Kerberos V5 accepts you ]\n");
+		    printf("[ Kerberos V5 accepts you ]\r\n");
 		auth_finished(ap, AUTH_USER);
 #ifdef	FORWARD
 		if (forward_flags & OPTS_FORWARD_CREDS)
@@ -513,14 +516,14 @@ kerberos5_reply(ap, data, cnt)
 		    tmpkey.length = sizeof(des_cblock);
 
 		    if (r = krb5_rd_rep(&inbuf, &tmpkey, &reply)) {
-			printf("[ Mutual authentication failed: %s ]\n",
+			printf("[ Mutual authentication failed: %s ]\r\n",
 			       error_message(r));
 			auth_send_retry();
 			return;
 		    }
 		    if (reply->ctime != authenticator.ctime ||
 			reply->cusec != authenticator.cusec) {
-			printf("[ Mutual authentication failed (mismatched KRB_AP_REP) ]\n");
+			printf("[ Mutual authentication failed (mismatched KRB_AP_REP) ]\r\n");
 			auth_send_retry();
 			return;
 		    }
@@ -530,7 +533,7 @@ kerberos5_reply(ap, data, cnt)
 		return;
 #ifdef	FORWARD
 	case KRB_FORWARD_ACCEPT:
-		printf("[ Kerberos V5 accepted forwarded credentials ]\n");
+		printf("[ Kerberos V5 accepted forwarded credentials ]\r\n");
 		return;
 	case KRB_FORWARD_REJECT:
 		printf("[ Kerberos V5 refuses forwarded credentials because %.*s ]\r\n",
@@ -571,7 +574,7 @@ kerberos5_printsub(data, cnt, buf, buflen)
 	int cnt, buflen;
 {
 	char lbuf[32];
-	register int i;
+	int i;
 
 	buf[buflen-1] = '\0';		/* make sure its NULL terminated */
 	buflen -= 1;
