@@ -32,8 +32,11 @@
  */
 
 #include <config.h>
+#ifdef SOCKS
+#include <socks.h>
+#endif
 
-RCSID("$Id: krb4encpwd.c,v 1.5 1996/05/10 22:25:42 assar Exp $");
+RCSID("$Id: krb4encpwd.c,v 1.10 1996/11/19 22:48:35 assar Exp $");
 
 #ifdef	KRB4_ENCPWD
 /*
@@ -125,7 +128,7 @@ Data(ap, type, d, c)
 	unsigned char *cd = (unsigned char *)d;
 
 	if (c == -1)
-		c = strlen((char *)cd);
+		c = strlen(cd);
 
 	if (0) {
 		printf("%s:%d: [%d] (%d)",
@@ -161,7 +164,7 @@ krb4encpwd_init(ap, server)
 		str_data[3] = TELQUAL_REPLY;
 	} else {
 		str_data[3] = TELQUAL_IS;
-		gethostname(hostname, sizeof(hostname));
+		k_gethostname(hostname, sizeof(hostname));
 		realm = krb_realmofhost(hostname);
 		cp = strchr(hostname, '.');
 		if (*cp != NULL) *cp = NULL;
@@ -178,7 +181,7 @@ krb4encpwd_send(ap)
 	Authenticator *ap;
 {
 
-	printf("[ Trying KRB4ENCPWD ... ]\n");
+	printf("[ Trying KRB4ENCPWD ... ]\r\n");
 	if (!UserNameRequested) {
 		return(0);
 	}
@@ -186,7 +189,7 @@ krb4encpwd_send(ap)
 		return(0);
 	}
 
-	if (!Data(ap, KRB4_ENCPWD_ACK, (void *)NULL, 0)) {
+	if (!Data(ap, KRB4_ENCPWD_ACK, NULL, 0)) {
 		return(0);
 	}
 
@@ -210,13 +213,13 @@ krb4encpwd_is(ap, data, cnt)
 		return;
 	switch (*data++) {
 	case KRB4_ENCPWD_AUTH:
-		memmove((void *)auth.dat, (void *)data, auth.length = cnt);
+		memmove(auth.dat, data, auth.length = cnt);
 
-		gethostname(lhostname, sizeof(lhostname));
+		k_gethostname(lhostname, sizeof(lhostname));
 		if ((cp = strchr(lhostname, '.')) != 0)  *cp = '\0';
 
 		if (r = krb_rd_encpwd_req(&auth, KRB_SERVICE_NAME, lhostname, 0, &adat, NULL, challenge, r_user, r_passwd)) {
-			Data(ap, KRB4_ENCPWD_REJECT, (void *)"Auth failed", -1);
+			Data(ap, KRB4_ENCPWD_REJECT, "Auth failed", -1);
 			auth_finished(ap, AUTH_REJECT);
 			return;
 		}
@@ -225,13 +228,13 @@ krb4encpwd_is(ap, data, cnt)
 		  /*
 		   *  illegal username and password
 		   */
-		  Data(ap, KRB4_ENCPWD_REJECT, (void *)"Illegal password", -1);
+		  Data(ap, KRB4_ENCPWD_REJECT, "Illegal password", -1);
 		  auth_finished(ap, AUTH_REJECT);
 		  return;
 		}
 
-		memmove((void *)session_key, (void *)adat.session, sizeof(des_cblock));
-		Data(ap, KRB4_ENCPWD_ACCEPT, (void *)0, 0);
+		memmove(session_key, adat.session, sizeof(des_cblock));
+		Data(ap, KRB4_ENCPWD_ACCEPT, 0, 0);
 		auth_finished(ap, AUTH_USER);
 		break;
 
@@ -240,7 +243,7 @@ krb4encpwd_is(ap, data, cnt)
 		 *  Take the received random challenge text and save
 		 *  for future authentication.
 		 */
-		memmove((void *)challenge, (void *)data, sizeof(des_cblock));
+		memmove(challenge, data, sizeof(des_cblock));
 		break;
 
 
@@ -255,11 +258,11 @@ krb4encpwd_is(ap, data, cnt)
 		 */
 
 		if ((ap->way & AUTH_HOW_MASK) == AUTH_HOW_MUTUAL) {
-		  register int i;
+		  int i;
 
 		  time(&now);
 		  sprintf(challenge, "%x", now);
-		  Data(ap, KRB4_ENCPWD_CHALLENGE, (void *)challenge, strlen(challenge));
+		  Data(ap, KRB4_ENCPWD_CHALLENGE, challenge, strlen(challenge));
 		}
 		break;
 
@@ -296,7 +299,7 @@ krb4encpwd_reply(ap, data, cnt)
 		auth_send_retry();
 		return;
 	case KRB4_ENCPWD_ACCEPT:
-		printf("[ KRB4_ENCPWD accepts you ]\n");
+		printf("[ KRB4_ENCPWD accepts you ]\r\n");
 		auth_finished(ap, AUTH_USER);
 		return;
 	case KRB4_ENCPWD_CHALLENGE:
@@ -304,9 +307,9 @@ krb4encpwd_reply(ap, data, cnt)
 		 * Verify that the response to the challenge is correct.
 		 */
 
-		gethostname(hostname, sizeof(hostname));
+		k_gethostname(hostname, sizeof(hostname));
 		realm = krb_realmofhost(hostname);
-		memmove((void *)challenge, (void *)data, cnt);
+		memmove(challenge, data, cnt);
 		memset(user_passwd, 0, sizeof(user_passwd));
 		local_des_read_pw_string(user_passwd, sizeof(user_passwd)-1, "Password: ", 0);
 		UserPassword = user_passwd;
@@ -318,7 +321,7 @@ krb4encpwd_reply(ap, data, cnt)
 		  krb_token.length = 0;
 		}
 
-		if (!Data(ap, KRB4_ENCPWD_AUTH, (void *)krb_token.dat, krb_token.length)) {
+		if (!Data(ap, KRB4_ENCPWD_AUTH, krb_token.dat, krb_token.length)) {
 		  return;
 		}
 
@@ -356,7 +359,7 @@ krb4encpwd_printsub(data, cnt, buf, buflen)
 	int cnt, buflen;
 {
 	char lbuf[32];
-	register int i;
+	int i;
 
 	buf[buflen-1] = '\0';		/* make sure its NULL terminated */
 	buflen -= 1;
@@ -433,7 +436,7 @@ prkey(msg, key)
 	char *msg;
 	unsigned char *key;
 {
-	register int i;
+	int i;
 	printf("%s:", msg);
 	for (i = 0; i < 8; i++)
 		printf(" %3d", key[i]);
