@@ -45,8 +45,11 @@
  */
 
 #include <config.h>
+#ifdef SOCKS
+#include <socks.h>
+#endif
 
-RCSID("$Id: read_password.c,v 1.3 1995/12/27 13:24:54 bg Exp $");
+RCSID("$Id: read_password.c,v 1.6 1996/11/19 22:48:35 assar Exp $");
 
 #if	defined(RSA_ENCPWD) || defined(KRB4_ENCPWD)
 
@@ -84,7 +87,7 @@ local_des_read_pw_string(s,max,prompt,verify)
     }
 
     /* XXX assume jmp_buf is typedef'ed to an array */
-    memmove((char *)env, (char *)old_env, sizeof(env));
+    memmove(env, old_env, sizeof(env));
     if (setjmp(env))
 	goto lose;
 
@@ -99,15 +102,15 @@ local_des_read_pw_string(s,max,prompt,verify)
     if (ioctl(0,TIOCSETP,(char *)&tty_state) == -1)
 	return -1;
     while (!ok) {
-	(void) printf(prompt);
-	(void) fflush(stdout);
+	printf(prompt);
+	fflush(stdout);
 	while (!fgets(s, max, stdin));
 
 	if ((ptr = strchr(s, '\n')))
 	    *ptr = '\0';
 	if (verify) {
 	    printf("\nVerifying, please re-enter %s",prompt);
-	    (void) fflush(stdout);
+	    fflush(stdout);
 	    if (!fgets(key_string, sizeof(key_string), stdin)) {
 		clearerr(stdin);
 		continue;
@@ -116,7 +119,7 @@ local_des_read_pw_string(s,max,prompt,verify)
 	    *ptr = '\0';
 	    if (strcmp(s,key_string)) {
 		printf("\n\07\07Mismatch - try again\n");
-		(void) fflush(stdout);
+		fflush(stdout);
 		continue;
 	    }
 	}
@@ -134,7 +137,7 @@ lose:
 /*
     pop_signals();
 */
-    memmove((char *)old_env, (char *)env, sizeof(env));
+    memmove(old_env, env, sizeof(env));
     if (verify)
 	memset(key_string, 0, sizeof (key_string));
     s[max-1] = 0;		/* force termination */
