@@ -32,8 +32,11 @@
  */
 
 #include <config.h>
+#ifdef SOCKS
+#include <socks.h>
+#endif
 
-RCSID("$Id: rsaencpwd.c,v 1.5 1996/05/10 22:25:43 assar Exp $");
+RCSID("$Id: rsaencpwd.c,v 1.10 1996/11/19 22:48:36 assar Exp $");
 
 #ifdef	RSA_ENCPWD
 /*
@@ -158,7 +161,7 @@ rsaencpwd_init(ap, server)
 	if (server) {
 		str_data[3] = TELQUAL_REPLY;
 		memset(key_file, 0, sizeof(key_file));
-		gethostname(lhostname, sizeof(lhostname));
+		k_gethostname(lhostname, sizeof(lhostname));
 		if ((cp = strchr(lhostname, '.')) != 0)  *cp = '\0';
 		strcpy(key_file, "/etc/.");
 		strcat(key_file, lhostname);
@@ -176,14 +179,14 @@ rsaencpwd_send(ap)
 	Authenticator *ap;
 {
 
-	printf("[ Trying RSAENCPWD ... ]\n");
+	printf("[ Trying RSAENCPWD ... ]\r\n");
 	if (!UserNameRequested) {
 		return(0);
 	}
 	if (!auth_sendname(UserNameRequested, strlen(UserNameRequested))) {
 		return(0);
 	}
-	if (!Data(ap, NULL, (void *)NULL, 0)) {
+	if (!Data(ap, NULL, NULL, 0)) {
 		return(0);
 	}
 
@@ -209,10 +212,10 @@ rsaencpwd_is(ap, data, cnt)
 	cnt--;
 	switch (*data++) {
 	case RSA_ENCPWD_AUTH:
-		memmove((void *)auth.dat, (void *)data, auth.length = cnt);
+		memmove(auth.dat, data, auth.length = cnt);
 
 		if ((fp=fopen(key_file, "r"))==NULL) {
-		  Data(ap, RSA_ENCPWD_REJECT, (void *)"Auth failed", -1);
+		  Data(ap, RSA_ENCPWD_REJECT, "Auth failed", -1);
 		  auth_finished(ap, AUTH_REJECT);
 		  return;
 		}
@@ -228,7 +231,7 @@ rsaencpwd_is(ap, data, cnt)
 		r = accept_rsa_encpwd(&auth, key, challenge,
 				      challenge_len, r_passwd);
 		if (r < 0) {
-		  Data(ap, RSA_ENCPWD_REJECT, (void *)"Auth failed", -1);
+		  Data(ap, RSA_ENCPWD_REJECT, "Auth failed", -1);
 		  auth_finished(ap, AUTH_REJECT);
 		  return;
 		}
@@ -237,12 +240,12 @@ rsaencpwd_is(ap, data, cnt)
 		  /*
 		   *  illegal username and password
 		   */
-		  Data(ap, RSA_ENCPWD_REJECT, (void *)"Illegal password", -1);
+		  Data(ap, RSA_ENCPWD_REJECT, "Illegal password", -1);
 		  auth_finished(ap, AUTH_REJECT);
 		  return;
 		}
 
-		Data(ap, RSA_ENCPWD_ACCEPT, (void *)0, 0);
+		Data(ap, RSA_ENCPWD_ACCEPT, 0, 0);
 		auth_finished(ap, AUTH_USER);
 		break;
 
@@ -254,7 +257,7 @@ rsaencpwd_is(ap, data, cnt)
 		 * the challenge, and verify it when the response comes back.
 		 */
 		if ((ap->way & AUTH_HOW_MASK) == AUTH_HOW_ONE_WAY) {
-		  register int i;
+		  int i;
 
 
 		  time(&now);
@@ -267,7 +270,7 @@ rsaencpwd_is(ap, data, cnt)
 		  }
 
 		  if ((fp=fopen(key_file, "r"))==NULL) {
-		    Data(ap, RSA_ENCPWD_REJECT, (void *)"Auth failed", -1);
+		    Data(ap, RSA_ENCPWD_REJECT, "Auth failed", -1);
 		    auth_finished(ap, AUTH_REJECT);
 		    return;
 		  }
@@ -300,7 +303,7 @@ rsaencpwd_is(ap, data, cnt)
 		  ptr += NumEncodeLengthOctets(i);
 		  memmove(ptr, key, i);
 		  chalkey_len = 1+NumEncodeLengthOctets(chalkey_len)+chalkey_len;
-		  Data(ap, RSA_ENCPWD_CHALLENGEKEY, (void *)chalkey, chalkey_len);
+		  Data(ap, RSA_ENCPWD_CHALLENGEKEY, chalkey, chalkey_len);
 		}
 		break;
 
@@ -336,7 +339,7 @@ rsaencpwd_reply(ap, data, cnt)
 		auth_send_retry();
 		return;
 	case RSA_ENCPWD_ACCEPT:
-		printf("[ RSA_ENCPWD accepts you ]\n");
+		printf("[ RSA_ENCPWD accepts you ]\r\n");
 		auth_finished(ap, AUTH_USER);
 		return;
 	case RSA_ENCPWD_CHALLENGEKEY:
@@ -344,7 +347,7 @@ rsaencpwd_reply(ap, data, cnt)
 		 * Verify that the response to the challenge is correct.
 		 */
 
-		memmove((void *)chalkey, (void *)data, cnt);
+		memmove(chalkey, data, cnt);
 		ptr = (char *) &chalkey[0];
 		ptr += DecodeHeaderLength(chalkey);
 		if (*ptr != 0x04) {
@@ -371,7 +374,7 @@ rsaencpwd_reply(ap, data, cnt)
 		  token.length = 1;
 		}
 
-		if (!Data(ap, RSA_ENCPWD_AUTH, (void *)token.dat, token.length)) {
+		if (!Data(ap, RSA_ENCPWD_AUTH, token.dat, token.length)) {
 		  return;
 		}
 
@@ -409,7 +412,7 @@ rsaencpwd_printsub(data, cnt, buf, buflen)
 	int cnt, buflen;
 {
 	char lbuf[32];
-	register int i;
+	int i;
 
 	buf[buflen-1] = '\0';		/* make sure its NULL terminated */
 	buflen -= 1;
@@ -482,7 +485,7 @@ prkey(msg, key)
 	char *msg;
 	unsigned char *key;
 {
-	register int i;
+	int i;
 	printf("%s:", msg);
 	for (i = 0; i < 8; i++)
 		printf(" %3d", key[i]);
