@@ -32,8 +32,11 @@
  */
 
 #include <config.h>
+#ifdef SOCKS
+#include <socks.h>
+#endif
 
-RCSID("$Id: spx.c,v 1.5 1996/05/10 22:25:45 assar Exp $");
+RCSID("$Id: spx.c,v 1.10 1996/11/19 22:48:36 assar Exp $");
 
 #ifdef	SPX
 /*
@@ -170,7 +173,7 @@ spx_init(ap, server)
 
 	if (server) {
 		str_data[3] = TELQUAL_REPLY;
-		gethostname(lhostname, sizeof(lhostname));
+		k_gethostname(lhostname, sizeof(lhostname));
 		strcpy(targ_printable, "SERVICE:rcmd@");
 		strcat(targ_printable, lhostname);
 		input_name_buffer.length = strlen(targ_printable);
@@ -213,7 +216,7 @@ spx_send(ap)
 	int  deleg_flag=1, mutual_flag=0, replay_flag=0, seq_flag=0;
 	char *address;
 
-	printf("[ Trying SPX ... ]\n");
+	printf("[ Trying SPX ... ]\r\n");
 	strcpy(targ_printable, "SERVICE:rcmd@");
 	strcat(targ_printable, RemoteHostName);
 
@@ -296,7 +299,7 @@ spx_send(ap)
 		return(0);
 	}
 
-	if (!Data(ap, SPX_AUTH, (void *)output_token.value, output_token.length)) {
+	if (!Data(ap, SPX_AUTH, output_token.value, output_token.length)) {
 		return(0);
 	}
 
@@ -320,7 +323,7 @@ spx_is(ap, data, cnt)
 		input_token.length = cnt;
 		input_token.value = (char *) data;
 
-		gethostname(lhostname, sizeof(lhostname));
+		k_gethostname(lhostname, sizeof(lhostname));
 
 		strcpy(targ_printable, "SERVICE:rcmd@");
 		strcat(targ_printable, lhostname);
@@ -384,7 +387,7 @@ spx_is(ap, data, cnt)
 					src_name,
 					&fullname_buffer,
 					&fullname_type);
-			Data(ap, SPX_REJECT, (void *)"auth failed", -1);
+			Data(ap, SPX_REJECT, "auth failed", -1);
 			auth_finished(ap, AUTH_REJECT);
 			return;
 		}
@@ -395,7 +398,7 @@ spx_is(ap, data, cnt)
 					&fullname_type);
 
 
-		Data(ap, SPX_ACCEPT, (void *)output_token.value, output_token.length);
+		Data(ap, SPX_ACCEPT, output_token.value, output_token.length);
 		auth_finished(ap, AUTH_USER);
 		break;
 
@@ -426,7 +429,7 @@ spx_reply(ap, data, cnt)
 		auth_send_retry();
 		return;
 	case SPX_ACCEPT:
-		printf("[ SPX accepts you ]\n");
+		printf("[ SPX accepts you ]\r\n");
 		if ((ap->way & AUTH_HOW_MASK) == AUTH_HOW_MUTUAL) {
 			/*
 			 * Send over the encrypted challenge.
@@ -527,7 +530,7 @@ spx_printsub(data, cnt, buf, buflen)
 	int cnt, buflen;
 {
 	char lbuf[32];
-	register int i;
+	int i;
 
 	buf[buflen-1] = '\0';		/* make sure its NULL terminated */
 	buflen -= 1;
@@ -576,7 +579,7 @@ prkey(msg, key)
 	char *msg;
 	unsigned char *key;
 {
-	register int i;
+	int i;
 	printf("%s:", msg);
 	for (i = 0; i < 8; i++)
 		printf(" %3d", key[i]);
