@@ -32,8 +32,11 @@
  */
 
 #include <config.h>
+#ifdef SOCKS
+#include <socks.h>
+#endif
 
-RCSID("$Id: commands.c,v 1.15 1996/08/08 13:26:51 assar Exp $");
+RCSID("$Id: commands.c,v 1.22 1996/11/19 22:48:37 assar Exp $");
 
 #include <sys/param.h>
 #include <sys/types.h>
@@ -107,8 +110,8 @@ static char *margv[20];
     static void
 makeargv()
 {
-    register char *cp, *cp2, c;
-    register char **argp = margv;
+    char *cp, *cp2, c;
+    char **argp = margv;
 
     margc = 0;
     cp = line;
@@ -119,7 +122,7 @@ makeargv()
 	cp++;
     }
     while (c = *cp) {
-	register int inquote = 0;
+	int inquote = 0;
 	while (isspace(c))
 	    c = *++cp;
 	if (c == '\0')
@@ -163,7 +166,7 @@ makeargv()
 
 static char special(char *s)
 {
-	register char c;
+	char c;
 	char b;
 
 	switch (*s) {
@@ -188,7 +191,7 @@ static char special(char *s)
  */
 	static char *
 control(c)
-	register cc_t c;
+	cc_t c;
 {
 	static char buf[5];
 	/*
@@ -198,7 +201,7 @@ control(c)
 	 * was to assign "c" to an unsigned int variable...
 	 * Arggg....
 	 */
-	register unsigned int uic = (unsigned int)c;
+	unsigned int uic = (unsigned int)c;
 
 	if (uic == 0x7f)
 		return ("^?");
@@ -345,7 +348,7 @@ static int sendcmd(int argc, char **argv)
     for (i = 1; i < argc; i++) {
 	if ((s = GETSEND(argv[i])) == 0) {
 	    fprintf(stderr, "Telnet 'send' error - argument disappeared!\n");
-	    (void) quit();
+	    quit();
 	    /*NOTREACHED*/
 	}
 	if (s->handler) {
@@ -401,10 +404,10 @@ send_tncmd(func, cmd, name)
 {
     char **cpp;
     extern char *telopts[];
-    register int val = 0;
+    int val = 0;
 
     if (isprefix(name, "help") || isprefix(name, "?")) {
-	register int col, len;
+	int col, len;
 
 	printf("Usage: send %s <value|option>\n", cmd);
 	printf("\"value\" must be from 0 to 255\n");
@@ -432,7 +435,7 @@ send_tncmd(func, cmd, name)
     if (cpp) {
 	val = cpp - telopts;
     } else {
-	register char *cp = name;
+	char *cp = name;
 
 	while (*cp >= '0' && *cp <= '9') {
 	    val *= 10;
@@ -994,7 +997,7 @@ unsetcmd(argc, argv)
 {
     struct setlist *ct;
     struct togglelist *c;
-    register char *name;
+    char *name;
 
     if (argc < 2) {
 	fprintf(stderr,
@@ -1292,7 +1295,7 @@ setescape(argc, argv)
 	int argc;
 	char *argv[];
 {
-	register char *arg;
+	char *arg;
 	char buf[50];
 
 	printf(
@@ -1302,14 +1305,14 @@ setescape(argc, argv)
 		arg = argv[1];
 	else {
 		printf("new escape character: ");
-		(void) fgets(buf, sizeof(buf), stdin);
+		fgets(buf, sizeof(buf), stdin);
 		arg = buf;
 	}
 	if (arg[0] != '\0')
 		escape = arg[0];
 	printf("Escape character is '%s'.\n", control(escape));
 
-	(void) fflush(stdout);
+	fflush(stdout);
 	return 1;
 }
 
@@ -1320,7 +1323,7 @@ togcrmod()
     crmod = !crmod;
     printf("Deprecated usage - please use 'toggle crmod' in the future.\n");
     printf("%s map carriage return on output.\n", crmod ? "Will" : "Won't");
-    (void) fflush(stdout);
+    fflush(stdout);
     return 1;
 }
 
@@ -1334,7 +1337,7 @@ suspend()
 	long oldrows, oldcols, newrows, newcols, err;
 
 	err = (TerminalWindowSize(&oldrows, &oldcols) == 0) ? 1 : 0;
-	(void) kill(0, SIGTSTP);
+	kill(0, SIGTSTP);
 	/*
 	 * If we didn't get the window size before the SUSPEND, but we
 	 * can get them now (?), then send the NAWS to make sure that
@@ -1373,7 +1376,7 @@ shell(int argc, char **argv)
 	    /*
 	     * Fire up the shell in the child.
 	     */
-	    register char *shellp, *shellname;
+	    char *shellp, *shellname;
 
 	    shellp = getenv("SHELL");
 	    if (shellp == NULL)
@@ -1390,7 +1393,7 @@ shell(int argc, char **argv)
 	    _exit(1);
 	}
     default:
-	    (void)wait((int *)0);	/* Wait for the shell to complete */
+	    wait((int *)0);	/* Wait for the shell to complete */
 
 	    if (TerminalWindowSize(&newrows, &newcols) && connected &&
 		(err || ((oldrows != newrows) || (oldcols != newcols)))) {
@@ -1406,9 +1409,9 @@ static int bye(int argc, char **argv)
     extern int resettermname;
 
     if (connected) {
-	(void) shutdown(net, 2);
+	shutdown(net, 2);
 	printf("Connection closed.\n");
-	(void) NetClose(net);
+	NetClose(net);
 	connected = 0;
 	resettermname = 1;
 #if	defined(AUTHENTICATION) || defined(ENCRYPTION)
@@ -1425,7 +1428,7 @@ static int bye(int argc, char **argv)
 /*VARARGS*/
 int quit(void)
 {
-	(void) call(bye, "bye", "fromquit", 0);
+	call(bye, "bye", "fromquit", 0);
 	Exit(0);
 	return 0; /*NOTREACHED*/
 }
@@ -1435,7 +1438,7 @@ int quit(void)
 logout()
 {
 	send_do(TELOPT_LOGOUT, 1);
-	(void) netflush();
+	netflush();
 	return 1;
 }
 
@@ -1621,7 +1624,7 @@ struct env_lst envlisthead;
 env_find(var)
 	unsigned char *var;
 {
-	register struct env_lst *ep;
+	struct env_lst *ep;
 
 	for (ep = envlisthead.next; ep; ep = ep->next) {
 		if (strcmp((char *)ep->var, (char *)var) == 0)
@@ -1638,8 +1641,8 @@ env_find(var)
 env_init()
 {
 	extern char **environ;
-	register char **epp, *cp;
-	register struct env_lst *ep;
+	char **epp, *cp;
+	struct env_lst *ep;
 
 	for (epp = environ; *epp; epp++) {
 		if (cp = strchr(*epp, '=')) {
@@ -1661,7 +1664,7 @@ env_init()
 		char hbuf[256+1];
 		char *cp2 = strchr((char *)ep->value, ':');
 
-		gethostname(hbuf, 256);
+		k_gethostname(hbuf, 256);
 		hbuf[256] = '\0';
 
 		/* If this is not the full name, try to get it via DNS */
@@ -1694,7 +1697,7 @@ env_init()
 env_define(var, value)
 	unsigned char *var, *value;
 {
-	register struct env_lst *ep;
+	struct env_lst *ep;
 
 	if (ep = env_find(var)) {
 		if (ep->var)
@@ -1720,7 +1723,7 @@ env_define(var, value)
 env_undefine(var)
 	unsigned char *var;
 {
-	register struct env_lst *ep;
+	struct env_lst *ep;
 
 	if (ep = env_find(var)) {
 		ep->prev->next = ep->next;
@@ -1738,7 +1741,7 @@ env_undefine(var)
 env_export(var)
 	unsigned char *var;
 {
-	register struct env_lst *ep;
+	struct env_lst *ep;
 
 	if (ep = env_find(var))
 		ep->export = 1;
@@ -1748,7 +1751,7 @@ env_export(var)
 env_unexport(var)
 	unsigned char *var;
 {
-	register struct env_lst *ep;
+	struct env_lst *ep;
 
 	if (ep = env_find(var))
 		ep->export = 0;
@@ -1758,7 +1761,7 @@ env_unexport(var)
 env_send(var)
 	unsigned char *var;
 {
-	register struct env_lst *ep;
+	struct env_lst *ep;
 
 	if (my_state_is_wont(TELOPT_NEW_ENVIRON)
 #ifdef	OLD_ENVIRON
@@ -1784,7 +1787,7 @@ env_send(var)
 	void
 env_list()
 {
-	register struct env_lst *ep;
+	struct env_lst *ep;
 
 	for (ep = envlisthead.next; ep; ep = ep->next) {
 		printf("%c %-20s %s\n", ep->export ? '*' : ' ',
@@ -1815,7 +1818,7 @@ env_default(init, welldefined)
 env_getvalue(var)
 	unsigned char *var;
 {
-	register struct env_lst *ep;
+	struct env_lst *ep;
 
 	if (ep = env_find(var))
 		return(ep->value);
@@ -2055,7 +2058,7 @@ static int status(int argc, char **argv)
 	printf("No connection.\n");
     }
     printf("Escape character is '%s'.\n", control(escape));
-    (void) fflush(stdout);
+    fflush(stdout);
     return 1;
 }
 
@@ -2065,7 +2068,7 @@ static int status(int argc, char **argv)
  */
 ayt_status()
 {
-    (void) call(status, "status", "notmuch", 0);
+    call(status, "status", "notmuch", 0);
 }
 #endif
 
@@ -2078,7 +2081,7 @@ static Command *getcmd(char *name);
 
 static void cmdrc(char *m1, char *m2)
 {
-    register Command *c;
+    Command *c;
     FILE *rcfile;
     int gotmachine = 0;
     int l1 = strlen(m1);
@@ -2157,7 +2160,7 @@ static void cmdrc(char *m1, char *m2)
 
 int tn(int argc, char **argv)
 {
-    register struct hostent *host = 0;
+    struct hostent *host = 0;
     struct sockaddr_in sin;
     struct servent *sp = 0;
     unsigned long temp;
@@ -2169,7 +2172,7 @@ int tn(int argc, char **argv)
     char *cmd, *hostp = 0, *portp = 0, *user = 0;
 
     /* clear the socket address prior to use */
-    memset((char *)&sin, 0, sizeof(sin));
+    memset(&sin, 0, sizeof(sin));
 
     if (connected) {
 	printf("?Already connected to %s\n", hostname);
@@ -2177,9 +2180,9 @@ int tn(int argc, char **argv)
 	return 0;
     }
     if (argc < 2) {
-	(void) strcpy(line, "open ");
+	strcpy(line, "open ");
 	printf("(to) ");
-	(void) fgets(&line[strlen(line)], sizeof(line) - strlen(line), stdin);
+	fgets(&line[strlen(line)], sizeof(line) - strlen(line), stdin);
 	makeargv();
 	argc = margc;
 	argv = margv;
@@ -2245,17 +2248,18 @@ int tn(int argc, char **argv)
 	if (temp != (unsigned long) -1) {
 	    sin.sin_addr.s_addr = temp;
 	    sin.sin_family = AF_INET;
-	    (void) strcpy(_hostname, hostp);
+	    strcpy(_hostname, hostp);
 	    hostname = _hostname;
 	} else {
 	    host = gethostbyname(hostp);
 	    if (host) {
 		sin.sin_family = host->h_addrtype;
 #if	defined(h_addr)		/* In 4.3, this is a #define */
-		memmove((caddr_t)&sin.sin_addr,
-				host->h_addr_list[0], host->h_length);
+		memmove(&sin.sin_addr,
+			host->h_addr_list[0],
+			sizeof(sin.sin_addr));
 #else	/* defined(h_addr) */
-		memmove((caddr_t)&sin.sin_addr, host->h_addr, host->h_length);
+		memmove(&sin.sin_addr, host->h_addr, sizeof(sin.sin_addr));
 #endif	/* defined(h_addr) */
 		strncpy(_hostname, host->h_name, sizeof(_hostname));
 		_hostname[sizeof(_hostname)-1] = '\0';
@@ -2346,11 +2350,12 @@ int tn(int argc, char **argv)
 		fprintf(stderr, "telnet: connect to address %s: ",
 						inet_ntoa(sin.sin_addr));
 		errno = oerrno;
-		perror((char *)0);
+		perror(NULL);
 		host->h_addr_list++;
-		memmove((caddr_t)&sin.sin_addr,
-			host->h_addr_list[0], host->h_length);
-		(void) NetClose(net);
+		memmove(&sin.sin_addr,
+			host->h_addr_list[0],
+			sizeof(sin.sin_addr));
+		NetClose(net);
 		continue;
 	    }
 #endif	/* defined(h_addr) */
@@ -2369,7 +2374,7 @@ int tn(int argc, char **argv)
 	user = getenv("USER");
 	if (user == NULL ||
 	    ((pw = k_getpwnam(user)) && pw->pw_uid != getuid())) {
-		if (pw = getpwuid(getuid()))
+		if (pw = k_getpwuid(getuid()))
 			user = pw->pw_name;
 		else
 			user = NULL;
@@ -2379,10 +2384,10 @@ int tn(int argc, char **argv)
 	env_define((unsigned char *)"USER", (unsigned char *)user);
 	env_export((unsigned char *)"USER");
     }
-    (void) call(status, "status", "notmuch", 0);
+    call(status, "status", "notmuch", 0);
     if (setjmp(peerdied) == 0)
 	telnet(user);
-    (void) NetClose(net);
+    NetClose(net);
     ExitString("Connection closed by foreign host.\n",1);
     /*NOTREACHED*/
 }
@@ -2484,20 +2489,20 @@ command(top, tbuf, cnt)
     char *tbuf;
     int cnt;
 {
-    register Command *c;
+    Command *c;
 
     setcommandmode();
     if (!top) {
 	putchar('\n');
     } else {
-	(void) signal(SIGINT, SIG_DFL);
-	(void) signal(SIGQUIT, SIG_DFL);
+	signal(SIGINT, SIG_DFL);
+	signal(SIGQUIT, SIG_DFL);
     }
     for (;;) {
 	if (rlogin == _POSIX_VDISABLE)
 		printf("%s> ", prompt);
 	if (tbuf) {
-	    register char *cp;
+	    char *cp;
 	    cp = line;
 	    while (cnt > 0 && (*cp++ = *tbuf++) != '\n')
 		cnt--;
@@ -2513,7 +2518,7 @@ command(top, tbuf, cnt)
 		printf("%s> ", prompt);
 	    if (fgets(line, sizeof(line), stdin) == NULL) {
 		if (feof(stdin) || ferror(stdin)) {
-		    (void) quit();
+		    quit();
 		    /*NOTREACHED*/
 		}
 		break;
@@ -2556,7 +2561,7 @@ command(top, tbuf, cnt)
  */
 static int help(int argc, char **argv)
 {
-	register Command *c;
+	Command *c;
 
 	if (argc == 1) {
 		printf("Commands may be abbreviated.  Commands are:\n\n");
@@ -2568,7 +2573,7 @@ static int help(int argc, char **argv)
 		return 0;
 	}
 	while (--argc > 0) {
-		register char *arg;
+		char *arg;
 		arg = *++argv;
 		c = getcmd(arg);
 		if (Ambiguous(c))
@@ -2634,10 +2639,10 @@ sourceroute(arg, cpp, lenp)
 	static IOPTN ipopt;
 #endif
 	char *cp, *cp2, *lsrp, *lsrep;
-	register int tmp;
+	int tmp;
 	struct in_addr sin_addr;
-	register struct hostent *host = 0;
-	register char c;
+	struct hostent *host = 0;
+	char c;
 
 	/*
 	 * Verify the arguments, and make sure we have
@@ -2715,16 +2720,18 @@ sourceroute(arg, cpp, lenp)
 			sin_addr.s_addr = tmp;
 		} else if (host = gethostbyname(cp)) {
 #if	defined(h_addr)
-			memmove((caddr_t)&sin_addr,
-				host->h_addr_list[0], host->h_length);
+			memmove(&sin_addr,
+				host->h_addr_list[0],
+				sizeof(sin_addr));
 #else
-			memmove((caddr_t)&sin_addr, host->h_addr, host->h_length);
+			memmove(&sin_addr, host->h_addr,
+				sizeof(sin_addr));
 #endif
 		} else {
 			*cpp = cp;
 			return(0);
 		}
-		memmove(lsrp, (char *)&sin_addr, 4);
+		memmove(lsrp, &sin_addr, 4);
 		lsrp += 4;
 		if (cp2)
 			cp = cp2;
