@@ -38,8 +38,12 @@ static char copyright[] =
 #endif /* not lint */
 
 #include <config.h>
+#ifdef SOCKS
+#include <socks.h>
+#endif
+#include "roken.h"
 
-RCSID("$Id: main.c,v 1.12 1996/06/03 04:12:20 joda Exp $");
+RCSID("$Id: main.c,v 1.16 1996/11/17 20:23:26 assar Exp $");
 
 #include <sys/types.h>
 #include <string.h>
@@ -60,7 +64,7 @@ RCSID("$Id: main.c,v 1.12 1996/06/03 04:12:20 joda Exp $");
 /*
  * Initialize variables.
  */
-    void
+void
 tninit()
 {
     init_terminal();
@@ -99,8 +103,6 @@ void usage(void)
 
 int main(int argc, char **argv)
 {
-	extern char *optarg;
-	extern int optind;
 	int ch;
 	char *user;
 #ifdef	FORWARD
@@ -130,7 +132,7 @@ int main(int argc, char **argv)
 	 */
 	autologin = -1;
 
-	while ((ch = getopt(argc, argv, "78EKLS:X:acde:fFk:l:n:rt:x")) != EOF) {
+	while((ch = getopt(argc, argv, "78DEKLS:X:acde:fFk:l:n:rx")) != EOF) {
 		switch(ch) {
 		case '8':
 			eight = 3;	/* binary output and input */
@@ -138,6 +140,13 @@ int main(int argc, char **argv)
 		case '7':
 			eight = 0;
 			break;
+		case 'D': {
+		    /* sometimes we don't want a mangled display */
+		    char *p;
+		    if((p = getenv("DISPLAY")))
+			env_define("DISPLAY", p);
+		    break;
+		}
 		case 'E':
 			rlogin = escape = _POSIX_VDISABLE;
 			break;
@@ -220,7 +229,7 @@ int main(int argc, char **argv)
 			extern char *dest_realm, dst_realm_buf[];
 			extern int dst_realm_sz;
 			dest_realm = dst_realm_buf;
-			(void)strncpy(dest_realm, optarg, dst_realm_sz);
+			strncpy(dest_realm, optarg, dst_realm_sz);
 		    }
 #else
 			fprintf(stderr,
@@ -297,7 +306,7 @@ int main(int argc, char **argv)
 		else
 			return (1);
 	}
-	(void)setjmp(toplevel);
+	setjmp(toplevel);
 	for (;;) {
 			command(1, 0, 0);
 	}
