@@ -32,8 +32,11 @@
  */
 
 #include <config.h>
+#ifdef SOCKS
+#include <socks.h>
+#endif
 
-RCSID("$Id: network.c,v 1.5 1996/03/27 11:42:41 bg Exp $");
+RCSID("$Id: network.c,v 1.8 1996/11/17 20:23:26 assar Exp $");
 
 #include <sys/types.h>
 #ifdef HAVE_SYS_SELECT_H
@@ -92,7 +95,7 @@ stilloob()
 
     if (value < 0) {
 	perror("select");
-	(void) quit();
+	quit();
 	/* NOTREACHED */
     }
     if (FD_ISSET(net, &excepts)) {
@@ -129,7 +132,7 @@ setneturg()
     int
 netflush()
 {
-    register int n, n1;
+    int n, n1;
 
 #if	defined(ENCRYPTION)
     if (encrypt_output)
@@ -154,7 +157,7 @@ netflush()
 	if (errno != ENOBUFS && errno != EWOULDBLOCK) {
 	    setcommandmode();
 	    perror(hostname);
-	    (void)NetClose(net);
+	    NetClose(net);
 	    ring_clear_mark(&netoring);
 	    longjmp(peerdied, -1);
 	    /*NOTREACHED*/
@@ -171,7 +174,7 @@ netflush()
 	 * up the other half.
 	 */
 	if ((n1 == n) && ring_full_consecutive(&netoring)) {
-	    (void) netflush();
+	    netflush();
 	}
 	return 1;
     } else {
