@@ -32,8 +32,11 @@
  */
 
 #include <config.h>
+#ifdef SOCKS
+#include <socks.h>
+#endif
 
-RCSID("$Id: sys_bsd.c,v 1.8 1996/05/13 01:49:40 joda Exp $");
+RCSID("$Id: sys_bsd.c,v 1.11 1996/11/17 20:23:27 assar Exp $");
 
 /*
  * The following routines try to encapsulate what is system dependent
@@ -210,9 +213,9 @@ void
 TerminalFlushOutput()
 {
 #ifdef	TIOCFLUSH
-    (void) ioctl(fileno(stdout), TIOCFLUSH, (char *) 0);
+    ioctl(fileno(stdout), TIOCFLUSH, (char *) 0);
 #else
-    (void) ioctl(fileno(stdout), TCFLSH, (char *) 0);
+    ioctl(fileno(stdout), TCFLSH, (char *) 0);
 #endif
 }
 
@@ -484,10 +487,10 @@ TerminalNewMode(int f)
 #endif
 
 #ifdef	SIGTSTP
-	(void) signal(SIGTSTP, susp);
+	signal(SIGTSTP, susp);
 #endif	/* SIGTSTP */
 #ifdef	SIGINFO
-	(void) signal(SIGINFO, ayt);
+	signal(SIGINFO, ayt);
 #endif
 #ifdef NOKERNINFO
 	tmp_tc.c_lflag |= NOKERNINFO;
@@ -523,10 +526,10 @@ TerminalNewMode(int f)
 #ifdef	SIGINFO
 	RETSIGTYPE ayt_status();
 
-	(void) signal(SIGINFO, ayt_status);
+	signal(SIGINFO, ayt_status);
 #endif
 #ifdef	SIGTSTP
-	(void) signal(SIGTSTP, SIG_DFL);
+	signal(SIGTSTP, SIG_DFL);
 	sigemptyset(&sm);
 	sigaddset(&sm, SIGTSTP);
 	sigprocmask(SIG_UNBLOCK, &sm, NULL);
@@ -612,9 +615,9 @@ TerminalSpeeds(ispeed, ospeed)
     long *ospeed;
 {
 #ifdef	DECODE_BAUD
-    register struct termspeeds *tp;
+    struct termspeeds *tp;
 #endif	/* DECODE_BAUD */
-    register long in, out;
+    long in, out;
 
     out = cfgetospeed(&old_tc);
     in = cfgetispeed(&old_tc);
@@ -754,17 +757,17 @@ ayt(sig)
     void
 sys_telnet_init()
 {
-    (void) signal(SIGINT, intr);
-    (void) signal(SIGQUIT, intr2);
-    (void) signal(SIGPIPE, deadpeer);
+    signal(SIGINT, intr);
+    signal(SIGQUIT, intr2);
+    signal(SIGPIPE, deadpeer);
 #ifdef	SIGWINCH
-    (void) signal(SIGWINCH, sendwin);
+    signal(SIGWINCH, sendwin);
 #endif
 #ifdef	SIGTSTP
-    (void) signal(SIGTSTP, susp);
+    signal(SIGTSTP, susp);
 #endif
 #ifdef	SIGINFO
-    (void) signal(SIGINFO, ayt);
+    signal(SIGINFO, ayt);
 #endif
 
     setconnmode(0);
@@ -794,7 +797,7 @@ sys_telnet_init()
 process_rings(netin, netout, netex, ttyin, ttyout, poll)
     int poll;		/* If 0, then block until something to do */
 {
-    register int c;
+    int c;
 		/* One wants to be a bit careful about setting returnValue
 		 * to one, since a one implies we did some useful work,
 		 * and therefore probably won't be called to block next
@@ -842,7 +845,7 @@ process_rings(netin, netout, netex, ttyin, ttyout, poll)
     if (FD_ISSET(net, &xbits)) {
 	FD_CLR(net, &xbits);
 	SYNCHing = 1;
-	(void) ttyflush(1);	/* flush already enqueued data */
+	ttyflush(1);	/* flush already enqueued data */
     }
 
     /*
