@@ -32,8 +32,11 @@
  */
 
 #include <config.h>
+#ifdef SOCKS
+#include <socks.h>
+#endif
 
-RCSID("$Id: utilities.c,v 1.9 1996/08/13 23:37:41 assar Exp $");
+RCSID("$Id: utilities.c,v 1.12 1996/11/17 20:23:28 assar Exp $");
 
 #define	TELOPTS
 #define	TELCMDS
@@ -69,7 +72,7 @@ int	prettydump;
 void
 upcase(char *argument)
 {
-    register int c;
+    int c;
 
     while ((c = *argument) != 0) {
 	if (islower(c)) {
@@ -184,7 +187,7 @@ printoption(char *direction, int cmd, int option)
 		else
 		    fprintf(NetTrace, "%s IAC %d", direction, option);
 	} else {
-		register char *fmt;
+		char *fmt;
 		fmt = (cmd == WILL) ? "WILL" : (cmd == WONT) ? "WONT" :
 			(cmd == DO) ? "DO" : (cmd == DONT) ? "DONT" : 0;
 		if (fmt) {
@@ -210,7 +213,7 @@ printoption(char *direction, int cmd, int option)
 void
 optionstatus(void)
 {
-    register int i;
+    int i;
     extern char will_wont_resp[], do_dont_resp[];
 
     for (i = 0; i < 256; i++) {
@@ -287,7 +290,7 @@ optionstatus(void)
 void
 printsub(char direction, unsigned char *pointer, int length)
 {
-    register int i;
+    int i;
     char buf[512];
     extern int want_status_response;
 
@@ -297,7 +300,7 @@ printsub(char direction, unsigned char *pointer, int length)
 	    fprintf(NetTrace, "%s IAC SB ",
 				(direction == '<')? "RCVD":"SENT");
 	    if (length >= 3) {
-		register int j;
+		int j;
 
 		i = pointer[length-2];
 		j = pointer[length-1];
@@ -648,8 +651,8 @@ printsub(char direction, unsigned char *pointer, int length)
 	    break;
 
 	case TELOPT_STATUS: {
-	    register char *cp;
-	    register int j, k;
+	    char *cp;
+	    int j, k;
 
 	    fprintf(NetTrace, "STATUS");
 
@@ -762,7 +765,7 @@ printsub(char direction, unsigned char *pointer, int length)
 		fprintf(NetTrace, "INFO ");
 	    env_common:
 		{
-		    register int noquote = 2;
+		    int noquote = 2;
 		    for (i = 2; i < length; i++ ) {
 			switch (pointer[i]) {
 			case NEW_ENV_VALUE:
@@ -854,13 +857,13 @@ EmptyTerminal(void)
 
     if (TTYBYTES() == 0) {
 	FD_SET(tout, &outs);
-	(void) select(tout+1, 0, &outs, 0,
+	select(tout+1, 0, &outs, 0,
 		      (struct timeval *) 0); /* wait for TTLOWAT */
     } else {
 	while (TTYBYTES()) {
-	    (void) ttyflush(0);
+	    ttyflush(0);
 	    FD_SET(tout, &outs);
-	    (void) select(tout+1, 0, &outs, 0,
+	    select(tout+1, 0, &outs, 0,
 			  (struct timeval *) 0); /* wait for TTLOWAT */
 	}
     }
@@ -871,7 +874,7 @@ SetForExit(void)
 {
     setconnmode(0);
     do {
-	(void)telrcv();			/* Process any incoming data */
+	telrcv();			/* Process any incoming data */
 	EmptyTerminal();
     } while (ring_full_count(&netiring));	/* While there is any */
     setcommandmode();
