@@ -35,8 +35,11 @@
  */
 
 #include <config.h>
+#ifdef SOCKS
+#include <socks.h>
+#endif
 
-RCSID("$Id: global.c,v 1.7 1996/02/26 16:58:55 d91-jda Exp $");
+RCSID("$Id: global.c,v 1.11 1996/11/17 00:19:59 assar Exp $");
 
 #include "defs.h"
 #include "ext.h"
@@ -63,12 +66,7 @@ int	restartany;	/* restart output on any character state */
 #ifdef DIAGNOSTICS
 int	diagnostic;	/* telnet diagnostic capabilities */
 #endif /* DIAGNOSTICS */
-#ifdef BFTPDAEMON
-int	bftpd;		/* behave as bftp daemon */
-#endif /* BFTPDAEMON */
-#if	defined(SecurID)
-int	require_SecurID;
-#endif
+int	require_otp;
 
 slcfun	slctab[NSLC + 1];	/* slc mapping table */
 
@@ -86,11 +84,6 @@ char	*neturg;		/* one past last bye of urgent data */
 
 int	pcc, ncc;
 
-#if defined(CRAY2) && defined(UNICOS5)
-int unpcc;  /* characters left unprocessed by CRAY-2 terminal routine */
-char *unptyip;  /* pointer to remaining characters in buffer */
-#endif
-
 int	ourpty, net;
 int	SYNCHing;		/* we are in TELNET SYNCH mode */
 
@@ -104,3 +97,6 @@ struct clocks_t clocks;
 
 /* whether to log unauthenticated login attempts */
 int log_unauth;
+
+/* do not print warning if connection is not encrypted */
+int no_warn;
