@@ -32,8 +32,11 @@
  */
 
 #include <config.h>
+#ifdef SOCKS
+#include <socks.h>
+#endif
 
-RCSID("$Id: state.c,v 1.5 1996/02/09 23:51:58 d91-jda Exp $");
+RCSID("$Id: state.c,v 1.9 1996/11/17 20:23:30 assar Exp $");
 
 #include "telnetd.h"
 #if	defined(AUTHENTICATION)
@@ -84,11 +87,8 @@ unsigned char *subsave;
 	void
 telrcv(void)
 {
-	register int c;
+	int c;
 	static int state = TS_DATA;
-#if	defined(CRAY2) && defined(UNICOS5)
-	char *opfrontp = pfrontp;
-#endif
 
 	while (ncc > 0) {
 		if ((&ptyobuf[BUFSIZ] - pfrontp) < 2)
@@ -360,21 +360,6 @@ gotiac:			switch (c) {
 			exit(1);
 		}
 	}
-#if	defined(CRAY2) && defined(UNICOS5)
-	if (!linemode) {
-		char	xptyobuf[BUFSIZ+NETSLOP];
-		char	xbuf2[BUFSIZ];
-		register char *cp;
-		int n = pfrontp - opfrontp, oc;
-		memmove(xptyobuf, opfrontp, n);
-		pfrontp = opfrontp;
-		pfrontp += term_input(xptyobuf, pfrontp, n, BUFSIZ+NETSLOP,
-					xbuf2, &oc, BUFSIZ);
-		for (cp = xbuf2; oc > 0; --oc)
-			if ((*nfrontp++ = *cp++) == IAC)
-				*nfrontp++ = IAC;
-	}
-#endif	/* defined(CRAY2) && defined(UNICOS5) */
 }  /* end of telrcv */
 
 /*
@@ -451,7 +436,7 @@ send_do(int option, int init)
 			set_his_want_state_will(option);
 		do_dont_resp[option]++;
 	}
-	(void) sprintf(nfrontp, (char *)doopt, option);
+	sprintf(nfrontp, (char *)doopt, option);
 	nfrontp += sizeof (dont) - 2;
 
 	DIAG(TD_OPTIONS, printoption("td: send do", option));
@@ -670,7 +655,7 @@ send_dont(int option, int init)
 		set_his_want_state_wont(option);
 		do_dont_resp[option]++;
 	}
-	(void) sprintf(nfrontp, (char *)dont, option);
+	sprintf(nfrontp, (char *)dont, option);
 	nfrontp += sizeof (doopt) - 2;
 
 	DIAG(TD_OPTIONS, printoption("td: send dont", option));
@@ -817,7 +802,7 @@ send_will(int option, int init)
 		set_my_want_state_will(option);
 		will_wont_resp[option]++;
 	}
-	(void) sprintf(nfrontp, (char *)will, option);
+	sprintf(nfrontp, (char *)will, option);
 	nfrontp += sizeof (doopt) - 2;
 
 	DIAG(TD_OPTIONS, printoption("td: send will", option));
@@ -929,7 +914,7 @@ dooption(int option)
 			set_my_want_state_will(TELOPT_LOGOUT);
 			send_will(TELOPT_LOGOUT, 0);
 			set_my_state_will(TELOPT_LOGOUT);
-			(void)netflush();
+			netflush();
 			cleanup(0);
 			/* NOT REACHED */
 			break;
@@ -974,7 +959,7 @@ send_wont(int option, int init)
 		set_my_want_state_wont(option);
 		will_wont_resp[option]++;
 	}
-	(void) sprintf(nfrontp, (char *)wont, option);
+	sprintf(nfrontp, (char *)wont, option);
 	nfrontp += sizeof (wont) - 2;
 
 	DIAG(TD_OPTIONS, printoption("td: send wont", option));
@@ -1088,14 +1073,14 @@ int env_ovalue = -1;
 	void
 suboption(void)
 {
-    register int subchar;
+    int subchar;
 
     DIAG(TD_OPTIONS, {netflush(); printsub('<', subpointer, SB_LEN()+2);});
 
     subchar = SB_GET();
     switch (subchar) {
     case TELOPT_TSPEED: {
-	register int xspeed, rspeed;
+	int xspeed, rspeed;
 
 	if (his_state_is_wont(TELOPT_TSPEED))	/* Ignore if option disabled */
 		break;
@@ -1133,7 +1118,7 @@ suboption(void)
 
 	while ((terminaltype < (terminalname + sizeof terminalname-1)) &&
 								    !SB_EOF()) {
-	    register int c;
+	    int c;
 
 	    c = SB_GET();
 	    if (isupper(c)) {
@@ -1147,7 +1132,7 @@ suboption(void)
     }  /* end of case TELOPT_TTYPE */
 
     case TELOPT_NAWS: {
-	register int xwinsize, ywinsize;
+	int xwinsize, ywinsize;
 
 	if (his_state_is_wont(TELOPT_NAWS))	/* Ignore if option disabled */
 		break;
@@ -1172,7 +1157,7 @@ suboption(void)
 
 #ifdef	LINEMODE
     case TELOPT_LINEMODE: {
-	register int request;
+	int request;
 
 	if (his_state_is_wont(TELOPT_LINEMODE))	/* Ignore if option disabled */
 		break;
@@ -1192,7 +1177,7 @@ suboption(void)
 		 */
 		start_slc(1);
 		do_opt_slc(subpointer, subend - subpointer);
-		(void) end_slc(0);
+		end_slc(0);
 		break;
 	} else if (request == LM_MODE) {
 		if (SB_EOF())
@@ -1244,7 +1229,7 @@ suboption(void)
 		return;
 	settimer(xdisplocsubopt);
 	subpointer[SB_LEN()] = '\0';
-	(void)setenv("DISPLAY", (char *)subpointer, 1);
+	setenv("DISPLAY", (char *)subpointer, 1);
 	break;
     }  /* end of case TELOPT_XDISPLOC */
 
@@ -1252,8 +1237,8 @@ suboption(void)
     case TELOPT_NEW_ENVIRON:
 #endif
     case TELOPT_OLD_ENVIRON: {
-	register int c;
-	register char *cp, *varp, *valp;
+	int c;
+	char *cp, *varp, *valp;
 
 	if (SB_EOF())
 		return;
@@ -1284,7 +1269,7 @@ suboption(void)
 	     * reversed.
 	     */
 	    if (env_ovar < 0) {
-		register int last = -1;		/* invalid value */
+		int last = -1;		/* invalid value */
 		int empty = 0;
 		int got_var = 0, got_value = 0, got_uservar = 0;
 
@@ -1411,7 +1396,7 @@ suboption(void)
 		case ENV_USERVAR:
 			*cp = '\0';
 			if (valp)
-				(void)setenv(varp, valp, 1);
+				setenv(varp, valp, 1);
 			else
 				unsetenv(varp);
 			cp = varp = (char *)subpointer;
@@ -1430,7 +1415,7 @@ suboption(void)
 	}
 	*cp = '\0';
 	if (valp)
-		(void)setenv(varp, valp, 1);
+		setenv(varp, valp, 1);
 	else
 		unsetenv(varp);
 	break;
@@ -1518,8 +1503,8 @@ doclientstat(void)
 send_status(void)
 {
 	unsigned char statusbuf[256];
-	register unsigned char *ncp;
-	register unsigned char i;
+	unsigned char *ncp;
+	unsigned char i;
 
 	ncp = statusbuf;
 
