@@ -32,8 +32,11 @@
  */
 
 #include <config.h>
+#ifdef SOCKS
+#include <socks.h>
+#endif
 
-RCSID("$Id: sys_term.c,v 1.46 1996/08/24 23:13:03 joda Exp $");
+RCSID("$Id: sys_term.c,v 1.56 1996/11/19 22:48:39 assar Exp $");
 
 #include "telnetd.h"
 #include "pathnames.h"
@@ -42,49 +45,38 @@ RCSID("$Id: sys_term.c,v 1.46 1996/08/24 23:13:03 joda Exp $");
 #include <libtelnet/auth.h>
 #endif
 
-#if defined(CRAY) || defined(__hpux)
+#if defined(CRAY) || (defined(__hpux) && !defined(HAVE_UTMPX_H))
 # define PARENT_DOES_UTMP
 #endif
 
-#ifdef	NEWINIT
-#include <initreq.h>
-int	utmp_len = MaxHostNameLen;	/* sizeof(init_request.host) */
-#else	/* NEWINIT*/
-# ifdef	HAVE_UTMPX
-# include <utmpx.h>
+#ifdef  NEWINIT
+#error NEWINIT not supported
+#endif
+
+#ifdef HAVE_UTMPX
+#include <utmpx.h>
 struct	utmpx wtmp;
-# else
-# include <utmp.h>
+#else
+#include <utmp.h>
 struct	utmp wtmp;
-# endif /* HAVE_UTMPX */
+#endif /* HAVE_UTMPX */
 
 #ifdef HAVE_UT_HOST
 int	utmp_len = sizeof(wtmp.ut_host);
 #else
 int	utmp_len = MaxHostNameLen;
 #endif
-# ifndef PARENT_DOES_UTMP
+#ifndef PARENT_DOES_UTMP
 char	wtmpf[]	= "/usr/adm/wtmp";
 char	utmpf[] = "/etc/utmp";
-# else /* PARENT_DOES_UTMP */
+#else /* PARENT_DOES_UTMP */
 char	wtmpf[]	= "/etc/wtmp";
-# endif /* PARENT_DOES_UTMP */
+#endif /* PARENT_DOES_UTMP */
 
-# ifdef CRAY
+#ifdef CRAY
 #include <tmpdir.h>
 #include <sys/wait.h>
-#  if (UNICOS_LVL == '7.0') || (UNICOS_LVL == '7.1')
-#   define UNICOS7x
-#  endif
-
-#  ifdef UNICOS7x
-#include <sys/sysv.h>
-#include <sys/secstat.h>
-extern int secflag;
-extern struct sysv sysv;
-#  endif /* UNICOS7x */
-# endif	/* CRAY */
-#endif	/* NEWINIT */
+#endif	/* CRAY */
 
 #ifdef	STREAMSPTY
 
@@ -95,7 +87,7 @@ extern struct sysv sysv;
 #include <sys/stropts.h>
 #endif
 
-#define SCPYN(a, b)	(void) strncpy(a, b, sizeof(a))
+#define SCPYN(a, b)	strncpy(a, b, sizeof(a))
 #define SCMPN(a, b)	strncmp(a, b, sizeof(a))
 
 #ifdef	HAVE_SYS_STREAM_H
@@ -127,10 +119,6 @@ extern struct sysv sysv;
 #undef	t_lnextc
 #endif
 
-#if defined(UNICOS5) && defined(CRAY2) && !defined(EXTPROC)
-# define EXTPROC 0400
-#endif
-
 # ifndef	TCSANOW
 #  ifdef TCSETS
 #   define	TCSANOW		TCSETS
@@ -163,7 +151,8 @@ extern struct sysv sysv;
 # endif /* TCSANOW */
 struct termios termbuf, termbuf2;	/* pty control structure */
 # ifdef  STREAMSPTY
-int ttyfd = -1;
+static int ttyfd = -1;
+int really_stream = 0;
 # endif
 
 char *new_login = LOGIN_PATH;
@@ -183,10 +172,11 @@ void
 init_termbuf(void)
 {
 # ifdef  STREAMSPTY
-	(void) tcgetattr(ttyfd, &termbuf);
-# else
-	(void) tcgetattr(ourpty, &termbuf);
+	if (really_stream)
+		tcgetattr(ttyfd, &termbuf);
+	else
 # endif
+		tcgetattr(ourpty, &termbuf);
 	termbuf2 = termbuf;
 }
 
@@ -198,7 +188,7 @@ copy_termbuf(cp, len)
 {
 	if (len > sizeof(termbuf))
 		len = sizeof(termbuf);
-	memmove((char *)&termbuf, cp, len);
+	memmove(&termbuf, cp, len);
 	termbuf2 = termbuf;
 }
 #endif	/* defined(LINEMODE) && defined(TIOCPKT_IOCTL) */
@@ -209,15 +199,13 @@ set_termbuf(void)
 	/*
 	 * Only make the necessary changes.
 	 */
-	if (memcmp((char *)&termbuf, (char *)&termbuf2, sizeof(termbuf)))
+	if (memcmp(&termbuf, &termbuf2, sizeof(termbuf)))
 # ifdef  STREAMSPTY
-		(void) tcsetattr(ttyfd, TCSANOW, &termbuf);
-# else
-		(void) tcsetattr(ourpty, TCSANOW, &termbuf);
-# endif
-# if	defined(CRAY2) && defined(UNICOS5)
-	needtermstat = 1;
+		if (really_stream)
+			tcsetattr(ttyfd, TCSANOW, &termbuf);
+		else
 # endif
+			tcsetattr(ourpty, TCSANOW, &termbuf);
 }
 
 
@@ -345,7 +333,6 @@ getnpty()
 }
 #endif /* CRAY */
 
-#ifndef	convex
 /*
  * getpty()
  *
@@ -456,6 +443,7 @@ int getpty(int *ptynum)
 	    unlockpt(p);
 #endif
 	    strcpy(line, ptsname(p));
+	    really_stream = 1;
 	    return p;
 	  }
 	}
@@ -463,11 +451,11 @@ int getpty(int *ptynum)
 #ifndef CRAY
 
 #ifndef	__hpux
-	(void) sprintf(line, "/dev/ptyXX");
+	sprintf(line, "/dev/ptyXX");
 	p1 = &line[8];
 	p2 = &line[9];
 #else
-	(void) sprintf(line, "/dev/ptym/ptyXX");
+	sprintf(line, "/dev/ptym/ptyXX");
 	p1 = &line[13];
 	p2 = &line[14];
 #endif
@@ -515,23 +503,23 @@ int getpty(int *ptynum)
 	struct stat sb;
 
 	for (*ptynum = lowpty; *ptynum <= highpty; (*ptynum)++) {
-		(void) sprintf(myline, "/dev/pty/%03d", *ptynum);
+		sprintf(myline, "/dev/pty/%03d", *ptynum);
 		p = open(myline, 2);
 		if (p < 0)
 			continue;
-		(void) sprintf(line, "/dev/ttyp%03d", *ptynum);
+		sprintf(line, "/dev/ttyp%03d", *ptynum);
 		/*
 		 * Here are some shenanigans to make sure that there
 		 * are no listeners lurking on the line.
 		 */
 		if(stat(line, &sb) < 0) {
-			(void) close(p);
+			close(p);
 			continue;
 		}
 		if(sb.st_uid || sb.st_gid || sb.st_mode != 0600) {
 			chown(line, 0, 0);
 			chmod(line, 0600);
-			(void)close(p);
+			close(p);
 			p = open(myline, 2);
 			if (p < 0)
 				continue;
@@ -543,7 +531,7 @@ int getpty(int *ptynum)
 			return(p);
 		else {
 			/* no tty side to pty so skip it */
-			(void) close(p);
+			close(p);
 		}
 	}
 #endif	/* CRAY */
@@ -551,7 +539,6 @@ int getpty(int *ptynum)
 #endif /* OPENPTY */
 	return(-1);
 #endif
-#endif
 }
 
 #ifdef	LINEMODE
@@ -576,18 +563,11 @@ int getpty(int *ptynum)
  * tty_rspeed(val)	Set receive speed to val.
  */
 
-#ifdef convex
-static int linestate;
-#endif
 
 	int
 tty_linemode()
 {
-#ifndef convex
 	return(termbuf.c_lflag & EXTPROC);
-#else
-	return(linestate);
-#endif
 }
 
 	void
@@ -595,15 +575,9 @@ tty_setlinemode(on)
 	int on;
 {
 #ifdef	TIOCEXT
-# ifndef convex
 	set_termbuf();
-# else
-	linestate = on;
-# endif
-	(void) ioctl(ourpty, TIOCEXT, (char *)&on);
-# ifndef convex
+	ioctl(ourpty, TIOCEXT, (char *)&on);
 	init_termbuf();
-# endif
 #else	/* !TIOCEXT */
 # ifdef	EXTPROC
 	if (on)
@@ -853,7 +827,7 @@ struct termspeeds {
 tty_tspeed(int val)
 {
 #ifdef	DECODE_BAUD
-	register struct termspeeds *tp;
+	struct termspeeds *tp;
 
 	for (tp = termspeeds; (tp->speed != -1) && (val > tp->speed); tp++)
 		;
@@ -869,7 +843,7 @@ tty_tspeed(int val)
 tty_rspeed(int val)
 {
 #ifdef	DECODE_BAUD
-	register struct termspeeds *tp;
+	struct termspeeds *tp;
 
 	for (tp = termspeeds; (tp->speed != -1) && (val > tp->speed); tp++)
 		;
@@ -881,39 +855,15 @@ tty_rspeed(int val)
 #endif	/* DECODE_BAUD */
 }
 
-#if	defined(CRAY2) && defined(UNICOS5)
-	int
-tty_isnewmap()
-{
-	return((termbuf.c_oflag & OPOST) && (termbuf.c_oflag & ONLCR) &&
-			!(termbuf.c_oflag & ONLRET));
-}
-#endif
-
 #ifdef PARENT_DOES_UTMP
-# ifndef NEWINIT
 extern	struct utmp wtmp;
 extern char wtmpf[];
-# else	/* NEWINIT */
-int	gotalarm;
 
-/* ARGSUSED */
-void
-nologinproc(int sig)
-{
-	gotalarm++;
-}
-# endif	/* NEWINIT */
-#endif /* PARENT_DOES_UTMP */
-
-#ifndef	NEWINIT
-# ifdef PARENT_DOES_UTMP
 extern void utmp_sig_init P((void));
 extern void utmp_sig_reset P((void));
 extern void utmp_sig_wait P((void));
 extern void utmp_sig_notify P((int));
 # endif /* PARENT_DOES_UTMP */
-#endif
 
 #ifdef STREAMSPTY
 
@@ -982,9 +932,8 @@ static void maybe_push_modules(int fd, char **modules)
  */
 void getptyslave(void)
 {
-	register int t = -1;
+	int t = -1;
 
-#if	!defined(CRAY) || !defined(NEWINIT)
 # ifdef	LINEMODE
 	int waslm;
 # endif
@@ -1018,8 +967,8 @@ void getptyslave(void)
 # ifdef	TIOCNOTTY
 	t = open(_PATH_TTY, O_RDWR);
 	if (t >= 0) {
-		(void) ioctl(t, TIOCNOTTY, (char *)0);
-		(void) close(t);
+		ioctl(t, TIOCNOTTY, (char *)0);
+		close(t);
 	}
 # endif
 #endif
@@ -1044,6 +993,7 @@ void getptyslave(void)
 	 * don't flag it as a fatal error if they don't exist.
 	 */
 
+	if (really_stream)
 	{
 	  /* these are the streams modules that we want pushed. note
 	     that they are in reverse order, ptem will be pushed
@@ -1070,10 +1020,10 @@ void getptyslave(void)
 	init_termbuf();
 # ifdef	TIOCGWINSZ
 	if (def_row || def_col) {
-		memset((char *)&ws, 0, sizeof(ws));
+		memset(&ws, 0, sizeof(ws));
 		ws.ws_col = def_col;
 		ws.ws_row = def_row;
-		(void)ioctl(t, TIOCSWINSZ, (char *)&ws);
+		ioctl(t, TIOCSWINSZ, (char *)&ws);
 	}
 # endif
 
@@ -1118,9 +1068,8 @@ void getptyslave(void)
 	set_termbuf();
 	if (login_tty(t) == -1)
 		fatalperror(net, "login_tty");
-#endif	/* !defined(CRAY) || !defined(NEWINIT) */
 	if (net > 2)
-		(void) close(net);
+		close(net);
 #if	defined(AUTHENTICATION) && defined(NO_LOGIN_F) && defined(LOGIN_R)
 	/*
 	 * Leave the pty open so that we can write out the rlogin
@@ -1128,13 +1077,12 @@ void getptyslave(void)
 	 */
 #else
 	if (ourpty > 2) {
-		(void) close(ourpty);
+		close(ourpty);
 		ourpty = -1;
 	}
 #endif
 }
 
-#if	!defined(CRAY) || !defined(NEWINIT)
 #ifndef	O_NOCTTY
 #define	O_NOCTTY	0
 #endif
@@ -1145,45 +1093,26 @@ void getptyslave(void)
 
 int cleanopen(char *line)
 {
-	register int t;
-#ifdef	UNICOS7x
-	struct secstat secbuf;
-#endif	/* UNICOS7x */
+	int t;
 
-#ifndef STREAMSPTY
-	/*
-	 * Make sure that other people can't open the
-	 * slave side of the connection.
-	 */
-	(void) chown(line, 0, 0);
-	(void) chmod(line, 0600);
+#ifdef STREAMSPTY
+	if (!really_stream)
 #endif
+	{
+		/*
+		 * Make sure that other people can't open the
+		 * slave side of the connection.
+		 */
+		chown(line, 0, 0);
+		chmod(line, 0600);
+	}
 
 # if !defined(CRAY) && (BSD > 43)
-	(void) revoke(line);
+	revoke(line);
 # endif
-#ifdef	UNICOS7x
-	if (secflag) {
-		if (secstat(line, &secbuf) < 0)
-			return(-1);
-		if (setulvl(secbuf.st_slevel) < 0)
-			return(-1);
-		if (setucmp(secbuf.st_compart) < 0)
-			return(-1);
-	}
-#endif	/* UNICOS7x */
 
 	t = open(line, O_RDWR|O_NOCTTY);
 
-#ifdef	UNICOS7x
-	if (secflag) {
-		if (setulvl(sysv.sy_minlvl) < 0)
-			return(-1);
-		if (setucmp(0) < 0)
-			return(-1);
-	}
-#endif	/* UNICOS7x */
-
 	if (t < 0)
 		return(-1);
 
@@ -1192,54 +1121,33 @@ int cleanopen(char *line)
 	 * ourselves.
 	 */
 # if !(defined(CRAY) || defined(__hpux)) && (BSD <= 43) && !defined(STREAMSPTY)
-	(void) signal(SIGHUP, SIG_IGN);
+	signal(SIGHUP, SIG_IGN);
 #ifdef HAVE_VHANGUP
 	vhangup();
 #else
 #endif
-	(void) signal(SIGHUP, SIG_DFL);
+	signal(SIGHUP, SIG_DFL);
 	t = open(line, O_RDWR|O_NOCTTY);
 	if (t < 0)
 		return(-1);
 # endif
 # if	defined(CRAY) && defined(TCVHUP)
 	{
-		register int i;
-		(void) signal(SIGHUP, SIG_IGN);
-		(void) ioctl(t, TCVHUP, (char *)0);
-		(void) signal(SIGHUP, SIG_DFL);
-
-#ifdef	UNICOS7x
-		if (secflag) {
-			if (secstat(line, &secbuf) < 0)
-				return(-1);
-			if (setulvl(secbuf.st_slevel) < 0)
-				return(-1);
-			if (setucmp(secbuf.st_compart) < 0)
-				return(-1);
-		}
-#endif	/* UNICOS7x */
+		int i;
+		signal(SIGHUP, SIG_IGN);
+		ioctl(t, TCVHUP, (char *)0);
+		signal(SIGHUP, SIG_DFL);
 
 		i = open(line, O_RDWR);
 
-#ifdef	UNICOS7x
-		if (secflag) {
-			if (setulvl(sysv.sy_minlvl) < 0)
-				return(-1);
-			if (setucmp(0) < 0)
-				return(-1);
-		}
-#endif	/* UNICOS7x */
-
 		if (i < 0)
 			return(-1);
-		(void) close(t);
+		close(t);
 		t = i;
 	}
 # endif	/* defined(CRAY) && defined(TCVHUP) */
 	return(t);
 }
-#endif	/* !defined(CRAY) || !defined(NEWINIT) */
 
 #if !defined(BSD4_4)
 
@@ -1281,29 +1189,25 @@ int login_tty(int t)
 	 * it out before opening the tty...
 	 */
 #if defined HAVE_SETPGID
-	(void) setpgid(0, 0);
+	setpgid(0, 0);
 #else
-	(void) setpgrp(0, 0); /* if setpgid isn't available, setpgrp
+	setpgrp(0, 0); /* if setpgid isn't available, setpgrp
 				 probably takes arguments */
 #endif
 	close(open(line, O_RDWR));
 # endif
 	if (t != 0)
-		(void) dup2(t, 0);
+		dup2(t, 0);
 	if (t != 1)
-		(void) dup2(t, 1);
+		dup2(t, 1);
 	if (t != 2)
-		(void) dup2(t, 2);
+		dup2(t, 2);
 	if (t > 2)
 		close(t);
 	return(0);
 }
 #endif	/* BSD <= 43 */
 
-#ifdef	NEWINIT
-char *gen_id = "fe";
-#endif
-
 /*
  * startslave(host)
  *
@@ -1315,14 +1219,8 @@ char *gen_id = "fe";
 	void
 startslave(char *host, int autologin, char *autoname)
 {
-	register int i;
+	int i;
 	char name[256];
-#ifdef	NEWINIT
-	extern char *ptyip;
-	struct init_request request;
-	void nologinproc();
-	register int n;
-#endif	/* NEWINIT */
 
 #if	defined(AUTHENTICATION)
 	if (!autoname || !autoname[0])
@@ -1339,11 +1237,10 @@ startslave(char *host, int autologin, char *autoname)
 	  "\r\n*** Connection not encrypted! "
 	  "Communication may be eavesdropped. ***\r\n";
 #ifdef ENCRYPTION
-	if (encrypt_output == 0 || decrypt_input == 0)
+	if (!no_warn && (encrypt_output == 0 || decrypt_input == 0))
 #endif
 	  writenet((unsigned char*)tbuf, strlen(tbuf));
       }
-#ifndef	NEWINIT
 # ifdef	PARENT_DOES_UTMP
 	utmp_sig_init();
 # endif	/* PARENT_DOES_UTMP */
@@ -1357,7 +1254,7 @@ startslave(char *host, int autologin, char *autoname)
 		 * signal to child to tell when done.  Child waits for signal
 		 * before doing anything important.
 		 */
-		register int pid = i;
+		int pid = i;
 		void sigjob P((int));
 
 		setpgrp();
@@ -1365,7 +1262,7 @@ startslave(char *host, int autologin, char *autoname)
 		/*
 		 * Create utmp entry for child
 		 */
-		(void) time(&wtmp.ut_time);
+		time(&wtmp.ut_time);
 		wtmp.ut_type = LOGIN_PROCESS;
 		wtmp.ut_pid = pid;
 		SCPYN(wtmp.ut_user, "LOGIN");
@@ -1379,11 +1276,11 @@ startslave(char *host, int autologin, char *autoname)
 		pututline(&wtmp);
 		endutent();
 		if ((i = open(wtmpf, O_WRONLY|O_APPEND)) >= 0) {
-			(void) write(i, (char *)&wtmp, sizeof(struct utmp));
-			(void) close(i);
+			write(i, &wtmp, sizeof(struct utmp));
+			close(i);
 		}
 #ifdef	CRAY
-		(void) signal(WJSIGNAL, sigjob);
+		signal(WJSIGNAL, sigjob);
 #endif
 		utmp_sig_notify(pid);
 # endif	/* PARENT_DOES_UTMP */
@@ -1392,60 +1289,6 @@ startslave(char *host, int autologin, char *autoname)
 	  start_login(host, autologin, autoname);
 	  /*NOTREACHED*/
 	}
-#else	/* NEWINIT */
-
-	/*
-	 * Init will start up login process if we ask nicely.  We only wait
-	 * for it to start up and begin normal telnet operation.
-	 */
-	if ((i = open(INIT_FIFO, O_WRONLY)) < 0) {
-		char tbuf[128];
-		(void) sprintf(tbuf, "Can't open %s\n", INIT_FIFO);
-		fatalperror(net, tbuf);
-	}
-	memset((char *)&request, 0, sizeof(request));
-	request.magic = INIT_MAGIC;
-	SCPYN(request.gen_id, gen_id);
-	SCPYN(request.tty_id, &line[8]);
-	SCPYN(request.host, host);
-	SCPYN(request.term_type, terminaltype ? terminaltype : "network");
-#if	!defined(UNICOS5)
-	request.signal = SIGCLD;
-	request.pid = getpid();
-#endif
-#ifdef BFTPDAEMON
-	/*
-	 * Are we working as the bftp daemon?
-	 */
-	if (bftpd) {
-		SCPYN(request.exec_name, BFTPPATH);
-	}
-#endif /* BFTPDAEMON */
-	if (write(i, (char *)&request, sizeof(request)) < 0) {
-		char tbuf[128];
-		(void) sprintf(tbuf, "Can't write to %s\n", INIT_FIFO);
-		fatalperror(net, tbuf);
-	}
-	(void) close(i);
-	(void) signal(SIGALRM, nologinproc);
-	for (i = 0; ; i++) {
-		char tbuf[128];
-		alarm(15);
-		n = read(ourpty, ptyip, BUFSIZ);
-		if (i == 3 || n >= 0 || !gotalarm)
-			break;
-		gotalarm = 0;
-		sprintf(tbuf, "telnetd: waiting for /etc/init to start login process on %s\r\n", line);
-		(void) write(net, tbuf, strlen(tbuf));
-	}
-	if (n < 0 && gotalarm)
-		fatal(net, "/etc/init didn't start login process");
-	pcc += n;
-	alarm(0);
-	(void) signal(SIGALRM, SIG_DFL);
-
-	return;
-#endif	/* NEWINIT */
 }
 
 char	*envinit[3];
@@ -1468,8 +1311,6 @@ init_env(void)
 	environ = envinit;
 }
 
-#ifndef	NEWINIT
-
 /*
  * scrub_env()
  *
@@ -1486,10 +1327,11 @@ static void scrub_env(void)
   char **p;
   
   for (cpp2 = cpp = environ; *cpp; cpp++) {
-    for(p = remove; *p; p++)
-      if(strncmp(*cpp, *p, strlen(*p)) == 0)
-	continue;
-    *cpp2++ = *cpp;
+      for(p = remove; *p; p++)
+	  if(strncmp(*cpp, *p, strlen(*p)) == 0)
+	      break;
+      if(*p == NULL)
+	  *cpp2++ = *cpp;
   }
   *cpp2 = 0;
 }
@@ -1512,14 +1354,14 @@ int addarg(struct arg_val*, char*);
 
 void start_login(char *host, int autologin, char *name)
 {
-	register char *cp;
+	char *cp;
 	struct arg_val argv;
 	extern char *getenv(const char *);
 
 #ifdef	HAVE_UTMPX
 	char id_buf[3];
 	int ptynum;
-	register int pid = getpid();
+	int pid = getpid();
 	struct utmpx utmpx;
 #endif
 
@@ -1589,28 +1431,15 @@ void start_login(char *host, int autologin, char *name)
 		setenv("LINEMODE", "kludge", 1);
 # endif
 #endif
-#ifdef	BFTPDAEMON
-	/*
-	 * Are we working as the bftp daemon?  If so, then ask login
-	 * to start bftp instead of shell.
-	 */
-	if (bftpd) {
-		addarg(&argv, "-e");
-		addarg(&argv, BFTPPATH);
-	} else
-#endif
-#if	defined (SecurID)
-	/*
-	 * don't worry about the -f that might get sent.
-	 * A -s is supposed to override it anyhow.
-	 */
-	if (require_SecurID)
-		addarg(&argv, "-s");
-#endif
 #if	defined (AUTHENTICATION)
 	if (auth_level < 0 || autologin != AUTH_VALID) {
-		printf("User not authenticated. "
-		       "Using plaintext username and password\r\n");
+		if(!no_warn)
+		  printf("User not authenticated. "
+			 "Using plaintext username and password\r\n");
+		if (require_otp) {
+		  addarg(&argv, "-a");
+		  addarg(&argv, "otp");
+		}
 		if(log_unauth) {
 		  char *u;
 		  if(name[0]) u = name;
@@ -1636,7 +1465,7 @@ void start_login(char *host, int autologin, char *name)
 		 */
 
 		if (ourpty > 2) {
-			register char *cp;
+			char *cp;
 			char speed[128];
 			int isecho, israw, xpty, len;
 			extern int def_rspeed;
@@ -1658,11 +1487,13 @@ void start_login(char *host, int autologin, char *name)
 			addarg(&argv, LOGIN_HOST);
 
 			xpty = ourpty;
-# ifndef  STREAMSPTY
-			pty = 0;
-# else
-			ttyfd = 0;
-# endif
+#ifdef STREAMSPTY
+			if (really_stream)
+				ttyfd = 0;
+			else
+#endif
+				pty = 0;
+
 			init_termbuf();
 			isecho = tty_isecho();
 			israw = tty_israw();
@@ -1707,7 +1538,7 @@ void start_login(char *host, int autologin, char *name)
 		addarg(&argv, getenv("USER"));
 #if	defined(LOGIN_ARGS) && defined(NO_LOGIN_P)
 		{
-			register char **cpp;
+			char **cpp;
 			for (cpp = environ; *cpp; cpp++) {
 				addarg(&argv, *cpp);
 			}
@@ -1768,8 +1599,6 @@ int addarg(struct arg_val *argv, char *val)
 }
 
 
-#endif	/* NEWINIT */
-
 /*
  * rmut()
  *
@@ -1802,11 +1631,18 @@ rmut(void)
 	if (utxp) {
 	    strcpy(utxp->ut_user, "");
 	    utxp->ut_type = DEAD_PROCESS;
+#ifdef _STRUCT___EXIT_STATUS
+	    utxp->ut_exit.__e_termination = 0;
+	    utxp->ut_exit.__e_exit = 0;
+#else
 	    utxp->ut_exit.e_termination = 0;
 	    utxp->ut_exit.e_exit = 0;
+#endif
 	    gettimeofday(&utxp->ut_tv, NULL);
 	    pututxline(utxp);
+#ifdef WTMPX_FILE
 	    updwtmpx(WTMPX_FILE, utxp);
+#endif
 	}
 	endutxent();
 }  /* end of rmut */
@@ -1817,7 +1653,7 @@ static
 void
 rmut(void)
 {
-	register f;
+	int f;
 	int found = 0;
 	struct utmp *u, *utmp;
 	int nutmp;
@@ -1825,29 +1661,29 @@ rmut(void)
 
 	f = open(utmpf, O_RDWR);
 	if (f >= 0) {
-		(void) fstat(f, &statbf);
+		fstat(f, &statbf);
 		utmp = (struct utmp *)malloc((unsigned)statbf.st_size);
 		if (!utmp)
 			syslog(LOG_ERR, "utmp malloc failed");
 		if (statbf.st_size && utmp) {
-			nutmp = read(f, (char *)utmp, (int)statbf.st_size);
+			nutmp = read(f, utmp, (int)statbf.st_size);
 			nutmp /= sizeof(struct utmp);
 
 			for (u = utmp ; u < &utmp[nutmp] ; u++) {
 				if (SCMPN(u->ut_line, line+5) ||
 				    u->ut_name[0]==0)
 					continue;
-				(void) lseek(f, ((long)u)-((long)utmp), L_SET);
+				lseek(f, ((long)u)-((long)utmp), L_SET);
 				SCPYN(u->ut_name, "");
 #ifdef HAVE_UT_HOST
 				SCPYN(u->ut_host, "");
 #endif
-				(void) time(&u->ut_time);
-				(void) write(f, (char *)u, sizeof(wtmp));
+				time(&u->ut_time);
+				write(f, u, sizeof(wtmp));
 				found++;
 			}
 		}
-		(void) close(f);
+		close(f);
 	}
 	if (found) {
 		f = open(wtmpf, O_WRONLY|O_APPEND);
@@ -1857,20 +1693,20 @@ rmut(void)
 #ifdef HAVE_UT_HOST
 			SCPYN(wtmp.ut_host, "");
 #endif
-			(void) time(&wtmp.ut_time);
-			(void) write(f, (char *)&wtmp, sizeof(wtmp));
-			(void) close(f);
+			time(&wtmp.ut_time);
+			write(f, &wtmp, sizeof(wtmp));
+			close(f);
 		}
 	}
-	(void) chmod(line, 0666);
-	(void) chown(line, 0, 0);
+	chmod(line, 0666);
+	chown(line, 0, 0);
 	line[strlen("/dev/")] = 'p';
-	(void) chmod(line, 0666);
-	(void) chown(line, 0, 0);
+	chmod(line, 0666);
+	chown(line, 0, 0);
 }  /* end of rmut */
 #endif	/* CRAY */
 
-#ifdef __hpux
+#if defined(__hpux) && !defined(HAVE_UTMPX)
 static
 void
 rmut (char *line)
@@ -1880,24 +1716,24 @@ rmut (char *line)
 	int fd;			/* for /etc/wtmp */
 
 	utmp.ut_type = USER_PROCESS;
-	(void) strncpy(utmp.ut_id, line+12, sizeof(utmp.ut_id));
-	(void) setutent();
+	strncpy(utmp.ut_id, line+12, sizeof(utmp.ut_id));
+	setutent();
 	utptr = getutid(&utmp);
 	/* write it out only if it exists */
 	if (utptr) {
 		utptr->ut_type = DEAD_PROCESS;
 		utptr->ut_time = time((long *) 0);
-		(void) pututline(utptr);
+		pututline(utptr);
 		/* set wtmp entry if wtmp file exists */
 		if ((fd = open(wtmpf, O_WRONLY | O_APPEND)) >= 0) {
-			(void) write(fd, utptr, sizeof(utmp));
-			(void) close(fd);
+			write(fd, utptr, sizeof(utmp));
+			close(fd);
 		}
 	}
-	(void) endutent();
+	endutent();
 
-	(void) chmod(line, 0666);
-	(void) chown(line, 0, 0);
+	chmod(line, 0666);
+	chown(line, 0, 0);
 	line[14] = line[13];
 	line[13] = line[12];
 	line[8] = 'm';
@@ -1905,8 +1741,8 @@ rmut (char *line)
 	line[10] = 'p';
 	line[11] = 't';
 	line[12] = 'y';
-	(void) chmod(line, 0666);
-	(void) chown(line, 0, 0);
+	chmod(line, 0666);
+	chown(line, 0, 0);
 }
 #endif
 
@@ -1922,13 +1758,9 @@ rmut (char *line)
 void
 cleanup(int sig)
 {
-# ifdef	NEWINIT
-    shutdown(net, 2);
-    exit(1);
-# else	/* NEWINIT */
 #  ifdef CRAY
     static int incleanup = 0;
-    register int t;
+    int t;
     int child_status; /* status of child process as returned by waitpid */
     int flags = WNOHANG|WUNTRACED;
     
@@ -1959,36 +1791,22 @@ cleanup(int sig)
     }
     incleanup = 1;
     sigsetmask(t);
-#ifdef	UNICOS7x
-    if (secflag) {
-	/*
-	 *	We need to set ourselves back to a null
-	 *	label to clean up.
-	 */
-	
-	setulvl(sysv.sy_minlvl);
-	setucmp((long)0);
-    }
-#endif	/* UNICOS7x */
     
     t = cleantmp(&wtmp);
     setutent();	/* just to make sure */
 #  endif /* CRAY */
     rmut(line);
     close(ourpty);
-    (void) shutdown(net, 2);
+    shutdown(net, 2);
 #  ifdef CRAY
     if (t == 0)
 	cleantmp(&wtmp);
 #  endif /* CRAY */
     exit(1);
-# endif	/* NEWINT */
 }
 
 #else /* PARENT_DOES_UTMP */
 
-extern void rmut(void);
-
 void
 cleanup(int sig)
 {
@@ -2015,7 +1833,7 @@ cleanup(int sig)
 
 #endif /* PARENT_DOES_UTMP */
 
-#if defined(PARENT_DOES_UTMP) && !defined(NEWINIT)
+#if defined(PARENT_DOES_UTMP)
 /*
  * _utmp_sig_rcv
  * utmp_sig_init
@@ -2034,7 +1852,7 @@ _utmp_sig_rcv(sig)
 	int sig;
 {
 	caught = 1;
-	(void) signal(SIGUSR1, func);
+	signal(SIGUSR1, func);
 }
 
 	void
@@ -2050,7 +1868,7 @@ utmp_sig_init()
 	void
 utmp_sig_reset()
 {
-	(void) signal(SIGUSR1, func);	/* reset handler to default */
+	signal(SIGUSR1, func);	/* reset handler to default */
 }
 
 # ifdef __hpux
@@ -2086,8 +1904,8 @@ static int gotsigjob = 0;
 sigjob(sig)
 	int sig;
 {
-	register int jid;
-	register struct jobtemp *jp;
+	int jid;
+	struct jobtemp *jp;
 
 	while ((jid = waitjob(NULL)) != -1) {
 		if (jid == 0) {
@@ -2130,11 +1948,11 @@ jid_getutid(jid)
  */
 	int
 cleantmp(wtp)
-	register struct utmp *wtp;
+	struct utmp *wtp;
 {
 	struct utmp *utp;
 	static int first = 1;
-	register int mask, omask, ret;
+	int mask, omask, ret;
 	extern struct utmp *getutid P((const struct utmp *_Id));
 
 
@@ -2171,9 +1989,9 @@ cleantmp(wtp)
 
 	int
 jobend(jid, path, user)
-	register int jid;
-	register char *path;
-	register char *user;
+	int jid;
+	char *path;
+	char *user;
 {
 	static int saved_jid = 0;
 	static int pty_saved_jid = 0;
@@ -2233,9 +2051,9 @@ jobend(jid, path, user)
  * Fork a child process to clean up the TMPDIR
  */
 cleantmpdir(jid, tpath, user)
-	register int jid;
-	register char *tpath;
-	register char *user;
+	int jid;
+	char *tpath;
+	char *user;
 {
 	switch(fork()) {
 	case -1:
