@@ -34,8 +34,11 @@
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
+#ifdef SOCKS
+#include <socks.h>
+#endif
 
-RCSID("$Id: telnetd.c,v 1.23 1996/08/24 23:12:29 joda Exp $");
+RCSID("$Id: telnetd.c,v 1.35 1996/11/19 22:48:40 assar Exp $");
 
 #include "telnetd.h"
 #include "pathnames.h"
@@ -71,9 +74,6 @@ struct	socket_security ss;
 #include <libtelnet/auth.h>
 int	auth_level = 0;
 #endif
-#if	defined(SecurID)
-int	require_SecurID = 0;
-#endif
 
 extern	int utmp_len;
 int	registerd_host_only = 0;
@@ -153,26 +153,20 @@ char valid_opts[] = {
 #ifdef	AUTHENTICATION
 	'a', ':', 'X', ':',
 #endif
-#ifdef BFTPDAEMON
-	'B',
-#endif
 #ifdef DIAGNOSTICS
 	'D', ':',
 #endif
-#if	defined(CRAY) && defined(NEWINIT)
-	'I', ':',
-#endif
 #ifdef	LINEMODE
 	'l',
 #endif
 #ifdef CRAY
 	'r', ':',
-#endif
-#ifdef	SecurID
-	's',
 #endif
 	'L', ':',
+#ifdef AUTHENTICATION
+	'y',
 	'z',
+#endif
 	'\0'
 };
 
@@ -182,9 +176,7 @@ int main(int argc, char **argv)
 {
 	struct sockaddr_in from;
 	int on = 1, fromlen;
-	register int ch;
-	extern char *optarg;
-	extern int optind;
+	int ch;
 #if	defined(IPPROTO_IP) && defined(IP_TOS)
 	int tos = -1;
 #endif
@@ -218,10 +210,12 @@ int main(int argc, char **argv)
 			 * Check for required authentication level
 			 */
 			if (strcmp(optarg, "debug") == 0) {
-				extern int auth_debug_mode;
 				auth_debug_mode = 1;
 			} else if (strcasecmp(optarg, "none") == 0) {
 				auth_level = 0;
+			} else if (strcasecmp(optarg, "otp") == 0) {
+				auth_level = 0;
+				require_otp = 1;
 			} else if (strcasecmp(optarg, "other") == 0) {
 				auth_level = AUTH_OTHER;
 			} else if (strcasecmp(optarg, "user") == 0) {
@@ -240,12 +234,6 @@ int main(int argc, char **argv)
 			break;
 #endif	/* AUTHENTICATION */
 
-#ifdef BFTPDAEMON
-		case 'B':
-			bftpd++;
-			break;
-#endif /* BFTPDAEMON */
-
 		case 'd':
 			if (strcmp(optarg, "ebug") == 0) {
 				debug++;
@@ -282,15 +270,6 @@ int main(int argc, char **argv)
 			hostinfo = 0;
 			break;
 
-#if	defined(CRAY) && defined(NEWINIT)
-		case 'I':
-		    {
-			extern char *gen_id;
-			gen_id = optarg;
-			break;
-		    }
-#endif	/* defined(CRAY) && defined(NEWINIT) */
-
 #ifdef	LINEMODE
 		case 'l':
 			alwayslinemode = 1;
@@ -337,12 +316,6 @@ int main(int argc, char **argv)
 		    }
 #endif	/* CRAY */
 
-#ifdef	SecurID
-		case 's':
-			/* SecurID required */
-			require_SecurID = 1;
-			break;
-#endif	/* SecurID */
 		case 'S':
 #ifdef	HAS_GETTOS
 			if ((tos = parsetos(optarg, "tcp")) < 0)
@@ -370,6 +343,9 @@ int main(int argc, char **argv)
 			 */
 			auth_disable_name(optarg);
 			break;
+		case 'y':
+		  no_warn = 1;
+		  break;
 		case 'z':
 		  log_unauth = 1;
 		  break;
@@ -393,62 +369,21 @@ int main(int argc, char **argv)
 	argv += optind;
 
 	if (debug) {
-	    int s, ns, foo;
+	    int port;
 	    struct servent *sp;
-	    static struct sockaddr_in sin = { AF_INET };
 
 	    if (argc > 1) {
-		usage();
-		/* NOT REACHED */
+		usage ();
 	    } else if (argc == 1) {
-		    if (sp = getservbyname(*argv, "tcp")) {
-			sin.sin_port = sp->s_port;
-		    } else {
-			sin.sin_port = atoi(*argv);
-			if ((int)sin.sin_port <= 0) {
-			    fprintf(stderr, "telnetd: %s: bad port #\n", *argv);
-			    usage();
-			    /* NOT REACHED */
-			}
-			sin.sin_port = htons((u_short)sin.sin_port);
-		   }
+		sp = getservbyname (*argv, "tcp");
+		if (sp)
+		    port = sp->s_port;
+		else
+		    port = htons(atoi(*argv));
 	    } else {
-		sp = getservbyname("telnet", "tcp");
-		if (sp == 0) {
-		    fprintf(stderr, "telnetd: tcp/telnet: unknown service\n");
-		    exit(1);
-		}
-		sin.sin_port = sp->s_port;
+		port = k_getportbyname ("telnet", "tcp", htons(23));
 	    }
-
-	    s = socket(AF_INET, SOCK_STREAM, 0);
-	    if (s < 0) {
-		    perror("telnetd: socket");;
-		    exit(1);
-	    }
-	    (void) setsockopt(s, SOL_SOCKET, SO_REUSEADDR,
-				(void *)&on, sizeof(on));
-	    if (bind(s, (struct sockaddr *)&sin, sizeof sin) < 0) {
-		perror("bind");
-		exit(1);
-	    }
-	    if (listen(s, 1) < 0) {
-		perror("listen");
-		exit(1);
-	    }
-	    foo = sizeof sin;
-	    ns = accept(s, (struct sockaddr *)&sin, &foo);
-	    if (ns < 0) {
-		perror("accept");
-		exit(1);
-	    }
-	    (void) dup2(ns, 0);
-	    (void) close(ns);
-	    (void) close(s);
-#ifdef convex
-	} else if (argc == 1) {
-		; /* VOID*/		/* Just ignore the host/port name */
-#endif
+	    mini_inetd (port);
 	} else if (argc > 0) {
 		usage();
 		/* NOT REACHED */
@@ -467,7 +402,7 @@ int main(int argc, char **argv)
 		int szi = sizeof(int);
 #endif /* SO_SEC_MULTI */
 
-		memset((char *)&dv, 0, sizeof(dv));
+		memset(&dv, 0, sizeof(dv));
 
 		if (getsysv(&sysv, sizeof(struct sysv)) != 0) {
 			perror("getsysv");
@@ -550,10 +485,7 @@ usage()
 {
 	fprintf(stderr, "Usage: telnetd");
 #ifdef	AUTHENTICATION
-	fprintf(stderr, " [-a (debug|other|user|valid|off|none)]\n\t");
-#endif
-#ifdef BFTPDAEMON
-	fprintf(stderr, " [-B]");
+	fprintf(stderr, " [-a (debug|other|otp|user|valid|off|none)]\n\t");
 #endif
 	fprintf(stderr, " [-debug]");
 #ifdef DIAGNOSTICS
@@ -563,9 +495,6 @@ usage()
 	fprintf(stderr, " [-edebug]");
 #endif
 	fprintf(stderr, " [-h]");
-#if	defined(CRAY) && defined(NEWINIT)
-	fprintf(stderr, " [-Iinitid]");
-#endif
 #if	defined(LINEMODE) && defined(KLUDGELINEMODE)
 	fprintf(stderr, " [-k]");
 #endif
@@ -578,14 +507,11 @@ usage()
 	fprintf(stderr, " [-r[lowpty]-[highpty]]");
 #endif
 	fprintf(stderr, "\n\t");
-#ifdef	SecurID
-	fprintf(stderr, " [-s]");
-#endif
 #ifdef	HAS_GETTOS
 	fprintf(stderr, " [-S tos]");
 #endif
 #ifdef	AUTHENTICATION
-	fprintf(stderr, " [-X auth-type] [-z]");
+	fprintf(stderr, " [-X auth-type] [-y] [-z]");
 #endif
 	fprintf(stderr, " [-u utmp_hostname_length] [-U]");
 	fprintf(stderr, " [port]\n");
@@ -717,12 +643,12 @@ getterminaltype(name)
 	 * we have to just go with what we (might) have already gotten.
 	 */
 	if (his_state_is_will(TELOPT_TTYPE) && !terminaltypeok(terminaltype)) {
-	    (void) strncpy(first, terminaltype, sizeof(first));
+	    strncpy(first, terminaltype, sizeof(first));
 	    for(;;) {
 		/*
 		 * Save the unknown name, and request the next name.
 		 */
-		(void) strncpy(last, terminaltype, sizeof(last));
+		strncpy(last, terminaltype, sizeof(last));
 		_gettermname();
 		if (terminaltypeok(terminaltype))
 		    break;
@@ -741,7 +667,7 @@ getterminaltype(name)
 		     */
 		     _gettermname();
 		    if (strncmp(first, terminaltype, sizeof(first)) != 0)
-			(void) strcpy(terminaltype, first);
+			strcpy(terminaltype, first);
 		    break;
 		}
 	    }
@@ -795,11 +721,7 @@ char *hostname;
 char host_name[MaxHostNameLen];
 char remote_host_name[MaxHostNameLen];
 
-#ifndef	convex
 extern void telnet P((int, int));
-#else
-extern void telnet P((int, int, char *));
-#endif
 
 /*
  * Get a pty, scan input lines.
@@ -816,26 +738,10 @@ void doit(struct sockaddr_in *who)
 	/*
 	 * Find an available pty to use.
 	 */
-#ifndef	convex
 	ourpty = getpty(&ptynum);
 	if (ourpty < 0)
 		fatal(net, "All network ports in use");
 	set_utid();
-#else
-	for (;;) {
-		char *lp;
-		extern char *line, *getpty();
-
-		if ((lp = getpty()) == NULL)
-			fatal(net, "Out of ptys");
-
-		if ((ourpty = open(lp, 2)) >= 0) {
-			strcpy(line,lp);
-			line[5] = 't';
-			break;
-		}
-	}
-#endif
 
 #if	defined(_SC_CRAY_SECURE_SYS)
 	/*
@@ -873,15 +779,13 @@ void doit(struct sockaddr_in *who)
 	remote_host_name[sizeof(remote_host_name)-1] = 0;
 	host = remote_host_name;
 
-	(void) gethostname(host_name, sizeof (host_name));
+	k_gethostname(host_name, sizeof (host_name));
 	hostname = host_name;
 
 #ifndef abs
 #define abs(x) ((x < 0) ? (-x) : x)
 #endif
 
-#define TRIM_HOSTNAME
-#ifdef  TRIM_HOSTNAME
       /* Only trim if too long (and possible) */
       if (strlen(remote_host_name) > abs(utmp_len)) {
               char *domain = strchr(host_name, '.');
@@ -889,7 +793,7 @@ void doit(struct sockaddr_in *who)
               if (domain && p && (strcmp(p, domain) == 0))
                       *p = 0; /* remove domain part */
       }
-#endif /* TRIM_HOSTNAME */
+
 
       /*
        * If hostname still doesn't fit utmp, use ipaddr.
@@ -914,7 +818,6 @@ void doit(struct sockaddr_in *who)
 	/*
 	 * Start up the login process on the slave side of the terminal
 	 */
-#ifndef	convex
 	startslave(host, level, user_name);
 
 #if	defined(_SC_CRAY_SECURE_SYS)
@@ -927,41 +830,16 @@ void doit(struct sockaddr_in *who)
 #endif	/* _SC_CRAY_SECURE_SYS */
 
 	telnet(net, ourpty);  /* begin server processing */
-#else
-	telnet(net, ourpty, host);
-#endif
 	/*NOTREACHED*/
 }  /* end of doit */
 
-#if	defined(CRAY2) && defined(UNICOS5) && defined(UNICOS50)
-	int
-Xterm_output(ibufp, obuf, icountp, ocount)
-	char **ibufp, *obuf;
-	int *icountp, ocount;
-{
-	int ret;
-	ret = term_output(*ibufp, obuf, *icountp, ocount);
-	*ibufp += *icountp;
-	*icountp = 0;
-	return(ret);
-}
-#define	term_output	Xterm_output
-#endif	/* defined(CRAY2) && defined(UNICOS5) && defined(UNICOS50) */
-
 /*
  * Main loop.  Select from pty and network, and
  * hand data to telnet receiver finite state machine.
  */
 	void
-#ifndef	convex
 telnet(f, p)
-#else
-telnet(f, p, host)
-#endif
 	int f, p;
-#ifdef convex
-	char *host;
-#endif
 {
 	int on = 1;
 #define	TABBUFSIZ	512
@@ -1071,11 +949,14 @@ telnet(f, p, host)
 	if (my_state_is_wont(TELOPT_ECHO))
 		send_will(TELOPT_ECHO, 1);
 
-#ifndef	STREAMSPTY
-	/*
-	 * Turn on packet mode
-	 */
-	(void) ioctl(p, TIOCPKT, (char *)&on);
+#ifdef TIOCPKT
+#ifdef	STREAMSPTY
+	if (!really_stream)
+#endif
+		/*
+		 * Turn on packet mode
+		 */
+		ioctl(p, TIOCPKT, (char *)&on);
 #endif
 
 #if	defined(LINEMODE) && defined(KLUDGELINEMODE)
@@ -1095,61 +976,38 @@ telnet(f, p, host)
 	 */
 	telrcv();
 
-	(void) ioctl(f, FIONBIO, (char *)&on);
-	(void) ioctl(p, FIONBIO, (char *)&on);
-#if	defined(CRAY2) && defined(UNICOS5)
-	init_termdriver(f, p, interrupt, sendbrk);
-#endif
+	ioctl(f, FIONBIO, (char *)&on);
+	ioctl(p, FIONBIO, (char *)&on);
 
 #if	defined(SO_OOBINLINE)
-	(void) setsockopt(net, SOL_SOCKET, SO_OOBINLINE,
+	setsockopt(net, SOL_SOCKET, SO_OOBINLINE,
 				(void *)&on, sizeof on);
 #endif	/* defined(SO_OOBINLINE) */
 
 #ifdef	SIGTSTP
-	(void) signal(SIGTSTP, SIG_IGN);
+	signal(SIGTSTP, SIG_IGN);
 #endif
 #ifdef	SIGTTOU
 	/*
 	 * Ignoring SIGTTOU keeps the kernel from blocking us
 	 * in ttioct() in /sys/tty.c.
 	 */
-	(void) signal(SIGTTOU, SIG_IGN);
+	signal(SIGTTOU, SIG_IGN);
 #endif
 
-	(void) signal(SIGCHLD, cleanup);
-
-#if	defined(CRAY2) && defined(UNICOS5)
-	/*
-	 * Cray-2 will send a signal when pty modes are changed by slave
-	 * side.  Set up signal handler now.
-	 */
-	if ((int)signal(SIGUSR1, termstat) < 0)
-		perror("signal");
-	else if (ioctl(p, TCSIGME, (char *)SIGUSR1) < 0)
-		perror("ioctl:TCSIGME");
-	/*
-	 * Make processing loop check terminal characteristics early on.
-	 */
-	termstat();
-#endif
+	signal(SIGCHLD, cleanup);
 
 #ifdef  TIOCNOTTY
 	{
-		register int t;
+		int t;
 		t = open(_PATH_TTY, O_RDWR);
 		if (t >= 0) {
-			(void) ioctl(t, TIOCNOTTY, (char *)0);
-			(void) close(t);
+			ioctl(t, TIOCNOTTY, (char *)0);
+			close(t);
 		}
 	}
 #endif
 
-#if	defined(CRAY) && defined(NEWINIT) && defined(TIOCSCTTY)
-	(void) setsid();
-	ioctl(p, TIOCSCTTY, 0);
-#endif
-
 	/*
 	 * Show banner that getty never gave.
 	 *
@@ -1158,10 +1016,8 @@ telnet(f, p, host)
 	 * other pty --> client data.
 	 */
 
-#if	!defined(CRAY) || !defined(NEWINIT)
 	if (getenv("USER"))
 		hostinfo = 0;
-#endif
 
 	if (getent(defent, "default") == 1) {
 		char *getstr();
@@ -1171,7 +1027,7 @@ telnet(f, p, host)
 		HN = getstr("hn", &cp);
 		IM = getstr("im", &cp);
 		if (HN && *HN)
-			(void) strcpy(host_name, HN);
+			strcpy(host_name, HN);
 		if (IM == 0)
 			IM = "";
 	} else {
@@ -1183,7 +1039,7 @@ telnet(f, p, host)
 		putf(IM, ptyibuf2);
 
 	if (pcc)
-		(void) strncat(ptyibuf2, ptyip, pcc+1);
+		strncat(ptyibuf2, ptyip, pcc+1);
 	ptyip = ptyibuf2;
 	pcc = strlen(ptyip);
 #ifdef	LINEMODE
@@ -1198,22 +1054,15 @@ telnet(f, p, host)
 		{sprintf(nfrontp, "td: Entering processing loop\r\n");
 		 nfrontp += strlen(nfrontp);});
 
-#ifdef	convex
-	startslave(host);
-#endif
 
 	nfd = ((f > p) ? f : p) + 1;
 	for (;;) {
 		fd_set ibits, obits, xbits;
-		register int c;
+		int c;
 
 		if (ncc < 0 && pcc < 0)
 			break;
 
-#if	defined(CRAY2) && defined(UNICOS5)
-		if (needtermstat)
-			_termstat();
-#endif	/* defined(CRAY2) && defined(UNICOS5) */
 		FD_ZERO(&ibits);
 		FD_ZERO(&obits);
 		FD_ZERO(&xbits);
@@ -1294,7 +1143,7 @@ telnet(f, p, host)
 		    if (SYNCHing) {
 			int atmark;
 
-			(void) ioctl(net, SIOCATMARK, (char *)&atmark);
+			ioctl(net, SIOCATMARK, (char *)&atmark);
 			if (atmark) {
 			    ncc = recv(net, netibuf, sizeof (netibuf), MSG_OOB);
 			    if ((ncc == -1) && (errno == EINVAL)) {
@@ -1331,11 +1180,13 @@ telnet(f, p, host)
 		 * Something to read from the pty...
 		 */
 		if (FD_ISSET(p, &ibits)) {
-#ifndef	STREAMSPTY
-			pcc = read(p, ptyibuf, BUFSIZ);
-#else
-			pcc = readstream(p, ptyibuf, BUFSIZ);
+#ifdef STREAMSPTY
+			if (really_stream)
+				pcc = readstream(p, ptyibuf, BUFSIZ);
+			else
 #endif
+				pcc = read(p, ptyibuf, BUFSIZ);
+
 			/*
 			 * On some systems, if we try to read something
 			 * off the master side before the slave side is
@@ -1350,7 +1201,6 @@ telnet(f, p, host)
 			} else {
 				if (pcc <= 0)
 					break;
-#if	!defined(CRAY2) || !defined(UNICOS5)
 #ifdef	LINEMODE
 				/*
 				 * If ioctl from pty, pass it through net
@@ -1385,7 +1235,7 @@ telnet(f, p, host)
 					    ptyibuf[0] & TIOCPKT_DOSTOP ? 1 : 0;
 					if (newflow != flowmode) {
 						flowmode = newflow;
-						(void) sprintf(nfrontp,
+						sprintf(nfrontp,
 							"%c%c%c%c%c%c",
 							IAC, SB, TELOPT_LFLOW,
 							flowmode ? LFLOW_ON
@@ -1399,16 +1249,6 @@ telnet(f, p, host)
 				}
 				pcc--;
 				ptyip = ptyibuf+1;
-#else	/* defined(CRAY2) && defined(UNICOS5) */
-				if (!uselinemode) {
-					unpcc = pcc;
-					unptyip = ptyibuf;
-					pcc = term_output(&unptyip, ptyibuf2,
-								&unpcc, BUFSIZ);
-					ptyip = ptyibuf2;
-				} else
-					ptyip = ptyibuf;
-#endif	/* defined(CRAY2) && defined(UNICOS5) */
 			}
 		}
 
@@ -1418,11 +1258,6 @@ telnet(f, p, host)
 			c = *ptyip++ & 0377, pcc--;
 			if (c == IAC)
 				*nfrontp++ = c;
-#if	defined(CRAY2) && defined(UNICOS5)
-			else if (c == '\n' &&
-				     my_state_is_wont(TELOPT_BINARY) && newmap)
-				*nfrontp++ = '\r';
-#endif	/* defined(CRAY2) && defined(UNICOS5) */
 			*nfrontp++ = c;
 			if ((c == '\r') && (my_state_is_wont(TELOPT_BINARY))) {
 				if (pcc > 0 && ((*ptyip & 0377) == '\n')) {
@@ -1432,17 +1267,6 @@ telnet(f, p, host)
 					*nfrontp++ = '\0';
 			}
 		}
-#if	defined(CRAY2) && defined(UNICOS5)
-		/*
-		 * If chars were left over from the terminal driver,
-		 * note their existence.
-		 */
-		if (!uselinemode && unpcc) {
-			pcc = unpcc;
-			unpcc = 0;
-			ptyip = unptyip;
-		}
-#endif	/* defined(CRAY2) && defined(UNICOS5) */
 
 		if (FD_ISSET(f, &obits) && (nfrontp - nbackp) > 0)
 			netflush();
@@ -1565,14 +1389,15 @@ interrupt()
 
 #if defined(STREAMSPTY) && defined(TIOCSIGNAL)
 	/* Streams PTY style ioctl to post a signal */
+	if (really_stream)
 	{
 		int sig = SIGINT;
-		(void) ioctl(ourpty, TIOCSIGNAL, &sig);
-		(void) ioctl(ourpty, I_FLUSH, FLUSHR);
+		ioctl(ourpty, TIOCSIGNAL, &sig);
+		ioctl(ourpty, I_FLUSH, FLUSHR);
 	}
 #else
 #ifdef	TCSIG
-	(void) ioctl(ourpty, TCSIG, (char *)SIGINT);
+	ioctl(ourpty, TCSIG, (char *)SIGINT);
 #else	/* TCSIG */
 	init_termbuf();
 	*pfrontp++ = slctab[SLC_IP].sptr ?
@@ -1591,7 +1416,7 @@ sendbrk()
 {
 	ptyflush();	/* half-hearted */
 #ifdef	TCSIG
-	(void) ioctl(ourpty, TCSIG, (char *)SIGQUIT);
+	ioctl(ourpty, TCSIG, (char *)SIGQUIT);
 #else	/* TCSIG */
 	init_termbuf();
 	*pfrontp++ = slctab[SLC_ABORT].sptr ?
@@ -1605,7 +1430,7 @@ sendsusp()
 #ifdef	SIGTSTP
 	ptyflush();	/* half-hearted */
 # ifdef	TCSIG
-	(void) ioctl(ourpty, TCSIG, (char *)SIGTSTP);
+	ioctl(ourpty, TCSIG, (char *)SIGTSTP);
 # else	/* TCSIG */
 	*pfrontp++ = slctab[SLC_SUSP].sptr ?
 			(unsigned char)*slctab[SLC_SUSP].sptr : '\032';
@@ -1622,11 +1447,11 @@ recv_ayt()
 {
 #if	defined(SIGINFO) && defined(TCSIG)
 	if (slctab[SLC_AYT].sptr && *slctab[SLC_AYT].sptr != _POSIX_VDISABLE) {
-		(void) ioctl(ourpty, TCSIG, (char *)SIGINFO);
+		ioctl(ourpty, TCSIG, (char *)SIGINFO);
 		return;
 	}
 #endif
-	(void) strcpy(nfrontp, "\r\n[Yes]\r\n");
+	strcpy(nfrontp, "\r\n[Yes]\r\n");
 	nfrontp += 9;
 }
 
