@@ -32,8 +32,11 @@
  */
 
 #include <config.h>
+#ifdef SOCKS
+#include <socks.h>
+#endif
 
-RCSID("$Id: termstat.c,v 1.4 1996/02/04 16:14:04 assar Exp $");
+RCSID("$Id: termstat.c,v 1.9 1996/11/19 22:48:40 assar Exp $");
 
 #include "telnetd.h"
 
@@ -48,10 +51,6 @@ int def_row = 0, def_col = 0;
 static int _terminit = 0;
 #endif	/* LINEMODE */
 
-#if	defined(CRAY2) && defined(UNICOS5)
-int	newmap = 1;	/* nonzero if \n maps to ^M^J */
-#endif
-
 #ifdef	LINEMODE
 /*
  * localstat
@@ -135,14 +134,6 @@ localstat()
 	void netflush();
 	int need_will_echo = 0;
 
-#if	defined(CRAY2) && defined(UNICOS5)
-	/*
-	 * Keep track of that ol' CR/NL mapping while we're in the
-	 * neighborhood.
-	 */
-	newmap = tty_isnewmap();
-#endif	/* defined(CRAY2) && defined(UNICOS5) */
-
 	/*
 	 * Check for state of BINARY options.
 	 */
@@ -285,7 +276,7 @@ localstat()
 # endif	/* KLUDGELINEMODE */
 			send_do(TELOPT_LINEMODE, 1);
 			/* send along edit modes */
-			(void) sprintf(nfrontp, "%c%c%c%c%c%c%c", IAC, SB,
+			sprintf(nfrontp, "%c%c%c%c%c%c%c", IAC, SB,
 				TELOPT_LINEMODE, LM_MODE, useeditmode,
 				IAC, SE);
 			nfrontp += 7;
@@ -314,7 +305,7 @@ localstat()
 			/*
 			 * Send along appropriate edit mode mask.
 			 */
-			(void) sprintf(nfrontp, "%c%c%c%c%c%c%c", IAC, SB,
+			sprintf(nfrontp, "%c%c%c%c%c%c%c", IAC, SB,
 				TELOPT_LINEMODE, LM_MODE, useeditmode,
 				IAC, SE);
 			nfrontp += 7;
@@ -327,7 +318,7 @@ localstat()
 		 */
 		start_slc(0);
 		check_slc();
-		(void) end_slc(0);
+		end_slc(0);
 	}
 
 done:
@@ -361,7 +352,7 @@ flowstat()
 	if (his_state_is_will(TELOPT_LFLOW)) {
 		if (tty_flowmode() != flowmode) {
 			flowmode = tty_flowmode();
-			(void) sprintf(nfrontp, "%c%c%c%c%c%c",
+			sprintf(nfrontp, "%c%c%c%c%c%c",
 					IAC, SB, TELOPT_LFLOW,
 					flowmode ? LFLOW_ON : LFLOW_OFF,
 					IAC, SE);
@@ -369,7 +360,7 @@ flowstat()
 		}
 		if (tty_restartany() != restartany) {
 			restartany = tty_restartany();
-			(void) sprintf(nfrontp, "%c%c%c%c%c%c",
+			sprintf(nfrontp, "%c%c%c%c%c%c",
 					IAC, SB, TELOPT_LFLOW,
 					restartany ? LFLOW_RESTART_ANY
 						   : LFLOW_RESTART_XON,
@@ -389,7 +380,7 @@ flowstat()
  */
 	void
 clientstat(code, parm1, parm2)
-	register int code, parm1, parm2;
+	int code, parm1, parm2;
 {
 	void netflush();
 
@@ -447,7 +438,7 @@ clientstat(code, parm1, parm2)
 					useeditmode |= MODE_SOFT_TAB;
 				if (tty_islitecho())
 					useeditmode |= MODE_LIT_ECHO;
-				(void) sprintf(nfrontp, "%c%c%c%c%c%c%c", IAC,
+				sprintf(nfrontp, "%c%c%c%c%c%c%c", IAC,
 					SB, TELOPT_LINEMODE, LM_MODE,
 							useeditmode, IAC, SE);
 				nfrontp += 7;
@@ -466,7 +457,7 @@ clientstat(code, parm1, parm2)
 
 	case LM_MODE:
 	    {
-		register int ack, changed;
+		int ack, changed;
 
 		/*
 		 * Client has sent along a mode mask.  If it agrees with
@@ -506,7 +497,7 @@ clientstat(code, parm1, parm2)
 			set_termbuf();
 
  			if (!ack) {
- 				(void) sprintf(nfrontp, "%c%c%c%c%c%c%c", IAC,
+ 				sprintf(nfrontp, "%c%c%c%c%c%c%c", IAC,
 					SB, TELOPT_LINEMODE, LM_MODE,
  					useeditmode|MODE_ACK,
  					IAC, SE);
@@ -543,7 +534,7 @@ clientstat(code, parm1, parm2)
 
 		ws.ws_col = parm1;
 		ws.ws_row = parm2;
-		(void) ioctl(ourpty, TIOCSWINSZ, (char *)&ws);
+		ioctl(ourpty, TIOCSWINSZ, (char *)&ws);
 	    }
 #endif	/* TIOCSWINSZ */
 
@@ -579,34 +570,10 @@ clientstat(code, parm1, parm2)
 		break;
 	}  /* end of switch */
 
-#if	defined(CRAY2) && defined(UNICOS5)
-	/*
-	 * Just in case of the likely event that we changed the pty state.
-	 */
-	rcv_ioctl();
-#endif	/* defined(CRAY2) && defined(UNICOS5) */
-
 	netflush();
 
 }  /* end of clientstat */
 
-#if	defined(CRAY2) && defined(UNICOS5)
-	void
-termstat()
-{
-	needtermstat = 1;
-}
-
-	void
-_termstat()
-{
-	needtermstat = 0;
-	init_termbuf();
-	localstat();
-	rcv_ioctl();
-}
-#endif	/* defined(CRAY2) && defined(UNICOS5) */
-
 #ifdef	LINEMODE
 /*
  * defer_terminit
@@ -632,10 +599,10 @@ defer_terminit()
 	if (def_col || def_row) {
 		struct winsize ws;
 
-		memset((char *)&ws, 0, sizeof(ws));
+		memset(&ws, 0, sizeof(ws));
 		ws.ws_col = def_col;
 		ws.ws_row = def_row;
-		(void) ioctl(ourpty, TIOCSWINSZ, (char *)&ws);
+		ioctl(ourpty, TIOCSWINSZ, (char *)&ws);
 	}
 #endif
 
