@@ -9,7 +9,7 @@
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #include <protos.h>
-RCSID("$Id: xnlock.c,v 1.42 1996/06/24 00:08:29 assar Exp $");
+RCSID("$Id: xnlock.c,v 1.54 1996/11/24 05:19:48 joda Exp $");
 #endif
 
 #include <stdio.h>
@@ -22,21 +22,23 @@ RCSID("$Id: xnlock.c,v 1.42 1996/06/24 00:08:29 assar Exp $");
 #include <X11/Shell.h>
 #include <X11/Xos.h>
 #include <ctype.h>
+#ifdef HAVE_PWD_H
 #include <pwd.h>
+#endif
 
 #include <krb.h>
 #include <kafs.h>
 
 #include "roken.h"
 
-char inst[100];
-char name[100];
-char realm[REALM_SZ + 1];
+static char name[ANAME_SZ];
+static char inst[INST_SZ];
+static char realm[REALM_SZ + 1];
 
 #define font_height(font)	  	(font->ascent + font->descent)
 
-char *SPACE_STRING = "                                                      ";
-char STRING[] = "****************";
+static char *SPACE_STRING = "                                                      ";
+static char STRING[] = "****************";
 
 #define STRING_LENGTH (sizeof(STRING))
 #define MAX_PASSWD_LENGTH 256
@@ -54,36 +56,32 @@ char STRING[] = "****************";
 #define XNLOCK_CTRL 1
 #define XNLOCK_NOCTRL 0
 
-#ifndef min
-#define min(x,y) (((x)<(y))?(x):(y))
-#endif
-
-XtAppContext	app;
-Display        *dpy;
-unsigned short	Width, Height;
-Widget		widget;
-GC		gc;
-XtIntervalId	timeout_id;
-char	       *ProgName, *words;
-int		x, y;
-Pixel		Black, White;
-XFontStruct    *font;
-struct passwd  *pw;
-char		root_pw[16];
-int		time_left, prompt_x, prompt_y, time_x, time_y;
-unsigned long	interval;
-Pixmap		left0, left1, right0, right1, left_front,
-		right_front, front, down;
+static XtAppContext	app;
+static Display        *dpy;
+static unsigned short	Width, Height;
+static Widget		widget;
+static GC		gc;
+static XtIntervalId	timeout_id;
+static char	       *ProgName, *words;
+static int		x, y;
+static Pixel		Black, White;
+static XFontStruct    *font;
+static char		root_cpass[16];
+static char		user_cpass[16];
+static int		time_left, prompt_x, prompt_y, time_x, time_y;
+static unsigned long	interval;
+static Pixmap		left0, left1, right0, right1, left_front,
+			right_front, front, down;
 
 #define MAXLINES 40
 
 #define IS_MOVING  1
 #define GET_PASSWD 2
-int state; /* indicates states: walking or getting passwd */
+static int state; /* indicates states: walking or getting passwd */
 
-int ALLOW_LOGOUT = (60*10);	/* Allow logout after nn seconds */
-char LOGOUT_PASSWD[] = "LOGOUT"; /* when given password "xx" */
-time_t locked_at;
+static int ALLOW_LOGOUT = (60*10);	/* Allow logout after nn seconds */
+static char LOGOUT_PASSWD[] = "LOGOUT"; /* when given password "xx" */
+static time_t locked_at;
 
 struct appres_t {
     Pixel bg;
@@ -168,7 +166,9 @@ get_words(void)
     return appres.text;
 }
 
-void usage(void)
+static
+void
+usage(void)
 {
     fprintf(stderr, "usage: %s [options] [message]\n", ProgName);
     fprintf(stderr, "-fg color     foreground color\n");
@@ -241,7 +241,7 @@ static void talk(int force_erase);
 static unsigned long look(void);
 
 static int
-zrefresh()
+zrefresh(void)
 {
   switch (fork()) {
   case -1:
@@ -251,9 +251,6 @@ zrefresh()
       /* Child */
       execlp("zrefresh", "zrefresh", 0);
       execl(BINDIR "/zrefresh", "zrefresh", 0);
-#if 0
-      fprintf(stderr, "Warning %s: Failed to exec zrefresh\n", ProgName);
-#endif
       return -1;
   default:
       /* Parent */
@@ -276,7 +273,7 @@ leave(void)
 static void
 walk(int dir)
 {
-    register int incr = 0;
+    int incr = 0;
     static int lastdir;
     static int up = 1;
     static Pixmap frame;
@@ -356,7 +353,7 @@ move(XtPointer _p, XtIntervalId *_id)
     static int length, dir;
 
     if (!length) {
-	register int tries = 0;
+	int tries = 0;
 	dir = 0;
 	if ((rand() & 1) && think()) {
 	    talk(0); /* sets timeout to itself */
@@ -508,10 +505,10 @@ countdown(XtPointer _t, XtIntervalId *_d)
     }
     seconds = time(0) - locked_at;
     if (seconds >= 3600)
-      (void) sprintf(buf, "Locked for %d:%02d:%02d    ",
+      sprintf(buf, "Locked for %d:%02d:%02d    ",
                    (int)seconds/3600, (int)seconds/60%60, (int)seconds%60);
     else
-      (void) sprintf(buf, "Locked for %2d:%02d    ",
+      sprintf(buf, "Locked for %2d:%02d    ",
 		     (int)seconds/60, (int)seconds%60);
       
     XDrawImageString(dpy, XtWindow(widget), gc,
@@ -528,9 +525,10 @@ verify(char *password)
     /*
      * First try with root password, if allowed.
      */
-    
-    if(appres.accept_root && verify_unix_user("root", password) == 0)
-	return 0;
+    if (   appres.accept_root
+	&& strcmp(crypt(password, root_cpass), root_cpass) == 0)
+      return 0;
+
     /*
      * Password that log out user
      */
@@ -564,9 +562,15 @@ verify(char *password)
     }
     
     /*
-     * Try to verify as user.
+     * Try copy of users password.
      */
-    if(verify_unix_user(name, password) == 0)
+    if (strcmp(crypt(password, user_cpass), user_cpass) == 0)
+      return 0;
+
+    /*
+     * Try to verify as user in case password change.
+     */
+    if(unix_verify_user(name, password) == 0)
 	return 0;
     return -1;
 }
@@ -592,7 +596,7 @@ GetPasswd(Widget w, XEvent *_event, String *_s, Cardinal *_n)
 	/* guy is running around--change to post prompt box. */
 	XtRemoveTimeOut(timeout_id);
 	state = GET_PASSWD;
-	if (appres.ignore_passwd || !strlen(pw->pw_passwd))
+	if (appres.ignore_passwd || !strlen(user_cpass))
 	    leave();
 	post_prompt_box(XtWindow(w));
 	cnt = 0;
@@ -698,7 +702,7 @@ talk(int force_erase)
     int width = 0, height, Z, total = 0;
     static int X, Y, talking;
     static struct { int x, y, width, height; } s_rect;
-    register char *p, *p2;
+    char *p, *p2;
     char buf[BUFSIZ], args[MAXLINES][256];
 
     /* clear what we've written */
@@ -729,7 +733,7 @@ talk(int force_erase)
      * if no CR or only one, then just print the line
      */
     if (!(p2 = strchr(p, '\n')) || !p2[1]) {
-	register int w;
+	int w;
 
 	if (p2)
 	    *p2 = 0;
@@ -838,10 +842,33 @@ look(void)
 int
 main (int argc, char **argv)
 {
-    register int i;
+    int i;
     Widget override;
     XGCValues gcvalues;
 
+    /*
+     * Must be setuid root to read /etc/shadow, copy encrypted
+     * passwords here and then switch to sane uid.
+     */
+    {
+      struct passwd *pw;
+      if (!(pw = k_getpwuid(0)))
+	{
+	  fprintf(stderr, "%s: can't get root's passwd!\n", ProgName);
+	  exit(1);
+	}
+      strcpy(root_cpass, pw->pw_passwd);
+
+      if (!(pw = k_getpwuid(getuid())))
+	{
+	  fprintf(stderr, "%s: Can't get your password entry!\n", ProgName);
+	  exit(1);
+	} 
+      strcpy(user_cpass, pw->pw_passwd);
+      setuid(getuid());
+      /* Now we're no longer running setuid root. */
+    }
+
     srand(getpid());
     for (i = 0; i < STRING_LENGTH; i++)
 	STRING[i] = ((unsigned long)rand() % ('~' - ' ')) + ' ';
@@ -853,22 +880,11 @@ main (int argc, char **argv)
     else
 	ProgName = *argv;
 
-    /* getpwuid() returns static pointer, so get root's passwd first */
-    if (!(pw = getpwuid(0))){
-	fprintf(stderr, "%s: can't get root's passwd!\n", ProgName);
-	exit(1);
-    }
-    strcpy(root_pw, pw->pw_passwd);
-    if (!(pw = getpwuid(getuid()))){
-      fprintf(stderr, "%s: Can't get your password entry!\n", ProgName);
-      exit(1);
-    } 
-
     krb_get_default_principal(name, inst, realm);
     
 
     override = XtVaAppInitialize(&app, "XNlock", options, XtNumber(options),
-				 &argc, argv, NULL, 
+				 (Cardinal*)&argc, argv, NULL, 
 				 XtNoverrideRedirect, True, 
 				 NULL);
     
