@@ -35,7 +35,7 @@ or implied warranty.
 
 #include "kadm_locl.h"
 
-RCSID("$Id: admin_server.c,v 1.30 1996/08/22 19:16:29 assar Exp $");
+RCSID("$Id: admin_server.c,v 1.35 1996/11/19 22:48:41 assar Exp $");
 
 /* Almost all procs and such need this, so it is global */
 admin_params prm;		/* The command line parameters struct */
@@ -62,14 +62,14 @@ RETSIGTYPE
 do_child(int sig)
 {
     int pid;
-    register int i, j;
+    int i, j;
 
     int status;
 
     pid = wait(&status);
 
     /* Reinstall signal handlers for SysV. Must be done *after* wait */
-    (void) signal(SIGCHLD, do_child);
+    signal(SIGCHLD, do_child);
 
     for (i = 0; i < pidarraysize; i++)
 	if (pidarray[i] == pid) {
@@ -80,11 +80,11 @@ do_child(int sig)
 	    pidarraysize--;
 	    if ((WIFEXITED(status) && WEXITSTATUS(status) != 0)
 		|| WIFSIGNALED(status))
-	      k_log("child %d: termsig %d, retcode %d", pid,
+	      krb_log("child %d: termsig %d, retcode %d", pid,
 		  WTERMSIG(status), WEXITSTATUS(status));
 	    SIGRETURN(0);
 	}
-    k_log("child %d not in list: termsig %d, retcode %d", pid,
+    krb_log("child %d not in list: termsig %d, retcode %d", pid,
 	WTERMSIG(status), WEXITSTATUS(status));
     SIGRETURN(0);
 }
@@ -96,7 +96,7 @@ kill_children(void)
 
     for (i = 0; i < pidarraysize; i++) {
 	kill(pidarray[i], SIGINT);
-	k_log("killing child %d", pidarray[i]);
+	krb_log("killing child %d", pidarray[i]);
     }
 }
 
@@ -104,7 +104,7 @@ kill_children(void)
 static void
 close_syslog(void)
 {
-   k_log("Shutting down admin server");
+   krb_log("Shutting down admin server");
 }
 
 static void
@@ -150,12 +150,12 @@ process_client(int fd, struct sockaddr_in *who)
     int status;
 
     if (setsockopt(fd, SOL_SOCKET, SO_KEEPALIVE, (void *)&on, sizeof(on)) < 0)
-	k_log("setsockopt keepalive: %d",errno);
+	krb_log("setsockopt keepalive: %d",errno);
 
     server_parm.recv_addr = *who;
 
     if (kerb_init()) {			/* Open as client */
-	k_log("can't open krb db");
+	krb_log("can't open krb db");
 	cleanexit(1);
     }
     /* need to set service key to changepw.KRB_MASTER */
@@ -175,7 +175,7 @@ process_client(int fd, struct sockaddr_in *who)
       memcpy(pdat+KADM_VERSIZE, &retcode, sizeof(retcode));
       goto out;
     } else if (!status) {
-      k_log("no service %s.%s",server_parm.sname, server_parm.sinst);
+      krb_log("no service %s.%s",server_parm.sname, server_parm.sinst);
       cleanexit(2);
     }
 
@@ -183,7 +183,7 @@ process_client(int fd, struct sockaddr_in *who)
     memset(&service, 0, sizeof(service));
     kdb_encrypt_key (&skey, &skey, &server_parm.master_key,
 		     server_parm.master_key_schedule, DES_DECRYPT);
-    krb_set_key((char *)skey, 0); /* if error, will show up when
+    krb_set_key(skey, 0); /* if error, will show up when
 					    rd_req fails */
     memset(skey, 0, sizeof(skey));
 
@@ -191,9 +191,9 @@ process_client(int fd, struct sockaddr_in *who)
 	if ((retval = krb_net_read(fd, &dlen, sizeof(u_short))) !=
 	    sizeof(u_short)) {
 	    if (retval < 0)
-		k_log("dlen read: %s",error_message(errno));
+		krb_log("dlen read: %s",error_message(errno));
 	    else if (retval)
-		k_log("short dlen read: %d",retval);
+		krb_log("short dlen read: %d",retval);
 	    close(fd);
 	    cleanexit(retval ? 3 : 0);
 	}
@@ -203,15 +203,15 @@ process_client(int fd, struct sockaddr_in *who)
 	dat_len = (int) ntohs(dlen);
 	dat = (u_char *) malloc((unsigned)dat_len);
 	if (!dat) {
-	    k_log("malloc: No memory");
-	    (void) close(fd);
+	    krb_log("malloc: No memory");
+	    close(fd);
 	    cleanexit(4);
 	}
 	if ((retval = krb_net_read(fd, dat, dat_len)) != dat_len) {
 	    if (retval < 0)
-		k_log("data read: %s",error_message(errno));
+		krb_log("data read: %s",error_message(errno));
 	    else
-		k_log("short read: %d vs. %d", dat_len, retval);
+		krb_log("short read: %d vs. %d", dat_len, retval);
 	    close(fd);
 	    cleanexit(5);
 	}
@@ -219,7 +219,7 @@ process_client(int fd, struct sockaddr_in *who)
 	    cleanexit(0);
 	}
 	if ((retval = kadm_ser_in(&dat,&dat_len)) != KADM_SUCCESS)
-	    k_log("processing request: %s", error_message(retval));
+	    krb_log("processing request: %s", error_message(retval));
     
 	/* kadm_ser_in did the processing and returned stuff in
 	   dat & dat_len , return the appropriate data */
@@ -234,13 +234,13 @@ process_client(int fd, struct sockaddr_in *who)
 	dlen = htons(dlen);
     
 	if (krb_net_write(fd, &dlen, sizeof(u_short)) < 0) {
-	    k_log("writing dlen to client: %s",error_message(errno));
+	    krb_log("writing dlen to client: %s",error_message(errno));
 	    close(fd);
 	    cleanexit(6);
 	}
     
 	if (krb_net_write(fd, dat, dat_len) < 0) {
-	    k_log("writing to client: %s", error_message(errno));
+	    krb_log("writing to client: %s", error_message(errno));
 	    close(fd);
 	    cleanexit(7);
 	}
@@ -298,7 +298,7 @@ kadm_listen(void)
 	    continue;			/* no things read */
 	if (found < 0) {
 	    if (errno != EINTR)
-		k_log("select: %s",error_message(errno));
+		krb_log("select: %s",error_message(errno));
 	    continue;
 	}      
 	if (FD_ISSET(admin_fd, &readfds)) {
@@ -306,7 +306,7 @@ kadm_listen(void)
 	    addrlen = sizeof(peer);
 	    if ((peer_fd = accept(admin_fd, (struct sockaddr *)&peer,
 				  &addrlen)) < 0) {
-		k_log("accept: %s",error_message(errno));
+		krb_log("accept: %s",error_message(errno));
 		continue;
 	    }
 #ifndef DEBUG
@@ -314,7 +314,7 @@ kadm_listen(void)
 	    if ((pid = fork())) {
 		/* parent */
 		if (pid < 0) {
-		    k_log("fork: %s",error_message(errno));
+		    krb_log("fork: %s",error_message(errno));
 		    close(peer_fd);
 		    continue;
 		}
@@ -329,7 +329,7 @@ kadm_listen(void)
 		}
 	    } else {
 		/* child */
-		(void) close(admin_fd);
+		close(admin_fd);
 #endif /* DEBUG */
 		/*
 		 * If we are multihomed we need to figure out which
@@ -346,7 +346,7 @@ kadm_listen(void)
 	    }
 #endif
 	} else {
-	    k_log("something else woke me up!");
+	    krb_log("something else woke me up!");
 	    return(0);
 	}
     }
@@ -399,7 +399,7 @@ main(int argc, char **argv)		/* admin_server main routine */
 	case 'h':			/* get help on using admin_server */
 	default:
 	    printf("Usage: admin_server [-h] [-n] [-r realm] [-d dbname] [-f filename] [-a acldir]\n");
-	    exit(-1);			/* failure */
+	    exit (1);			/* failure */
 	}
 
     if (krbrlm[0] == 0)
@@ -414,7 +414,7 @@ main(int argc, char **argv)		/* admin_server main routine */
     printf("regular kill instead\n\n");
 
     set_logfile(prm.sysfile);
-    k_log("Admin server starting");
+    krb_log("Admin server starting");
 
     kerb_db_set_lockmode(KERB_DBL_NONBLOCKING);
     errval = kerb_init();		/* Open the Kerberos database */
