@@ -35,7 +35,7 @@ unwraps wrapped packets and calls the appropriate server subroutine
 
 #include "kadm_locl.h"
 
-RCSID("$Id: kadm_ser_wrap.c,v 1.17 1996/06/11 12:06:50 bg Exp $");
+RCSID("$Id: kadm_ser_wrap.c,v 1.19 1996/11/19 22:48:42 assar Exp $");
 
 /* GLOBAL */
 Kadm_Server server_parm;
@@ -52,14 +52,14 @@ kadm_ser_init(int inter, char *realm)
   struct hostent *hp;
   char hostname[MaxHostNameLen];
 
-  (void) init_kadm_err_tbl();
-  (void) init_krb_err_tbl();
+  init_kadm_err_tbl();
+  init_krb_err_tbl();
   if (k_gethostname(hostname, sizeof(hostname)))
       return KADM_NO_HOSTNAME;
 
-  (void) strcpy(server_parm.sname, PWSERV_NAME);
-  (void) strcpy(server_parm.sinst, KRB_MASTER);
-  (void) strcpy(server_parm.krbrlm, realm);
+  strcpy(server_parm.sname, PWSERV_NAME);
+  strcpy(server_parm.sinst, KRB_MASTER);
+  strcpy(server_parm.krbrlm, realm);
 
   server_parm.admin_fd = -1;
   /* setting up the addrs */
@@ -88,13 +88,13 @@ static void errpkt(u_char **dat, int *dat_len, int code)
     u_int32_t retcode;
     char *pdat;
 
-    free((char *)*dat);			/* free up req */
+    free(*dat);			/* free up req */
     *dat_len = KADM_VERSIZE + sizeof(u_int32_t);
     *dat = (u_char *) malloc((unsigned)*dat_len);
     pdat = (char *) *dat;
     retcode = htonl((u_int32_t) code);
-    (void) strncpy(pdat, KADM_ULOSE, KADM_VERSIZE);
-    memcpy(&pdat[KADM_VERSIZE], (char *)&retcode, sizeof(u_int32_t));
+    strncpy(pdat, KADM_ULOSE, KADM_VERSIZE);
+    memcpy(&pdat[KADM_VERSIZE], &retcode, sizeof(u_int32_t));
     return;
 }
 
@@ -127,11 +127,11 @@ kadm_ser_in(u_char **dat, int *dat_len)
 	return KADM_LENGTH_ERROR;
     in_len += retc;
     authent.length = *dat_len - r_len - KADM_VERSIZE - sizeof(u_int32_t);
-    memcpy((char *)authent.dat, (char *)(*dat) + in_len, authent.length);
+    memcpy(authent.dat, (char *)(*dat) + in_len, authent.length);
     authent.mbz = 0;
     /* service key should be set before here */
     if ((retc = krb_rd_req(&authent, server_parm.sname, server_parm.sinst,
-			  server_parm.recv_addr.sin_addr.s_addr, &ad, (char *)0)))
+			  server_parm.recv_addr.sin_addr.s_addr, &ad, NULL)))
     {
 	errpkt(dat, dat_len,retc + krb_err_base);
 	return retc + krb_err_base;
@@ -189,12 +189,12 @@ kadm_ser_in(u_char **dat, int *dat_len)
 	return KADM_NO_OPCODE;
     }
     /* Now seal the response back into a priv msg */
-    free((char *)*dat);
+    free(*dat);
     tmpdat = (u_char *) malloc((unsigned)(retlen + KADM_VERSIZE +
 					  sizeof(u_int32_t)));
-    (void) strncpy((char *)tmpdat, KADM_VERSTR, KADM_VERSIZE);
+    strncpy((char *)tmpdat, KADM_VERSTR, KADM_VERSIZE);
     retval = htonl((u_int32_t)retval);
-    memcpy((char *)tmpdat + KADM_VERSIZE, (char *)&retval, sizeof(u_int32_t));
+    memcpy((char *)tmpdat + KADM_VERSIZE, &retval, sizeof(u_int32_t));
     if (retlen) {
         memcpy((char *)tmpdat + KADM_VERSIZE + sizeof(u_int32_t), retdat,
 	       retlen);
