@@ -30,13 +30,46 @@ or implied warranty.
  * The default behavior of kadmin is if the -m option is given 
  * on the commandline, multiple requests are allowed to be given
  * with one entry of the admin password (until the tickets expire).
- * If you do not want this to be an available option, compile with
- * NO_MULTIPLE defined.
  */
 
 #include "kadm_locl.h"
 
-RCSID("$Id: kadmin.c,v 1.30 1996/08/22 10:26:04 bg Exp $");
+RCSID("$Id: kadmin.c,v 1.42 1996/11/23 23:25:37 assar Exp $");
+
+static void change_password(int argc, char **argv);
+static void change_key(int argc, char **argv);
+static void change_admin_password(int argc, char **argv);
+static void add_new_key(int argc, char **argv);
+static void del_entry(int argc, char **argv);
+static void get_entry(int argc, char **argv);
+static void mod_entry(int argc, char **argv);
+static void help(int argc, char **argv);
+static void clean_up_cmd(int argc, char **argv);
+static void quit_cmd(int argc, char **argv);
+
+static SL_cmd cmds[] = {
+  {"change_password", change_password, "Change a user's password"},
+  {"cpw"},
+  {"passwd"},
+  {"change_key", change_key, "Change a user's password as a DES binary key"},
+  {"ckey"},
+  {"change_admin_password", change_admin_password,
+   "Change your admin password"},
+  {"cap"},
+  {"add_new_key", add_new_key, "Add new user to kerberos database"},
+  {"ank"},
+  {"del_entry", del_entry, "Delete entry from database"},
+  {"del"},
+  {"delete"},
+  {"get_entry", get_entry, "Get entry from kerberos database"},
+  {"mod_entry", mod_entry, "Modify entry in kerberos database"},
+  {"destroy_tickets", clean_up_cmd, "Destroy admin tickets"},
+  {"exit", quit_cmd, "Exit program"},
+  {"quit"},
+  {"help", help, "Help"},
+  {"?"},
+  {NULL}
+};
 
 #define BAD_PW 1
 #define GOOD_PW 0
@@ -50,11 +83,7 @@ RCSID("$Id: kadmin.c,v 1.30 1996/08/22 10:26:04 bg Exp $");
 #define DONTSWAP 0
 #define SWAP 1
 
-extern ss_request_table admin_cmds;
-
-static char myname[ANAME_SZ];
-static char myinst[INST_SZ];
-static char myrealm[REALM_SZ];
+static krb_principal pr;
 static char default_realm[REALM_SZ]; /* default kerberos realm */
 static char krbrlm[REALM_SZ];	/* current realm being administered */
 static int multiple = 0;	/* Allow multiple requests per ticket */
@@ -119,7 +148,6 @@ static void
 get_expdate(Kadm_vals *vals)
 {
     char buff[BUFSIZ];
-    int ok = 0;
     struct tm edate;
 
     memset(&edate, 0, sizeof(edate));
@@ -149,7 +177,9 @@ princ_exists(char *name, char *instance, char *realm)
 {
     int status;
 
-    status = krb_get_pw_in_tkt(name, instance, realm, "krbtgt", realm, 1, "");
+    status = krb_get_pw_in_tkt(name, instance, realm,
+			       KRB_TICKET_GRANTING_TICKET,
+			       realm, 1, "");
 
     if ((status == KSUCCESS) || (status == INTK_BADPW))
 	return(PE_YES);
@@ -221,14 +251,15 @@ get_admin_password(void)
 	ticket_life = DEFAULT_TKT_LIFE;
     }
     
-    if (princ_exists(myname, myinst, myrealm) != PE_NO) {
+    if (princ_exists(pr.name, pr.instance, pr.realm) != PE_NO) {
 	if (read_long_pw_string(admin_passwd, sizeof(admin_passwd)-1,
 				"Admin password:", 0)) {
 	    fprintf(stderr, "Error reading admin password.\n");
 	    goto bad;
 	}
-	status = krb_get_pw_in_tkt(myname, myinst, myrealm, PWSERV_NAME, 
-				   KADM_SINST, ticket_life, admin_passwd);
+	status = krb_get_pw_in_tkt(pr.name, pr.instance, pr.realm,
+				   PWSERV_NAME, KADM_SINST,
+				   ticket_life, admin_passwd);
 	memset(admin_passwd, 0, sizeof(admin_passwd));
 
 	/* Initialize non shared random sequence from session key. */
@@ -243,8 +274,7 @@ get_admin_password(void)
     case GT_PW_OK:
 	return(GOOD_PW);
     case KDC_PR_UNKNOWN:
-	printf("Principal %s%s%s@%s does not exist.\n", myname, 
-	       *myinst ? "." : "", myinst, myrealm);
+	printf("Principal %s does not exist.\n", krb_unparse_name(&pr));
 	goto bad;
     case GT_PW_BADPW:
 	printf("Incorrect admin password.\n");
@@ -257,134 +287,113 @@ get_admin_password(void)
     
  bad:
     memset(admin_passwd, 0, sizeof(admin_passwd));
-    (void) dest_tkt();
+    dest_tkt();
     return(BAD_PW);
 }
 
 static void
 usage(void)
 {
-    fprintf(stderr, "Usage: kadmin [-u admin_name] [-r default_realm]");
-    fprintf(stderr, " [-m]");
-    fprintf(stderr, "\n");
-    fprintf(stderr, "   -m allows multiple admin requests to be ");
-    fprintf(stderr, "serviced with one entry of admin\n");
-    fprintf(stderr, "   password.\n");
-    exit(1);
+    fprintf (stderr, "Usage: kadmin [[-u|-p] admin_name] [-r default_realm]"
+	     " [-m]\n"
+	     "   -m allows multiple admin requests to be "
+	     "serviced with one entry of admin\n"	     
+	     "   password.\n");
+    exit (1);
 }
 
 /* GLOBAL */
-void
-clean_up(void)
+static void
+clean_up()
 {
-    (void) dest_tkt();
-    return;
+    dest_tkt();
+}
+
+static void
+clean_up_cmd (int argc, char **argv)
+{
+    clean_up();
 }
 
 /* GLOBAL */
-void 
-quit(void)
+static void 
+quit()
 {
     printf("Cleaning up and exiting.\n");
     clean_up();
     exit(0);
 }
 
+static void
+quit_cmd (int argc, char **argv)
+{
+    quit();
+}
+
 static void
 do_init(int argc, char **argv)
 {
-    struct passwd *pw;
     int c;
-    int tflag;
+    int tflag = 0;
     char tktstring[MaxPathLen];
     int k_errno;
     
-    *myname = '\0';
-    strcpy (myinst, "admin");
-
-    /* 
-     * This is only as a default/initial realm; we don't care 
-     * about failure.
-     */
-    if (krb_get_lrealm(default_realm, 1) != KSUCCESS)
-      strcpy(default_realm, KRB_REALM);
-    else if (krbrlm[0] == 0)
-      strcpy(krbrlm, default_realm);
-
-    /* 
-     * If we can reach the local realm, initialize to it.  Otherwise,
-     * don't initialize.
-     */
-    if (kadm_init_link(PWSERV_NAME, KRB_MASTER, krbrlm) != KADM_SUCCESS)
-      *krbrlm = '\0';
-    else
-      strcpy(krbrlm, default_realm);
-    strcpy (myrealm, krbrlm);
-
-    tflag = 0;
-
-    while ((c = getopt(argc, argv, "u:r:mt")) != EOF) 
-      switch (c) {
-      case 'u':
-	if((k_errno = kname_parse(myname, myinst, myrealm, optarg))
-	   != KSUCCESS) {
-	     fprintf (stderr, "%s: %s\n", argv[0], krb_get_err_text(k_errno));
-	     exit (1);
-	}
-	break;
-      case 'r':
-	memset(default_realm, 0, sizeof(default_realm));
-	strncpy(default_realm, optarg, sizeof(default_realm) - 1);
-	break;
-      case 'm':
-	multiple++;
-	break;
-      case 't':
-	tflag++;
-	break;
-      default:
-	usage();
-	break;
-      }
-    if (optind < argc)
-      usage();
-    if (!myname[0]) {
-	char n[ANAME_SZ], i[INST_SZ], r[REALM_SZ];
-	if (krb_get_default_principal(n, i, r) >= 0) {
-	    strcpy(myname, n);
-	} else {
-	    pw = getpwuid((int) getuid());
-	    if (!pw) {
-		fprintf(stderr,
-			"You aren't in the password file.  Who are you?\n");
-		exit(1);
+    memset(&pr, 0, sizeof(pr));
+    if (krb_get_default_principal(pr.name, pr.instance, default_realm) < 0) {
+	fprintf (stderr, "%s: I could not even guess who you might be\n",
+		 argv[0]);
+	exit (1);
+    }	
+    while ((c = getopt(argc, argv, "p:u:r:mt")) != EOF) 
+	switch (c) {
+	case 'p':
+	case 'u':
+	    if((k_errno = krb_parse_name(optarg, &pr)) != KSUCCESS) {
+		fprintf (stderr, "%s: %s\n", argv[0],
+			 krb_get_err_text(k_errno));
+		exit (1);
 	    }
-	    (void) strcpy(myname, pw->pw_name);
-	}	
-    }
+	    break;
+	case 'r':
+	    memset(default_realm, 0, sizeof(default_realm));
+	    strncpy(default_realm, optarg, sizeof(default_realm) - 1);
+	    break;
+	case 'm':
+	    multiple++;
+	    break;
+	case 't':
+	    tflag++;
+	    break;
+	default:
+	    usage();
+	    break;
+	}
+    if (optind < argc)
+	usage();
+    strcpy(krbrlm, default_realm);
+
+    if (kadm_init_link(PWSERV_NAME, KRB_MASTER, krbrlm) != KADM_SUCCESS)
+	*krbrlm = '\0';
+    if (pr.realm[0] == '\0')
+	strcpy (pr.realm, krbrlm);
+    if (pr.instance[0] == '\0')
+	strcpy(pr.instance, "admin");
+    
     if (!tflag) {
-      (void) sprintf(tktstring, TKT_ROOT "_adm_%d",(int)getpid());
-      krb_set_tkt_string(tktstring);
+	sprintf(tktstring, TKT_ROOT "_adm_%d",(int)getpid());
+	krb_set_tkt_string(tktstring);
     }
+    
 }
 
 int
 main(int argc, char **argv)
 {
-    int     sci_idx;
-    int     code;
-
-    sci_idx = ss_create_invocation("admin", "2.0", (char *) NULL,
-				   &admin_cmds, &code);
-    if (code) {
-	ss_perror(sci_idx, code, "creating invocation");
-	exit(1);
-    }
     do_init(argc, argv);
 
     printf("Welcome to the Kerberos Administration Program, version 2\n");
     printf("Type \"help\" if you need it.\n");
-    code = ss_listen(sci_idx);
+    sl_loop (cmds, "kadmin: ");
     printf("\n");
     quit();
     exit(0);
@@ -420,7 +429,7 @@ setvals(Kadm_vals *vals, char *string)
 	return KADM_SUCCESS;
 }    
 
-void 
+static void 
 change_password(int argc, char **argv)
 {
     Kadm_vals old, new;
@@ -445,7 +454,7 @@ change_password(int argc, char **argv)
 	    return;
 
 	/* get the new password */
-	(void) sprintf(pw_prompt, "New password for %s:", argv[1]);
+	sprintf(pw_prompt, "New password for %s:", argv[1]);
 	
 	if (get_password(&new.key_low, &new.key_high,
 			 pw_prompt, SWAP) == GOOD_PW) {
@@ -463,12 +472,12 @@ change_password(int argc, char **argv)
 	    clean_up();
     }
     else 
-	printf("kadmin: Principal does not exist.\n");
+	printf("kadmin: Principal %s does not exist.\n",
+	       krb_unparse_name_long (old.name, old.instance, krbrlm));
     return;
 }
 
-static
-int
+static int
 getkey(unsigned char *k)
 {
     int i, c;
@@ -496,8 +505,7 @@ getkey(unsigned char *k)
     return 1;			/* Success */
 }
 
-static
-void
+static void
 printkey(unsigned char *tkey)
 {
     int j;
@@ -509,7 +517,7 @@ printkey(unsigned char *tkey)
     printf("\n");
 }
 
-void 
+static void 
 change_key(int argc, char **argv)
 {
     Kadm_vals old, new;
@@ -534,7 +542,7 @@ change_key(int argc, char **argv)
 	    return;
 
 	/* get the new password */
-	(void) printf("New DES key for %s: ", argv[1]);
+	printf("New DES key for %s: ", argv[1]);
 	
 	if (getkey(newkey)) {
 	    memcpy(&new.key_low, newkey, 4);
@@ -557,12 +565,12 @@ change_key(int argc, char **argv)
 	    clean_up();
     }
     else 
-	printf("kadmin: Principal does not exist.\n");
+	printf("kadmin: Principal %s does not exist.\n",
+	       krb_unparse_name_long (old.name, old.instance, krbrlm));
     return;
 }
 
-/*ARGSUSED*/
-void 
+static void 
 change_admin_password(int argc, char **argv)
 {
     des_cblock newkey;
@@ -574,8 +582,7 @@ change_admin_password(int argc, char **argv)
 	printf("Usage: change_admin_password\n");
 	return;
     }
-    if (get_pw_new_pwd(pword, sizeof(pword), myname, myinst,
-		       myrealm, 1) == 0) {
+    if (get_pw_new_pwd(pword, sizeof(pword), &pr, 1) == 0) {
 	 des_string_to_key(pword, &newkey);
 	 status = kadm_change_pw_plain(newkey, pword, &pw_msg);
 	 if(status == KADM_INSECURE_PW)
@@ -592,7 +599,7 @@ change_admin_password(int argc, char **argv)
     return;
 }
 
-void 
+static void 
 add_new_key(int argc, char **argv)
 {
     Kadm_vals new;
@@ -637,7 +644,7 @@ add_new_key(int argc, char **argv)
 		printf ("kadm error: %s\n", error_message(status));
 		return;
 	    }
-	    if (vals.max_life = 255) /* Defaults not set! */ {
+	    if (vals.max_life == 255) /* Defaults not set! */ {
 	      /* This is the default maximum lifetime for new principals. */
 	      if (strcmp(new.instance, "admin") == 0)
 		vals.max_life = 1 + (CLOCK_SKEW/(5*60)); /* 5+5 minutes */
@@ -663,7 +670,7 @@ add_new_key(int argc, char **argv)
 	get_expdate(&new);
 
 	/* get the new password */
-	(void) sprintf(pw_prompt, "Password for %s:", argv[1]);
+	sprintf(pw_prompt, "Password for %s:", argv[1]);
 	
 	if (get_password(&new.key_low, &new.key_high,
 			 pw_prompt, SWAP) == GOOD_PW) {
@@ -684,7 +691,7 @@ add_new_key(int argc, char **argv)
     return;
 }
 
-void 
+static void 
 del_entry(int argc, char **argv)
 {
     int status;
@@ -705,7 +712,7 @@ del_entry(int argc, char **argv)
 	
 	if ((status = kadm_del(&vals)) == KADM_SUCCESS){
 	    printf("%s removed from database.\n", argv[1]);
-	}else{
+	} else {
 	    printf("kadm error: %s\n",error_message(status));
 	}
 	
@@ -713,11 +720,12 @@ del_entry(int argc, char **argv)
 	    clean_up();
     }
     else
-	printf("kadmin: Principal does not exist.\n");
+	printf("kadmin: Principal %s does not exist.\n",
+	       krb_unparse_name_long (vals.name, vals.instance, krbrlm));
     return;
 }
 
-void 
+static void 
 get_entry(int argc, char **argv)
 {
     int status;
@@ -758,11 +766,12 @@ get_entry(int argc, char **argv)
 	    clean_up();
     }
     else
-	printf("kadmin: Principal does not exist.\n");
+	printf("kadmin: Principal %s does not exist.\n",
+	       krb_unparse_name_long (vals.name, vals.instance, krbrlm));
     return;
 }
 
-void 
+static void 
 mod_entry(int argc, char **argv)
 {
     int status;
@@ -788,7 +797,8 @@ mod_entry(int argc, char **argv)
     nvals = ovals;
 
     if (princ_exists(ovals.name, ovals.instance, krbrlm) == PE_NO) {
-	printf("kadmin: Principal does not exist.\n");
+	printf("kadmin: Principal %s does not exist.\n",
+	       krb_unparse_name_long (ovals.name, ovals.instance, krbrlm));
 	return;
     }
 
@@ -812,7 +822,9 @@ mod_entry(int argc, char **argv)
     get_attr(&nvals);
     get_expdate(&nvals);
     
-    if (IS_FIELD(KADM_MAXLIFE, nvals.fields) || IS_FIELD(KADM_ATTR, nvals.fields) || IS_FIELD(KADM_EXPDATE, nvals.fields)) {
+    if (IS_FIELD(KADM_MAXLIFE, nvals.fields) ||
+	IS_FIELD(KADM_ATTR, nvals.fields) ||
+	IS_FIELD(KADM_EXPDATE, nvals.fields)) {
 	if ((status = kadm_mod(&ovals, &nvals)) != KADM_SUCCESS) {
 	    printf("kadm error: %s\n",error_message(status));
 	    goto out;
@@ -830,127 +842,8 @@ out:
     return;
 }
 
-void 
+static void
 help(int argc, char **argv)
 {
-    if (argc == 1) {
-	printf("Welcome to the Kerberos administration program.");
-	printf("Type \"?\" to get\n");
-	printf("a list of requests that are available. You can");
-	printf(" get help on each of\n");
-	printf("the commands by typing \"help command_name\".");
-	printf(" Some functions of this\n");
-	printf("program will require an \"admin\" password");
-	printf(" from you. This is a password\n");
-	printf("private to you, that is used to authenticate");
-	printf(" requests from this\n");
-	printf("program. You can change this password with");
-	printf(" the \"change_admin_password\"\n");
-	printf("(or short form \"cap\") command. Good Luck!    \n");
-    } else if (!strcmp(argv[1], "change_password") ||
-	       !strcmp(argv[1], "cpw")) {
-	printf("Usage: change_password user_name.\n");
-	printf("\n");
-	printf("user_name is the name of the user whose password");
-	printf(" you wish to change. \n");
-	printf("His/her password is changed in the kerberos database\n");
-	printf("When this command is issued, first the \"Admin\"");
-	printf(" password will be prompted\n");
-	printf("for and if correct the user's new password will");
-	printf(" be prompted for (twice with\n");
-	printf("appropriate comparison). Note: No minimum password");
-	printf(" length restrictions apply, but\n");
-	printf("longer passwords are more secure.\n");
-    } else if (!strcmp(argv[1], "change_key") ||
-	       !strcmp(argv[1], "ckey")) {
-	printf("Usage: change_key principal-name.\n");
-	printf("\n");
-	printf("Descripton:\n");
-	printf("\tAs change_password but input password as binary key\n");
-    } else if (!strcmp(argv[1], "change_admin_password") ||
-	       !strcmp(argv[1], "cap")) {
-	printf("Usage: change_admin_password.\n");
-	printf("\n");
-	printf("This command takes no arguments and is used");
-	printf(" to change your private\n");
-	printf("\"Admin\" password. It will first prompt for");
-	printf(" the (current) \"Admin\"\n");
-	printf("password and then ask for the new password");
-	printf(" by prompting:\n");
-	printf("\n");
-	printf("New password for <Your User Name>.admin:\n");
-	printf("\n");
-	printf("Enter the new admin password that you desire");
-	printf(" (it will be asked for\n");
-	printf("twice to avoid errors).\n");
-    } else if (!strcmp(argv[1], "add_new_key") ||
-	       !strcmp(argv[1], "ank")) {
-	printf("Usage: add_new_key user_name.\n");
-	printf("\n");
-	printf("user_name is the name of a new user to put");
-	printf(" in the kerberos database. Your\n");
-	printf("\"Admin\" password and the user's password");
-	printf(" are prompted for. The user's\n");
-	printf("password will be asked for");
-	printf(" twice to avoid errors.\n");
-	printf("You are also prompted for the default ticket");
-	printf(" lifetime, attributes\n");
-	printf("and expiration date (see the 'mod_entry' command).\n");
-    } else if (!strcmp(argv[1], "del_entry") ||
-	       !strcmp(argv[1], "del") ||
-	       !strcmp(argv[1], "delete")) {
-	printf("Usage: del_entry user_name.\n");
-	printf("\n");
-	printf("user_name is the name of a user whose");
-	printf(" entry you wish to delete.  Your\n");
-	printf("\"Admin\" password is prompted for. \n");
-    } else if (!strcmp(argv[1], "get_entry") ||
-	       !strcmp(argv[1], "get")) {
-	printf("Usage: get_entry user_name.\n");
-	printf("\n");
-	printf("user_name is the name of a user whose");
-	printf(" entry you wish to review.  Your\n");
-	printf("\"Admin\" password is prompted for. ");
-	printf(" The key field is not filled in, for\n");
-	printf("security reasons.\n");
-    } else if (!strcmp(argv[1], "mod_entry") ||
-	       !strcmp(argv[1], "mod")) {
-	printf("Usage: mod_entry user_name.\n");
-	printf("\n");
-	printf("user_name is the name of a user whose");
-	printf(" entry you wish to modify.  Your\n");
-	printf("\"Admin\" password is prompted for.");
-	printf(" You will also be prompted for the new\n");
-	printf("default ticket lifetime, attributes");
-	printf(" and expiration date. Attributes may\n");
-	printf("be entered in decimal by default,");
-	printf(" octal if begun with '0', or hexadecimal\n");
-	printf("if begun with '0x'. End the lifetime");
-	printf(" with 'm' to specify minutes, 'h'\n");
-	printf("to specify hours.\n");
-    } else if (!strcmp(argv[1], "destroy_tickets") ||
-	       !strcmp(argv[1], "dest")) {
-	printf("Usage: destroy_tickets\n");
-	printf("\n");
-	printf("Destroy your admin tickets.  This will");
-	printf(" cause you to be prompted for your\n");
-	printf("admin password on your next request.\n");
-    } else if (!strcmp(argv[1], "list_requests") ||
-	       !strcmp(argv[1], "lr") ||
-	       !strcmp(argv[1], "?")) {
-	printf("Usage: list_requests\n");
-	printf("\n");
-	printf("This command lists what other commands are");
-	printf(" currently available.\n");
-    } else if (!strcmp(argv[1], "exit") ||
-	       !strcmp(argv[1], "quit") ||
-	       !strcmp(argv[1], "q")) {
-	printf("Usage: quit\n");
-	printf("\n");
-	printf("This command exits this program.\n");
-    } else {
-	printf("Sorry there is no such command as %s.", argv[1]);
-	printf(" Type \"help\" for more information.    \n");
-    }
-    return;
+    sl_help (cmds, argc, argv);
 }
