@@ -30,14 +30,8 @@ or implied warranty.
 
 #include "kadm_locl.h"
 
-RCSID("$Id: kpasswd.c,v 1.17 1996/07/02 09:48:36 bg Exp $");
+RCSID("$Id: kpasswd.c,v 1.21 1996/11/19 04:06:58 assar Exp $");
 
-#ifdef NOENCRYPTION
-#define read_long_pw_string placebo_read_pw_string
-#else
-#define read_long_pw_string des_read_pw_string
-#endif
-    
 static void
 usage(int value)
 {
@@ -50,12 +44,8 @@ usage(int value)
 int
 main(int argc, char **argv)
 {
-    char name[ANAME_SZ];	/* name of user */
-    char inst[INST_SZ];		/* instance of user */
-    char realm[REALM_SZ];	/* realm of user */
-    char default_name[ANAME_SZ];
-    char default_inst[INST_SZ];
-    char default_realm[REALM_SZ];
+    krb_principal principal;
+    krb_principal default_principal;
     int realm_given = 0;	/* True if realm was give on cmdline */
     int use_default = 1;	/* True if we should use default name */
     struct passwd *pw;
@@ -64,75 +54,68 @@ main(int argc, char **argv)
     int c;
     char tktstring[MaxPathLen];
     
-    memset(name, 0, sizeof(name));
-    memset(inst, 0, sizeof(inst));
-    memset(realm, 0, sizeof(realm));
+    memset (&principal, 0, sizeof(principal));
+    memset (&default_principal, 0, sizeof(default_principal));
     
-    if (krb_get_tf_fullname(TKT_FILE, default_name, default_inst, 
-			    default_realm) != KSUCCESS) {
-	pw = getpwuid((int) getuid());
-	if (pw)
-	    (void) strcpy(default_name, pw->pw_name);
-	else
-	    /* seems like a null name is kinda silly */
-	    (void) strcpy(default_name, ""); 
-	strcpy(default_inst, "");
-	if (krb_get_lrealm(default_realm, 1) != KSUCCESS)
-	    strcpy(default_realm, KRB_REALM);
-    }
+    krb_get_default_principal (default_principal.name,
+			       default_principal.instance,
+			       default_principal.realm);
 
     while ((c = getopt(argc, argv, "u:n:i:r:h")) != EOF) {
 	switch (c) {
-	  case 'u':
-	    if ((status = kname_parse(name, inst, realm, optarg))) {
-		fprintf(stderr, "Kerberos error: %s\n", krb_get_err_text(status));
-		exit(2);
+	case 'u':
+	    status = krb_parse_name (optarg, &principal);
+	    if (status != KSUCCESS) {
+		fprintf (stderr, "Kerberos error: %s\n",
+			 krb_get_err_text(status));
+		exit (2);
 	    }
-	    if (realm[0])
+	    if (principal.realm[0])
 		realm_given++;
-	    else
-		if (krb_get_lrealm(realm, 1) != KSUCCESS)
-		    strcpy(realm, KRB_REALM);
+	    else if (krb_get_lrealm(principal.realm, 1) != KSUCCESS) {
+		fprintf (stderr, "Could not find default realm!\n");
+		exit (1);
+	    }
 	    break;
-	  case 'n':
+	case 'n':
 	    if (k_isname(optarg))
-		(void) strncpy(name, optarg, sizeof(name) - 1);
+		strncpy(principal.name, optarg, sizeof(principal.name) - 1);
 	    else {
 		fprintf(stderr, "Bad name: %s\n", optarg);
 		usage(1);
 	    }
 	    break;
-	  case 'i':
+	case 'i':
 	    if (k_isinst(optarg))
-		(void) strncpy(inst, optarg, sizeof(inst) - 1);
+		strncpy(principal.instance,
+			optarg,
+			sizeof(principal.instance) - 1);
 	    else {
 		fprintf(stderr, "Bad instance: %s\n", optarg);
 		usage(1);
 	    }
-	    (void) strcpy(inst, optarg);
 	    break;
-	  case 'r':
+	case 'r':
 	    if (k_isrealm(optarg)) {
-		(void) strncpy(realm, optarg, sizeof(realm) - 1);
+		strncpy(principal.realm, optarg, sizeof(principal.realm) - 1);
 		realm_given++; 
-	    }
-	    else {
+	    } else {
 		fprintf(stderr, "Bad realm: %s\n", optarg);
 		usage(1);
 	    }
 	    break;
-	  case 'h':
+	case 'h':
 	    usage(0);
 	    break;
-	  default:
+	default:
 	    usage(1);
 	    break;
 	}
 	use_default = 0;
     }
-    if (optind < argc){
+    if (optind < argc) {
 	use_default = 0;
-	status = kname_parse(name, inst, realm, argv[optind]);
+	status = krb_parse_name (argv[optind], &principal);
 	if(status != KSUCCESS){
 	    fprintf(stderr, "Kerberos error: %s\n", krb_get_err_text(status));
 	    exit(1);
@@ -140,52 +123,51 @@ main(int argc, char **argv)
     }
 
     if (use_default) {
-	strcpy(name, default_name);
-	strcpy(inst, default_inst);
-	strcpy(realm, default_realm);
-    }
-    else {
-	if (!name[0])
-	    strcpy(name, default_name);
-	if (!realm[0])
-	    strcpy(realm, default_realm);
+	strcpy(principal.name, default_principal.name);
+	strcpy(principal.instance, default_principal.instance);
+	strcpy(principal.realm, default_principal.realm);
+    } else {
+	if (!principal.name[0])
+	    strcpy(principal.name, default_principal.name);
+	if (!principal.realm[0])
+	    strcpy(principal.realm, default_principal.realm);
     }
 
-    (void) sprintf(tktstring, TKT_ROOT "_cpw_%d",(int)getpid());
+    sprintf(tktstring, TKT_ROOT "_cpw_%d",(int)getpid());
     krb_set_tkt_string(tktstring);
     
-    if (get_pw_new_pwd(pword, sizeof(pword), name, inst, realm,
+    if (get_pw_new_pwd(pword, sizeof(pword), &principal,
 		       realm_given)) {
-      dest_tkt ();
-      exit(1);
+	dest_tkt ();
+	exit(1);
     }
     
-    status = kadm_init_link("changepw", KRB_MASTER, realm);
+    status = kadm_init_link (PWSERV_NAME, KRB_MASTER, principal.realm);
     if (status != KADM_SUCCESS) 
-      com_err(argv[0], status, "while initializing");
+	com_err(argv[0], status, "while initializing");
     else {
-      des_cblock newkey;
-      char *pw_msg; /* message from server */
+	des_cblock newkey;
+	char *pw_msg; /* message from server */
 
-      des_string_to_key(pword, &newkey);
-      status = kadm_change_pw_plain((unsigned char*)&newkey, pword, &pw_msg);
-      memset(newkey, 0, sizeof(newkey));
+	des_string_to_key(pword, &newkey);
+	status = kadm_change_pw_plain((unsigned char*)&newkey, pword, &pw_msg);
+	memset(newkey, 0, sizeof(newkey));
       
-      if (status == KADM_INSECURE_PW)
-	fprintf(stderr, "%s: Insecure password: %s\n", argv[0], pw_msg);
-      else if (status != KADM_SUCCESS)
-	com_err(argv[0], status, " attempting to change password.");
+	if (status == KADM_INSECURE_PW)
+	    fprintf(stderr, "%s: Insecure password: %s\n", argv[0], pw_msg);
+	else if (status != KADM_SUCCESS)
+	    com_err(argv[0], status, " attempting to change password.");
     }
     memset(pword, 0, sizeof(pword));
 
     if (status != KADM_SUCCESS)
-      fprintf(stderr,"Password NOT changed.\n");
+	fprintf(stderr,"Password NOT changed.\n");
     else
-      printf("Password changed.\n");
+	printf("Password changed.\n");
 
-    (void) dest_tkt();
+    dest_tkt();
     if (status)
-      exit(2);
+	return 2;
     else 
-      exit(0);
+	return 0;
 }
