@@ -1,7 +1,7 @@
 /*
  * This software may now be redistributed outside the US.
  *
- * $Id: ksrvutil.c,v 1.27 1996/08/22 19:17:25 assar Exp $
+ * $Id: ksrvutil.c,v 1.34 1996/11/24 00:59:18 assar Exp $
  *
  */
 
@@ -37,7 +37,7 @@ or implied warranty.
 
 #include "kadm_locl.h"
 
-RCSID("$Id: ksrvutil.c,v 1.27 1996/08/22 19:17:25 assar Exp $");
+RCSID("$Id: ksrvutil.c,v 1.34 1996/11/24 00:59:18 assar Exp $");
 
 #include "ksrvutil.h"
 
@@ -95,7 +95,7 @@ copy_keyfile(char *keyfile, char *backup_keyfile)
 	try_again = FALSE;
 	if ((keyfile_fd = open(keyfile, O_RDONLY, 0)) < 0) {
 	    if (errno != ENOENT) {
-		(void)fprintf(stderr, "%s: Unable to read %s: %s\n", progname, 
+		fprintf(stderr, "%s: Unable to read %s: %s\n", progname, 
 			      keyfile, strerror(errno));
 		exit(1);
 	    }
@@ -104,13 +104,13 @@ copy_keyfile(char *keyfile, char *backup_keyfile)
 		if ((keyfile_fd = 
 		     open(keyfile, 
 			  O_WRONLY | O_TRUNC | O_CREAT, SRVTAB_MODE)) < 0) {
-		    (void) fprintf(stderr, "%s: Unable to create %s: %s\n", 
+		    fprintf(stderr, "%s: Unable to create %s: %s\n", 
 				   progname, keyfile, strerror(errno));
 		    exit(1);
 		}
 		else
 		    if (close(keyfile_fd) < 0) {
-			(void) fprintf(stderr, "%s: Failure closing %s: %s\n",
+			fprintf(stderr, "%s: Failure closing %s: %s\n",
 				       progname, keyfile, strerror(errno));
 			exit(1);
 		    }
@@ -123,29 +123,29 @@ copy_keyfile(char *keyfile, char *backup_keyfile)
     if ((backup_keyfile_fd = 
 	 open(backup_keyfile, O_WRONLY | O_TRUNC | O_CREAT, 
 	      keyfile_mode)) < 0) {
-	(void) fprintf(stderr, "%s: Unable to write %s: %s\n", progname, 
+	fprintf(stderr, "%s: Unable to write %s: %s\n", progname, 
 		       backup_keyfile, strerror(errno));
 	exit(1);
     }
     do {
-	if ((rcount = read(keyfile_fd, (char *)buf, sizeof(buf))) < 0) {
-	    (void) fprintf(stderr, "%s: Error reading %s: %s\n", progname,
+	if ((rcount = read(keyfile_fd, buf, sizeof(buf))) < 0) {
+	    fprintf(stderr, "%s: Error reading %s: %s\n", progname,
 			   keyfile, strerror(errno));
 	    exit(1);
 	}
 	if (rcount && (write(backup_keyfile_fd, buf, rcount) != rcount)) {
-	    (void) fprintf(stderr, "%s: Error writing %s: %s\n", progname,
+	    fprintf(stderr, "%s: Error writing %s: %s\n", progname,
 			   backup_keyfile, strerror(errno));
 	    exit(1);
 	}
     } while (rcount);
     if (close(backup_keyfile_fd) < 0) {
-	(void) fprintf(stderr, "%s: Error closing %s: %s\n", progname,
+	fprintf(stderr, "%s: Error closing %s: %s\n", progname,
 		       backup_keyfile, strerror(errno));
 	exit(1);
     }
     if (close(keyfile_fd) < 0) {
-	(void) fprintf(stderr, "%s: Error closing %s: %s\n", progname,
+	fprintf(stderr, "%s: Error closing %s: %s\n", progname,
 		       keyfile, strerror(errno));
 	exit(1);
     }
@@ -155,35 +155,33 @@ void
 leave(char *str, int x)
 {
     if (str)
-	(void) fprintf(stderr, "%s\n", str);
+	fprintf(stderr, "%s\n", str);
     if (destroyp)
-	 (void) dest_tkt();
+	 dest_tkt();
     exit(x);
 }
 
 void
 safe_read_stdin(char *prompt, char *buf, size_t size)
 {
-    printf(prompt);
+    printf("%s", prompt);
     fflush(stdout);
     memset(buf, 0, size);
     if (read(0, buf, size - 1) < 0) {
-	(void) fprintf(stderr, "Failure reading from stdin: %s\n", 
+	fprintf(stderr, "Failure reading from stdin: %s\n", 
 		       strerror(errno));
-	leave((char *)NULL, 1);
+	leave(NULL, 1);
     }
-    fflush(stdin);
     buf[strlen(buf)-1] = 0;
-}	
-  
+}
 
 void
 safe_write(char *filename, int fd, void *buf, size_t len)
 {
     if (write(fd, buf, len) != len) {
-	(void) fprintf(stderr, "%s: Failure writing to %s: %s\n", progname,
+	fprintf(stderr, "%s: Failure writing to %s: %s\n", progname,
 		       filename, strerror(errno));
-	(void) close(fd);
+	close(fd);
 	leave("In progress srvtab in this file.", 1);
     }
 }
@@ -204,7 +202,7 @@ yes_no(char *string, int dflt)
     else if(ynbuf[0] == 0)
       return dflt;
     else {
-      (void) printf("Please enter 'y' or 'n': ");
+      printf("Please enter 'y' or 'n': ");
       fflush(stdout);
     }
   }
@@ -227,9 +225,9 @@ append_srvtab(char *filename, int fd, char *sname, char *sinst, char *srealm, un
     safe_write(filename, fd, sname, strlen(sname) + 1);
     safe_write(filename, fd, sinst, strlen(sinst) + 1);
     safe_write(filename, fd, srealm, strlen(srealm) + 1);
-    safe_write(filename, fd, (char *)&key_vno, 1);
-    safe_write(filename, fd, (char *)key, sizeof(des_cblock));
-    (void) fsync(fd);
+    safe_write(filename, fd, &key_vno, 1);
+    safe_write(filename, fd, key, sizeof(des_cblock));
+    fsync(fd);
 }    
 
 static void
@@ -238,33 +236,33 @@ print_key(unsigned char *key)
     int i;
 
     for (i = 0; i < 4; i++)
-	(void) printf("%02x", key[i]);
-    (void) printf(" ");
+	printf("%02x", key[i]);
+    printf(" ");
     for (i = 4; i < 8; i++)
-	(void) printf("%02x", key[i]);
+	printf("%02x", key[i]);
 }
 
 static void
 print_name(char *name, char *inst, char *realm)
 {
-    (void) printf("%s%s%s%s%s", name, inst[0] ? "." : "", inst,
-		  realm[0] ? "@" : "", realm);
+    printf("%s", krb_unparse_name_long(name, inst, realm));
 }
 
 static int
-get_svc_new_key(des_cblock *new_key, char *sname, char *sinst, char *srealm, char *keyfile)
+get_svc_new_key(des_cblock *new_key, char *sname, char *sinst,
+		char *srealm, char *keyfile)
 {
     int status = KADM_SUCCESS;
 
     if (((status = krb_get_svc_in_tkt(sname, sinst, srealm, PWSERV_NAME,
 				      KADM_SINST, 1, keyfile)) == KSUCCESS) &&
-	((status = kadm_init_link("changepw", KRB_MASTER, srealm)) == 
+	((status = kadm_init_link(PWSERV_NAME, KRB_MASTER, srealm)) == 
 	 KADM_SUCCESS)) {
 #ifdef NOENCRYPTION
 	memset(new_key, 0, sizeof(des_cblock));
-	new_key[0] = (unsigned char) 1;
+	(*new_key)[0] = (unsigned char) 1;
 #else /* NOENCRYPTION */
-	(void) des_new_random_key(new_key);
+	des_new_random_key(new_key);
 #endif /* NOENCRYPTION */
 	return(KADM_SUCCESS);
     }
@@ -282,12 +280,12 @@ get_key_from_password(des_cblock (*key), char *cellname)
 
 #ifdef NOENCRYPTION
     memset(key, 0, sizeof(des_cblock));
-    key[0] = (unsigned char) 1;
+    (*key)[0] = (unsigned char) 1;
 #else /* NOENCRYPTION */
     if (strlen(cellname) == 0)
-      (void) des_string_to_key(password, key);
+      des_string_to_key(password, key);
     else
-      (void) afs_string_to_key(password, cellname, key);
+      afs_string_to_key(password, cellname, key);
 #endif /* NOENCRYPTION */
     memset(password, 0, sizeof(password));
 }    
@@ -295,14 +293,14 @@ get_key_from_password(des_cblock (*key), char *cellname)
 static void
 usage(void)
 {
-    (void) fprintf(stderr, "Usage: ksrvutil [-f keyfile] [-i] [-k] ");
-    (void) fprintf(stderr, "[-p principal] [-r realm] ");
-    (void) fprintf(stderr, "[-c AFS cellname] ");
-    (void) fprintf(stderr, "{list | change | add | get}\n");
-    (void) fprintf(stderr, "   -i causes the program to ask for ");
-    (void) fprintf(stderr, "confirmation before changing keys.\n");
-    (void) fprintf(stderr, "   -k causes the key to printed for list or ");
-    (void) fprintf(stderr, "change.\n");
+    fprintf(stderr, "Usage: ksrvutil [-f keyfile] [-i] [-k] ");
+    fprintf(stderr, "[-p principal] [-r realm] ");
+    fprintf(stderr, "[-c AFS cellname] ");
+    fprintf(stderr, "{list | change | add | get}\n");
+    fprintf(stderr, "   -i causes the program to ask for ");
+    fprintf(stderr, "confirmation before changing keys.\n");
+    fprintf(stderr, "   -k causes the key to printed for list or ");
+    fprintf(stderr, "change.\n");
     exit(1);
 }
 
@@ -357,7 +355,7 @@ main(int argc, char **argv)
 
     /* This is used only as a default for adding keys */
     if (krb_get_lrealm(local_realm, 1) != KSUCCESS)
-	(void) strcpy(local_realm, KRB_REALM);
+	strcpy(local_realm, KRB_REALM);
     
     while((c = getopt(argc, argv, "ikc:f:p:r:")) != EOF) {
 	 switch (c) {
@@ -368,10 +366,10 @@ main(int argc, char **argv)
 	      key++;
 	      break;
 	      case 'c':
-	      (void) strcpy(cellname, optarg);
+	      strcpy(cellname, optarg);
 	      break;
 	      case 'f':
-	      (void) strcpy(keyfile, optarg);
+	      strcpy(keyfile, optarg);
 	      break;
 	      case 'p':
 	      if((status = kname_parse (u_name, u_inst, u_realm, optarg)) !=
@@ -383,7 +381,7 @@ main(int argc, char **argv)
 	      }
 	      break;
 	      case 'r':
-	      (void) strcpy(u_realm, optarg);
+	      strcpy(u_realm, optarg);
 	      break;
 	      case '?':
 	      usage();
@@ -431,14 +429,14 @@ main(int argc, char **argv)
 	usage();
 
     if (!keyfile[0])
-	(void) strcpy(keyfile, KEYFILE);
+	strcpy(keyfile, KEYFILE);
     
-    (void) strcpy(work_keyfile, keyfile);
-    (void) strcpy(backup_keyfile, keyfile);
+    strcpy(work_keyfile, keyfile);
+    strcpy(backup_keyfile, keyfile);
     
     if (change || add || get) {
-	(void) strcat(work_keyfile, ".work");
-	(void) strcat(backup_keyfile, ".old");
+	strcat(work_keyfile, ".work");
+	strcat(backup_keyfile, ".old");
 	
 	copy_keyfile(keyfile, backup_keyfile);
     }
@@ -450,9 +448,9 @@ main(int argc, char **argv)
 
     if (change || list) {
 	if ((backup_keyfile_fd = open(backup_keyfile, O_RDONLY, 0)) < 0) {
-	  (void) fprintf(stderr, "%s: Unable to read %s: %s\n", progname,
+	  fprintf(stderr, "%s: Unable to read %s: %s\n", progname,
 			   backup_keyfile, strerror(errno));
-	    exit(1);
+	    return 1;
 	}
     }
 
@@ -460,26 +458,26 @@ main(int argc, char **argv)
 	if ((work_keyfile_fd = 
 	     open(work_keyfile, O_WRONLY | O_CREAT | O_TRUNC, 
 		  SRVTAB_MODE)) < 0) {
-	    (void) fprintf(stderr, "%s: Unable to write %s: %s\n", progname,
+	    fprintf(stderr, "%s: Unable to write %s: %s\n", progname,
 			   work_keyfile, strerror(errno));
-	    exit(1);
+	    return 1;
 	}
     }
     else if (add) {
 	if ((work_keyfile_fd =
 	     open(work_keyfile, O_APPEND | O_WRONLY, SRVTAB_MODE)) < 0) {
-	    (void) fprintf(stderr, "%s: Unable to open %s for append: %s\n",
+	    fprintf(stderr, "%s: Unable to open %s for append: %s\n",
 			   progname, work_keyfile, strerror(errno));
-	    exit(1);
+	    return 1;
 	}
     }
     else if (get) {
 	if ((work_keyfile_fd =
 	     open(work_keyfile, O_RDWR | O_CREAT, SRVTAB_MODE)) < 0) {
-	     (void) fprintf(stderr, "%s: Unable to open %s for writing: %s\n",
+	     fprintf(stderr, "%s: Unable to open %s for writing: %s\n",
 			    progname, work_keyfile,
 			    strerror(errno));
-	     exit(1);
+	     return 1;
 	}
     }
     
@@ -488,36 +486,36 @@ main(int argc, char **argv)
 	       (getst(backup_keyfile_fd, sinst, INST_SZ) > 0) &&
 	       (getst(backup_keyfile_fd, srealm, REALM_SZ) > 0) &&
 	       (read(backup_keyfile_fd, &key_vno, 1) > 0) &&
-	       (read(backup_keyfile_fd,(char *)old_key,sizeof(old_key)) > 0)) {
+	       (read(backup_keyfile_fd, old_key, sizeof(old_key)) > 0)) {
 	    if (list) {
 		if (!first_printed) {
-		    (void) printf(VNO_HEADER);
-		    (void) printf(PAD);
+		    printf(VNO_HEADER);
+		    printf(PAD);
 		    if (key) {
-			(void) printf(KEY_HEADER);
-			(void) printf(PAD);
+			printf(KEY_HEADER);
+			printf(PAD);
 		    }
-		    (void) printf(PRINC_HEADER);
+		    printf(PRINC_HEADER);
 		    first_printed = 1;
 		}
-		(void) printf(VNO_FORMAT, key_vno);
-		(void) printf(PAD);
+		printf(VNO_FORMAT, key_vno);
+		printf(PAD);
 		if (key) {
 		    print_key(old_key);
-		    (void) printf(PAD);
+		    printf(PAD);
 		}
 		print_name(sname, sinst, srealm);
-		(void) printf("\n");
+		printf("\n");
 	    }
 	    else if (change) {
-		(void) sprintf(change_tkt, TKT_ROOT "_ksrvutil.%d",
+		sprintf(change_tkt, TKT_ROOT "_ksrvutil.%d",
 			       (int)getpid());
 		krb_set_tkt_string(change_tkt);
 		destroyp = TRUE;
 
-		(void) printf("\nPrincipal: ");
+		printf("\nPrincipal: ");
 		print_name(sname, sinst, srealm);
-		(void) printf("; version %d\n", key_vno);
+		printf("; version %d\n", key_vno);
 		if (interactive)
 		    change_this_key = yn("Change this key?");
 		else if (change)
@@ -526,9 +524,9 @@ main(int argc, char **argv)
 		    change_this_key = 0;
 		
 		if (change_this_key)
-		    (void) printf("Changing to version %d.\n", key_vno + 1);
+		    printf("Changing to version %d.\n", key_vno + 1);
 		else if (change)
-		    (void) printf("Not changing this key.\n");
+		    printf("Not changing this key.\n");
 		
 		if (change_this_key) {
 		    /*
@@ -558,37 +556,37 @@ main(int argc, char **argv)
 		    }
 		}
 		else 
-		    (void) memcpy(new_key, old_key, sizeof(new_key));
+		    memcpy(new_key, old_key, sizeof(new_key));
 		append_srvtab(work_keyfile, work_keyfile_fd, 
 			      sname, sinst, srealm, key_vno, new_key);
 		if (key && change_this_key) {
-		    (void) printf("Old key: ");
+		    printf("Old key: ");
 		    print_key(old_key);
-		    (void) printf("; new key: ");
+		    printf("; new key: ");
 		    print_key(new_key);
-		    (void) printf("\n");
+		    printf("\n");
 		}
 		if (change_this_key) {
 		    if ((status = kadm_change_pw(new_key)) == KADM_SUCCESS) {
-			(void) printf("Key changed.\n");
-			(void) dest_tkt();
+			printf("Key changed.\n");
+			dest_tkt();
 		    }
 		    else {
 			com_err(progname, status, 
 				" attempting to change password.");
-			(void) dest_tkt();
+			dest_tkt();
 			/* XXX This knows the format of a keyfile */
 			if (lseek(work_keyfile_fd, -9, SEEK_CUR) >= 0) {
 			    key_vno--;
 			    safe_write(work_keyfile,
-				       work_keyfile_fd, (char *)&key_vno, 1);
+				       work_keyfile_fd, &key_vno, 1);
 			    safe_write(work_keyfile, work_keyfile_fd,
-				       (char *)old_key, sizeof(des_cblock));
-			    (void) fsync(work_keyfile_fd);
-			    (void) fprintf(stderr,"Key NOT changed.\n");
+				       old_key, sizeof(des_cblock));
+			    fsync(work_keyfile_fd);
+			    fprintf(stderr,"Key NOT changed.\n");
 			}
 			else {
-			    (void)fprintf(stderr, 
+			    fprintf(stderr, 
 					  "%s: Unable to revert keyfile: %s\n",
 					  progname, strerror(errno));
 			    leave("", 1);
@@ -604,35 +602,35 @@ main(int argc, char **argv)
 	do {
 	    do {
 		safe_read_stdin("Name: ", databuf, sizeof(databuf));
-		(void) strncpy(sname, databuf, sizeof(sname) - 1);
+		strncpy(sname, databuf, sizeof(sname) - 1);
 		if (strchr(sname, '.') != 0) {
 		  strcpy(sinst, strchr(sname, '.') + 1);
 		  *(strchr(sname, '.')) = 0;
 		} else {
 		  safe_read_stdin("Instance: ", databuf, sizeof(databuf));
-		  (void) strncpy(sinst, databuf, sizeof(sinst) - 1);
+		  strncpy(sinst, databuf, sizeof(sinst) - 1);
 		}
 		safe_read_stdin("Realm: ", databuf, sizeof(databuf));
-		(void) strncpy(srealm, databuf, sizeof(srealm) - 1);
+		strncpy(srealm, databuf, sizeof(srealm) - 1);
 		safe_read_stdin("Version number: ", databuf, sizeof(databuf));
 		key_vno = atoi(databuf);
 		if (key_vno == 0)
 			key_vno = 1; /* Version numbers are never 0 */
 		if (!srealm[0])
-		    (void) strcpy(srealm, local_realm);
-		(void) printf("New principal: ");
+		    strcpy(srealm, local_realm);
+		printf("New principal: ");
 		print_name(sname, sinst, srealm);
-		(void) printf("; version %d\n", key_vno);
+		printf("; version %d\n", key_vno);
 	    } while (!yn("Is this correct?"));
 	    get_key_from_password(&new_key, cellname);
 	    if (key) {
-		(void) printf("Key: ");
+		printf("Key: ");
 		print_key(new_key);
-		(void) printf("\n");
+		printf("\n");
 	    }
 	    append_srvtab(work_keyfile, work_keyfile_fd, 
 			  sname, sinst, srealm, key_vno, new_key);
-	    (void) printf("Key successfully added.\n");
+	    printf("Key successfully added.\n");
 	} while (yn("Would you like to add another key?"));
     }
     else if (get) {
@@ -642,27 +640,26 @@ main(int argc, char **argv)
 
     if (change || list) 
 	if (close(backup_keyfile_fd) < 0) {
-	    (void) fprintf(stderr, "%s: Failure closing %s: %s\n",
+	    fprintf(stderr, "%s: Failure closing %s: %s\n",
 			   progname, backup_keyfile, strerror(errno));
-	    (void) fprintf(stderr, "continuing...\n");
+	    fprintf(stderr, "continuing...\n");
 	}
     
     if (change || add || get) {
 	if (close(work_keyfile_fd) < 0) {
-	    (void) fprintf(stderr, "%s: Failure closing %s: %s\n",
+	    fprintf(stderr, "%s: Failure closing %s: %s\n",
 			   progname, work_keyfile, strerror(errno));
-	    exit(1);
+	    return 1;
 	}
 	if (rename(work_keyfile, keyfile) < 0) {
-	    (void) fprintf(stderr, "%s: Failure renaming %s to %s: %s\n",
+	    fprintf(stderr, "%s: Failure renaming %s to %s: %s\n",
 			   progname, work_keyfile, keyfile, 
 			   strerror(errno));
-	    exit(1);
+	    return 1;
 	}
-	(void) chmod(backup_keyfile, keyfile_mode);
-	(void) chmod(keyfile, keyfile_mode);
-	(void) printf("Old keyfile in %s.\n", backup_keyfile);
+	chmod(backup_keyfile, keyfile_mode);
+	chmod(keyfile, keyfile_mode);
+	printf("Old keyfile in %s.\n", backup_keyfile);
     }
-
-    exit(0);
+    return 0;
 }
