@@ -1,7 +1,45 @@
+/*
+ * Copyright (c) 1995, 1996 Kungliga Tekniska Hgskolan (Royal Institute
+ * of Technology, Stockholm, Sweden).
+ * All rights reserved.
+ * 
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
+ * 
+ * 1. Redistributions of source code must retain the above copyright
+ *    notice, this list of conditions and the following disclaimer.
+ * 
+ * 2. Redistributions in binary form must reproduce the above copyright
+ *    notice, this list of conditions and the following disclaimer in the
+ *    documentation and/or other materials provided with the distribution.
+ * 
+ * 3. All advertising materials mentioning features or use of this software
+ *    must display the following acknowledgement:
+ *      This product includes software developed by the Kungliga Tekniska
+ *      Hgskolan and its contributors.
+ * 
+ * 4. Neither the name of the Institute nor the names of its contributors
+ *    may be used to endorse or promote products derived from this software
+ *    without specific prior written permission.
+ * 
+ * THIS SOFTWARE IS PROVIDED BY THE INSTITUTE AND CONTRIBUTORS ``AS IS'' AND
+ * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED.  IN NO EVENT SHALL THE INSTITUTE OR CONTRIBUTORS BE LIABLE
+ * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
+ * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
+ * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
+ * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
+ * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
+ * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
+ * SUCH DAMAGE.
+ */
+
 #include "kadm_locl.h"
 #include "ksrvutil.h"
 
-RCSID("$Id: ksrvutil_get.c,v 1.18 1996/08/22 19:17:46 assar Exp $");
+RCSID("$Id: ksrvutil_get.c,v 1.25 1996/11/24 00:59:48 assar Exp $");
 
 #define BAD_PW 1
 #define GOOD_PW 0
@@ -17,7 +55,9 @@ princ_exists(char *name, char *instance, char *realm)
 {
     int status;
 
-    status = krb_get_pw_in_tkt(name, instance, realm, "krbtgt", realm, 1, "");
+    status = krb_get_pw_in_tkt(name, instance, realm,
+			       KRB_TICKET_GRANTING_TICKET,
+			       realm, 1, "");
 
     if ((status == KSUCCESS) || (status == INTK_BADPW))
 	return(PE_YES);
@@ -37,8 +77,8 @@ get_admin_password(char *myname, char *myinst, char *myrealm)
   CREDENTIALS c;
 
   if (princ_exists(myname, myinst, myrealm) != PE_NO) {
-    sprintf(buf, "Password for %s.%s@%s:", 
-	    myname, myinst, myrealm);
+    sprintf(buf, "Password for %s",
+	    krb_unparse_name_long (myname, myinst, myrealm));
     if (des_read_pw_string(admin_passwd, sizeof(admin_passwd)-1,
 			    buf, 0)) {
       fprintf(stderr, "Error reading admin password.\n");
@@ -60,7 +100,8 @@ get_admin_password(char *myname, char *myinst, char *myrealm)
   case GT_PW_OK:
     return(GOOD_PW);
   case KDC_PR_UNKNOWN:
-    printf("Principal %s.%s@%s does not exist.\n", myname, myinst, myrealm);
+    printf("Principal %s does not exist.\n",
+	   krb_unparse_name_long(myname, myinst, myrealm));
     goto bad;
   case GT_PW_BADPW:
     printf("Incorrect admin password.\n");
@@ -71,9 +112,9 @@ get_admin_password(char *myname, char *myinst, char *myrealm)
     goto bad;
   }
   
-  bad:
+bad:
   memset(admin_passwd, 0, sizeof(admin_passwd));
-  (void) dest_tkt();
+  dest_tkt();
   return(BAD_PW);
 }
 
@@ -151,7 +192,7 @@ get_srvtab_ent(int fd, char *filename, char *name, char *inst, char *realm)
   memset(&values, 0, sizeof(values));
   strcpy(values.name, name);
   strcpy(values.instance, inst);
-  (void) des_new_random_key(&newkey);
+  des_new_random_key(&newkey);
   values.key_low = (newkey[0] << 24) | (newkey[1] << 16)
     | (newkey[2] << 8) | (newkey[3] << 0);
   values.key_high = (newkey[4] << 24) | (newkey[5] << 16)
@@ -193,8 +234,11 @@ get_srvtab_ent(int fd, char *filename, char *name, char *inst, char *realm)
   unlink(new_tktfile);
     
   if(ret != KSUCCESS) {
-    fprintf (stderr, "%s: Could not get a ticket for %s.%s@%s: %s\n",
-	     progname, name, inst, realm, krb_get_err_text(ret));
+    memset(&newkey, 0, sizeof(newkey));
+    fprintf (stderr, "%s: Could not get a ticket for %s: %s\n",
+	     progname,
+	     krb_unparse_name_long(name, inst, realm),
+	     krb_get_err_text(ret));
     return;
   }
 
@@ -203,10 +247,9 @@ get_srvtab_ent(int fd, char *filename, char *name, char *inst, char *realm)
   srvtab_put_key (fd, filename, name, inst, realm, kvno, newkey);
   memset(&newkey, 0, sizeof(newkey));
 
-  fprintf (stderr, "Written %s.%s\n", name, inst);
+  fprintf (stderr, "Added %s\n", krb_unparse_name_long (name, inst, realm));
 }
 
-
 static void
 ksrvutil_kadm(int fd, char *filename, struct srv_ent *p)
 {
@@ -216,7 +259,7 @@ ksrvutil_kadm(int fd, char *filename, struct srv_ent *p)
   ret = kadm_init_link(PWSERV_NAME, KADM_SINST, u_realm);
   if (ret != KADM_SUCCESS) {
     fprintf(stderr, "%s: Couldn't initialize kadmin link: %s\n",
-	    progname, krb_get_err_text(ret));
+	    progname, error_message(ret));
     leave(NULL, 1);
   }
   
@@ -247,6 +290,34 @@ ksrvutil_kadm(int fd, char *filename, struct srv_ent *p)
   unlink(tktstring);
 }
 
+static void
+parseinput (char *result, size_t sz, char *val, char *def)
+{
+  char *lim;
+  int inq;
+
+  if (val[0] == '\0') {
+    strncpy (result, def, sz-1);
+    return;
+  }
+  lim = result + sz - 1;
+  inq = 0;
+  while(*val && result < lim) {
+    switch(*val) {
+    case '\'' :
+      inq = !inq;
+      ++val;
+      break;
+    case '\\' :
+      if(!inq)
+	val++;
+    default:
+      *result++ = *val++;
+      break;
+    }
+  }
+  *result = '\0';
+}
 
 void
 ksrvutil_get(int fd, char *filename, int argc, char **argv)
@@ -255,14 +326,11 @@ ksrvutil_get(int fd, char *filename, int argc, char **argv)
   char sinst[INST_SZ];		/* instance of service */
   char srealm[REALM_SZ];	/* realm of service */
   char databuf[BUFSIZ];
-  char local_realm[REALM_SZ];	/* local kerberos realm */
   char local_hostname[100];
   char prompt[100];
   struct srv_ent *head=NULL;
   int i;
 
-  if (krb_get_lrealm(local_realm, 1) != KSUCCESS)
-    strcpy(local_realm, KRB_REALM);
   k_gethostname(local_hostname, sizeof(local_hostname));
   strcpy(local_hostname, krb_get_phost(local_hostname));
 
@@ -274,9 +342,6 @@ ksrvutil_get(int fd, char *filename, int argc, char **argv)
 	fprintf(stderr, "%s: out of memory in malloc\n", progname);
 	leave(NULL,1);
       }
-      strcpy(p->name, "rcmd");
-      strcpy(p->inst, local_hostname);
-      strcpy(p->realm, local_realm);
       p->next = head;
       if (kname_parse (p->name, p->inst, p->realm, argv[i]) !=
 	  KSUCCESS) {
@@ -285,30 +350,28 @@ ksrvutil_get(int fd, char *filename, int argc, char **argv)
 	free(p);
 	continue;
       }
+      if (p->name[0] == '\0')
+	strcpy(p->name, "rcmd");
+      if (p->inst[0] == '\0')
+	strcpy(p->inst, local_hostname);
+      if (p->realm[0] == '\0')
+	strcpy(p->realm, u_realm);
       head = p;
     }
 
   else
     do{
       safe_read_stdin("Name [rcmd]: ", databuf, sizeof(databuf));
-      if(databuf[0])
-	strncpy(sname, databuf, sizeof(sname)-1);
-      else
-	strcpy(sname, "rcmd");
+      parseinput (sname, sizeof(sname), databuf, "rcmd");
     
       sprintf(prompt, "Instance [%s]: ", local_hostname);
       safe_read_stdin(prompt, databuf, sizeof(databuf));
-      if (databuf[0])
-	strncpy(sinst, databuf, sizeof(sinst) - 1);
-      else
-	strcpy(sinst, local_hostname);
+      parseinput (sinst, sizeof(sinst), databuf, local_hostname);
     
-      sprintf(prompt, "Realm [%s]: ", local_realm);
+      sprintf(prompt, "Realm [%s]: ", u_realm);
       safe_read_stdin(prompt, databuf, sizeof(databuf));
-      if (databuf[0])
-	strncpy(srealm, databuf, sizeof(srealm) - 1);
-      else
-	strcpy(srealm, local_realm);
+      parseinput (srealm, sizeof(srealm), databuf, u_realm);
+
       if(yn("Is this correct?")){
 	struct srv_ent *p=(struct srv_ent*)malloc(sizeof(struct srv_ent));
 	p->next=head;
