@@ -9,8 +9,15 @@
  */
 
 #include "kuser_locl.h"
+#ifdef HAVE_SYS_IOCTL_H
+#include <sys/ioctl.h>
+#endif
+#ifdef HAVE_SYS_IOCCOM_H
+#include <sys/ioccom.h>
+#endif
+#include <kafs.h>
 
-RCSID("$Id: klist.c,v 1.12 1996/08/13 23:40:08 assar Exp $");
+RCSID("$Id: klist.c,v 1.22 1996/11/19 22:48:43 assar Exp $");
 
 static char   *whoami;			/* What was I invoked as?? */
 static int option_verbose = 0;
@@ -18,7 +25,7 @@ static int option_verbose = 0;
 static char *
 short_date(int32_t dp)
 {
-    register char *cp;
+    char *cp;
     time_t t = (time_t)dp;
 
     if (t == (time_t)(-1L)) return "***  Never  *** ";
@@ -30,9 +37,7 @@ short_date(int32_t dp)
 static void
 display_tktfile(char *file, int tgt_test, int long_form)
 {
-    char    pname[ANAME_SZ];
-    char    pinst[INST_SZ];
-    char    prealm[REALM_SZ];
+    krb_principal pr;
     char    buf1[20], buf2[20];
     int     k_errno;
     CREDENTIALS c;
@@ -61,7 +66,7 @@ display_tktfile(char *file, int tgt_test, int long_form)
 	exit(1);
     }
     /* Close ticket file */
-    (void) tf_close();
+    tf_close();
 
     /* 
      * We must find the realm of the ticket file here before calling
@@ -69,7 +74,7 @@ display_tktfile(char *file, int tgt_test, int long_form)
      * really stored in the principal section of the file, the
      * routine we use must itself call tf_init and tf_close.
      */
-    if ((k_errno = krb_get_tf_realm(file, prealm)) != KSUCCESS) {
+    if ((k_errno = krb_get_tf_realm(file, pr.realm)) != KSUCCESS) {
 	if (!tgt_test)
 	    fprintf(stderr, "%s: can't find realm of ticket file: %s\n",
 		    whoami, krb_get_err_text(k_errno));
@@ -83,8 +88,8 @@ display_tktfile(char *file, int tgt_test, int long_form)
 	exit(1);
     }
     /* Get principal name and instance */
-    if ((k_errno = tf_get_pname(pname)) ||
-	(k_errno = tf_get_pinst(pinst))) {
+    if ((k_errno = tf_get_pname(pr.name)) ||
+	(k_errno = tf_get_pinst(pr.instance))) {
 	    if (!tgt_test)
 		    fprintf(stderr, "%s: %s\n", whoami, krb_get_err_text(k_errno));
 	    exit(1);
@@ -98,9 +103,7 @@ display_tktfile(char *file, int tgt_test, int long_form)
      */
        
     if (!tgt_test && long_form)
-	printf("Principal:\t%s%s%s%s%s\n\n", pname,
-	       (pinst[0] ? "." : ""), pinst,
-	       (prealm[0] ? "@" : ""), prealm);
+	printf("Principal:\t%s\n\n", krb_unparse_name(&pr));
     while ((k_errno = tf_get_cred(&c)) == KSUCCESS) {
 	if (!tgt_test && long_form && header) {
 	    printf("%-15s  %-15s  %s%s\n",
@@ -110,8 +113,8 @@ display_tktfile(char *file, int tgt_test, int long_form)
 	}
 	if (tgt_test) {
 	    c.issue_date = krb_life_to_time(c.issue_date, c.lifetime);
-	    if (!strcmp(c.service, TICKET_GRANTING_TICKET) &&
-		!strcmp(c.instance, prealm)) {
+	    if (!strcmp(c.service, KRB_TICKET_GRANTING_TICKET) &&
+		!strcmp(c.instance, pr.realm)) {
 		if (time(0) < c.issue_date)
 		    exit(0);		/* tgt hasn't expired */
 		else
@@ -120,17 +123,15 @@ display_tktfile(char *file, int tgt_test, int long_form)
 	    continue;			/* not a tgt */
 	}
 	if (long_form) {
-	    (void) strcpy(buf1, short_date(c.issue_date));
+	    strcpy(buf1, short_date(c.issue_date));
 	    c.issue_date = krb_life_to_time(c.issue_date, c.lifetime);
 	    if (time(0) < (unsigned long) c.issue_date)
-	        (void) strcpy(buf2, short_date(c.issue_date));
+	        strcpy(buf2, short_date(c.issue_date));
 	    else
-	        (void) strcpy(buf2, ">>> Expired <<< ");
+	        strcpy(buf2, ">>> Expired <<< ");
 	    printf("%s  %s  ", buf1, buf2);
 	}
-	printf("%s%s%s%s%s",
-	       c.service, (c.instance[0] ? "." : ""), c.instance,
-	       (c.realm[0] ? "@" : ""), c.realm); 
+	printf("%s", krb_unparse_name_long(c.service, c.instance, c.realm));
 	if(long_form && option_verbose)
 	  printf(" (%d)", c.kvno);
 	printf("\n");
@@ -169,6 +170,30 @@ ok_getst(int fd, char *s, int n)
     return (n - count);
 }
 
+static void
+display_tokens()
+{
+    u_int32_t i;
+    int ret;
+    unsigned char t[128];
+    struct ViceIoctl parms;
+    struct ClearToken ct;
+    int size1, size2;
+    parms.in = (void*)&i;
+    parms.in_size = sizeof(i);
+    parms.out = (void*)t;
+    parms.out_size = sizeof(t);
+    i = 0;
+    while((ret = k_pioctl(NULL, VIOCGETTOK, &parms, 0)) == 0){
+	memcpy(&size1, t, 4);
+	memcpy(&size2, t + 4 + size1, 4);
+	memcpy(&ct, t + 4 + size1 + 4 + size2, size2);
+	printf("%d\t%s\t%s\t%d\n", ct.ViceId, short_date(ct.BeginTimestamp), 
+	       short_date(ct.EndTimestamp), ct.AuthHandle);
+	i++;
+    }
+}
+
 static void
 display_srvtab(char *file)
 {
@@ -194,8 +219,8 @@ display_srvtab(char *file)
     while (((count = ok_getst(stab, serv, SNAME_SZ)) > 0)
 	   && ((count = ok_getst(stab, inst, INST_SZ)) > 0)
 	   && ((count = ok_getst(stab, rlm, REALM_SZ)) > 0)) {
-	if (((count = read(stab,(char *) &vno,1)) != 1) ||
-	     ((count = read(stab,(char *) key,8)) != 8)) {
+	if (((count = read(stab,  &vno,1)) != 1) ||
+	     ((count = read(stab, key,8)) != 8)) {
 	    if (count < 0)
 		perror("reading from key file");
 	    else
@@ -206,7 +231,7 @@ display_srvtab(char *file)
     }
     if (count < 0)
 	perror(file);
-    (void) close(stab);
+    close(stab);
 }
 
 static void
@@ -224,6 +249,7 @@ main(int argc, char **argv)
     int     long_form = 1;
     int     tgt_test = 0;
     int     do_srvtab = 0;
+    int     do_tokens = 0;
     char   *tkt_file = NULL;
     char   *cp;
 
@@ -243,6 +269,10 @@ main(int argc, char **argv)
 	    long_form = 0;
 	    continue;
 	}
+	if (!strcmp(*argv, "-tokens") && k_hasafs()){
+	    do_tokens = 1;
+	    continue;
+	}
 	if (!strcmp(*argv, "-l")) {	/* now default */
 	    continue;
 	}
@@ -263,6 +293,8 @@ main(int argc, char **argv)
 	usage();
     }
 
+    if (do_tokens)
+	display_tokens();
     if (do_srvtab)
 	display_srvtab(tkt_file);
     else
