@@ -16,14 +16,14 @@
 #include <conf.h>
 
 const char rcsid[] =
-    "$Id: ksrvtgt.c,v 1.5 1996/06/12 21:28:46 bg Exp $";
+    "$Id: ksrvtgt.c,v 1.8 1996/11/17 21:08:34 assar Exp $";
 
 main(argc,argv)
     int argc;
     char **argv;
 {
     char realm[REALM_SZ + 1];
-    register int code;
+    int code;
     char srvtab[MaxPathLen + 1];
 
     memset(realm, 0, sizeof(realm));
@@ -36,22 +36,23 @@ main(argc,argv)
     }
     
     if (argc == 4)
-	(void) strncpy(srvtab, argv[3], sizeof(srvtab) -1);
+	strncpy(srvtab, argv[3], sizeof(srvtab) -1);
     
     if (argc == 5) {
-	(void) strncpy(realm, argv[3], sizeof(realm) - 1);
-	(void) strncpy(srvtab, argv[4], sizeof(srvtab) -1);
+	strncpy(realm, argv[3], sizeof(realm) - 1);
+	strncpy(srvtab, argv[4], sizeof(srvtab) -1);
     }
 
     if (srvtab[0] == 0)
-	(void) strcpy(srvtab, KEYFILE);
+	strcpy(srvtab, KEYFILE);
 
     if (realm[0] == 0)
 	if (krb_get_lrealm(realm, 1) != KSUCCESS)
-	    (void) strcpy(realm, KRB_REALM);
+	    strcpy(realm, KRB_REALM);
 
     code = krb_get_svc_in_tkt(argv[1], argv[2], realm,
-			      "krbtgt", realm, 1, srvtab);
+			      KRB_TICKET_GRANTING_TICKET,
+			      realm, 1, srvtab);
     if (code)
 	fprintf(stderr, "%s\n", krb_get_err_text(code));
     exit(code);
