@@ -27,22 +27,34 @@ or implied warranty.
 #include "config.h"
 #include "protos.h"
 
-RCSID("$Id: acl_files.c,v 1.6 1996/07/02 09:48:39 bg Exp $");
+RCSID("$Id: acl_files.c,v 1.8 1996/11/17 20:04:38 assar Exp $");
 
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 
+#ifdef HAVE_UNISTD_H
 #include <unistd.h>
+#endif
+#ifdef HAVE_SYS_TYPES_H
 #include <sys/types.h>
+#endif
 #include <time.h>
+#ifdef HAVE_FCNTL_H
 #include <fcntl.h>
+#endif
+#ifdef HAVE_SYS_FILE_H
 #include <sys/file.h>
+#endif
+#ifdef HAVE_SYS_STAT_H
 #include <sys/stat.h>
+#endif
 
 #include <errno.h>
 #include <ctype.h>
 
+#include <roken.h>
+
 #include <krb.h>
 #include <acl.h>
 
@@ -62,9 +74,6 @@ RCSID("$Id: acl_files.c,v 1.6 1996/07/02 09:48:39 bg Exp $");
 				/* Each acl costs 1 open file descriptor */
 #define ACL_LEN 16		/* Twice a reasonable acl length */
 
-#define MAX(a,b) (((a)>(b))?(a):(b))
-#define MIN(a,b) (((a)<(b))?(a):(b))
-
 #define COR(a,b) ((a!=NULL)?(a):(b))
 
 /* Canonicalize a principal name */
@@ -99,7 +108,7 @@ acl_canonicalize_principal(char *principal, char *canon)
     end = principal + strlen(principal);
 
     /* Get the principal name */
-    len = MIN(ANAME_SZ, COR(dot, COR(atsign, end)) - principal);
+    len = min(ANAME_SZ, COR(dot, COR(atsign, end)) - principal);
     strncpy(canon, principal, len);
     canon += len;
 
@@ -109,7 +118,7 @@ acl_canonicalize_principal(char *principal, char *canon)
     /* Get the instance, if it exists */
     if(dot != NULL) {
 	++dot;
-	len = MIN(INST_SZ, COR(atsign, end) - dot);
+	len = min(INST_SZ, COR(atsign, end) - dot);
 	strncpy(canon, dot, len);
 	canon += len;
     }
@@ -121,7 +130,7 @@ acl_canonicalize_principal(char *principal, char *canon)
     /* Otherwise, default to local realm */
     if(atsign != NULL) {
 	++atsign;
-	len = MIN(REALM_SZ, end - atsign);
+	len = min(REALM_SZ, end - atsign);
 	strncpy(canon, atsign, len);
 	canon += len;
 	*canon++ = '\0';
@@ -254,7 +263,7 @@ acl_initialize(char *acl_file, int perm)
 static void
  nuke_whitespace(char *buf)
 {
-    register char *pin, *pout;
+    char *pin, *pout;
 
     for(pin = pout = buf; *pin != '\0'; pin++)
 	if(!isspace(*pin)) *pout++ = *pin;
@@ -298,9 +307,9 @@ destroy_hash(struct hashtbl *h)
 
 /* Compute hash value for a string */
 static unsigned int
-hashval(register char *s)
+hashval(char *s)
 {
-    register unsigned hv;
+    unsigned hv;
 
     for(hv = 0; *s != '\0'; s++) {
 	hv ^= ((hv << 3) ^ *s);
