@@ -1,10 +1,49 @@
+/*
+ * Copyright (c) 1995, 1996 Kungliga Tekniska Hgskolan (Royal Institute
+ * of Technology, Stockholm, Sweden).
+ * All rights reserved.
+ * 
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
+ * 
+ * 1. Redistributions of source code must retain the above copyright
+ *    notice, this list of conditions and the following disclaimer.
+ * 
+ * 2. Redistributions in binary form must reproduce the above copyright
+ *    notice, this list of conditions and the following disclaimer in the
+ *    documentation and/or other materials provided with the distribution.
+ * 
+ * 3. All advertising materials mentioning features or use of this software
+ *    must display the following acknowledgement:
+ *      This product includes software developed by the Kungliga Tekniska
+ *      Hgskolan and its contributors.
+ * 
+ * 4. Neither the name of the Institute nor the names of its contributors
+ *    may be used to endorse or promote products derived from this software
+ *    without specific prior written permission.
+ * 
+ * THIS SOFTWARE IS PROVIDED BY THE INSTITUTE AND CONTRIBUTORS ``AS IS'' AND
+ * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED.  IN NO EVENT SHALL THE INSTITUTE OR CONTRIBUTORS BE LIABLE
+ * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
+ * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
+ * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
+ * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
+ * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
+ * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
+ * SUCH DAMAGE.
+ */
+
+#ifdef HAVE_CONFIG_H
 #include "config.h"
 
-RCSID("$Id: md5.c,v 1.2 1996/05/04 04:44:01 assar Exp $");
+RCSID("$Id: md5.c,v 1.8 1996/10/27 16:26:15 joda Exp $");
+#endif
 
-#include <sys/cdefs.h>
-#include <sys/types.h>
-#include <sys/bitypes.h>
+#include <stdlib.h>
+#include <string.h>
 
 #include "md5.h"
 
@@ -175,14 +214,12 @@ swap_u_int32_t (u_int32_t t)
 }
 
 void
-md5_update (struct md5 *m, const void *p_, size_t len)
+md5_update (struct md5 *m, void *v, size_t len)
 {
-  const unsigned char *p = p_;
+  u_char *p = (u_char *)v;
   m->sz += len;
-  while (len > 0) {
-    unsigned l;
-
-    if (m->offset == 0 && len >= 64) {
+  if (m->offset == 0 && len % 64 == 0) 
+    while (len > 0) {
 #if defined(WORDS_BIGENDIAN)
       {
 	int i;
@@ -197,7 +234,11 @@ md5_update (struct md5 *m, const void *p_, size_t len)
 #endif
       p += 64;
       len -= 64;
-    } else {
+    }
+  else
+    while (len > 0) {
+      unsigned l;
+
       l = min(64 - m->offset, len);
       memcpy ((char *)m->current + m->offset, p, l);
       p += l;
@@ -214,23 +255,24 @@ md5_update (struct md5 *m, const void *p_, size_t len)
 	m->offset = 0;
       }
     }
-  }
 }
 
 void
 md5_finito (struct md5 *m, void *res)
 {
-  u_int32_t *r = (u_int32_t *)res;
-  static char zeros[64] = {0x80, 0x00, 0x00, 0x00};
+  static u_char zeros[72];
   u_int32_t len;
   unsigned dstart = (120 - m->offset - 1) % 64 + 1;
 
+  *zeros = 0x80;
+  memset (zeros + 1, 0, sizeof(zeros) - 1);
   len = 8 * m->sz;
   len = swap_u_int32_t (len);
   memcpy (zeros + dstart, &len, sizeof(len));
   md5_update (m, zeros, dstart + 8);
   {
     int i;
+    u_int32_t *r = (u_int32_t *)res;
 
     for (i = 0; i < 4; ++i)
       r[i] = swap_u_int32_t (m->counter[i]);
@@ -253,7 +295,7 @@ MD5Init (MD5_CTX *mdContext)
 void
 MD5Update (MD5_CTX *mdContext, const unsigned char *inBuf, unsigned int inLen)
 {
-  md5_update(&mdContext->m.d5, inBuf, inLen);
+  md5_update(&mdContext->m.d5, (unsigned char *)inBuf, inLen);
 }
 
 void
