@@ -1,15 +1,61 @@
+/*
+ * Copyright (c) 1995, 1996 Kungliga Tekniska Hgskolan (Royal Institute
+ * of Technology, Stockholm, Sweden).
+ * All rights reserved.
+ * 
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
+ * 
+ * 1. Redistributions of source code must retain the above copyright
+ *    notice, this list of conditions and the following disclaimer.
+ * 
+ * 2. Redistributions in binary form must reproduce the above copyright
+ *    notice, this list of conditions and the following disclaimer in the
+ *    documentation and/or other materials provided with the distribution.
+ * 
+ * 3. All advertising materials mentioning features or use of this software
+ *    must display the following acknowledgement:
+ *      This product includes software developed by the Kungliga Tekniska
+ *      Hgskolan and its contributors.
+ * 
+ * 4. Neither the name of the Institute nor the names of its contributors
+ *    may be used to endorse or promote products derived from this software
+ *    without specific prior written permission.
+ * 
+ * THIS SOFTWARE IS PROVIDED BY THE INSTITUTE AND CONTRIBUTORS ``AS IS'' AND
+ * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED.  IN NO EVENT SHALL THE INSTITUTE OR CONTRIBUTORS BE LIABLE
+ * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
+ * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
+ * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
+ * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
+ * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
+ * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
+ * SUCH DAMAGE.
+ */
+
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #include "protos.h"
 
-RCSID("$Id: rnd_keys.c,v 1.30 1996/08/12 10:02:20 bg Exp $");
+RCSID("$Id: rnd_keys.c,v 1.40 1996/11/15 18:39:07 bg Exp $");
 #endif
 
 #include <des.h>
+#include <des_locl.h>
 
 #include <sys/bitypes.h>
 #include <sys/time.h>
+
+#ifdef HAVE_UNISTD_H
 #include <unistd.h>
+#endif
+#ifdef HAVE_IO_H
+#include <io.h>
+#endif
+
 #include <signal.h>
 #include <fcntl.h>
 #include <string.h>
@@ -22,10 +68,10 @@ RCSID("$Id: rnd_keys.c,v 1.30 1996/08/12 10:02:20 bg Exp $");
  */
 static
 int
-sumFile (const char *name, int len, void *sum_)
+sumFile (const char *name, int len, void *res)
 {
-  int32_t *sum = sum_;
-  int32_t buf[1024*2];
+  u_int32_t sum[2];
+  u_int32_t buf[1024*2];
   int fd, i;
 
   fd = open (name, 0);
@@ -49,6 +95,7 @@ sumFile (const char *name, int len, void *sum_)
       len -= n;
     }
   close (fd);
+  memcpy (res, &sum, sizeof(sum));
   return 0;
 }
 
@@ -102,6 +149,8 @@ static volatile unsigned char *gdata; /* Global data */
 static volatile int igdata;	/* Index into global data */
 static int gsize;
 
+#ifndef WIN32	/* Visual C++ 4.0 (Windows95/NT) */
+
 static
 RETSIGTYPE
 sigALRM(int sig)
@@ -112,56 +161,74 @@ sigALRM(int sig)
     SIGRETURN(0);
 }
 
-#if !defined(HAVE_SETITIMER) && defined(HAVE_RANDOM)
+#endif
 
-/* XXX this is a quick hack, should be fixed */
+#if !defined(HAVE_RANDOM) && defined(HAVE_RAND)
+#ifndef srandom
+#define srandom srand
+#endif
+#ifndef random
+#define random rand
+#endif
+#endif
+
+#ifdef HAVE_RANDOM
 
-static
 void
-des_rand_data(unsigned char *data, int size)
+des_not_rand_data(unsigned char *data, int size)
 {
   int i;
 
   srandom (time (NULL));
 
   for(i = 0; i < size; ++i)
-    data[i] = random() % 0x100;
+    data[i] ^= random() % 0x100;
 }
 
-#else
+#endif
+
+#ifndef WIN32
+
+#ifndef HAVE_SETITIMER
+void pacemaker(struct timeval *tv)
+{
+    fd_set fds;
+    pid_t pid;
+    pid = getppid();
+    while(1){
+	FD_ZERO(&fds);
+	FD_SET(0, &fds);
+	select(1, &fds, NULL, NULL, tv);
+	kill(pid, SIGALRM);
+    }
+}
+#endif
 
 /*
  * Generate size bytes of "random" data using timed interrupts.
  * It takes about 40ms/byte random data.
  * It's not neccessary to be root to run it.
  */
-static
 void
 des_rand_data(unsigned char *data, int size)
 {
     struct itimerval tv, otv;
     struct sigaction sa, osa;
     int i, j;
-  
-    /*
-     * If there is a /dev/random it's use is preferred.
-     */
-    {
-      int fd = open("/dev/random", O_RDONLY);
-      if (fd != -1 && read(fd, data, size) == size)
-	{
-	  close(fd);
-	  return;
-	}
-      close(fd);
-    }
-    {
-      int fd = open("/dev/rnd", O_RDONLY);
-      if (fd != -1 && read(fd, data, size) == size)
-	{
-	  close(fd);
-	  return;
-	}
+    pid_t pid;
+    char *rnd_devices[] = {"/dev/random",
+			   "/dev/srandom",
+			   "/dev/urandom",
+			   NULL};
+    char **p;
+
+    for(p = rnd_devices; *p; p++) {
+      int fd = open(*p, O_RDONLY | O_NDELAY);
+      
+      if(fd >= 0 && read(fd, data, size) == size) {
+	close(fd);
+	return;
+      }
       close(fd);
     }
 
@@ -183,7 +250,17 @@ des_rand_data(unsigned char *data, int size)
     tv.it_value.tv_sec = 0;
     tv.it_value.tv_usec = 10 * 1000; /* 10 ms */
     tv.it_interval = tv.it_value;
+#ifdef HAVE_SETITIMER
     setitimer(ITIMER_REAL, &tv, &otv);
+#else
+    pid = fork();
+    if(pid == -1){
+	des_not_rand_data(data, size);
+	return;
+    }
+    if(pid == 0)
+	pacemaker(&tv.it_interval);
+#endif
 
     for(i = 0; i < 4; i++) {
 	for (igdata = 0; igdata < size;) /* igdata++ in sigALRM */
@@ -191,9 +268,20 @@ des_rand_data(unsigned char *data, int size)
 	for (j = 0; j < size; j++) /* Only use 2 bits each lap */
 	    gdata[j] = (gdata[j]>>2) | (gdata[j]<<6);
     }
+#ifdef HAVE_SETITIMER
     setitimer(ITIMER_REAL, &otv, 0);
+#else
+    kill(pid, SIGKILL);
+    waitpid(pid, NULL, 0);
+#endif
     sigaction(SIGALRM, &osa, 0);
 }
+#else
+void
+des_rand_data(unsigned char *p, int s)
+{
+  return des_not_rand_data (p, s);
+}
 #endif
 
 void
@@ -202,7 +290,6 @@ des_generate_random_block(des_cblock *block)
   des_rand_data((unsigned char *)block, sizeof(*block));
 }
 
-#if 0
 /*
  * Generate a "random" DES key.
  */
@@ -234,7 +321,6 @@ des_mem_rand8(unsigned char *data)
 {
   return 1;
 }
-#endif
 
 /*
  * In case the generator does not get initialized use this as fallback.
