@@ -34,7 +34,7 @@ or implied warranty.
 
 #include "kadm_locl.h"
 
-RCSID("$Id: kadm_cli_wrap.c,v 1.15 1996/08/11 21:20:40 assar Exp $");
+RCSID("$Id: kadm_cli_wrap.c,v 1.19 1996/11/19 22:48:44 assar Exp $");
 
 #ifndef NULL
 #define NULL 0
@@ -62,8 +62,8 @@ static RETSIGTYPE (*opipe)();
 static void
 kadm_cli_disconn(void)
 {
-    (void) close(client_parm.admin_fd);
-    (void) signal(SIGPIPE, opipe);
+    close(client_parm.admin_fd);
+    signal(SIGPIPE, opipe);
     return;
 }
 
@@ -79,35 +79,30 @@ kadm_cli_disconn(void)
 int
 kadm_init_link(char *n, char *i, char *r)
 {
-	struct servent *sep;	       /* service we will talk to */
 	struct hostent *hop;	       /* host we will talk to */
 	char adm_hostname[MaxHostNameLen];
 
-	(void) init_kadm_err_tbl();
-	(void) init_krb_err_tbl();
-	(void) strcpy(client_parm.sname, n);
-	(void) strcpy(client_parm.sinst, i);
-	(void) strcpy(client_parm.krbrlm, r);
+	init_kadm_err_tbl();
+	init_krb_err_tbl();
+	strcpy(client_parm.sname, n);
+	strcpy(client_parm.sinst, i);
+	strcpy(client_parm.krbrlm, r);
 	client_parm.admin_fd = -1;
 
 	/* set up the admin_addr - fetch name of admin host */
 	if (krb_get_admhst(adm_hostname, client_parm.krbrlm, 1) != KSUCCESS)
 		return KADM_NO_HOST;
 	if ((hop = gethostbyname(adm_hostname)) == NULL)
-		return KADM_UNK_HOST;  /* couldnt find the admin servers
-				        * address */
-	memset(&client_parm.admin_addr, 0,
-	      sizeof(client_parm.admin_addr));
-	if ((sep = getservbyname(KADM_SNAME, "tcp")) == NULL){
-	  fprintf(stderr, "Warning: %s/tcp service not found.\n", KADM_SNAME);
-	  client_parm.admin_addr.sin_port = htons(751);
-	}else
-	  client_parm.admin_addr.sin_port = sep->s_port;
+		return KADM_UNK_HOST;
+	memset(&client_parm.admin_addr, 0, sizeof(client_parm.admin_addr));
+	client_parm.admin_addr.sin_port = 
+	  k_getportbyname(KADM_SNAME, "tcp", htons(KADM_PORT));
 	client_parm.admin_addr.sin_family = hop->h_addrtype;
-	memcpy(&client_parm.admin_addr.sin_addr, hop->h_addr, hop->h_length);
+	memcpy(&client_parm.admin_addr.sin_addr, hop->h_addr,
+	       sizeof(client_parm.admin_addr.sin_addr));
 
 	return KADM_SUCCESS;
-}				       /* procedure kadm_init_link */
+}
 
 static int
 kadm_cli_conn(void)
@@ -120,7 +115,7 @@ kadm_cli_conn(void)
     if (connect(client_parm.admin_fd,
 		(struct sockaddr *) & client_parm.admin_addr,
 		sizeof(client_parm.admin_addr))) {
-	(void) close(client_parm.admin_fd);
+	close(client_parm.admin_fd);
 	client_parm.admin_fd = -1;
 	return KADM_NO_CONN;		/* couldnt get the connect */
     }
@@ -129,17 +124,17 @@ kadm_cli_conn(void)
     if (getsockname(client_parm.admin_fd,
 		    (struct sockaddr *) & client_parm.my_addr,
 		    &client_parm.my_addr_len) < 0) {
-	(void) close(client_parm.admin_fd);
+	close(client_parm.admin_fd);
 	client_parm.admin_fd = -1;
-	(void) signal(SIGPIPE, opipe);
+	signal(SIGPIPE, opipe);
 	return KADM_NO_HERE;		/* couldnt find out who we are */
     }
     if (setsockopt(client_parm.admin_fd, SOL_SOCKET, SO_KEEPALIVE,
 		   (void *)&on,
 		   sizeof(on)) < 0) {
-	(void) close(client_parm.admin_fd);
+	close(client_parm.admin_fd);
 	client_parm.admin_fd = -1;
-	(void) signal(SIGPIPE, opipe);
+	signal(SIGPIPE, opipe);
 	return KADM_NO_CONN;		/* XXX */
     }
     return KADM_SUCCESS;
@@ -202,8 +197,8 @@ kadm_cli_out(u_char *dat, int dat_len, u_char **ret_dat, int *ret_siz)
 	if (!*ret_dat)
 	    return(KADM_NOMEM);
 
-	if ((retval = krb_net_read(client_parm.admin_fd, (char *) *ret_dat,
-				  (int) dlen) != dlen)) {
+	if ((retval = krb_net_read(client_parm.admin_fd,  *ret_dat,
+				  dlen) != dlen)) {
 	    if (retval < 0)
 		return(errno);		/* XXX */
 	    else
@@ -253,7 +248,7 @@ kadm_cli_send(u_char *st_dat, int st_siz, u_char **ret_dat, int *ret_siz)
 	act_len = KADM_VERSIZE;
 
 	if ((retdat = kadm_cli_keyd(&sess_key, sess_sched)) != KADM_SUCCESS) {
-		free((char *)act_st);
+		free(act_st);
 		return retdat;	       /* couldnt get key working */
 	}
 	priv_pak = (u_char *) malloc((unsigned)(st_siz + 200));
@@ -280,12 +275,11 @@ kadm_cli_send(u_char *st_dat, int st_siz, u_char **ret_dat, int *ret_siz)
 	    RET_N_FREE(retdat + krb_err_base);
 	}
 
-	act_st = (u_char *) realloc((char *) act_st,
-				    (unsigned) (act_len + authent.length
-						+ priv_len));
+	act_st = (u_char *) realloc(act_st,
+				    act_len + authent.length + priv_len);
 	if (!act_st) {
 	    clear_secrets();
-	    free((char *)priv_pak);
+	    free(priv_pak);
 	    return(KADM_NOMEM);
 	}
 	memcpy((char *)act_st + act_len, authent.dat, authent.length);
@@ -295,8 +289,8 @@ kadm_cli_send(u_char *st_dat, int st_siz, u_char **ret_dat, int *ret_siz)
 				   act_len + authent.length + priv_len,
 				   ret_dat, ret_siz)) != KADM_SUCCESS)
 	    RET_N_FREE(retdat);
-	free((char *)act_st);
-#define RET_N_FREE2(r) {free((char *)*ret_dat); clear_secrets(); return(r);}
+	free(act_st);
+#define RET_N_FREE2(r) {free(*ret_dat); clear_secrets(); return(r);}
 
 	/* first see if it's a YOULOUSE */
 	if ((*ret_siz >= KADM_VERSIZE) &&
@@ -376,7 +370,7 @@ int kadm_change_pw_plain(unsigned char *newkey, char *password, char **pw_msg)
 	  stsize += vts_string(password, &send_st, stsize);
 
 	retc = kadm_cli_send(send_st, stsize, &ret_st, &ret_sz);
-	free((char *)send_st);
+	free(send_st);
 	
 	if(retc != KADM_SUCCESS){
 	  status = stv_string(ret_st, msg, 0, sizeof(msg), ret_sz);
@@ -386,7 +380,7 @@ int kadm_change_pw_plain(unsigned char *newkey, char *password, char **pw_msg)
 	}
 
 	if (ret_st)
-	    free((char *)ret_st);
+	    free(ret_st);
 	
 	kadm_cli_disconn();
 	return(retc);
@@ -430,15 +424,15 @@ kadm_add(Kadm_vals *vals)
 	st_len = vals_to_stream(vals, &st);
 	st2 = (u_char *) malloc((unsigned)(1 + st_len));
 	*st2 = (u_char) ADD_ENT;       /* here's the opcode */
-	memcpy((char *) st2 + 1, (char *) st, st_len);	/* append st on */
+	memcpy((char *) st2 + 1, st, st_len);	/* append st on */
 	retc = kadm_cli_send(st2, st_len + 1, &ret_st, &ret_sz);
-	free((char *)st);
-	free((char *)st2);
+	free(st);
+	free(st2);
 	if (retc == KADM_SUCCESS) {
 	    /* ret_st has vals */
 	    if (stream_to_vals(ret_st, vals, ret_sz) < 0)
 		retc = KADM_LENGTH_ERROR;
-	    free((char *)ret_st);
+	    free(ret_st);
 	}
 	kadm_cli_disconn();
 	return(retc);
@@ -474,15 +468,15 @@ kadm_mod(Kadm_vals *vals1, Kadm_vals *vals2)
 	free(st);
 	nlen = vals_to_stream(vals2, &st);
 	st2 = (u_char *) realloc((char *) st2, (unsigned)(st_len + nlen));
-	memcpy((char *) st2 + st_len, (char *) st, nlen); /* append st on */
+	memcpy((char *) st2 + st_len, st, nlen); /* append st on */
 	retc = kadm_cli_send(st2, st_len + nlen, &ret_st, &ret_sz);
-	free((char *)st);
-	free((char *)st2);
+	free(st);
+	free(st2);
 	if (retc == KADM_SUCCESS) {
 	    /* ret_st has vals */
 	    if (stream_to_vals(ret_st, vals2, ret_sz) < 0)
 		retc = KADM_LENGTH_ERROR;
-	    free((char *)ret_st);
+	    free(ret_st);
 	}
 	kadm_cli_disconn();
 	return(retc);
@@ -541,13 +535,13 @@ kadm_get(Kadm_vals *vals, u_char *fl)
 	for (loop = FLDSZ - 1; loop >= 0; loop--)
 		*(st2 + st_len + FLDSZ - loop) = fl[loop]; /* append the flags */
 	retc = kadm_cli_send(st2, st_len + 1 + FLDSZ,  &ret_st, &ret_sz);
-	free((char *)st);
-	free((char *)st2);
+	free(st);
+	free(st2);
 	if (retc == KADM_SUCCESS) {
 	    /* ret_st has vals */
 	    if (stream_to_vals(ret_st, vals, ret_sz) < 0)
 		retc = KADM_LENGTH_ERROR;
-	    free((char *)ret_st);
+	    free(ret_st);
 	}
 	kadm_cli_disconn();
 	return(retc);
