@@ -42,7 +42,7 @@ or implied warranty.
 
 #include "kadm_locl.h"
 
-RCSID("$Id: kadm_stream.c,v 1.7 1996/07/31 13:09:57 joda Exp $");
+RCSID("$Id: kadm_stream.c,v 1.9 1996/11/19 22:48:44 assar Exp $");
 
 #define min(a,b) (((a) < (b)) ? (a) : (b))
 
@@ -52,7 +52,7 @@ build_field_header(u_char *cont, u_char **st)
             			/* stream */
 {
   *st = (u_char *) malloc (4);
-  memcpy((char *) *st, (char *) cont, 4);
+  memcpy(*st, cont, 4);
   return 4;			/* return pointer to current stream location */
 }
 
@@ -64,7 +64,7 @@ check_field_header(u_char *st, u_char *cont, int maxlen)
 {
   if (4 > maxlen)
       return(-1);
-  memcpy((char *) cont, (char *) st, 4);
+  memcpy(cont, st, 4);
   return 4;			/* return pointer to current stream location */
 }
 
@@ -74,7 +74,7 @@ vts_string(char *dat, u_char **st, int loc)
             			/* base pointer to the stream */
         			/* offset into the stream for current data */
 {
-  *st = (u_char *) realloc ((char *)*st, (unsigned) (loc + strlen(dat) + 1));
+  *st = (u_char *) realloc (*st, (unsigned) (loc + strlen(dat) + 1));
   memcpy(*st + loc, dat, strlen(dat)+1);
   return strlen(dat)+1;
 }
@@ -131,12 +131,11 @@ vts_long(u_int32_t dat, u_char **st, int loc)
 }
     
 int
-stv_string(register u_char *st, char *dat, register int loc, int stlen, int maxlen)
-                    		/* base pointer to the stream */
-          			/* a string to read from the stream */
-                 		/* offset into the stream for current data */
-          			/* max length of string to copy in */
-           			/* max length of input stream */
+stv_string(u_char *st,		/* base pointer to the stream */
+	   char *dat,		/* a string to read from the stream */
+	   int loc,		/* offset into the stream for current data */
+	   int stlen,		/* max length of string to copy in */
+	   int maxlen)		/* max length of input stream */
 {
   int maxcount;				/* max count of chars to copy */
 
@@ -249,8 +248,8 @@ stream_to_vals(u_char *dt_in, Kadm_vals *dt_out, int maxlen)
                   
            				/* max length to use */
 {
-  register int vsloop, stsize;		/* loop counter, stream size */
-  register int status;
+  int vsloop, stsize;		/* loop counter, stream size */
+  int status;
 
   memset(dt_out, 0, sizeof(*dt_out));
 
