@@ -40,7 +40,7 @@ or implied warranty.
 
 #include "kadm_locl.h"
     
-RCSID("$Id: kadm_supp.c,v 1.5 1996/06/10 01:13:19 joda Exp $");
+RCSID("$Id: kadm_supp.c,v 1.7 1996/11/17 20:23:40 assar Exp $");
 
 /*
 prin_vals:
@@ -59,15 +59,6 @@ prin_vals(Kadm_vals *vals)
 	  (long)vals->key_low, (long)vals->key_high);
 }
 
-#ifdef notdef
-nierror(s)
-int s;
-{
-    printf("Kerberos admin server loses..... %s\n",error_message(s));
-    return(s);
-}
-#endif
-
 /* kadm_prin_to_vals takes a fields arguments, a Kadm_vals and a Principal,
    it copies the fields in Principal specified by fields into Kadm_vals, 
    i.e from old to new */
@@ -77,11 +68,11 @@ kadm_prin_to_vals(u_char *fields, Kadm_vals *new, Principal *old)
 {
   memset(new, 0, sizeof(*new));
   if (IS_FIELD(KADM_NAME,fields)) {
-      (void) strncpy(new->name, old->name, ANAME_SZ); 
+      strncpy(new->name, old->name, ANAME_SZ); 
       SET_FIELD(KADM_NAME, new->fields);
   }
   if (IS_FIELD(KADM_INST,fields)) {
-      (void) strncpy(new->instance, old->instance, INST_SZ); 
+      strncpy(new->instance, old->instance, INST_SZ); 
       SET_FIELD(KADM_INST, new->fields);
   }      
   if (IS_FIELD(KADM_EXPDATE,fields)) {
@@ -109,9 +100,9 @@ kadm_vals_to_prin(u_char *fields, Principal *new, Kadm_vals *old)
 
   memset(new, 0, sizeof(*new));
   if (IS_FIELD(KADM_NAME,fields))
-    (void) strncpy(new->name, old->name, ANAME_SZ); 
+    strncpy(new->name, old->name, ANAME_SZ); 
   if (IS_FIELD(KADM_INST,fields))
-    (void) strncpy(new->instance, old->instance, INST_SZ); 
+    strncpy(new->instance, old->instance, INST_SZ); 
   if (IS_FIELD(KADM_EXPDATE,fields))
     new->exp_date   = old->exp_date; 
   if (IS_FIELD(KADM_ATTR,fields))
