@@ -1,13 +1,58 @@
+/*
+ * Copyright (c) 1995, 1996 Kungliga Tekniska Hgskolan (Royal Institute
+ * of Technology, Stockholm, Sweden).
+ * All rights reserved.
+ * 
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
+ * 
+ * 1. Redistributions of source code must retain the above copyright
+ *    notice, this list of conditions and the following disclaimer.
+ * 
+ * 2. Redistributions in binary form must reproduce the above copyright
+ *    notice, this list of conditions and the following disclaimer in the
+ *    documentation and/or other materials provided with the distribution.
+ * 
+ * 3. All advertising materials mentioning features or use of this software
+ *    must display the following acknowledgement:
+ *      This product includes software developed by the Kungliga Tekniska
+ *      Hgskolan and its contributors.
+ * 
+ * 4. Neither the name of the Institute nor the names of its contributors
+ *    may be used to endorse or promote products derived from this software
+ *    without specific prior written permission.
+ * 
+ * THIS SOFTWARE IS PROVIDED BY THE INSTITUTE AND CONTRIBUTORS ``AS IS'' AND
+ * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED.  IN NO EVENT SHALL THE INSTITUTE OR CONTRIBUTORS BE LIABLE
+ * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
+ * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
+ * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
+ * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
+ * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
+ * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
+ * SUCH DAMAGE.
+ */
+
 #include "config.h"
 #include "protos.h"
 
-RCSID("$Id: afssys.c,v 1.30 1996/08/26 17:46:51 joda Exp $");
+RCSID("$Id: afssys.c,v 1.43 1996/11/19 05:21:33 assar Exp $");
 
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
+#ifdef HAVE_SYS_TYPES_H
 #include <sys/types.h>
+#endif
+#ifdef HAVE_UNISTD_H
 #include <unistd.h>
+#endif
+#ifdef HAVE_SYS_IOCTL_H
 #include <sys/ioctl.h>
+#endif
 #ifdef HAVE_SYS_FILIO_H
 #include <sys/filio.h>
 #endif
@@ -18,12 +63,17 @@ RCSID("$Id: afssys.c,v 1.30 1996/08/26 17:46:51 joda Exp $");
 #include <signal.h>
 #include <setjmp.h>
 #include <errno.h>
-#include <string.h>
 #include <signal.h>
 
+#ifdef HAVE_SYS_SOCKET_H
 #include <sys/socket.h>
+#endif
+#ifdef HAVE_NETINET_IN_H
 #include <netinet/in.h>
+#endif
+#ifdef HAVE_NETDB_H
 #include <netdb.h>
+#endif
 
 #ifdef HAVE_ARPA_NAMESER_H
 #include <arpa/nameser.h>
@@ -35,6 +85,8 @@ RCSID("$Id: afssys.c,v 1.30 1996/08/26 17:46:51 joda Exp $");
 #include <krb.h>
 #include <kafs.h>
 
+#include <resolve.h>
+
 #include "afssysdefs.h"
 
 #define AUTH_SUPERUSER "afs"
@@ -79,75 +131,41 @@ get_cred(char *princ, char *inst, char *krealm, CREDENTIALS *c, KTEXT_ST *tkt)
 static u_int32_t ip_aton(char *ip)
 {
   u_int32_t addr;
-  int a, b, c, d;
-  if(sscanf(ip, "%d.%d.%d.%d", &a, &b, &c, &d) != 4)
-    return 0;
-  if(a < 0 || a > 255 || 
-     b < 0 || b > 255 || 
-     c < 0 || c > 255 || 
-     d < 0 || d > 255)
-    return 0;
+  unsigned int a, b, c, d;
+  if(sscanf(ip, "%u.%u.%u.%u", &a, &b, &c, &d) != 4)
+      return 0;
+  if((a | b | c | d) > 255)
+      return 0;
   addr = (a << 24) | (b << 16) | (c << 8) | d;
   addr = htonl(addr);
   return addr;
 }
 
 /* Try to get a db-server for an AFS cell from a AFSDB record */
+
 static int
 dns_find_cell(char *cell, char *dbserver)
 {
-#if defined(HAVE_DN_EXPAND) && defined(HAVE_RES_SEARCH)
-#ifndef T_AFSDB
-#define T_AFSDB 18
-#endif
-    unsigned char data[1024];
-    unsigned char host[MaxHostNameLen];
-    int len;
-
-    int status;
-    unsigned char *p;
-
-    len = res_search(cell, C_IN, T_AFSDB, data, sizeof(data));
-    if(len < 0)
-	return -1;
-    p = data + sizeof(HEADER);
-    status = dn_expand(data, data + len, p, host, sizeof(host));
-    if(status < 0)
-	return -1;
-    p += status;
-    p += 4; /* type and class */
-    while(p < data + len){
-	int type, subtype, class, ttl, size;
-	status = dn_expand(data, data + len, p, host, sizeof(host));
-	if(status < 0)
-	    return -1;
-	p += status;
-	type = (p[0] << 8) | p[1];
-	p += 2;
-	class = (p[0] << 8) | p[1];
-	p += 2;
-	ttl = (p[0] << 24) | (p[1] << 16) | (p[2] << 8) | p[3];
-	p += 4;
-	size = (p[0] << 8) | p[1];
-	p += 2;
-	if(type == T_AFSDB){
-	    subtype = (p[0] << 8) | p[1];
-	    if(subtype == 1){
-		p += 2;
-		status = dn_expand(data, data + len, p, host, sizeof(host));
-		if(status < 0)
-		    return -1;
-		strncpy(dbserver, (char*)host, MaxHostNameLen);
-		dbserver[MaxHostNameLen] = 0;
-		return 0;
+    struct dns_reply *r;
+    int ok = -1;
+    r = dns_lookup(cell, "afsdb");
+    if(r){
+	struct resource_record *rr = r->head;
+	while(rr){
+	    if(rr->type == T_AFSDB && rr->u.afsdb->preference == 1){
+		strncpy(dbserver, rr->u.afsdb->domain, MaxHostNameLen);
+		dbserver[MaxHostNameLen - 1] = 0;
+		ok = 0;
+		break;
 	    }
+	    rr = rr->next;
 	}
-	p += size;
+	dns_free_data(r);
     }
-#endif
-    return -1;
+    return ok;
 }
 
+
 /* Find the realm associated with cell. Do this by opening
    /usr/vice/etc/CellServDB and getting the realm-of-host for the
    first VL-server for the cell.
@@ -242,49 +260,69 @@ aix_setup(void)
 #endif
 
 
+
+/*
+ * Get tokens for all cells[]
+ */
+static int
+k_afslog_cells(char *cells[], int max, char *krealm, uid_t uid)
+{
+    int err = KSUCCESS;
+    int i;
+    for(i = 0; i < max; i++)
+	err = k_afsklog_uid(cells[i], krealm, uid);
+    return err;
+}
+
 /*
  * Try to find the cells we should try to klog to in "file".
  */
-static
-int
-k_afslog_file(char *file, char *krealm)
+static void
+k_find_cells(char *file, char *cells[], int size, int *index)
 {
     FILE *f;
     char cell[64];
-    int err = KSUCCESS;
+    int i;
     f = fopen(file, "r");
     if (f == NULL)
-	return KSUCCESS;	/* No config file is ok! */
-    while (fgets(cell, sizeof(cell), f) && err == KSUCCESS) {
+	return;
+    while (*index < size && fgets(cell, sizeof(cell), f)) {
 	char *nl = strchr(cell, '\n');
-	if (nl)
-	    *nl = 0;
-	err = k_afsklog(cell, krealm);
+	if (nl) *nl = 0;
+	for(i = 0; i < *index; i++)
+	    if(strcmp(cells[i], cell) == 0)
+		break;
+	if(i == *index)
+	    cells[(*index)++] = strdup(cell);
     }
     fclose(f);
-    return err;
 }
 
-static
-int
-k_afsklog_all_local_cells(char *krealm)
+static int
+k_afsklog_all_local_cells(char *krealm, uid_t uid)
 {
-    int err = KFAILURE;
-    char *p, home[MaxPathLen];
+    int err;
+    char *cells[32]; /* XXX */
+    int num_cells = sizeof(cells) / sizeof(cells[0]);
+    int index = 0;
 
+    char *p, home[MaxPathLen];
+    
     if ((p = getenv("HOME"))) {
 	sprintf(home, "%s/.TheseCells", p);
-	err = k_afslog_file(home, krealm);
+	k_find_cells(home, cells, num_cells, &index);
     }
-    if(k_afslog_file(_PATH_THESECELLS, krealm) == 0)
-	err = 0;
-    if(k_afslog_file(_PATH_THISCELL, krealm) == 0)
-	err = 0;
+    k_find_cells(_PATH_THESECELLS, cells, num_cells, &index);
+    k_find_cells(_PATH_THISCELL, cells, num_cells, &index);
+    
+    err = k_afslog_cells(cells, index, krealm, uid);
+    while(index > 0)
+	free(cells[--index]);
     return err;
 }
 
 int
-k_afsklog(char *cell, char *krealm)
+k_afsklog_uid(char *cell, char *krealm, uid_t uid)
 {
   int k_errno;
   CREDENTIALS c;
@@ -294,15 +332,10 @@ k_afsklog(char *cell, char *krealm)
   char *lrealm; /* local realm */
   char CELL[64];
 
-  if (!k_hasafs())
-    return KSUCCESS;
-
   if (cell == 0 || cell[0] == 0)
-    return k_afsklog_all_local_cells (krealm);
+    return k_afsklog_all_local_cells (krealm, uid);
   foldup(CELL, cell);
 
-  vl_realm = realm_of_cell(cell);
-
   k_errno = krb_get_lrealm(realm , 0);
   if(k_errno == KSUCCESS && (krealm == NULL || strcmp(krealm, realm)))
     lrealm = realm;
@@ -347,7 +380,7 @@ k_afsklog(char *cell, char *krealm)
     k_errno = get_cred(AUTH_SUPERUSER, "", CELL, &c, &ticket);
   
   /* this might work in some conditions */
-  if(k_errno && vl_realm){
+  if(k_errno && (vl_realm = realm_of_cell(cell))){
     k_errno = get_cred(AUTH_SUPERUSER, cell, vl_realm, &c, &ticket);
     if(k_errno)
       k_errno = get_cred(AUTH_SUPERUSER, "", vl_realm, &c, &ticket);
@@ -374,7 +407,7 @@ k_afsklog(char *cell, char *krealm)
        */
       ct.AuthHandle = c.kvno;
       memcpy (ct.HandShakeKey, c.session, sizeof(c.session));
-      ct.ViceId = getuid();	/* is this always valid? */
+      ct.ViceId = uid;	/* is this always valid? */
       ct.BeginTimestamp = 1 + c.issue_date;
       ct.EndTimestamp = krb_life_to_time(c.issue_date, c.lifetime);
 
@@ -421,6 +454,13 @@ k_afsklog(char *cell, char *krealm)
   return k_errno;
 }
 
+int
+k_afsklog(char *cell, char *krealm)
+{
+  return k_afsklog_uid (cell, krealm, getuid());
+}
+
+
 #define NO_ENTRY_POINT		0
 #define SINGLE_ENTRY_POINT	1
 #define MULTIPLE_ENTRY_POINT	2
@@ -474,6 +514,17 @@ k_pioctl(char *a_path,
   return -1;
 }
 
+int
+k_afs_cell_of_file(const char *path, char *cell, int len)
+{
+    struct ViceIoctl parms;
+    parms.in = NULL;
+    parms.in_size = 0;
+    parms.out = cell;
+    parms.out_size = len;
+    return k_pioctl((char*)path, VIOC_FILE_CELL_NAME, &parms, 1);
+}
+
 int
 k_unlog(void)
 {
@@ -501,6 +552,11 @@ k_setpag(void)
     return syscall(AFS_SYSCALL2, AFSCALL_SETPAG);
 #endif
 
+#ifdef AFS_SYSCALL3
+  if (afs_entry_point == SINGLE_ENTRY_POINT3)
+    return syscall(AFS_SYSCALL3, AFSCALL_SETPAG);
+#endif
+
 #ifdef _AIX
   if (afs_entry_point == AIX_ENTRY_POINTS)
       return Setpag();
@@ -518,7 +574,7 @@ static jmp_buf catch_SIGSYS;
 
 #ifdef SIGSYS
 
-static void
+static RETSIGTYPE
 SIGSYS_handler(int sig)
 {
   errno = 0;
