@@ -1,5 +1,5 @@
 /*
- * $Id: kdc.h,v 1.6 1996/06/12 21:28:56 bg Exp $
+ * $Id: kdc.h,v 1.7 1996/09/28 23:41:07 assar Exp $
  *
  * Copyright 1987, 1988 by the Massachusetts Institute of Technology. 
  *
@@ -14,9 +14,6 @@
 
 #define S_AD_SZ		sizeof(struct sockaddr_in)
 
-#define max(a,b)	(a>b ? a : b)
-#define min(a,b)	(a<b ? a : b)
-
 #define TRUE		1
 #define FALSE		0
 
