@@ -1,5 +1,5 @@
 /*
- * $Id: krb_db.h,v 1.12 1996/08/11 21:21:34 assar Exp $ 
+ * $Id: krb_db.h,v 1.13 1996/10/27 23:52:05 assar Exp $ 
  *
  * Copyright 1987, 1988 by the Massachusetts Institute of Technology. 
  *
@@ -101,7 +101,7 @@ int kerb_delete_principal __P((char *name, char *inst));
 void kerb_db_get_stat __P((DB_stat *));
 void kerb_db_put_stat __P((DB_stat *));
 int kerb_get_dba __P((char *, char *, Dba *, unsigned int, int *));
-int kerb_db_get_dba __P(());
+int kerb_db_get_dba __P((char *, char *, Dba *, unsigned, int *));
 int kerb_init __P((void));
 void kerb_fini __P((void));
 time_t kerb_get_db_age __P((void));
