@@ -26,17 +26,9 @@ or implied warranty.
 
 #include "kdb_locl.h"
 
-RCSID("$Id: krb_dbm.c,v 1.18 1996/08/13 23:42:03 assar Exp $");
+RCSID("$Id: krb_dbm.c,v 1.24 1996/11/19 22:48:45 assar Exp $");
 
-#ifdef NDBM
-#include <ndbm.h>
-#else /*NDBM*/
-#if defined(HAVE_DBM_H)
-#include <dbm.h>
-#elif defined(HAVE_RPCSVC_DBM_H)
-#include <rpcsvc/dbm.h>
-#endif
-#endif /*NDBM*/
+#include <xdbm.h>
 
 #define KERB_DB_MAX_RETRY 5
 
@@ -106,26 +98,6 @@ static int non_blocking = 0;
  * retry the operation.
  */
 
-/* Macros to convert ndbm names to dbm names.
- * Note that dbm_nextkey() cannot be simply converted using a macro, since
- * it is invoked giving the database, and nextkey() needs the previous key.
- *
- * Instead, all routines call "dbm_next" instead.
- */
-
-#ifndef NDBM
-typedef char DBM;
-
-#define dbm_open(file, flags, mode) ((dbminit(file) == 0)?"":((char *)0))
-#define dbm_fetch(db, key) fetch(key)
-#define dbm_store(db, key, content, flag) store(key, content)
-#define dbm_delete(db, key) delete(key)
-#define dbm_firstkey(db) firstkey()
-#define dbm_next(db,key) nextkey(key)
-#define dbm_close(db) dbmclose()
-#else
-#define dbm_next(db,key) dbm_nextkey(db)
-#endif
 
 /*
  * Utility routine: generate name of database file.
@@ -154,7 +126,7 @@ static void
 decode_princ_key(datum *key, char *name, char *instance)
 {
     strncpy(name, key->dptr, ANAME_SZ);
-    strncpy(instance, key->dptr + ANAME_SZ, INST_SZ);
+    strncpy(instance, (char *)key->dptr + ANAME_SZ, INST_SZ);
     name[ANAME_SZ - 1] = '\0';
     instance[INST_SZ - 1] = '\0';
 }
@@ -172,7 +144,7 @@ encode_princ_contents(datum *contents, Principal *principal)
 static void
 decode_princ_contents (datum *contents, Principal *principal)
 {
-    memcpy((char *) principal, contents->dptr, sizeof(*principal));
+    memcpy(principal, contents->dptr, sizeof(*principal));
 }
 
 static void
@@ -457,7 +429,7 @@ kerb_db_create(char *db_name)
 {
     char *okname = gen_dbsuffix(db_name, ".ok");
     int fd;
-    register int ret = 0;
+    int ret = 0;
 #ifdef NDBM
     DBM *db;
 
@@ -519,7 +491,7 @@ kerb_db_rename(char *from, char *to)
     
 #ifdef HAVE_NEW_DB
     if (rename (fromdb, todb) == 0) {
-	(void) unlink (fromok);
+	unlink (fromok);
 	ok = 1;
     }
     free (fromdb);
@@ -527,7 +499,7 @@ kerb_db_rename(char *from, char *to)
 #else
     if ((rename (fromdir, todir) == 0)
 	&& (rename (frompag, topag) == 0)) {
-	(void) unlink (fromok);
+	unlink (fromok);
 	ok = 1;
     }
     free (fromdir);
