@@ -36,7 +36,7 @@ or implied warranty.
 
 #include <kdc.h>
 
-RCSID("$Id: krb_kdb_utils.c,v 1.17 1996/07/02 09:11:12 bg Exp $");
+RCSID("$Id: krb_kdb_utils.c,v 1.19 1996/11/19 22:48:47 assar Exp $");
 
 /* always try /.k for backwards compatibility */
 static char *master_key_files[] = { MKEYFILE, "/.k", NULL };
@@ -97,7 +97,8 @@ kdb_new_get_master_key(des_cblock *key, des_key_schedule schedule)
   
   i=0;
   while(i < 3){
-      des_read_pw_string(buf, sizeof(buf), "Enter master password: ", 0);
+      if(des_read_pw_string(buf, sizeof(buf), "Enter master password: ", 0))
+	  break;
 
       /* buffer now contains either an old format master key password or a
        * new format base64 encoded master key
@@ -174,7 +175,7 @@ int kdb_kstash(des_cblock *master_key, char *file)
   if (kfile < 0) {
     return -1;
   }
-  if (write(kfile, (char *) master_key, sizeof(des_cblock)) != sizeof(des_cblock)) {
+  if (write(kfile, master_key, sizeof(des_cblock)) != sizeof(des_cblock)) {
     close(kfile);
     return -1;
   }
