@@ -26,7 +26,7 @@ or implied warranty.
 
 #include "kdb_locl.h"
 
-RCSID("$Id: krb_lib.c,v 1.6 1996/06/10 01:13:15 joda Exp $");
+RCSID("$Id: krb_lib.c,v 1.7 1996/11/17 20:23:44 assar Exp $");
 
 #ifdef DEBUG
 extern int debug;
@@ -168,7 +168,7 @@ kerb_put_principal(Principal *principal, unsigned int n)
     /* and mod date string */
 
     tp = k_localtime(&principal->mod_date);
-    (void) sprintf(principal->mod_date_txt, "%4d-%2d-%2d",
+    sprintf(principal->mod_date_txt, "%4d-%2d-%2d",
 		   tp->tm_year > 1900 ? tp->tm_year : tp->tm_year + 1900,
 		   tp->tm_mon + 1, tp->tm_mday); /* January is 0, not 1 */
 #ifdef DEBUG
