@@ -26,11 +26,9 @@ or implied warranty.
 
 #include "krb_locl.h"
 
-RCSID("$Id: debug_decl.c,v 1.4 1996/03/25 13:09:10 bg Exp $");
+RCSID("$Id: debug_decl.c,v 1.5 1996/09/26 20:57:12 assar Exp $");
 
 /* Declare global debugging variables. */
 
-#ifndef KRB_NDEB
 int krb_ap_req_debug = 0;
 int krb_debug = 0;
-#endif
