@@ -26,11 +26,7 @@ or implied warranty.
 
 #include "krb_locl.h"
 
-RCSID("$Id: dest_tkt.c,v 1.5 1996/05/31 21:00:00 assar Exp $");
-
-#ifdef TKT_SHMEM
-#include <sys/param.h>
-#endif
+RCSID("$Id: dest_tkt.c,v 1.9 1996/11/13 12:38:57 bg Exp $");
 
 /*
  * dest_tkt() is used to destroy the ticket store upon logout.
@@ -44,13 +40,10 @@ RCSID("$Id: dest_tkt.c,v 1.5 1996/05/31 21:00:00 assar Exp $");
 int
 dest_tkt(void)
 {
-    char *file = TKT_FILE;
+	char *file = TKT_FILE;
     int i,fd;
     struct stat statb;
     char buf[BUFSIZ];
-#ifdef TKT_SHMEM
-    char shmidname[MaxPathLen];
-#endif /* TKT_SHMEM */
 
     errno = 0;
     if (lstat(file,&statb) < 0)
@@ -68,24 +61,21 @@ dest_tkt(void)
 
     memset(buf, 0, BUFSIZ);
 
-    for (i = 0; i < statb.st_size; i += BUFSIZ)
+    for (i = 0; i < statb.st_size; i += sizeof(buf))
+	if (write(fd, buf, sizeof(buf)) != sizeof(buf)) {
+	    fsync(fd);
+	    close(fd);
+	    goto out;
+	}
+	
 
-    (void) fsync(fd);
-    (void) close(fd);
-
-    (void) unlink(file);
+    fsync(fd);
+    close(fd);
+    
+    unlink(file);
 
 out:
     if (errno == ENOENT) return RET_TKFIL;
     else if (errno != 0) return KFAILURE;
-#ifdef TKT_SHMEM
-    /* 
-     * handle the shared memory case 
-     */
-    (void) strcpy(shmidname, file);
-    (void) strcat(shmidname, ".shm");
-    if ((i = krb_shm_dest(shmidname)) != KSUCCESS)
-	return(i);
-#endif /* TKT_SHMEM */
     return(KSUCCESS);
 }
