@@ -1,8 +1,3 @@
-/*
- * This software may now be redistributed outside the US.
- *
- */
-
 /* 
    Copyright (C) 1989 by the Massachusetts Institute of Technology
 
@@ -26,7 +21,7 @@
 
 #include "krb_locl.h"
 
-RCSID("$Id: get_phost.c,v 1.8 1996/08/20 13:03:20 bg Exp $");
+RCSID("$Id: get_phost.c,v 1.12 1996/11/19 23:09:01 assar Exp $");
 
 /*
  * This routine takes an alias for a host name and returns the first
@@ -42,13 +37,14 @@ krb_get_phost(const char *alias)
   static char phost[MaxHostNameLen+1];
   char *p;
     
-  k_name_to_name(alias, phost);
+  krb_name_to_name(alias, phost);
+  p = phost;
 
-  p = strtok(phost, ".");
-  while (*p) {
-    if (isupper(*p))
-      *p = tolower(*p);
+  while (p && *p && *p != '.') {
+    *p = tolower(*p);
     p++;
   }
+  if (*p == '.')
+    *p = '\0';
   return phost;
 }
