@@ -26,7 +26,7 @@ or implied warranty.
 
 #include "krb_locl.h"
 
-RCSID("$Id: get_svc_in_tkt.c,v 1.4 1996/03/25 13:09:22 bg Exp $");
+RCSID("$Id: get_svc_in_tkt.c,v 1.7 1996/11/24 00:31:22 assar Exp $");
 
 /*
  * This file contains two routines: srvtab_to_key(), which gets
@@ -51,13 +51,14 @@ RCSID("$Id: get_svc_in_tkt.c,v 1.4 1996/03/25 13:09:22 bg Exp $");
  * The service key is placed in "key".
  */
 
-static int 
-srvtab_to_key(char *user, char *instance, char *realm, char *srvtab, unsigned char *key)
+int 
+srvtab_to_key(char *user, char *instance, char *realm, void *srvtab,
+	      des_cblock *key)
 {
     if (!srvtab)
         srvtab = KEYFILE;
 
-    return(read_service_key(user, instance, realm, 0, srvtab,
+    return(read_service_key(user, instance, realm, 0, (char *)srvtab,
                             (char *)key));
 }
 
@@ -72,8 +73,9 @@ srvtab_to_key(char *user, char *instance, char *realm, char *srvtab, unsigned ch
  */
 
 int
-krb_get_svc_in_tkt(char *user, char *instance, char *realm, char *service, char *sinstance, int life, char *srvtab)
+krb_get_svc_in_tkt(char *user, char *instance, char *realm, char *service,
+		   char *sinstance, int life, char *srvtab)
 {
     return(krb_get_in_tkt(user, instance, realm, service, sinstance,
-                          life, (key_proc_t)srvtab_to_key, NULL, srvtab));
+                          life, srvtab_to_key, NULL, srvtab));
 }
