@@ -1,8 +1,3 @@
-/*
- * This software may now be redistributed outside the US.
- *
- */
-
 /* 
   Copyright (C) 1989 by the Massachusetts Institute of Technology
 
@@ -26,7 +21,7 @@ or implied warranty.
 
 #include "krb_locl.h"
 
-RCSID("$Id: getrealm.c,v 1.13 1996/08/18 23:21:34 assar Exp $");
+RCSID("$Id: getrealm.c,v 1.19 1996/11/17 20:23:45 assar Exp $");
 
 #define MATCH_SUBDOMAINS        0
 
@@ -59,80 +54,34 @@ RCSID("$Id: getrealm.c,v 1.13 1996/08/18 23:21:34 assar Exp $");
  * krb4-realm.a.b.c, then krb4-realm.b.c and so on.
  */
 
-#if defined(HAVE_DN_EXPAND) && defined(HAVE_RES_SEARCH)
-
-#ifndef T_TXT
-#define T_TXT	16
-#endif
-
-static int
-parse_reply(unsigned char *data, int len)
-{
-    unsigned char *p;
-    unsigned char host[MaxHostNameLen];
-    int status;
-    int type, class, ttl, size;
-
-    p = data + sizeof(HEADER);
-    status = dn_expand(data, data + len, p, host, sizeof(host));
-    if(status < 0)
-	return -1;
-    p += status;
-    p += 4; /* type and class */
-    while(p < data + len){
-	status = dn_expand(data, data + len, p, host, sizeof(host));
-	if(status < 0)
-	  return -1;
-	p += status;
-	type = (p[0] << 8) | p[1];
-	p += 2;
-	class = (p[0] << 8) | p[1];
-	p += 2;
-	ttl = (p[0] << 24) | (p[1] << 16) | (p[2] << 8) | p[3];
-	p += 4;
-	size = (p[0] << 8) | p[1];
-	p += 2;
-	if(type == T_TXT){
-	    if (size > len)
-	      size = len;
-	    strncpy((char*)data, (char*)(p + 1), size - 1);
-	    data[size-1] = 0;
-	    return 0;
-	}
-	p += size;
-    }
-    return -1;
-}
-
 static int
 dns_find_realm(char *hostname, char *realm)
 {
-    unsigned char reply[1024];
     char domain[MaxHostNameLen];
     char host[MaxHostNameLen];
     char *p;
-    int len;
     int level = 0;
+    struct dns_reply *r;
     
     strcpy(host, hostname);
-#if 1
     if(host[strlen(host) - 1] != '.')
 	strcat(host, ".");
-#endif
     p = host;
 
     while(1){
-	sprintf(domain, "krb4-realm.%s", p);
-#if 0
-	printf("Trying %s\n", domain);
-#endif
-	len = res_search(domain, C_IN, T_TXT, reply, sizeof(reply));
-	if(len >= 0){
-	    if(parse_reply(reply, len) == 0){
-	        realm[REALM_SZ] = '\0';
-		strncpy(realm, (char*)reply, REALM_SZ);
-		return level;
+	sprintf(domain, "krb4-realm.%s.", p);
+	r = dns_lookup(domain, "TXT");
+	if(r){
+	    struct resource_record *rr = r->head;
+	    while(rr){
+		if(rr->type == T_TXT){
+		    strncpy(realm, rr->u.txt, REALM_SZ);
+		    dns_free_data(r);
+		    return level;
+		}
+		rr = rr->next;
 	    }
+	    dns_free_data(r);
 	}
 	level++;
 	p = strchr(p, '.');
@@ -143,15 +92,6 @@ dns_find_realm(char *hostname, char *realm)
     return -1;
 }
 
-#else
-
-static int
-dns_find_realm(char *hostname, char *realm)
-{
-    return -1;
-}
-
-#endif
 
 static FILE *
 open_krb_realms(void)
@@ -193,7 +133,7 @@ krb_realmofhost(const char *host)
 
   char phost[MaxHostNameLen+1];
 	
-  k_name_to_name(host, phost);
+  krb_name_to_name(host, phost);
 	
   domain = strchr(phost, '.');
 
@@ -228,7 +168,7 @@ krb_realmofhost(const char *host)
     trans_realm[REALM_SZ] = '\0';
     if (!strcasecmp(trans_host, phost)) {
       /* exact match of hostname, so return the realm */
-      (void) strcpy(ret_realm, trans_realm);
+      strcpy(ret_realm, trans_realm);
       fclose(trans_file);
       return(ret_realm);
     }
@@ -239,7 +179,7 @@ krb_realmofhost(const char *host)
 	/* this is a domain match */
 	if (!strcasecmp(trans_host, cp)) {
 	  /* domain match, save for later */
-	  (void) strcpy(ret_realm, trans_realm);
+	  strcpy(ret_realm, trans_realm);
 	  continue;
 	}
       }
@@ -247,7 +187,7 @@ krb_realmofhost(const char *host)
       /* this is a domain match */ 
       if (!strcasecmp(trans_host, domain)) { 
 	/* domain match, save for later */ 
-	(void) strcpy(ret_realm, trans_realm); 
+	strcpy(ret_realm, trans_realm); 
 	continue; 
       } 
 #endif  /* MATCH_SUBDOMAINS */
