@@ -26,7 +26,7 @@ or implied warranty.
 
 #include "krb_locl.h"
 
-RCSID("$Id: getst.c,v 1.4 1996/08/13 23:43:05 assar Exp $");
+RCSID("$Id: getst.c,v 1.5 1996/09/26 20:57:18 assar Exp $");
 
 /*
  * getst() takes a file descriptor, a string and a count.  It reads
@@ -39,7 +39,7 @@ RCSID("$Id: getst.c,v 1.4 1996/08/13 23:43:05 assar Exp $");
  */
 
 int
-getst(int fd, register char *s, int n)
+getst(int fd, char *s, int n)
 {
     int count = n;
     while (read(fd, s, 1) > 0 && --count)
