@@ -25,28 +25,39 @@ or implied warranty.
   */
 
 #include "krb_locl.h"
+RCSID("$Id: k_gethostname.c,v 1.9 1996/08/31 21:26:40 assar Exp $");
 
-RCSID("$Id: k_gethostname.c,v 1.5 1996/06/01 12:11:59 assar Exp $");
+#ifdef HAVE_SYS_UTSNAME_H
+#include <sys/utsname.h>
+#endif
 
 /*
  * Return the local host's name in "name", up to "namelen" characters.
  * "name" will be null-terminated if "namelen" is big enough.
  * The return code is 0 on success, -1 on failure.  (The calling
  * interface is identical to gethostname(2).)
- *
- * Currently defined for BSD 4.2 and PC.  The BSD version just calls
- * gethostname(); the PC code was taken from "kinit.c", and may or may
- * not work.
  */
 
 int
 k_gethostname(char *name, int namelen)
 {
-#ifdef HAVE_GETHOSTBYNAME
+#if defined(HAVE_GETHOSTNAME)
     return gethostname(name, namelen);
+#elif defined(HAVE_UNAME)
+    {
+	struct utsname utsname;
+	int ret;
+
+	ret = uname (&utsname);
+	if (ret < 0)
+	    return ret;
+	strncpy (name, utsname.nodename, namelen);
+	name[namelen-1] = '\0';
+	return 0;
+    }
 #else
-    name[namelen-1] = '\0';
     strncpy (name, "some.random.host", namelen);
-    return name;
+    name[namelen-1] = '\0';
+    return 0;
 #endif
 }
