@@ -52,7 +52,7 @@ or implied warranty.
 
 #include "krb_locl.h"
 
-RCSID("$Id: kntoln.c,v 1.4 1996/03/25 13:09:35 bg Exp $");
+RCSID("$Id: kntoln.c,v 1.6 1996/10/20 03:35:42 assar Exp $");
 
 int
 krb_kntoln(AUTH_DAT *ad, char *lname)
@@ -62,11 +62,11 @@ krb_kntoln(AUTH_DAT *ad, char *lname)
     if (!(*lrealm) && (krb_get_lrealm(lrealm,1) == KFAILURE))
         return(KFAILURE);
 
-    if (strcmp(ad->pinst,""))
+    if (strcmp(ad->pinst, ""))
         return(KFAILURE);
-    if (strcmp(ad->prealm,lrealm))
+    if (strcmp(ad->prealm, lrealm))
         return(KFAILURE);
-    (void) strcpy(lname,ad->pname);
+    strcpy(lname, ad->pname);
     return(KSUCCESS);
 }
 
@@ -80,6 +80,7 @@ krb_kntoln(AUTH_DAT *ad, char *lname)
 #include <strings.h>
 #include <sys/syslog.h>
 #include <sys/errno.h>
+
 extern int errno;
 /*
  * antoln converts an authentication name into a local name by looking up
