@@ -1,5 +1,5 @@
 /*
- * $Id: krb.h,v 1.36 1996/08/20 13:03:22 bg Exp $
+ * $Id: krb.h,v 1.65 1996/11/24 05:20:11 joda Exp $
  *
  * Copyright 1987, 1988 by the Massachusetts Institute of Technology. 
  *
@@ -15,12 +15,18 @@
 
 #include <sys/bitypes.h>
 #include <sys/cdefs.h>
+#include <stdarg.h>
+
+__BEGIN_DECLS
 
 #ifndef __P
 #define __P(x) x
 #endif
 
 /* Need some defs from des.h	 */
+#if !defined(NOPROTO) && !defined(__STDC__)
+#define NOPROTO
+#endif
 #include <des.h>
 
 /* Don't use these guys, they are only for compatibility with CNS. */
@@ -36,9 +42,6 @@ extern int krb_ignore_ip_address; /* To turn of IP address comparison */
 extern int krb_no_long_lifetimes; /* To disable AFS compatible lifetimes */
 extern int krbONE;
 #define         HOST_BYTE_ORDER (* (char *) &krbONE)
-extern int private_msg_ver; /* in rd_priv.c */
-extern int req_act_vno; /* in cr_err_reply.c NOT defined in server code */
-
 
 /* Text describing error codes */
 #define		MAX_KRB_ERRORS	256
@@ -92,20 +95,26 @@ const char *krb_get_err_text __P((int code));
 #define		REALM_SZ	40
 #define		SNAME_SZ	40
 #define		INST_SZ		40
-/* include space for '.' and '@' */
-#define		MAX_K_NAME_SZ	(ANAME_SZ + INST_SZ + REALM_SZ + 2)
+/* Leave space for quoting */
+#define		MAX_K_NAME_SZ	(2*ANAME_SZ + 2*INST_SZ + 2*REALM_SZ - 3)
 #define		KKEY_SZ		100
 #define		VERSION_SZ	1
 #define		MSG_TYPE_SZ	1
 #define		DATE_SZ		26	/* RTI date output */
 
-#define		MAX_HSTNM	100
+typedef struct krb_principal{
+    char name[ANAME_SZ];
+    char instance[INST_SZ];
+    char realm[REALM_SZ];
+}krb_principal;
 
 #ifndef DEFAULT_TKT_LIFE	/* allow compile-time override */
 /* default lifetime for krb_mk_req & co., 10 hrs */
 #define	DEFAULT_TKT_LIFE 120
 #endif
 
+#define		KRB_TICKET_GRANTING_TICKET	"krbtgt"
+
 /* Definition of text structure used to pass text around */
 #define		MAX_KTXT_LEN	1250
 
@@ -183,6 +192,16 @@ struct msg_dat {
 
 typedef struct msg_dat MSG_DAT;
 
+struct krb_host {
+    char *realm;
+    char *host;
+    int proto;
+    int port;
+    int admin;
+};
+
+struct krb_host *krb_get_host __P((int, char*, int));
+
 
 /* Location of ticket file for save_cred and get_cred */
 #define TKT_FILE        tkt_string()
@@ -260,6 +279,7 @@ typedef struct msg_dat MSG_DAT;
 /* Values returned by get_adtkt */
 #define         AD_OK           0	/* Ticket Obtained */
 #define         AD_NOTGT       71	/* Don't have tgt */
+#define         AD_INTR_RLM_NOTGT 72	/* Can't get inter-realm tgt */
 
 /* Error codes returned by ticket file utilities */
 #define		NO_TKT_FIL	76	/* No ticket file found */
@@ -356,9 +376,6 @@ typedef struct msg_dat MSG_DAT;
 
 #define	KRB_SENDAUTH_VLEN 8	    /* length for version strings */
 
-#ifdef ATHENA_COMPAT
-#define	KOPT_DO_OLDSTYLE 0x00000008 /* use the old-style protocol */
-#endif /* ATHENA_COMPAT */
 
 /* File locking */
 #define   K_LOCK_SH   1		/* Shared lock */
@@ -373,11 +390,20 @@ struct tm *k_localtime __P((u_int32_t *));
 int k_getsockinst __P((int fd, char *inst));
 int k_getportbyname __P((const char *service, const char *proto, int default_port));
 
-#include <sys/types.h> /* to get u_char */
+#include <time.h>
+#ifdef HAVE_SYS_TYPES_H
+#include <sys/types.h>
+#endif
+#ifdef HAVE_NETINET_IN_H
 #include <netinet/in.h>
-int k_get_all_addrs (struct in_addr **l);
+#endif
+#ifdef HAVE_WINSOCK_H
+#include <winsock.h>
+#endif
 
-/* --- Random prototypes */
+extern char *krb4_version;
+
+int k_get_all_addrs __P((struct in_addr **l));
 
 /* Host address comparison */
 int krb_equiv __P((u_int32_t, u_int32_t));
@@ -423,25 +449,32 @@ int dest_tkt __P((void));
 int get_ad_tkt __P((char *, char *, char *, int));
 int get_pw_tkt __P((char *, char *, char *, char *));
 int get_request __P((KTEXT, int, char **, char **));
-int get_request __P((KTEXT, int, char **, char **));
 int in_tkt __P((char *, char *));
 int k_gethostname __P((char *, int ));
 int k_isinst __P((char *));
 int k_isname __P((char *));
 int k_isrealm __P((char *));
 int kname_parse __P((char *, char *, char *, char *));
+int krb_parse_name __P((const char*, krb_principal*));
+char *krb_unparse_name  __P((krb_principal*));
+void krb_unparse_name_r  __P((krb_principal*, char*));
+char *krb_unparse_name_long  __P((char*, char*, char*));
 int krb_create_ticket __P((KTEXT, unsigned char, char *, char *, char *, int32_t, void *, int16_t, int32_t, char *, char *, des_cblock *));
 int krb_get_admhst __P((char *, char *, int));
-int krb_get_admhst __P((char *, char *, int));
 int krb_get_cred __P((char *, char *, char *, CREDENTIALS *));
 
-typedef int (*key_proc_t)(char*, char*, char*, void*, des_cblock*);
+typedef int (*key_proc_t) __P((char*, char*, char*, void*, des_cblock*));
 
-typedef int (*decrypt_proc_t)(char*, char*, char*, void*, 
-			      key_proc_t, KTEXT*);
+typedef int (*decrypt_proc_t) __P((char*, char*, char*, void*, 
+			      key_proc_t, KTEXT*));
 
 int krb_get_in_tkt __P((char*, char*, char*, char*, char*, int, key_proc_t, 
 			decrypt_proc_t, void*));
+
+int srvtab_to_key	__P((char *, char *, char *, void *, des_cblock *));
+int passwd_to_key	__P((char *, char *, char *, void *, des_cblock *));
+int passwd_to_afskey	__P((char *, char *, char *, void *, des_cblock *));
+
 int krb_get_krbhst __P((char *, char *, int));
 int krb_get_lrealm __P((char *, int));
 char *krb_get_default_realm __P((void));
@@ -452,13 +485,16 @@ int krb_get_tf_realm __P((char *, char *));
 int krb_kntoln __P((AUTH_DAT *, char *));
 int krb_mk_req __P((KTEXT , char *, char *, char *, int32_t));
 int krb_net_read __P((int , void *, size_t));
-int krb_net_write __P((int , void *, size_t));
+int krb_net_write __P((int , const void *, size_t));
 int krb_rd_err __P((u_char *, u_int32_t, int32_t *, MSG_DAT *));
 int krb_rd_req __P((KTEXT , char *, char *, int32_t, AUTH_DAT *, char *));
 int krb_recvauth __P((int32_t, int, KTEXT, char *, char *, struct sockaddr_in *, struct sockaddr_in *, AUTH_DAT *, char *, struct des_ks_struct *, char *));
-int krb_sendauth __P((int32_t, int, KTEXT, char *, const char *, char *, u_int32_t, MSG_DAT *, CREDENTIALS *, struct des_ks_struct *, struct sockaddr_in *, struct sockaddr_in *, char *));
+int krb_sendauth __P((int32_t, int, KTEXT, char *,char *, char *, u_int32_t, MSG_DAT *, CREDENTIALS *, struct des_ks_struct *, struct sockaddr_in *, struct sockaddr_in *, char *));
+int krb_mk_auth __P((int32_t, KTEXT, char *, char *, char *, u_int32_t, char *, KTEXT));
+int krb_check_auth __P((KTEXT, u_int32_t, MSG_DAT *, des_cblock *, struct des_ks_struct *, struct sockaddr_in *, struct sockaddr_in *));
 int krb_set_key __P((void *, int));
 int krb_set_lifetime __P((int));
+int krb_kuserok __P((char *name, char *inst, char *realm, char *luser));
 int kuserok __P((AUTH_DAT *, char *));
 int read_service_key __P((char *, char *, char *, int , char *, char *));
 int save_credentials __P((char *, char *, char *, unsigned char *, int , int , KTEXT , int32_t));
@@ -477,13 +513,39 @@ int krb_get_default_principal __P((char *, char *, char *));
 int krb_realm_parse __P((char *, int));
 int krb_verify_user __P((char*, char*, char*, char*, int, char *));
 
-void kset_logfile __P((char *));
-void set_logfile __P((char *));
+/* logging.c */
 
-void krb_log __P((const char *format, ...));
-#define k_log krb_log
+typedef int (*krb_log_func_t)(FILE *, const char *, va_list);
+
+typedef krb_log_func_t krb_warnfn_t;
+
+struct krb_log_facility;
+
+int krb_vlogger __P((struct krb_log_facility*, const char *, va_list));
+int krb_logger __P((struct krb_log_facility*, const char *, ...));
+int krb_openlog __P((struct krb_log_facility*, char*, FILE*, krb_log_func_t));
+void set_logfile __P((char *));
+void krb_log __P((const char*, ...));
+char *klog __P((int, const char*, ...));
+void kset_logfile __P((char*));
+void krb_set_warnfn  __P((krb_warnfn_t));
+krb_warnfn_t krb_get_warnfn  __P((void));
+void krb_warning  __P((const char*, ...));
 
 int getst __P((int, char *, int));
+const char *month_sname __P((int));
+const char *krb_stime __P((time_t *));
+int krb_check_tm __P((struct tm));
 
+int krb_get_int __P((void *from, u_int32_t *to, int size, int lsb));
+int krb_put_int __P((u_int32_t from, void *to, int size));
+int krb_get_address __P((void *from, u_int32_t *to));
+int krb_put_address __P((u_int32_t addr, void *to));
+int krb_put_string __P((char *from, void *to));
+int krb_get_string __P((void *from, char *to));
+int krb_get_nir __P((void *from, char *name, char *instance, char *realm));
+int krb_put_nir __P((char *name, char *instance, char *realm, void *to));
+
+__END_DECLS
 
 #endif /* KRB_DEFS */
