@@ -26,7 +26,7 @@ or implied warranty.
 
 #include "krb_locl.h"
 
-RCSID("$Id: krb_err_txt.c,v 1.7 1996/03/25 13:09:38 bg Exp $");
+RCSID("$Id: krb_err_txt.c,v 1.10 1996/10/27 13:30:28 bg Exp $");
 
 /*
  * This file contains an array of error text strings.
@@ -46,7 +46,7 @@ const char *krb_err_txt[256] = {
   "Principal unknown (kerberos)",			/* 008 */
   "Principal not unique (kerberos)",			/* 009 */
   "Principal has null key (kerberos)",			/* 010 */
-  "Reserved error message 11 (kerberos)",		/* 011 */
+  "Timeout in request (kerberos)",			/* 011 */
   "Reserved error message 12 (kerberos)",		/* 012 */
   "Reserved error message 13 (kerberos)",		/* 013 */
   "Reserved error message 14 (kerberos)",		/* 014 */
@@ -107,7 +107,7 @@ const char *krb_err_txt[256] = {
   "Reserved error message 69 (get_in_tkt)",		/* 069 */
   "Generic error (get_intkt)(can't write ticket file)", /* 070 */
   "Don't have ticket granting ticket (get_ad_tkt)",	/* 071 */
-  "Reserved error message 72 (get_ad_tkt)",		/* 072 */
+  "Can't get inter-realm ticket granting ticket (get_ad_tkt)",	/* 072 */
   "Reserved error message 73 (get_ad_tkt)",		/* 073 */
   "Reserved error message 74 (get_ad_tkt)",		/* 074 */
   "Reserved error message 75 (get_ad_tkt)",		/* 075 */
