@@ -1,6 +1,44 @@
+/*
+ * Copyright (c) 1995, 1996 Kungliga Tekniska Hgskolan (Royal Institute
+ * of Technology, Stockholm, Sweden).
+ * All rights reserved.
+ * 
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
+ * 
+ * 1. Redistributions of source code must retain the above copyright
+ *    notice, this list of conditions and the following disclaimer.
+ * 
+ * 2. Redistributions in binary form must reproduce the above copyright
+ *    notice, this list of conditions and the following disclaimer in the
+ *    documentation and/or other materials provided with the distribution.
+ * 
+ * 3. All advertising materials mentioning features or use of this software
+ *    must display the following acknowledgement:
+ *      This product includes software developed by the Kungliga Tekniska
+ *      Hgskolan and its contributors.
+ * 
+ * 4. Neither the name of the Institute nor the names of its contributors
+ *    may be used to endorse or promote products derived from this software
+ *    without specific prior written permission.
+ * 
+ * THIS SOFTWARE IS PROVIDED BY THE INSTITUTE AND CONTRIBUTORS ``AS IS'' AND
+ * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED.  IN NO EVENT SHALL THE INSTITUTE OR CONTRIBUTORS BE LIABLE
+ * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
+ * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
+ * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
+ * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
+ * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
+ * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
+ * SUCH DAMAGE.
+ */
+
 #include "krb_locl.h"
 
-RCSID("$Id: krb_get_in_tkt.c,v 1.14 1996/08/11 21:37:23 assar Exp $");
+RCSID("$Id: krb_get_in_tkt.c,v 1.17 1996/10/27 16:29:46 joda Exp $");
 
 /*
  * decrypt_tkt(): Given user, instance, realm, passwd, key_proc
@@ -125,15 +163,16 @@ krb_get_in_tkt(char *user, char *instance, char *realm,
 	    strcmp(cred.instance, sinstance) ||
 	    strcmp(cred.realm, realm))	/* not what we asked for */
 	    return INTK_ERR;	/* we need a better code here XXX */
-	
+
 	if (abs((int)(tv.tv_sec - cred.issue_date)) > CLOCK_SKEW) {
 	    return RD_AP_TIME; /* XXX should probably be better code */
 	}
 
 	/* initialize ticket cache */
 
-	if (tf_create(TKT_FILE) != KSUCCESS)
-	    return INTK_ERR;
+	kerror = tf_create(TKT_FILE);
+	if (kerror != KSUCCESS)
+	    return kerror;
 
 	if (tf_put_pname(user) != KSUCCESS ||
 	    tf_put_pinst(instance) != KSUCCESS) {
