@@ -18,7 +18,7 @@
 
 #include "krb_locl.h"
 
-RCSID("$Id: lifetime.c,v 1.6 1996/03/25 13:09:41 bg Exp $");
+RCSID("$Id: lifetime.c,v 1.7 1996/09/26 20:57:29 assar Exp $");
 
 /* If you want to disable this feature */
 int krb_no_long_lifetimes = 0;
@@ -178,7 +178,7 @@ int
 krb_atime_to_life(char *atime)
 {
     unsigned long when = 0;
-    register char *cp;
+    char *cp;
     int colon = 0, plus = 0;
     int n = 0;
 
