@@ -1,6 +1,44 @@
+/*
+ * Copyright (c) 1995, 1996 Kungliga Tekniska Hgskolan (Royal Institute
+ * of Technology, Stockholm, Sweden).
+ * All rights reserved.
+ * 
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
+ * 
+ * 1. Redistributions of source code must retain the above copyright
+ *    notice, this list of conditions and the following disclaimer.
+ * 
+ * 2. Redistributions in binary form must reproduce the above copyright
+ *    notice, this list of conditions and the following disclaimer in the
+ *    documentation and/or other materials provided with the distribution.
+ * 
+ * 3. All advertising materials mentioning features or use of this software
+ *    must display the following acknowledgement:
+ *      This product includes software developed by the Kungliga Tekniska
+ *      Hgskolan and its contributors.
+ * 
+ * 4. Neither the name of the Institute nor the names of its contributors
+ *    may be used to endorse or promote products derived from this software
+ *    without specific prior written permission.
+ * 
+ * THIS SOFTWARE IS PROVIDED BY THE INSTITUTE AND CONTRIBUTORS ``AS IS'' AND
+ * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED.  IN NO EVENT SHALL THE INSTITUTE OR CONTRIBUTORS BE LIABLE
+ * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
+ * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
+ * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
+ * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
+ * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
+ * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
+ * SUCH DAMAGE.
+ */
+
 #include "krb_locl.h"
 
-RCSID("$Id: mk_req.c,v 1.11 1996/08/11 21:37:25 assar Exp $");
+RCSID("$Id: mk_req.c,v 1.15 1996/10/27 16:29:49 joda Exp $");
 
 static int lifetime = 255;	/* But no longer than TGT says. */
 
@@ -74,7 +112,7 @@ build_request(KTEXT req, char *name, char *inst, char *realm,
  */
 
 int
-krb_mk_req(register KTEXT authent, char *service, char *instance, char *realm, 
+krb_mk_req(KTEXT authent, char *service, char *instance, char *realm, 
 	   int32_t checksum)
 {
     KTEXT_ST req_st;
@@ -93,10 +131,8 @@ krb_mk_req(register KTEXT authent, char *service, char *instance, char *realm,
     p += krb_put_int(AUTH_MSG_APPL_REQUEST, p, 1);
     
     /* Get the ticket and move it into the authenticator */
-#ifndef KRB_NDEB
     if (krb_ap_req_debug)
-        printf("Realm: %s\n",realm);
-#endif
+        krb_warning("Realm: %s\n", realm);
     /* 
      * Determine realm of these tickets.  We will send this to the
      * KDC from which we are requesting tickets so it knows what to
@@ -120,11 +156,9 @@ krb_mk_req(register KTEXT authent, char *service, char *instance, char *realm,
 	return retval;
 
 
-#ifndef KRB_NDEB
     if (krb_ap_req_debug)
-        printf("%s %s %s %s %s\n", service, instance, realm,
-               cr.pname, cr.pinst);
-#endif
+        krb_warning("%s %s %s %s %s\n", service, instance, realm,
+		    cr.pname, cr.pinst);
 
     p += krb_put_int(cr.kvno, p, 1);
 
@@ -151,14 +185,8 @@ krb_mk_req(register KTEXT authent, char *service, char *instance, char *realm,
     memset(&cr, 0, sizeof(cr));
     memset(&req_st, 0, sizeof(req_st));
 
-#ifndef KRB_NDEB
     if (krb_ap_req_debug)
-        printf("Authent->length = %d\n",authent->length);
-#if 0
-    if (krb_ap_req_debug)
-        printf("idl = %d, tl = %d\n",(int) *idl, (int) *tl);
-#endif
-#endif
+        krb_warning("Authent->length = %d\n", authent->length);
 
     return KSUCCESS;
 }
