@@ -1,6 +1,44 @@
+/*
+ * Copyright (c) 1995, 1996 Kungliga Tekniska Hgskolan (Royal Institute
+ * of Technology, Stockholm, Sweden).
+ * All rights reserved.
+ * 
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
+ * 
+ * 1. Redistributions of source code must retain the above copyright
+ *    notice, this list of conditions and the following disclaimer.
+ * 
+ * 2. Redistributions in binary form must reproduce the above copyright
+ *    notice, this list of conditions and the following disclaimer in the
+ *    documentation and/or other materials provided with the distribution.
+ * 
+ * 3. All advertising materials mentioning features or use of this software
+ *    must display the following acknowledgement:
+ *      This product includes software developed by the Kungliga Tekniska
+ *      Hgskolan and its contributors.
+ * 
+ * 4. Neither the name of the Institute nor the names of its contributors
+ *    may be used to endorse or promote products derived from this software
+ *    without specific prior written permission.
+ * 
+ * THIS SOFTWARE IS PROVIDED BY THE INSTITUTE AND CONTRIBUTORS ``AS IS'' AND
+ * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED.  IN NO EVENT SHALL THE INSTITUTE OR CONTRIBUTORS BE LIABLE
+ * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
+ * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
+ * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
+ * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
+ * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
+ * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
+ * SUCH DAMAGE.
+ */
+
 #include "krb_locl.h"
 
-RCSID("$Id: rd_req.c,v 1.13 1996/08/11 21:37:30 assar Exp $");
+RCSID("$Id: rd_req.c,v 1.21 1996/11/19 22:48:48 assar Exp $");
 
 static struct timeval t_local = { 0, 0 };
 
@@ -53,10 +91,10 @@ krb_set_key(void *key, int cvt)
     return KSUCCESS;
 #else /* Encrypt */
     if (cvt)
-        des_string_to_key((char *)key,&ky);
+        des_string_to_key(key, &ky);
     else
-        memcpy((char *)ky, key, 8);
-    return(des_key_sched(&ky,serv_key));
+        memcpy(ky, key, 8);
+    return(des_key_sched(&ky, serv_key));
 #endif /* NOENCRYPTION */
 }
 
@@ -103,19 +141,17 @@ krb_set_key(void *key, int cvt)
  */
 
 int
-krb_rd_req(register KTEXT authent, char *service, char *instance, 
-	   int32_t from_addr, AUTH_DAT *ad, char *fn)
-                           	/* The received message */
-                  		/* Service name */
-                   		/* Service instance */
-                   		/* Net address of originating host */
-                 		/* Structure to be filled in */
-             			/* Filename to get keys from */
+krb_rd_req(KTEXT authent,	/* The received message */
+	   char *service,	/* Service name */
+	   char *instance,	/* Service instance */
+	   int32_t from_addr,	/* Net address of originating host */
+	   AUTH_DAT *ad,	/* Structure to be filled in */
+	   char *fn)		/* Filename to get keys from */
 {
     static KTEXT_ST ticket;     /* Temp storage for ticket */
     static KTEXT tkt = &ticket;
     static KTEXT_ST req_id_st;  /* Temp storage for authenticator */
-    register KTEXT req_id = &req_id_st;
+    KTEXT req_id = &req_id_st;
 
     char realm[REALM_SZ];	/* Realm of issuing kerberos */
 
@@ -176,10 +212,10 @@ krb_rd_req(register KTEXT authent, char *service, char *instance,
                strcmp(st_rlm,realm) || (st_kvno != s_kvno))) {
         if (*fn == 0) fn = KEYFILE;
         st_kvno = s_kvno;
-        if (read_service_key(service, instance, realm, (int) s_kvno,
+        if (read_service_key(service, instance, realm, s_kvno,
 			     fn, (char *)skey))
             return(RD_AP_UNDEC);
-        if ((status = krb_set_key((char *)skey, 0)))
+        if ((status = krb_set_key(skey, 0)))
 	    return(status);
         strcpy(st_rlm, realm);
         strcpy(st_nam, service);
@@ -196,10 +232,8 @@ krb_rd_req(register KTEXT authent, char *service, char *instance,
     memcpy(tkt->dat, p, tkt->length);
     p += tkt->length;
 
-#ifndef KRB_NDEB
     if (krb_ap_req_debug)
-        k_log("ticket->length: %d",tkt->length);
-#endif
+        krb_log("ticket->length: %d",tkt->length);
 
     /* Decrypt and take apart ticket */
     if (decomp_ticket(tkt, &ad->k_flags, ad->pname, ad->pinst, ad->prealm,
@@ -207,14 +241,11 @@ krb_rd_req(register KTEXT authent, char *service, char *instance,
                       &ad->time_sec, sname, iname, &ky, serv_key))
         return RD_AP_UNDEC;
     
-#ifndef KRB_NDEB
     if (krb_ap_req_debug) {
-        k_log("Ticket Contents.");
-        k_log(" Aname:   %s.%s",ad->pname,
-	      ((int)*(ad->prealm) ? ad->prealm : "Athena"));
-        k_log(" Service: %s%s%s",sname,((int)*iname ? "." : ""),iname);
+        krb_log("Ticket Contents.");
+        krb_log(" Aname:   %s.%s",ad->pname, ad->prealm);
+        krb_log(" Service: %s", krb_unparse_name_long(sname, iname, NULL));
     }
-#endif
 
     /* Extract the authenticator */
     
@@ -226,17 +257,14 @@ krb_rd_req(register KTEXT authent, char *service, char *instance,
     
 #ifndef NOENCRYPTION
     /* And decrypt it with the session key from the ticket */
-#ifndef KRB_NDEB
-    if (krb_ap_req_debug) k_log("About to decrypt authenticator");
-#endif
+    if (krb_ap_req_debug) krb_log("About to decrypt authenticator");
 
     encrypt_ktext(req_id, &ad->session, DES_DECRYPT);
 
-#ifndef KRB_NDEB
-    if (krb_ap_req_debug) k_log("Done.");
-#endif
+    if (krb_ap_req_debug) krb_log("Done.");
 #endif /* NOENCRYPTION */
 
+    /* cast req_id->length to int? */
 #define check_ptr() if ((ptr - (char *) req_id->dat) > req_id->length) return(RD_AP_MODIFIED);
 
     p += krb_get_nir(p, r_aname, r_inst, r_realm); /* XXX no rangecheck */
@@ -248,20 +276,16 @@ krb_rd_req(register KTEXT authent, char *service, char *instance,
     p += krb_get_int(p, &r_time_sec, 4, little_endian);
 
     /* Check for authenticity of the request */
-#ifndef KRB_NDEB
     if (krb_ap_req_debug)
-        k_log("Principal: %s.%s@%s / %s.%s@%s",ad->pname,ad->pinst, ad->prealm, 
+        krb_log("Principal: %s.%s@%s / %s.%s@%s",ad->pname,ad->pinst, ad->prealm, 
 	      r_aname, r_inst, r_realm);
-#endif
     if (strcmp(ad->pname, r_aname) != 0 ||
 	strcmp(ad->pinst, r_inst) != 0 ||
 	strcmp(ad->prealm, r_realm) != 0)
 	return RD_AP_INCON;
     
-#ifndef KRB_NDEB
     if (krb_ap_req_debug)
-        k_log("Address: %x %x", ad->address, from_addr);
-#endif
+        krb_log("Address: %x %x", ad->address, from_addr);
 
     if (from_addr && (!krb_equiv(ad->address, from_addr)))
         return RD_AP_BADD;
@@ -269,22 +293,18 @@ krb_rd_req(register KTEXT authent, char *service, char *instance,
     gettimeofday(&tv, NULL);
     delta_t = abs((int)(tv.tv_sec - r_time_sec));
     if (delta_t > CLOCK_SKEW) {
-#ifndef KRB_NDEB
         if (krb_ap_req_debug)
-            k_log("Time out of range: %d - %d = %d",
+            krb_log("Time out of range: %d - %d = %d",
 		  t_local.tv_sec,r_time_sec,delta_t);
-#endif
         return RD_AP_TIME;
     }
 
     /* Now check for expiration of ticket */
 
     tkt_age = tv.tv_sec - ad->time_sec;
-#ifndef KRB_NDEB
     if (krb_ap_req_debug)
-        k_log("Time: %d Issue Date: %d Diff: %d Life %x",
+        krb_log("Time: %d Issue Date: %d Diff: %d Life %x",
 	      tv.tv_sec, ad->time_sec, tkt_age, ad->life);
-#endif
     
     if ((tkt_age < 0) && (-tkt_age > CLOCK_SKEW))
 	return RD_AP_NYV;
