@@ -26,15 +26,16 @@ or implied warranty.
 
 #include "krb_locl.h"
 
-RCSID("$Id: send_to_kdc.c,v 1.18 1996/08/22 19:23:01 assar Exp $");
+RCSID("$Id: send_to_kdc.c,v 1.37 1996/11/19 21:56:11 assar Exp $");
 
-#define S_AD_SZ sizeof(struct sockaddr_in)
-
-static int krb_udp_port = 0;
+struct host {
+  struct sockaddr_in addr;
+  int proto;
+};
 
 static const char *prog = "send_to_kdc";
 static send_recv(KTEXT pkt, KTEXT rpkt, int f,
-		 struct sockaddr_in *_to, struct sockaddr_in *addrs,
+		 struct sockaddr_in *_to, struct host *addrs,
 		 int h_hosts);
 
 /*
@@ -72,15 +73,18 @@ static send_recv(KTEXT pkt, KTEXT rpkt, int f,
 int
 send_to_kdc(KTEXT pkt, KTEXT rpkt, char *realm)
 {
-    int i, f;
+    int i;
     int no_host; /* was a kerberos host found? */
     int retry;
     int n_hosts;
     int retval;
-    struct sockaddr_in to, *addrlist;
     struct hostent *host;
-    char krbhst[MAX_HSTNM];
     char lrealm[REALM_SZ];
+    struct krb_host *k_host;
+    struct host *hosts = malloc(sizeof(*hosts));
+
+    if (hosts == NULL)
+      return SKDC_CANT;
 
     /*
      * If "realm" is non-null, use that, otherwise get the
@@ -90,93 +94,64 @@ send_to_kdc(KTEXT pkt, KTEXT rpkt, char *realm)
 	strcpy(lrealm, realm);
     else
 	if (krb_get_lrealm(lrealm,1)) {
-#ifndef KRB_NDEB
 	    if (krb_debug)
-		fprintf(stderr, "%s: can't get local realm\n", prog);
-#endif
+		krb_warning("%s: can't get local realm\n", prog);
 	    return(SKDC_CANT);
 	}
-#ifndef KRB_NDEB
     if (krb_debug)
-      fprintf(stderr, "lrealm is %s\n", lrealm);
-#endif
-    if (krb_udp_port == 0) {
-        krb_udp_port = k_getportbyname ("kerberos-iv", "udp", htons(KRB_PORT));
-#ifndef KRB_NDEB
-        if (krb_debug)
-	  fprintf(stderr, "krb_udp_port is %d\n", krb_udp_port);
-#endif
-    }
-    memset(&to, 0, S_AD_SZ);
-    addrlist = malloc(sizeof(*addrlist));
-    if (addrlist == NULL)
-        return (SKDC_CANT);
-    memset(addrlist, 0, sizeof(*addrlist));
-    if ((f = socket(AF_INET, SOCK_DGRAM, 0)) < 0) {
-#ifndef KRB_NDEB
-        if (krb_debug)
-            fprintf(stderr,"%s: Can't open socket\n", prog);
-#endif
-        return(SKDC_CANT);
-    }
-    /* from now on, exit through rtn label for cleanup */
+      krb_warning("lrealm is %s\n", lrealm);
 
     no_host = 1;
     /* get an initial allocation */
     n_hosts = 0;
-    for (i = 1; krb_get_krbhst(krbhst, lrealm, i) == KSUCCESS; ++i) {
+    for (i = 1; (k_host = krb_get_host(i, lrealm, 0)); ++i) {
 	char *p;
 
-#ifndef KRB_NDEB
+        if (krb_debug)
+	  krb_warning("Getting host entry for %s...", k_host->host);
+        host = gethostbyname(k_host->host);
         if (krb_debug) {
-	  fprintf(stderr, "Getting host entry for %s...",krbhst);
-	  /*(void) fflush(stdout);*/
+	  krb_warning("%s.\n",
+		      host ? "Got it" : "Didn't get it");
         }
-#endif
-        host = gethostbyname(krbhst);
-#ifndef KRB_NDEB
-        if (krb_debug) {
-	  fprintf(stderr, "%s.\n",
-                   host ? "Got it" : "Didn't get it");
-        }
-#endif
         if (!host)
             continue;
         no_host = 0;    /* found at least one */
 	while ((p = *(host->h_addr_list)++)) {
-          n_hosts++;
-  	  addrlist = realloc(addrlist, sizeof(*addrlist) * (n_hosts+1));
-	  if (addrlist == NULL)
-	    return SKDC_CANT;
-	  memset(&addrlist[n_hosts-1], 0, sizeof(*addrlist));
-	  addrlist[n_hosts-1].sin_family = host->h_addrtype;
-	  addrlist[n_hosts-1].sin_port   = krb_udp_port;
-	  memcpy(&addrlist[n_hosts-1].sin_addr, p, host->h_length);
-	  if (send_recv(pkt, rpkt, f, &addrlist[n_hosts-1],
-			addrlist, n_hosts)) {
-            retval = KSUCCESS;
-            goto rtn;
-        }
-#ifndef KRB_NDEB
-        if (krb_debug) {
-	  fprintf(stderr, "Timeout, error, or wrong descriptor\n");
-        }
-#endif
-      }
+	    hosts = realloc(hosts, sizeof(*hosts) * (n_hosts + 1));
+	    if (hosts == NULL)
+		return SKDC_CANT;
+	    memset (&hosts[n_hosts].addr, 0, sizeof(hosts[n_hosts].addr));
+	    hosts[n_hosts].addr.sin_family = host->h_addrtype;
+	    hosts[n_hosts].addr.sin_port = htons(k_host->port);
+	    hosts[n_hosts].proto = k_host->proto;
+	    memcpy(&hosts[n_hosts].addr.sin_addr, p,
+		   sizeof(hosts[n_hosts].addr.sin_addr));
+	    ++n_hosts;
+	    if (send_recv(pkt, rpkt, hosts[n_hosts-1].proto,
+			  &hosts[n_hosts-1].addr, hosts, n_hosts)) {
+		retval = KSUCCESS;
+		goto rtn;
+	    }
+	    if (krb_debug) {
+		krb_warning("Timeout, error, or wrong descriptor\n");
+	    }
+	}
     }
     if (no_host) {
-#ifndef KRB_NDEB
 	if (krb_debug)
-	    fprintf(stderr, "%s: can't find any Kerberos host.\n",
-		    prog);
-#endif
+	    krb_warning("%s: can't find any Kerberos host.\n",
+			prog);
         retval = SKDC_CANT;
         goto rtn;
     }
     /* retry each host in sequence */
     for (retry = 0; retry < CLIENT_KRB_RETRY; ++retry) {
 	for (i = 0; i < n_hosts; ++i) {
-	    if (send_recv(pkt, rpkt, f, &addrlist[i], addrlist,
+	    if (send_recv(pkt, rpkt,
+			  hosts[i].proto,
+			  &hosts[i].addr,
+			  hosts,
 			  n_hosts)) {
 		retval = KSUCCESS;
 		goto rtn;
@@ -185,8 +160,7 @@ send_to_kdc(KTEXT pkt, KTEXT rpkt, char *realm)
     }
     retval = SKDC_RETRY;
 rtn:
-    close(f);
-    free(addrlist);
+    free(hosts);
     return(retval);
 }
 
@@ -196,14 +170,12 @@ rtn:
  */
 
 static int
-send_recv(KTEXT pkt, KTEXT rpkt, int f, struct sockaddr_in *_to,
-	  struct sockaddr_in *addrs, int n_hosts)
+send_recv_it(KTEXT pkt, KTEXT rpkt, int stream, int f, 
+	     struct sockaddr_in *_to, struct host *addrs, int n_hosts)
 {
     fd_set readfds;
-    struct sockaddr_in from;
-    int sin_size;
     int numsent;
-    int i;
+    
     /* CLIENT_KRB_TIMEOUT indicates the time to wait before
      * retrying a server.  It's defined in "krb.h".
      */
@@ -211,86 +183,67 @@ send_recv(KTEXT pkt, KTEXT rpkt, int f, struct sockaddr_in *_to,
     timeout.tv_sec = CLIENT_KRB_TIMEOUT;
     timeout.tv_usec = 0;
 
-#ifndef KRB_NDEB
     if (krb_debug) {
         if (_to->sin_family == AF_INET)
-            fprintf(stderr, "Sending message to %s...",
-                   inet_ntoa(_to->sin_addr));
+	    krb_warning("Sending message to %s...",
+			inet_ntoa(_to->sin_addr));
         else
-	  fprintf(stderr, "Sending message...");
-        /*(void) fflush(stdout);*/
+	    krb_warning("Sending message...");
     }
-#endif
-    if ((numsent = sendto(f,(char *)(pkt->dat), pkt->length, 0, 
-			  (struct sockaddr *)_to,
-                          S_AD_SZ)) != pkt->length) {
-#ifndef KRB_NDEB
+    if ((numsent = send(f, pkt->dat, pkt->length, 0)) != pkt->length) {
         if (krb_debug)
-            fprintf(stderr, "sent only %d/%d\n",numsent, pkt->length);
-#endif
+            krb_warning("sent only %d/%d\n",numsent, pkt->length);
         return 0;
     }
-#ifndef KRB_NDEB
-    if (krb_debug) {
-      fprintf(stderr, "Sent\nWaiting for reply...");
-      /*(void) fflush(stdout);*/
-    }
-#endif
+    if(stream)
+	shutdown(f, 1);
+    if (krb_debug)
+	krb_warning("Sent\nWaiting for reply...");
     FD_ZERO(&readfds);
     FD_SET(f, &readfds);
-    errno = 0;
     /* select - either recv is ready, or timeout */
     /* see if timeout or error or wrong descriptor */
     if (select(f + 1, &readfds, 0, 0, &timeout) < 1
         || !FD_ISSET(f, &readfds)) {
-#ifndef KRB_NDEB
-        if (krb_debug) {
-	    long rfds;
-	    memcpy(&rfds, &readfds, sizeof(rfds));
-            fprintf(stderr, "select failed: readfds=%lx",
-                    rfds);
-            perror("");
-        }
-#endif
+        if (krb_debug)
+            krb_warning("select failed: errno = %d", errno);
         return 0;
     }
-    sin_size = sizeof(from);
-    if (recvfrom(f, (char *)(rpkt->dat), sizeof(rpkt->dat), 0,
-		 (struct sockaddr *)&from, &sin_size)
-        < 0) {
-#ifndef KRB_NDEB
-        if (krb_debug)
-            perror("recvfrom");
-#endif
-        return 0;
+    if(stream){
+	if(krb_net_read(f, rpkt->dat, sizeof(rpkt->dat)) <= 0)
+	    return 0;
+    }else{
+	if (recv (f, rpkt->dat, sizeof(rpkt->dat), 0) < 0) {
+	    if (krb_debug)
+		krb_warning("recvfrom: errno = %d\n", errno);
+	    return 0;
+	}
     }
-#ifndef KRB_NDEB
-    if (krb_debug) {
-      fprintf(stderr, "received packet from %s\n", inet_ntoa(from.sin_addr));
-      /*fflush(stdout);*/
-    }
-#endif
-    for (i = 0; i < n_hosts; ++i) {
-	 if (addrs[i].sin_addr.s_addr == from.sin_addr.s_addr) {
-#ifndef KRB_NDEB
-            if (krb_debug) {
-	      fprintf(stderr, "Received it\n");
-	      /*(void) fflush(stdout);*/
-            }
-#endif
-            return 1;
-        }
-#ifndef KRB_NDEB
-        if (krb_debug)
-            fprintf(stderr,
-                    "packet not from %lx\n",
-                    (long)addrs[i].sin_addr.s_addr);
-#endif
-    }
-#ifndef KRB_NDEB
-    if (krb_debug)
-        fprintf(stderr, "%s: received packet from wrong host! (%x)\n",
-                "send_to_kdc(send_rcv)", (int)from.sin_addr.s_addr);
-#endif
-    return 0;
+    return 1;
 }
+
+static int
+send_recv(KTEXT pkt, KTEXT rpkt, int proto, struct sockaddr_in *_to,
+	  struct host *addrs, int n_hosts)
+{
+    int f;
+    int ret = 0;
+    if(proto == IPPROTO_UDP)
+	f = socket(AF_INET, SOCK_DGRAM, IPPROTO_UDP);
+    else if(proto == IPPROTO_TCP)
+	f = socket(AF_INET, SOCK_STREAM, IPPROTO_TCP);
+    else{
+	krb_warning("Unknown protocol `%d'.\n", proto);
+	return 0;
+    }
+    
+    if(connect(f, (struct sockaddr*)_to, sizeof(*_to)) < 0)
+	krb_warning("Connecting socket: errno = %d\n", errno);
+    else
+	ret = send_recv_it(pkt, rpkt, proto == IPPROTO_TCP, f, 
+			   _to, addrs, n_hosts);
+    
+    close(f);
+    return ret;
+}
+
