@@ -1,5 +1,5 @@
 /*
- * $Id: stime.c,v 1.3 1996/05/31 21:00:24 assar Exp $
+ * $Id: stime.c,v 1.5 1996/09/09 19:26:05 assar Exp $
  *
  * Copyright 1985, 1986, 1987, 1988 by the Massachusetts Institute
  * of Technology.
@@ -10,7 +10,7 @@
 
 #include "krb_locl.h"
 
-RCSID("$Id: stime.c,v 1.3 1996/05/31 21:00:24 assar Exp $");
+RCSID("$Id: stime.c,v 1.5 1996/09/09 19:26:05 assar Exp $");
 
 /*
  * Given a pointer to a long containing the number of seconds
@@ -20,16 +20,15 @@ RCSID("$Id: stime.c,v 1.3 1996/05/31 21:00:24 assar Exp $");
  * "25-Jan-1988 10:17:56"
  */
 
-char *stime(long int *t)
+const char *
+krb_stime(time_t *t)
 {
-    static char st_data[40];
-    static char *st = st_data;
+    static char st[40];
     struct tm *tm;
-    char *month_sname(int n);
 
     tm = localtime(t);
-    (void) sprintf(st,"%2d-%s-%04d %02d:%02d:%02d",tm->tm_mday,
-                   month_sname(tm->tm_mon + 1),tm->tm_year + 1900,
-                   tm->tm_hour, tm->tm_min, tm->tm_sec);
+    sprintf(st, "%2d-%s-%04d %02d:%02d:%02d",tm->tm_mday,
+	    month_sname(tm->tm_mon + 1),tm->tm_year + 1900,
+	    tm->tm_hour, tm->tm_min, tm->tm_sec);
     return st;
 }
