@@ -23,16 +23,14 @@ this software for any purpose.  It is provided "as is" without express
 or implied warranty.
 
   */
-
+/* These functions are not needed in Windows95/NT implementation,
+ * since no ticket files are used.
+ */
+        
 #include "krb_locl.h"
 
-RCSID("$Id: tf_util.c,v 1.11 1996/08/13 23:43:09 assar Exp $");
+RCSID("$Id: tf_util.c,v 1.18 1996/11/19 22:48:49 assar Exp $");
 
-#ifdef TKT_SHMEM
-#include <sys/param.h>
-#include <sys/ipc.h>
-#include <sys/shm.h>
-#endif /* TKT_SHMEM */
 
 #define TOO_BIG -1
 #define TF_LCK_RETRY ((unsigned)2)	/* seconds to sleep before
@@ -40,11 +38,6 @@ RCSID("$Id: tf_util.c,v 1.11 1996/08/13 23:43:09 assar Exp $");
 					 * locked */
 #define	TF_LCK_RETRY_COUNT	(50)	/* number of retries	*/
 
-#ifdef TKT_SHMEM
-static char *krb_shm_addr = 0;
-static char *tmp_shm_addr = 0;
-static char krb_dummy_skey[8] = {0,0,0,0,0,0,0,0};
-#endif /* TKT_SHMEM */
 
 /*
  * fd must be initialized to something that won't ever occur as a real
@@ -64,7 +57,8 @@ static	int curpos;				/* Position in tfbfr */
 static	int lastpos;			/* End of tfbfr */
 static	char tfbfr[BUFSIZ];		/* Buffer for ticket data */
 
-static tf_gets(register char *s, int n), tf_read(register char *s, register int n);
+static int tf_gets(char *s, int n);
+static int tf_read(void *s, int n);
 
 /*
  * This file contains routines for manipulating the ticket cache file.
@@ -135,15 +129,11 @@ static tf_gets(register char *s, int n), tf_read(register char *s, register int
 int
 tf_init(char *tf_name, int rw)
 {
+	/* Unix implementation */
     int     wflag;
     struct stat stat_buf;
     int		i_retry;
 
-#ifdef TKT_SHMEM
-    char shmidname[MaxPathLen]; 
-    FILE *sfp;
-    int shmid;
-#endif
 
     switch (rw) {
     case R_TKT_FIL:
@@ -153,9 +143,8 @@ tf_init(char *tf_name, int rw)
 	wflag = 1;
 	break;
     default:
-#ifndef KRB_NDEB
-	if (krb_debug) fprintf(stderr, "tf_init: illegal parameter\n");
-#endif
+	if (krb_debug)
+	  krb_warning("tf_init: illegal parameter\n");
 	return TKT_FIL_ACC;
     }
     if (lstat(tf_name, &stat_buf) < 0)
@@ -177,15 +166,6 @@ tf_init(char *tf_name, int rw)
     if(!S_ISREG(stat_buf.st_mode))
       return TKT_FIL_ACC;
 
-#ifdef TKT_SHMEM
-    (void) strcpy(shmidname, tf_name);
-    (void) strcat(shmidname, ".shm");
-    if (stat(shmidname,&stat_buf) < 0)
-	return(TKT_FIL_ACC);
-    if ((stat_buf.st_uid != me && me != 0) ||
-	((stat_buf.st_mode & S_IFMT) != S_IFREG))
-	return TKT_FIL_ACC;
-#endif /* TKT_SHMEM */
 
     /*
      * If "wflag" is set, open the ticket file in append-writeonly mode
@@ -196,45 +176,6 @@ tf_init(char *tf_name, int rw)
 
     curpos = sizeof(tfbfr);
 
-#ifdef TKT_SHMEM
-    sfp = fopen(shmidname, "r");	/* only need read/write on the
-					   actual tickets */
-    if (sfp == 0)
-    	return TKT_FIL_ACC;
-    shmid = -1;
-    {
-	char buf[BUFSIZ];
-	int val;			/* useful for debugging fscanf */
-	/* We provide our own buffer here since some STDIO libraries
-	   barf on unbuffered input with fscanf() */
-
-	setbuf(sfp, buf);
-	if ((val = fscanf(sfp,"%d",&shmid)) != 1) {
-	    (void) fclose(sfp);
-	    return TKT_FIL_ACC;
-	}
-	if (shmid < 0) {
-	    (void) fclose(sfp);
-	    return TKT_FIL_ACC;
-	}
-	(void) fclose(sfp);
-    }
-    /*
-    * global krb_shm_addr is initialized to 0.  Ultrix bombs when you try and
-    * attach the same segment twice so we need this check.
-    */
-    if (!krb_shm_addr) {
-    	if ((krb_shm_addr = shmat(shmid,0,0)) == -1){
-		if (krb_debug)
-		    fprintf(stderr,
-			    "cannot attach shared memory for segment %d\n",
-			    shmid);
-		krb_shm_addr = 0;	/* reset so we catch further errors */
-		return TKT_FIL_ACC;
-	    }
-    }
-    tmp_shm_addr = krb_shm_addr;
-#endif /* TKT_SHMEM */
     
     if (wflag) {
       fd = open(tf_name, O_RDWR, 0600);
@@ -243,17 +184,15 @@ tf_init(char *tf_name, int rw)
       }
       for (i_retry = 0; i_retry < TF_LCK_RETRY_COUNT; i_retry++) {
 	if (k_flock(fd, K_LOCK_EX | K_LOCK_NB) < 0) {
-#ifndef KRB_NDEB
 	  if (krb_debug)
-	    fprintf(stderr, "tf_init: retry %d of write lock of `%s'.\n",
-		    i_retry, tf_name);
-#endif
+	    krb_warning("tf_init: retry %d of write lock of `%s'.\n",
+			i_retry, tf_name);
 	  sleep (TF_LCK_RETRY);
 	} else {
 	  return KSUCCESS;		/* all done */
 	}
       }
-      (void) close (fd);
+      close (fd);
       fd = -1;
       return TKT_FIL_LCK;
     }
@@ -269,18 +208,16 @@ tf_init(char *tf_name, int rw)
 
     for (i_retry = 0; i_retry < TF_LCK_RETRY_COUNT; i_retry++) {
 	if (k_flock(fd, K_LOCK_SH | K_LOCK_NB) < 0) {
-#ifndef KRB_NDEB
 	  if (krb_debug)
-	    fprintf(stderr, "tf_init: retry %d of read lock of `%s'.\n",
-		    i_retry, tf_name);
-#endif
+	    krb_warning("tf_init: retry %d of read lock of `%s'.\n",
+			i_retry, tf_name);
 	  sleep (TF_LCK_RETRY);
 	} else {
 	  return KSUCCESS;		/* all done */
 	}
       }
     /* failure */
-    (void) close(fd);
+    close(fd);
     fd = -1;
     return TKT_FIL_LCK;
 }
@@ -305,7 +242,7 @@ tf_create(char *tf_name)
     char garbage[BUFSIZ];
 
     fd = open(tf_name, O_RDWR, 0);
-    if (fd) {
+    if (fd >= 0) {
 	if (fstat (fd, &statbuf) == 0) {
 	    int i;
 
@@ -324,7 +261,7 @@ tf_create(char *tf_name)
     if (k_flock(fd, K_LOCK_EX | K_LOCK_NB) < 0) {
 	sleep(TF_LCK_RETRY);
 	if (k_flock(fd, K_LOCK_EX | K_LOCK_NB) < 0) {
-	    (void) close(fd);
+	    close(fd);
 	    fd = -1;
 	    return TKT_FIL_LCK;
 	}
@@ -345,17 +282,14 @@ int
 tf_get_pname(char *p)
 {
     if (fd < 0) {
-#ifndef KRB_NDEB
 	if (krb_debug)
-	    fprintf(stderr, "tf_get_pname called before tf_init.\n");
-#endif
+	    krb_warning("tf_get_pname called before tf_init.\n");
 	return TKT_FIL_INI;
     }
     if (tf_gets(p, ANAME_SZ) < 2)	/* can't be just a null */
       {
-#ifndef KRB_NDEB
-	if (krb_debug) fprintf (stderr, "tf_get_pname: pname < 2.\n");
-#endif
+	if (krb_debug) 
+	  krb_warning ("tf_get_pname: pname < 2.\n");
 	return TKT_FIL_FMT;
       }
     return KSUCCESS;
@@ -369,13 +303,11 @@ tf_get_pname(char *p)
 int
 tf_put_pname(char *p)
 {
-    unsigned count;
+	unsigned count;
 
     if (fd < 0) {
-#ifndef KRB_NDEB
 	if (krb_debug)
-	    fprintf(stderr, "tf_put_pname called before tf_create.\n");
-#endif
+	    krb_warning("tf_put_pname called before tf_create.\n");
 	return TKT_FIL_INI;
     }
     count = strlen(p)+1;
@@ -398,17 +330,14 @@ int
 tf_get_pinst(char *inst)
 {
     if (fd < 0) {
-#ifndef KRB_NDEB
 	if (krb_debug)
-	    fprintf(stderr, "tf_get_pinst called before tf_init.\n");
-#endif
+	    krb_warning("tf_get_pinst called before tf_init.\n");
 	return TKT_FIL_INI;
     }
     if (tf_gets(inst, INST_SZ) < 1)
       {
-#ifndef KRB_NDEB
-	if (krb_debug) fprintf (stderr, "tf_get_pinst: inst_sz < 1.\n");
-#endif
+	if (krb_debug)
+	  krb_warning("tf_get_pinst: inst_sz < 1.\n");
 	return TKT_FIL_FMT;
       }
     return KSUCCESS;
@@ -422,19 +351,17 @@ tf_get_pinst(char *inst)
 int
 tf_put_pinst(char *inst)
 {
-    unsigned count;
+	unsigned count;
 
     if (fd < 0) {
-#ifndef KRB_NDEB
 	if (krb_debug)
-	    fprintf(stderr, "tf_put_pinst called before tf_create.\n");
-#endif
+	    krb_warning("tf_put_pinst called before tf_create.\n");
 	return TKT_FIL_INI;
     }
     count = strlen(inst)+1;
     if (write(fd,inst,count) != count)
         return(KFAILURE);
-    return KSUCCESS;
+	return KSUCCESS;
 }
 
 /*
@@ -455,23 +382,19 @@ tf_get_cred(CREDENTIALS *c)
     int     k_errno;
 
     if (fd < 0) {
-#ifndef KRB_NDEB
 	if (krb_debug)
-	    fprintf(stderr, "tf_get_cred called before tf_init.\n");
-#endif
+	    krb_warning ("tf_get_cred called before tf_init.\n");
 	return TKT_FIL_INI;
     }
     if ((k_errno = tf_gets(c->service, SNAME_SZ)) < 2)
 	switch (k_errno) {
 	case TOO_BIG:
-#ifndef KRB_NDEB
-	  if (krb_debug) fprintf (stderr, "tf_get_cred: too big service cred.\n");
-#endif
+	  if (krb_debug)
+	    krb_warning("tf_get_cred: too big service cred.\n");
 	case 1:		/* can't be just a null */
 	  tf_close();
-#ifndef KRB_NDEB
-	  if (krb_debug) fprintf (stderr, "tf_get_cred: null service cred.\n");
-#endif
+	  if (krb_debug)
+	    krb_warning("tf_get_cred: null service cred.\n");
 	  return TKT_FIL_FMT;
 	case 0:
 	  return EOF;
@@ -479,9 +402,8 @@ tf_get_cred(CREDENTIALS *c)
     if ((k_errno = tf_gets(c->instance, INST_SZ)) < 1)
 	switch (k_errno) {
 	case TOO_BIG:
-#ifndef KRB_NDEB
-	  if (krb_debug) fprintf (stderr, "tf_get_cred: too big instance cred.\n");
-#endif
+	  if (krb_debug)
+	    krb_warning ("tf_get_cred: too big instance cred.\n");
 	  return TKT_FIL_FMT;
 	case 0:
 	  return EOF;
@@ -489,39 +411,32 @@ tf_get_cred(CREDENTIALS *c)
     if ((k_errno = tf_gets(c->realm, REALM_SZ)) < 2)
 	switch (k_errno) {
 	case TOO_BIG:
-#ifndef KRB_NDEB
-	  if (krb_debug) fprintf (stderr, "tf_get_cred: too big realm cred.\n");
-#endif
+	  if (krb_debug)
+	    krb_warning ("tf_get_cred: too big realm cred.\n");
 	case 1:		/* can't be just a null */
 	  tf_close();
-#ifndef KRB_NDEB
-	  if (krb_debug) fprintf (stderr, "tf_get_cred: null realm cred.\n");
-#endif
+	  if (krb_debug)
+	    krb_warning ("tf_get_cred: null realm cred.\n");
 	  return TKT_FIL_FMT;
 	case 0:
 	  return EOF;
 	}
     if (
-	tf_read((char *) (c->session), DES_KEY_SZ) < 1 ||
-	tf_read((char *) &(c->lifetime), sizeof(c->lifetime)) < 1 ||
-	tf_read((char *) &(c->kvno), sizeof(c->kvno)) < 1 ||
-	tf_read((char *) &(ticket->length), sizeof(ticket->length))
+	tf_read((c->session), DES_KEY_SZ) < 1 ||
+	tf_read(&(c->lifetime), sizeof(c->lifetime)) < 1 ||
+	tf_read(&(c->kvno), sizeof(c->kvno)) < 1 ||
+	tf_read(&(ticket->length), sizeof(ticket->length))
 	< 1 ||
     /* don't try to read a silly amount into ticket->dat */
 	ticket->length > MAX_KTXT_LEN ||
-	tf_read((char *) (ticket->dat), ticket->length) < 1 ||
-	tf_read((char *) &(c->issue_date), sizeof(c->issue_date)) < 1
+	tf_read((ticket->dat), ticket->length) < 1 ||
+	tf_read(&(c->issue_date), sizeof(c->issue_date)) < 1
 	) {
 	tf_close();
-#ifndef KRB_NDEB
-	if (krb_debug) fprintf (stderr, "tf_get_cred: failed tf_read.\n");
-#endif
+	if (krb_debug)
+	  krb_warning ("tf_get_cred: failed tf_read.\n");
 	return TKT_FIL_FMT;
     }
-#ifdef TKT_SHMEM
-    memcpy(c->session, tmp_shm_addr, KEY_SZ);
-    tmp_shm_addr += KEY_SZ;
-#endif /* TKT_SHMEM */
     return KSUCCESS;
 }
 
@@ -537,17 +452,8 @@ void
 tf_close(void)
 {
     if (!(fd < 0)) {
-#ifdef TKT_SHMEM
-	if (shmdt(krb_shm_addr)) {
-	    /* what kind of error? */
-	    if (krb_debug)
-		fprintf(stderr, "shmdt 0x%x: errno %d",krb_shm_addr, errno);
-	} else {
-	    krb_shm_addr = 0;
-	}
-#endif /* TKT_SHMEM */
-	(void) k_flock(fd, K_LOCK_UN);
-	(void) close(fd);
+	k_flock(fd, K_LOCK_UN);
+	close(fd);
 	fd = -1;		/* see declaration of fd above */
     }
     memset(tfbfr, 0, sizeof(tfbfr));
@@ -572,15 +478,13 @@ tf_close(void)
  */
 
 static int
-tf_gets(register char *s, int n)
+tf_gets(char *s, int n)
 {
     int count;
 
     if (fd < 0) {
-#ifndef KRB_NDEB
 	if (krb_debug)
-	    fprintf(stderr, "tf_gets called before tf_init.\n");
-#endif
+	    krb_warning ("tf_gets called before tf_init.\n");
 	return TKT_FIL_INI;
     }
     for (count = n - 1; count > 0; --count) {
@@ -614,8 +518,9 @@ tf_gets(register char *s, int n)
  */
 
 static int
-tf_read(register char *s, register int n)
+tf_read(void *v, int n)
 {
+    char *s = (char *)v;
     int count;
     
     for (count = n; count > 0; --count) {
@@ -632,8 +537,6 @@ tf_read(register char *s, register int n)
     return n;
 }
      
-char   *tkt_string(void);
-
 /*
  * tf_save_cred() appends an incoming ticket to the end of the ticket
  * file.  You must call tf_init() before calling tf_save_cred().
@@ -647,45 +550,26 @@ char   *tkt_string(void);
  * Returns KSUCCESS if all goes well, TKT_FIL_INI if tf_init() wasn't
  * called previously, and KFAILURE for anything else that went wrong.
  */
-
+ 
 int
-tf_save_cred(char *service, char *instance, char *realm, unsigned char *session, int lifetime, int kvno, KTEXT ticket, u_int32_t issue_date)
-                    		/* Service name */
-                     		/* Instance */
-                  		/* Auth domain */
-                    		/* Session key */
-                     		/* Lifetime */
-                 		/* Key version number */
-                   		/* The ticket itself */
-                       		/* The issue time */
+tf_save_cred(char *service,	/* Service name */
+	     char *instance,	/* Instance */
+	     char *realm,	/* Auth domain */
+	     unsigned char *session, /* Session key */
+	     int lifetime,	/* Lifetime */
+	     int kvno,		/* Key version number */
+	     KTEXT ticket,	/* The ticket itself */
+	     u_int32_t issue_date) /* The issue time */
 {
-
-    off_t   lseek(int, off_t, int);
     int     count;		/* count for write */
-#ifdef TKT_SHMEM
-    int	    *skey_check;
-#endif /* TKT_SHMEM */
 
     if (fd < 0) {		/* fd is ticket file as set by tf_init */
-#ifndef KRB_NDEB
 	  if (krb_debug)
-	      fprintf(stderr, "tf_save_cred called before tf_init.\n");
-#endif
+	      krb_warning ("tf_save_cred called before tf_init.\n");
 	  return TKT_FIL_INI;
     }
     /* Find the end of the ticket file */
-    (void) lseek(fd, 0L, 2);
-#ifdef TKT_SHMEM
-    /* scan to end of existing keys: pick first 'empty' slot.
-       we assume that no real keys will be completely zero (it's a weak
-       key under DES) */
-
-    skey_check = (int *) krb_shm_addr;
-
-    while (*skey_check && *(skey_check+1))
-	skey_check += 2;
-    tmp_shm_addr = (char *)skey_check;
-#endif /* TKT_SHMEM */
+    lseek(fd, 0L, SEEK_END);
 
     /* Write the ticket and associated data */
     /* Service */
@@ -701,32 +585,24 @@ tf_save_cred(char *service, char *instance, char *realm, unsigned char *session,
     if (write(fd, realm, count) != count)
 	goto bad;
     /* Session key */
-#ifdef TKT_SHMEM
-    memcpy(tmp_shm_addr, session, 8);
-    tmp_shm_addr+=8;
-    if (write(fd,krb_dummy_skey,8) != 8)
+    if (write(fd, session, 8) != 8)
 	goto bad;
-#else /* ! TKT_SHMEM */
-    if (write(fd, (char *) session, 8) != 8)
-	goto bad;
-#endif /* TKT_SHMEM */
     /* Lifetime */
-    if (write(fd, (char *) &lifetime, sizeof(int)) != sizeof(int))
+    if (write(fd, &lifetime, sizeof(int)) != sizeof(int))
 	goto bad;
     /* Key vno */
-    if (write(fd, (char *) &kvno, sizeof(int)) != sizeof(int))
+    if (write(fd, &kvno, sizeof(int)) != sizeof(int))
 	goto bad;
     /* Tkt length */
-    if (write(fd, (char *) &(ticket->length), sizeof(int)) !=
+    if (write(fd, &(ticket->length), sizeof(int)) !=
 	sizeof(int))
 	goto bad;
     /* Ticket */
     count = ticket->length;
-    if (write(fd, (char *) (ticket->dat), count) != count)
+    if (write(fd, ticket->dat, count) != count)
 	goto bad;
     /* Issue date */
-    if (write(fd, (char *) &issue_date, sizeof(issue_date))
-	!= sizeof(issue_date))
+    if (write(fd, &issue_date, sizeof(issue_date)) != sizeof(issue_date))
 	goto bad;
 
     /* Actually, we should check each write for success */
@@ -734,3 +610,4 @@ tf_save_cred(char *service, char *instance, char *realm, unsigned char *session,
 bad:
     return (KFAILURE);
 }
+	  
