@@ -26,7 +26,7 @@ or implied warranty.
 
 #include "krb_locl.h"
 
-RCSID("$Id: tkt_string.c,v 1.4 1996/05/31 21:00:27 assar Exp $");
+RCSID("$Id: tkt_string.c,v 1.6 1996/11/17 20:23:47 assar Exp $");
 
 /*
  * This routine is used to generate the name of the file that holds
@@ -47,17 +47,16 @@ static char krb_ticket_string[MaxPathLen] = "";
 char *tkt_string(void)
 {
     char *env;
-    uid_t getuid(void);
 
     if (!*krb_ticket_string) {
         if ((env = getenv("KRBTKFILE"))) {
-	    (void) strncpy(krb_ticket_string, env,
+	    strncpy(krb_ticket_string, env,
 			   sizeof(krb_ticket_string)-1);
 	    krb_ticket_string[sizeof(krb_ticket_string)-1] = '\0';
 	} else {
 	    /* 32 bits of signed integer will always fit in 11 characters
 	     (including the sign), so no need to worry about overflow */
-	    (void) sprintf(krb_ticket_string, "%s%d",TKT_ROOT,(int)getuid());
+	    sprintf(krb_ticket_string, "%s%d",TKT_ROOT,(int)getuid());
         }
     }
     return krb_ticket_string;
@@ -78,7 +77,7 @@ void
 krb_set_tkt_string(char *val)
 {
 
-    (void) strncpy(krb_ticket_string, val, sizeof(krb_ticket_string)-1);
+    strncpy(krb_ticket_string, val, sizeof(krb_ticket_string)-1);
     krb_ticket_string[sizeof(krb_ticket_string)-1] = '\0';
 
     return;
