@@ -19,7 +19,7 @@ provided "as is" without express or implied warranty.
 
 #include "slav_locl.h"
 
-RCSID("$Id: kprop.c,v 1.15 1996/06/17 04:39:02 assar Exp $");
+RCSID("$Id: kprop.c,v 1.22 1996/11/19 22:48:50 assar Exp $");
 
 #include "kprop.h"
 
@@ -65,7 +65,7 @@ int get_slaves(struct slave_host **psl, char *file, time_t ok_mtime)
 
     if ((fin = fopen(file, "r")) == NULL) {
 	fprintf(stderr, "Can't open slave host file, '%s'.\n", file);
-	exit(-1);
+	exit (1);
     }
     strcpy(path, file);
     if ((ppath = strrchr(path, '/'))) {
@@ -73,31 +73,41 @@ int get_slaves(struct slave_host **psl, char *file, time_t ok_mtime)
     } else {
 	ppath = path;
     }
-    for (th = psl; fgets(namebuf, sizeof namebuf, fin); th = &(*th)->next) {
+    th = psl;
+    while(fgets(namebuf, sizeof(namebuf), fin)){
 	if ((pc = strchr(namebuf, '\n'))) {
 	    *pc = '\0';
 	} else {
-	    fprintf(stderr, "Host name too long (>= %d chars) in '%s'.\n",
-		    (int)(sizeof(namebuf)), file);
-	    exit(-1);
+	    if(strlen(namebuf) == sizeof(namebuf) - 1){
+		fprintf(stderr, "Hostname too long (>= %d chars) in '%s'.\n",
+			sizeof(namebuf), file);
+		do{
+		    if(fgets(namebuf, sizeof(namebuf), fin) == NULL)
+			break;
+		}while(strchr(namebuf, '\n') == NULL);
+		continue;
+	    }
 	}
+	if(namebuf[0] == 0 || namebuf[0] == '#')
+	    continue;
 	host = gethostbyname(namebuf);
 	if (host == NULL) {
-	    fprintf(stderr, "Unknown host '%s' in '%s'.\n", namebuf, file);
-	    exit(-1);
+	    fprintf(stderr, "Ignoring unknown host '%s' in '%s'.\n", 
+		    namebuf, file);
+	    continue;
 	}
 	(*th) = (struct slave_host *) malloc(sizeof(struct slave_host));
 	if (!*th) {
 	    fprintf(stderr, "No memory reading host list from '%s'.\n",
 		    file);
-	    exit(-1);
+	    exit (1);
 	}
 	memset(*th, 0, sizeof(struct slave_host));
 	(*th)->name = malloc(strlen(namebuf) + 1);
 	if (!(*th)->name) {
 	    fprintf(stderr, "No memory reading host list from '%s'.\n",
 		    file);
-	    exit(-1);
+	    exit (1);
 	}
 	/* get kerberos cannonical instance name */
 	strcpy((*th)->name, namebuf);
@@ -106,12 +116,12 @@ int get_slaves(struct slave_host **psl, char *file, time_t ok_mtime)
 	if (!(*th)->instance) {
 	    fprintf(stderr, "No memory reading host list from '%s'.\n",
 		    file);
-	    exit(-1);
+	    exit (1);
 	}
 	strcpy((*th)->instance, inst);
 	/* what a concept, slave servers in different realms! */
 	(*th)->realm = my_realm;
-	memcpy(&(*th)->net_addr, host->h_addr, sizeof(host->h_addr));
+	memcpy(&(*th)->net_addr, host->h_addr, sizeof((*th)->net_addr));
 	(*th)->not_time_yet = 0;
 	(*th)->succeeded = 0;
 	(*th)->next = NULL;
@@ -120,6 +130,7 @@ int get_slaves(struct slave_host **psl, char *file, time_t ok_mtime)
 	    (*th)->not_time_yet = 1;
 	    (*th)->succeeded = 1;	/* no change since last success */
 	}
+	th = &(*th)->next;
     }
     fclose(fin);
     return (1);
@@ -156,7 +167,7 @@ prop_to_slaves(struct slave_host *sl, int fd, char *fslv)
     
     des_key_schedule session_sched;
 
-    (void) mktemp(tkstring);
+    mktemp(tkstring);
     krb_set_tkt_string(tkstring);
     
     memset(&sin, 0, sizeof sin);
@@ -228,7 +239,7 @@ prop_to_slaves(struct slave_host *sl, int fd, char *fslv)
 						 KRB_MASTER,
 #endif
 						 my_realm,
-						 TGT_SERVICE_NAME,
+						 KRB_TICKET_GRANTING_TICKET,
 						 my_realm,
 						 96,
 						 KPROP_SRVTAB);
@@ -421,8 +432,8 @@ main(int argc, char **argv)
     pc[strlen(pc) - 1] = '\0';
     printf("\nStart slave propagation: %s\n", pc);
  
-    floc = (char *) NULL;
-    fslv = (char *) NULL;
+    floc = NULL;
+    fslv = NULL;
 
     if (krb_get_lrealm(my_realm,1) != KSUCCESS)
       Death ("Getting my kerberos realm.  Check krb.conf");
@@ -454,10 +465,10 @@ main(int argc, char **argv)
 	break;
       default:
 	/* positional arguments are marginal at best ... */
-	if (floc == (char *) NULL)
+	if (floc == NULL)
 	  floc = argv[i];
 	else {
-	  if (fslv == (char *) NULL)
+	  if (fslv == NULL)
 	    fslv = argv[i];
 	  else 
 	      usage();
