@@ -1,10 +1,48 @@
+/*
+ * Copyright (c) 1995, 1996 Kungliga Tekniska Hgskolan (Royal Institute
+ * of Technology, Stockholm, Sweden).
+ * All rights reserved.
+ * 
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
+ * 
+ * 1. Redistributions of source code must retain the above copyright
+ *    notice, this list of conditions and the following disclaimer.
+ * 
+ * 2. Redistributions in binary form must reproduce the above copyright
+ *    notice, this list of conditions and the following disclaimer in the
+ *    documentation and/or other materials provided with the distribution.
+ * 
+ * 3. All advertising materials mentioning features or use of this software
+ *    must display the following acknowledgement:
+ *      This product includes software developed by the Kungliga Tekniska
+ *      Hgskolan and its contributors.
+ * 
+ * 4. Neither the name of the Institute nor the names of its contributors
+ *    may be used to endorse or promote products derived from this software
+ *    without specific prior written permission.
+ * 
+ * THIS SOFTWARE IS PROVIDED BY THE INSTITUTE AND CONTRIBUTORS ``AS IS'' AND
+ * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED.  IN NO EVENT SHALL THE INSTITUTE OR CONTRIBUTORS BE LIABLE
+ * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
+ * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
+ * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
+ * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
+ * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
+ * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
+ * SUCH DAMAGE.
+ */
+
 #include "slav_locl.h"
 #include <stdarg.h>
 #include <sys/wait.h>
 
 #include "kprop.h"
 
-RCSID("$Id: kpropd.c,v 2.7 1996/08/11 21:43:26 assar Exp $");
+RCSID("$Id: kpropd.c,v 2.14 1996/11/15 18:39:32 bg Exp $");
 
 #ifndef SBINDIR
 #define SBINDIR "/usr/athena/sbin"
@@ -26,6 +64,7 @@ char *srvtab = "";
 
 char realm[REALM_SZ];
 
+static
 void
 x_log(char *fmt, ...)
 {
@@ -37,6 +76,7 @@ x_log(char *fmt, ...)
     va_end(ap);
 }
 
+static
 int
 copy_data(int from, int to, des_cblock *session, des_key_schedule schedule)
 {
@@ -80,6 +120,7 @@ copy_data(int from, int to, des_cblock *session, des_key_schedule schedule)
 }
 
 
+static
 int
 kprop(int s)
 {
@@ -166,16 +207,17 @@ kprop(int s)
     return 1;
 }
 
+static
 int
 doit(void)
 {
     struct sockaddr_in sa;
-    int sa_len;
+    int salen;
     int s, s2;
     int ret;
 
-    sa_len = sizeof(sa);
-    ret = getpeername(0, (struct sockaddr*)&sa, &sa_len);
+    salen = sizeof(sa);
+    ret = getpeername(0, (struct sockaddr*)&sa, &salen);
     if(ret < 0 && (errno == ENOTSOCK || errno == EINVAL)){
 	s = socket(AF_INET, SOCK_STREAM, 0);
 	if(s < 0){
@@ -185,16 +227,16 @@ doit(void)
 	memset(&sa, 0, sizeof(sa));
 	sa.sin_family = AF_INET;
 	sa.sin_port = k_getportbyname ("krb_prop", "tcp", htons(754));
-	sa_len = sizeof(sa);
+	salen = sizeof(sa);
 	ret = bind(s, (struct sockaddr*)&sa, sizeof(sa));
 	if(ret < 0){
-	    k_log("bind: %s", strerror(errno));
+	    krb_log("bind: %s", strerror(errno));
 	    return 1;
 	}
 	listen(s, 5);
 	while(1){
-	    sa_len = sizeof(sa);
-	    s2 = accept(s, (struct sockaddr*)&sa, &sa_len);
+	    salen = sizeof(sa);
+	    s2 = accept(s, (struct sockaddr*)&sa, &salen);
 	    switch(fork()){
 	    case -1:
 		x_log("fork: %s", strerror(errno));
@@ -217,11 +259,8 @@ doit(void)
     return kprop(0);
 }
 
-extern int optopt;
-extern char *optarg;
-
 static void
-usage ()
+usage (void)
 {
      fprintf (stderr, 
 	      "Usage: kpropd [-d database] [-l log] [-m] [-[p|P] program] "
