@@ -1,4 +1,4 @@
-/* $Id: com_err.h,v 1.5 1996/08/26 22:48:53 assar Exp $ */
+/* $Id: com_err.h,v 1.6 1996/10/27 23:52:22 assar Exp $ */
 
 /*
  * Header file for common error description library.
@@ -26,7 +26,10 @@ void com_err_va 		(const char *whoami, long code,
 				 const char *fmt, va_list args);
 
 /* error_message.c */
-char* error_message	(long code);
+const char* error_message	(long code);
+
+/* init_et.c */
+int init_error_table(const char **msgs, int base, int count);
 
 #define __COM_ERR_H
 #endif /* ! defined(__COM_ERR_H) */
