@@ -9,31 +9,28 @@
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
+RCSID("$Id: compile_et.c,v 1.20 1996/11/19 22:49:05 assar Exp $");
 #endif /* HAVE_CONFIG_H */
 #include <stdio.h>
 #include <stdlib.h>
-#include <sys/types.h>
-#include <sys/file.h>
 #include <string.h>
+#ifdef HAVE_SYS_TYPES_H
+#include <sys/types.h>
+#endif
+#ifdef HAVE_SYS_FILE_H
+#include <sys/file.h>
+#endif
+#ifdef HAVE_SYS_PARAM_H
 #include <sys/param.h>
+#endif
 #include "mit-sipb-copyright.h"
 #include "compiler.h"
 
-
-#ifndef lint
-static const char copyright[] =
-    "Copyright 1987,1988 by MIT Student Information Processing Board";
-
-static const char rcsid_compile_et_c[] =
-    "$Id: compile_et.c,v 1.14 1996/08/17 14:35:43 assar Exp $";
-#endif
-
-extern char *gensym();
 extern char *current_token;
 extern long table_number;
 extern int current;
 char buffer[BUFSIZ];
-char *table_name = (char *)NULL;
+char *table_name = NULL;
 FILE *hfile, *cfile;
 
 /* lex stuff */
@@ -42,7 +39,7 @@ extern unsigned lineno;
 
 void yyparse(void);
 
-int yywrap ()
+int yywrap (void)
 {
     return 1;
 }
@@ -115,7 +112,7 @@ static char charmap[] = {
 
 int strcasecmp(char *s1, char *s2)
 {
-	register char *cm = charmap;
+	char *cm = charmap;
 
 	while (cm[*s1] == cm[*s2++])
 		if (*s1++ == '\0')
@@ -263,11 +260,11 @@ int main (int argc, char **argv)
 	exit (1);
     }
 
-    p = (char *)xmalloc (strlen (filename) + 5);
+    p = xmalloc (strlen (filename) + 5);
     strcpy (p, filename);
     filename = p;
     p = strrchr(filename, '/');
-    if (p == (char *)NULL)
+    if (p == NULL)
 	p = filename;
     else
 	p++;
@@ -305,6 +302,8 @@ int main (int argc, char **argv)
     }
     fprintf (cfile, warning, c_file);
 
+    fprintf (cfile, "\n#include <%s>\n\n", h_file);
+
     /* prologue */
     if (language == lang_C)
 	cpp = c_src_prolog;
